(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    695527,      17445]*)
(*NotebookOutlinePosition[    740832,      19047]*)
(*  CellTagsIndexPosition[    740147,      19022]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Formule goniometriche", "Title",
  FontFamily->"Helvetica"],

Cell["Deduzione delle principali identit\[AGrave] goniometriche", "Subtitle"],

Cell["Lorenzo Roi", "Author"],

Cell[TextData[{
  "Copyright 2006",
  ButtonBox[" www.lorenzoroi.net",
    ButtonData:>{
      URL[ "http://www.lorenzoroi.net"], None},
    ButtonStyle->"Hyperlink"]
}], "Copyright",
  CellMargins->{{Inherited, Inherited}, {10, Inherited}},
  TextAlignment->Right],

Cell[CellGroupData[{

Cell["Premessa", "Subsection"],

Cell[TextData[{
  "Questo notebook presenta le deduzioni delle principali identit\[AGrave] \
goniometriche a partire dalle definizioni delle funzioni ",
  Cell[BoxData[
      \(TraditionalForm\`sen(\[Alpha])\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`cos(\[Alpha])\)]],
  " e ",
  Cell[BoxData[
      \(TraditionalForm\`tan(\[Alpha])\)]],
  " introdotte invece nel notebook ",
  StyleBox["IntroduzioneFunzGonio", "InlineInput"],
  " e sostanzialmente indipendente da questo. A partire dall'identit\[AGrave] \
fondamentale della Goniometria si trattano quindi i valori delle funzioni \
goniometriche di angoli associati per passare poi, con il supporto di \
un'animazione grafica, alle formule di addizione e sottrazione e relative \
conseguenze. Si ottengono infine le formule di Werner e prostaferesi."
}], "Text"],

Cell[CellGroupData[{

Cell["Nota didattica", "Subsubsection"],

Cell[TextData[{
  "Poich\[EAcute] ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " procede in automatico ad elaborare argomenti numerici o simbolici di \
funzioni nonch\[EAcute] valori delle stesse fornendo di norma i risultati del \
calcolo senza presentare i passaggi intermedi, tale caratteristica ovviamente \
utile in numerose occasioni diventa al contrario un condizionamento tutte le \
volte che si intende sviluppare un graduale processo deduttivo nel quale \
l'uso di manipolazioni algebriche di un'espressione conduca alla \
dimostrazione di un asserto. Se ad esempio si considera il semplice input \
seguente"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sin[\[Pi]\/2 - \ \[Alpha]] \[Equal] Cos[\[Alpha]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Closed]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " semplifica automaticamente il primo membro riducendolo a ",
  Cell[BoxData[
      \(TraditionalForm\`Cos[\[Alpha]]\)]],
  " per cui, essendo uguale al secondo, fornisce in output l'esito del \
confronto con ",
  StyleBox["True", "InlineInput"],
  ". In ambiti opportuni pu\[OGrave] invece essere conveniente mantenere \
l'input, o parti di esso, inalterato nell'output. In sostanza, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " sembra inadatto in quelle situazioni, peraltro attivit\[AGrave] comune \
per l'insegnante, dove all'importanza o all'utilit\[AGrave] dei risultati si \
affianca pure l'obiettivo di una loro documentata deduzione."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Nota tecnica", "Subsubsection"],

Cell[TextData[{
  "Questo notebook rappresenta sostanzialmente una sperimentazione personale \
attorno ad alcune funzioni raramente usate in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " allo scopo di poter, in qualche modo, aggirare l'ostacolo accennato nella \
nota precedente. Pur esistendo in Internet alcuni interventi su queste \
problematiche (non molti per la verit\[AGrave]) sotto forma di notebook o \
package e certamente pi\[UGrave] ampi e approfonditi di questo tentativo, ho \
preferito non utilizzarli per provare soluzioni pi\[UGrave] limitate e \
controllabili anche se meno generali. Il processo di calcolo di ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " \[EGrave] pertanto stato aggirato creando gradualmente una base di regole \
per le \"nuove\" funzioni ",
  StyleBox["sen[]", "InlineInput"],
  ", ",
  StyleBox["cos[]", "InlineInput"],
  " e ",
  StyleBox["tan[]", "InlineInput"],
  " evitando di utilizzare le funzioni predefinite ",
  StyleBox["Sin[]", "InlineInput"],
  ", ",
  StyleBox["Cos[]", "InlineInput"],
  " e ",
  StyleBox["Tan[]", "InlineInput"],
  ". Quando opportuno, si \[EGrave] \"congelato\" momentaneamente \
l'automatismo di calcolo di ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " con la funzione ",
  StyleBox["HoldForm", "InlineInput"],
  " per poi riattivarlo con una funzione (",
  StyleBox["rilascia", "InlineInput"],
  ") creata ad hoc. In ogni caso si \[EGrave] cercato di sviluppare un \
insieme di funzioni minimale allo scopo.\nI comandi che vanno eseguiti prima \
di procedere alle varie deduzioni sono quelli contenuti nella sezione ",
  StyleBox["Funzioni di base",
    FontWeight->"Bold"],
  " e quelli inseriti all'inizio di ogni sezione e compresi in ",
  StyleBox["Identit\[AGrave] dimostrate",
    FontWeight->"Bold"],
  ". Altre brevi informazioni sulle funzioni implementate si trovano sotto \
forma di commenti nella sezione che segue."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Funzioni di base", "Subsection"],

Cell["\<\
Le seguenti funzioni vanno elaborate per poterne disporre in seguito nel \
notebook.\
\>", "Text"],

Cell[BoxData[
    \(\(\(\t\)\(\(Off[General::spell, General::spell1];\)\[IndentingNewLine]
    \ \ \ \ \ \ \ \ << 
      Graphics`Arrow`\[IndentingNewLine]\[IndentingNewLine] (*\ \ ELEMENTI\ \
STILISTICI\ \ *) \[IndentingNewLine] (*\(--definizioni\)\ di\ vari\ \(colori\
--\)*) \[IndentingNewLine]
    \ \ \ \ \ \ \ \ \(colBlu = RGBColor[0, \ 0, 1];\)\n
    \ \ \ \ \ \ \ \ \(colRosso = RGBColor[1, 0, 0];\)\[IndentingNewLine]
    \ \ \ \ \ \ \ \ \(colGiallo = RGBColor[1, \ 1, \ 0];\)\[IndentingNewLine]
    \ \ \ \ \ \ \ \ \(colVerde = 
        RGBColor[0, 1, 
          0];\)\n (*\(--stile\)\ per\ la\ rappresentazione\ grafica\ dei\ \
\(vettori--\)*) \[IndentingNewLine]
    \ \ \ \ \ \ \ \ \(stileVet = 
        Sequence[HeadLength \[Rule] 0.03, 
          HeadCenter \[Rule]  .9];\)\[IndentingNewLine] (*\(--stile\)\ del\ \
testo\ degli\ elementi\ inseriti\ \(automaticamente--\)*) \[IndentingNewLine]
    \t\($TextStyle = {FontFamily \[Rule] Helvetica, 
          FontSize \[Rule] 
            8};\)\[IndentingNewLine] (*\(--stile\)\ per\ il\ testo\ \
introdotto\ \(manualmente--\)*) \[IndentingNewLine]
    \ \ \ \ \ \ \ \ \(stileTesto = {FontSize \[Rule] 9, 
          FontFamily \[Rule] Helvetica, 
          FontWeight -> "\<Bold\>"};\)\[IndentingNewLine]\[IndentingNewLine] \
(*\ \ FUNZIONI\ \ *) \[IndentingNewLine] (*\(--elimina\)\ la\ presenza\ di\ \
HoldForm\ a\ qualsiasi\ livello\ e\ permette\ a\ Mathematica\ il\ calcolo\ \
automatico\ dell' \(espressione--\)*) \[IndentingNewLine]
    \t\(rilascia[expr_] := 
        MapAll[ReleaseHold, 
          expr];\)\n\[IndentingNewLine] (*\(--scambia\)\ il\ primo\ con\ il\ \
secondo\ membro\ di\ una\ identit\[AGrave]/\(uguaglianza--\)\
*) \[IndentingNewLine]
    \tscambia[id_Equal] := 
      id /. a_ \[Equal] b_ \[RuleDelayed] 
          b \[Equal] 
            a\[IndentingNewLine]\[IndentingNewLine] (*\(--la\)\ modifica\ \
sulla\ funzione\ Equal\ \[EGrave]\ di\ Roman\ \(Meader : \ 
          Algebraic\ \(Enhancements--\)\)*) \[IndentingNewLine] \
(*\(--permette\)\ una\ notazione\ sintetica\ nel\ sommare\ o\ moltiplicare\ \
entrambi\ i\ membri\ di\ un' 
        uguaglianza\ per\ uno\ stesso\ \(termine--\)*) \[IndentingNewLine]
    \t\(Unprotect[Equal];\)\ \n
    \t\(listableQ[f_]\  := \ MemberQ[Attributes[f], \ Listable];\)\n
    \t\(Equal /: \ 
        lhs : \((f_Symbol)\)?listableQ[___, \ _Equal, \ ___]\  := \ 
        Thread[Unevaluated[lhs], \ Equal];\)\n
    \t\(Protect[
        Equal];\)\[IndentingNewLine]\[IndentingNewLine] (*\(--Trasforma\)\ l' 
        uguaglianza\ tra\ due\ membri\ in\ una\ regola\ \((delayed)\)\ di\ \
sostituzione . \ 
          Viene\ utilizzata\ per\ aggiornare\ gradualmente\ la\ base\ di\ \
conoscenza\ sulle\ funzioni\ sen, \ cos\ e\ \(tan--\)*) \[IndentingNewLine]
    \ \ \ \ \ \ \ \ \(toRule[identita_Equal, 
          var_List: {\[Alpha], \[Beta], \[Gamma]}] := 
        RuleDelayed @@ \((Equal[
              identita[\([1]\)] /. \((Rule[#, Pattern[#, Blank[]]] &)\) /@ 
                  var, identita[\([2]\)]])\);\)\[IndentingNewLine]\
\[IndentingNewLine] (*\(--Esegue\)\ la\ trasformazione\ opposta\ alla\ \
\(precedente : \ da\ regola\ di\ sostituzione\ ad\ \(uguaglianza--\)\)*) \n
    \ \ \ \ \ \ \ \ \(toIdentita[rule_RuleDelayed] := 
        Block[{expr, pos}, expr = Equal @@ rule; \ 
          pos = Position[expr, Pattern]; 
          ReplacePart[expr, Apply[Symbol, #] &, 
            pos]];\)\[IndentingNewLine]\[IndentingNewLine] (*\(--applica\)\ \
al\ numeratore\ e\ al\ denominatore\ del\ secondo\ membro\ di\ una\ identit\
\[AGrave]\ la\ funzione\[IndentingNewLine]\ \ \(funz : \ 
          utilizzato\ per\ moltiplicare\ e\ dividere\ num\ e\ denom\ per\ uno\
\ stesso\ termine . \ Il\ secondo\ membro\ dev' 
            essere\ pertanto\ un\ rapporto\ tra\ num\ e\ \(den\ --\)\)\
*) \[IndentingNewLine]
    \ \ \ \ \ \ \ \ applicaND[eq_, funz_] := 
      Module[{num, den, tmp, dentmp}, 
        tmp = Replace[eq[\([2]\)], Power[_, \(-1\)] \[Rule] dentmp, {1}]; \ 
        num = tmp/dentmp; den = num/eq[\([2]\)]; \ 
        eq[\([1]\)] \[Equal] 
          funz[num]/
            funz[den]]\[IndentingNewLine]\n (*\ \ REGOLE\ DI\ SOSTITUZIONE\ \
INIZIALI\ *) \[IndentingNewLine] (*\(--"\<Base di conoscenza\>"\)\ iniziale\ \
sulle\ funzioni\ sen, \ cos, \ tan, \ 
      cot . \ \[IndentingNewLine]\ 
          Le\ sostituzioni\ defs\ rappresentano\ le\ definizioni\ \
\(geometriche : \ 
          le\ successive\ legano\ le\ principali\ funzioni\ dello\ stesso\ \
\(angolo : \ 
              utilizzate\ per\ semplificazioni\ e\ riscrittura\ di\ \(formule\
--\)\)\)*) \[IndentingNewLine]
    \ \ \ \ \ \ \ \ \(defs = {QP/OP \[Rule] sen[\[Alpha]], 
          OQ/OP \[Rule] cos[\[Alpha]], 
          QP/OQ \[Rule] tan[\[Alpha]]};\)\[IndentingNewLine]
    \ \ \ \ \ \ \ \ \(id1 = 
        tan[\[Alpha]_] \[RuleDelayed] 
          sen[\[Alpha]]/cos[\[Alpha]];\)\[IndentingNewLine]
    \ \ \ \ \ \ \ \ \(id2 = 
        cot[\[Alpha]_] \[RuleDelayed] 
          cos[\[Alpha]]/sen[\[Alpha]];\)\[IndentingNewLine]
    \ \ \ \ \ \ \ \ \(id3 = 
        1/tan[\[Alpha]_] \[RuleDelayed] cot[\[Alpha]];\)\[IndentingNewLine]
    \ \ \ \ \ \ \ \ \(id4 = {sen[\[Alpha]_]/cos[\[Alpha]_] \[RuleDelayed] 
            tan[\[Alpha]], 
          Times[Power[
                cos[\[Alpha]_], \(-2\)], \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \
Power[sen[\[Alpha]_], 2]] \[RuleDelayed] 
            Power[tan[\[Alpha]], 2]};\)\)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Identit\[AGrave] fondamentale", "Section"],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[{
    \(\(\[Alpha] = 50  Degree;\)\), "\n", 
    \(pP = {Cos[\[Alpha]], Sin[\[Alpha]]}; pQ = {Cos[\[Alpha]], 0}; 
    origine = {0, 0};\), "\n", 
    \(Show[
      Graphics[{Circle[origine, 1], Line[{{\(-1.2\), 0}, {1.2, 0}}], 
          Line[{{0, \(-1.2\)}, {0, 1.2}}], 
          Line[{pP, origine}]}], \[IndentingNewLine]Graphics[{colBlu, 
          Arrow[origine, pQ, stileVet], 
          Arrow[pQ, pP, 
            stileVet]}], \[IndentingNewLine]Graphics[{Text["\<O\>", 
            origine, {1, 1}, TextStyle \[Rule] stileTesto], 
          Text["\<Q\>", pQ, {0, 1}, TextStyle \[Rule] stileTesto], 
          Text["\<P\>", pP, {0, \(-1\)}, TextStyle \[Rule] stileTesto]}], 
      Prolog -> {{colGiallo, Polygon[{origine, pQ, pP}]}, {colRosso, 
            Disk[origine,  .2, {0, \[Alpha]}]}}, 
      AspectRatio \[Rule] Automatic, Axes \[Rule] True]; 
    Clear[\[Alpha]];\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Grafico e definizioni relative all'angolo \[Alpha]\
\>", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.396825 0.5 0.396825 [
[.10317 .4875 -6.96875 -10.9375 ]
[.10317 .4875 6.96875 0 ]
[.30159 .4875 -10.3125 -10.9375 ]
[.30159 .4875 10.3125 0 ]
[.69841 .4875 -7.5625 -10.9375 ]
[.69841 .4875 7.5625 0 ]
[.89683 .4875 -4.21875 -10.9375 ]
[.89683 .4875 4.21875 0 ]
[.4875 .10317 -13.9375 -5.46875 ]
[.4875 .10317 0 5.46875 ]
[.4875 .30159 -20.625 -5.46875 ]
[.4875 .30159 0 5.46875 ]
[.4875 .69841 -15.125 -5.46875 ]
[.4875 .69841 0 5.46875 ]
[.4875 .89683 -8.4375 -5.46875 ]
[.4875 .89683 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .5 m
.10317 .50625 L
s
gsave
.10317 .4875 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.30159 .5 m
.30159 .50625 L
s
gsave
.30159 .4875 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.69841 .5 m
.69841 .50625 L
s
gsave
.69841 .4875 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.89683 .5 m
.89683 .50625 L
s
gsave
.89683 .4875 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.14286 .5 m
.14286 .50375 L
s
.18254 .5 m
.18254 .50375 L
s
.22222 .5 m
.22222 .50375 L
s
.2619 .5 m
.2619 .50375 L
s
.34127 .5 m
.34127 .50375 L
s
.38095 .5 m
.38095 .50375 L
s
.42063 .5 m
.42063 .50375 L
s
.46032 .5 m
.46032 .50375 L
s
.53968 .5 m
.53968 .50375 L
s
.57937 .5 m
.57937 .50375 L
s
.61905 .5 m
.61905 .50375 L
s
.65873 .5 m
.65873 .50375 L
s
.7381 .5 m
.7381 .50375 L
s
.77778 .5 m
.77778 .50375 L
s
.81746 .5 m
.81746 .50375 L
s
.85714 .5 m
.85714 .50375 L
s
.06349 .5 m
.06349 .50375 L
s
.02381 .5 m
.02381 .50375 L
s
.93651 .5 m
.93651 .50375 L
s
.97619 .5 m
.97619 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .10317 m
.50625 .10317 L
s
gsave
.4875 .10317 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .30159 m
.50625 .30159 L
s
gsave
.4875 .30159 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .69841 m
.50625 .69841 L
s
gsave
.4875 .69841 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .89683 m
.50625 .89683 L
s
gsave
.4875 .89683 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .14286 m
.50375 .14286 L
s
.5 .18254 m
.50375 .18254 L
s
.5 .22222 m
.50375 .22222 L
s
.5 .2619 m
.50375 .2619 L
s
.5 .34127 m
.50375 .34127 L
s
.5 .38095 m
.50375 .38095 L
s
.5 .42063 m
.50375 .42063 L
s
.5 .46032 m
.50375 .46032 L
s
.5 .53968 m
.50375 .53968 L
s
.5 .57937 m
.50375 .57937 L
s
.5 .61905 m
.50375 .61905 L
s
.5 .65873 m
.50375 .65873 L
s
.5 .7381 m
.50375 .7381 L
s
.5 .77778 m
.50375 .77778 L
s
.5 .81746 m
.50375 .81746 L
s
.5 .85714 m
.50375 .85714 L
s
.5 .06349 m
.50375 .06349 L
s
.5 .02381 m
.50375 .02381 L
s
.5 .93651 m
.50375 .93651 L
s
.5 .97619 m
.50375 .97619 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto fill
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto
-0.03 0.0075 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
1 1 0 r
.5 .5 m
.75507 .5 L
.75507 .80399 L
F
1 0 0 r
.5 .5 m
.5 .5 .07937 0 50 arc
F
0 g
.5 Mabswid
newpath
.5 .5 .39683 0 365.73 arc
s
.02381 .5 m
.97619 .5 L
s
.5 .02381 m
.5 .97619 L
s
.75507 .80399 m
.5 .5 L
s
0 0 1 r
.5 .5 m
.75507 .5 L
s
% Start of user PostScript
0 0 0.642788 0 MAarrowhead1
% End of user PostScript
.75507 .5 m
.75507 .80399 L
s
% Start of user PostScript
0.642788 0 0.642788 0.766044 MAarrowhead1
% End of user PostScript
0 g
gsave
.5 .5 -71.9375 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75507 .5 -66.4688 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Q) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75507 .80399 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
69.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  Magnification->0.9,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?oo
o`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?oo
o`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3o
ool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo
0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?oo
o`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000
003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0
oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80
oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<00000
0?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3o
ool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0
oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<0
00000?ooo`3oool0/P3oool00:P0oooo00<0oooO09a8M02oool0203oool00`000000oooo0?ooo`2b
0?ooo`00Z03oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo0;80oooo002P0?ooo`03
0?noM000000000000080000000H004RL0=ooo`3oool0oooO09a8M02oool80?ooo`030000003oool0
oooo0;80oooo002S0?ooob400000Y03oool009`0oooo1`0000030?ooo`050?oog`2LW;l0oooO09a8
M02oool0203oool00`000000oooo0?ooo`0>0?ooo`L00000W@3oool009L0oooo1@00000;0?ooo`04
0?noM0000000001d0;ooo`P0oooo00<000000?ooo`3oool05@3oool5000009P0oooo002C0?ooo`@0
00004@3oool00`3ookl0M01d0;ooo`080?ooo`030000003oool0oooo01X0oooo1000002D0?ooo`00
SP3oool500000200oooo00<000000?ooo`3oool07P3oool5000008l0oooo002;0?ooo`<000009@3o
ool00`000000oooo0?ooo`0S0?ooo`<00000S03oool008L0oooo1000000X0?ooo`030000003oool0
oooo02H0oooo100000280?ooo`00QP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0Q@3oool00880oooo1000000]0?ooo`030000003oool0oooo02/0
oooo100000230?ooo`00O`3oool300000340oooo00<000000?ooo`3oool0;`3oool300000800oooo
001m0?ooo`800000=03oool00`000000oooo0?ooo`0b0?ooo`800000OP3oool007X0oooo0`00000f
0?ooo`030000003oool0oooo03@0oooo0`00001k0?ooo`00N03oool2000003T0oooo00<000000?oo
o`3oool0=`3oool2000007T0oooo001g0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`1f0?ooo`00M03oool3000003`0oooo0P00000k0?ooo`<00000
M@3oool00780oooo0P00000o0?ooo`030000003oool0oooo03d0oooo0P00001c0?ooo`00L03oool2
00000440oooo00<000000?ooo`3oool0?`3oool200000740oooo001_0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1^0?ooo`00K@3oool2000004@0
oooo00<000000?ooo`3oool0@P3oool2000006h0oooo001/0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1[0?ooo`00J@3oool3000004L0oooo00<0
00000?ooo`3oool0A@3oool3000006X0oooo001W0?ooo`800000BP3oool00`000000oooo0?ooo`18
0?ooo`800000J03oool006H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo06D0oooo001T0?ooo`800000C@3oool00`000000oooo0?ooo`1;0?ooo`80
0000I@3oool006<0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo0680oooo001Q0?ooo`800000D03oool00`000000oooo0?ooo`1>0?ooo`800000HP3o
ool00600oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo05l0oooo001N0?ooo`800000D`3oool00`000000oooo0?ooo`1A0?ooo`800000G`3oool005d0
oooo00<000000?ooo`3oool0D`3oool2000005@0oooo00<000000?ooo`3oool0G03oool005`0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05/0oooo
001K0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`1J0?ooo`00FP3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool0F@3oool005P0oooo0P00001I0?ooo`030000003oool0oooo05L0oooo0P00001I0?oo
o`00E`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0EP3oool005H0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo05D0oooo001E0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`1D0?ooo`00E03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo05`0oooo00<000000?ooo`3oool0D`3oool005<0oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`1M0?ooo`030000003oool0oooo0580oooo001B0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1A0?ooo`00D@3oool00`000000oooo
0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0D03oool00500oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo04l0oooo001?
0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1>
0?ooo`00CP3oool00`000000oooo0?ooo`1R0?ooo`800000H`3oool00`000000oooo0?ooo`1=0?oo
o`00C@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool0C03oool004`0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1T0?ooo`030000
003oool0oooo04/0oooo001;0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`1:0?ooo`00BP3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0
oooo06H0oooo00<000000?ooo`3oool0B@3oool004T0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`1W0?ooo`030000003oool0oooo04P0oooo00180?ooo`030000003oool0oooo06P0
oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`170?ooo`00A`3oool00`000000oooo
0?ooo`1Y0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0AP3oool004H0oooo00<0
00000?ooo`3oool0JP3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo04D0oooo0015
0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`14
0?ooo`00A@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0A03oool004@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo04<0oooo00130?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0
K@3oool00`000000oooo0?ooo`120?ooo`00@P3oool00`000000oooo0?ooo`1^0?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool0@@3oool00440oooo00<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0400oooo00100?ooo`030000003oool0oooo
0700oooo0P00001a0?ooo`030000003oool0oooo03l0oooo00100?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0o0?ooo`00?`3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0?P3oool003h0oooo00<0
00000?ooo`3oool0LP3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo03d0oooo000n
0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0m
0?ooo`00?@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool0?03oool003`0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo03/0oooo000l0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`0k0?ooo`00>`3oool00`000000oooo0?ooo`1e0?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool0>P3oool003X0oooo00<000000?ooo`3oool0MP3oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo03T0oooo000j0?ooo`030000003oool0oooo
07H0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0i0?ooo`00>@3oool00`000000
oooo0?ooo`1S0?ooo`0:0;md00000000001809cOo`3oool0oono07A8W03Oool0oooo0;md00800000
00<0B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo03P0oooo
000i0?ooo`030000003oool0oooo0680oooo00H0okmd0018W03Oool0okmd0018W03Oool30?ooo`06
0?noM018W=l0oooo0?ooo`3OW4P0M;oo1P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0
oooo03P0oooo000h0?ooo`030000003oool0oooo05`0oooo00<0okmd0000000000000P0000002000
B9`0gooo0=nLB018W=l0oooo0?oo_`1d07@0_ooo1`3oool00`3o_g@0B9cO0?ooo`050?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool0>03oool003P0oooo00<000000?ooo`3oool0H`3o
ool01P3OW4P0M;oo0?ooo`3ooml0W4Qd0;ooo`<0oooo00H0okmd0000M02oool0oooo0=nLB01d_ol6
0?ooo`<00000N03oool00`000000oooo0?ooo`0g0?ooo`00=`3oool00`000000oooo0?ooo`1T0?oo
o`060=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q804P00000000007Bo00L0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0f0?ooo`00=P3oool00`000000oooo0?oo
o`1U0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool00`3ooml0W4Q809cOo`090?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0
IP3oool0102oM00000000000B02Lgol50?ooo`050;md0000000000000000B02Lgol01P3oool00`00
0000oooo0?ooo`1j0?ooo`030000003oool0oooo03D0oooo000e0?ooo`030000003oool0oooo07/0
oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0d0?ooo`00=03oool00`000000oooo
0?ooo`1l0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0=03oool003@0oooo00<0
00000?ooo`3oool0O03oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03<0oooo000c
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0c
0?ooo`00<`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo07d0oooo00<000000?oo
o`3oool0<P3oool003<0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`1m0?ooo`03
0000003oool0oooo0380oooo000b0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0b0?ooo`00<P3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo07h0oooo00<000000?ooo`3oool0<@3oool00340oooo00<000000?ooo`3oool0O`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0300oooo000`0?ooo`030000003oool0oooo
0800oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0`0?ooo`00<03oool00`000000
oooo0?ooo`200?ooo`800000P@3oool00`000000oooo0?ooo`0_0?ooo`00<03oool00`000000oooo
0?ooo`200?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0;`3oool00300oooo00<0
00000?ooo`3oool0P03oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo02l0oooo000_
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0^
0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0840oooo00<000000?oo
o`3oool0;P3oool002h0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`220?ooo`03
0000003oool0oooo02d0oooo000^0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0
PP3oool00`000000oooo0?ooo`0]0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000003o
ool0oooo0880oooo00<000000?ooo`3oool0;@3oool002d0oooo00<000000?ooo`3oool0P`3oool0
0`000000oooo0?ooo`230?ooo`030000003oool0oooo02`0oooo000]0?ooo`030000003oool0oooo
08<0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0/0?ooo`00;@3oool00`000000
oooo0?ooo`230?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0;03oool002`0oooo
00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo02`0oooo
000/0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?oo
o`0[0?ooo`00:`3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0Q@3oool2000008H0oooo00<000000?oo
o`3oool0:P3oool002/0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`250?ooo`03
0000003oool0oooo02X0oooo000Z0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
Q@3oool00`000000oooo0?ooo`0Z0?ooo`00:P3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0:@3oool002X0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo02T0oooo000Y0?ooo`030000003oool0oooo
08L0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0Y0?ooo`00:@3oool00`000000
oooo0?ooo`270?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0:03oool002T0oooo
00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo02P0oooo
000Y0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?oo
o`0X0?ooo`00:@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo08L0oooo00<00000
0?ooo`3oool0:03oool002T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`270?oo
o`030000003oool0oooo02P0oooo000X0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool0R03oool00`000000oooo0?ooo`0W0?ooo`00:03oool00`000000oooo0?ooo`280?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool09`3oool002P0oooo00<000000?ooo`3oool0R03o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo02L0oooo000W0?ooo`030000003oool0
oooo08T0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0W0?ooo`009`3oool00`00
0000oooo0?ooo`290?ooo`800000RP3oool00`000000oooo0?ooo`0V0?ooo`009`3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool09P3oool002L0oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo02H0oooo
000W0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?oo
o`0V0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo08T0oooo00<00000
0?ooo`3oool09P3oool002H0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`2:0?oo
o`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000
003oool0oooo08X0oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool0RP3o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0
oooo08X0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`00
0000oooo0?ooo`2:0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool09@3oool002D0
oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02D0
oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo08/0oooo00<0
00000?ooo`3oool0903oool002D0oooo00D000000?ooo`3ooml0W4Qd0;ooo`0o0?ooo`0:0;md0000
0000001809cOo`3oool0oono07A8W03Oool0oooo0;md0080000000<0B9cO0?ooo`3oool0>`3oool2
000003l0oooo00X0_g@00000000004P0W=oo0?ooo`3ookl0M4RL0=ooo`3oool0_g@00P0000000`18
W=l0oooo0?ooo`0n0?ooo`030000002LB7@0_ooo02@0oooo000U0?ooo`050000003oool0oooO09a8
M02oool0?P3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00H0okmd04RLg`3oool0oooo
0=nLB01d_oll0?ooo`030000003oool0oooo03d0oooo00H0okmd0018W03Oool0okmd0018W03Oool3
0?ooo`060?noM018W=l0oooo0?ooo`3OW4P0M;oo?`3oool00`000000W4Qd0;ooo`0T0?ooo`007P3o
ool00`3o_g@0000000000002000000070018W03Oool000000?ooo`3ooml0W4Qd0;ooo`0g0?ooo`03
0?noM000000000000080000000P004RL0=ooo`3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`L0oooo00<0
okmd04RLg`3oool0>`3oool00`000000oooo0?ooo`0m0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0
_ooo1`3oool00`3o_g@0B9cO0?ooo`0=0?ooo`030?noM000M;l0oooo02h0oooo00<0000009a8M02o
ool0903oool002D0oooo00D000000?ooo`3ooml0W4Qd0;ooo`0n0?ooo`060=nLB01d_ol0oooo0?oo
g`2LB7@0_ooo0`3oool01P3o_g@0001d0;ooo`3oool0gia807Booc80oooo00H0oono07@000000000
00000000M02oool40?ooo`030000003oool0oooo03d0oooo00H0gia807Boo`3oool0oooO09a8M02o
ool30?ooo`060?noM00007@0_ooo0?ooo`3OW4P0M;oo2@3oool00`3ookl0M0000000000200000003
0000M02oool0oooo02h0oooo00<0000009a8M02oool0903oool002D0oooo00D0000009bL_`3ooml0
W4Qd0;ooo`0n0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q804P00000
000007Bo0380oooo00P0oono07@00000B9`0gooo0?oog`2LB000001d0;ooo`<0oooo00<000000?oo
o`3oool0?@3oool01P3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`<0oooo00D0oono07A8B01800000000
001d_`090?ooo`080?oo_`1d000004RL0=ooo`2oM00000000000B02Lgol]0?ooo`050?oog`2LW;l0
000009a8M02oool0903oool002D0oooo00D000000?noM0000000001d0;ooo`0n0?ooo`060?noM000
B9`0gooo0?noM000B9`0gooo0`3oool00`3ooml0W4Q809cOo`0d0?ooo`030?noM00004P0W=oo0080
oooo00<0omnL04P0001d_ol00`3oool00`000000oooo0?ooo`0m0?ooo`060?noM000B9`0gooo0?no
M000B9`0gooo0`3oool00`3ooml0W4Q809cOo`0;0?ooo`080?noM00004P0W=oo0?oOW018B9`0gmnL
04P00018W=l^0?ooo`040?noM0000000001d0;ooob@0oooo000U0?ooo`050000003oool0oono07@0
M02oool0?`3oool0102oM00000000000B02Lgol50?ooo`050;md0000000000000000B02Lgol0<@3o
ool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo00<000000?ooo`3oool0?P3o
ool0102oM00000000000B02Lgol50?ooo`050;md0000000000000000B02Lgol0203oool00`3OW4P0
001d0;ooo`020?ooo`030?oo_`1d0000B9cO02l0oooo00<0000007@0M02oool0903oool002D0oooo
00<000000?ooo`3oool0P03oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo
00<000000?ooo`3oool0E03oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO02l0oooo
00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0P03oool00`3o_g@0001809cO
o`020?ooo`030?oOW0180000M;oo00<0oooo00<000000?ooo`3oool0E03oool00`3o_g@0001809cO
o`020?ooo`030?oOW0180000M;oo02l0oooo00<000000?ooo`3oool0903oool002D0oooo00<00000
0?ooo`3oool0P03oool00`3ookl0M000001d_`020?ooo`030;md000007@0_ooo00<0oooo00<00000
0?ooo`3oool0E03oool0203ookl0M0000018W03Oool0oooo0;md0000B9`0gooo;`3oool00`000000
oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`210?ooo`060?oo_`1d0000000000000000
07@0_ooo103oool00`000000oooo0?ooo`1E0?ooo`060?oo_`1d0000000000000000B9`0gooo<03o
ool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0
oooo04h0oooo0P000?lk0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo
08/0oooo00<000000?ooo`3oool0CP3oool60000ocL0oooo00<000000?ooo`3oool0903oool002D0
oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`1?0?ooo`T0003o<`3oool00`000000
oooo0?ooo`0T0?ooo`00/`00001M0000oeP0000000080?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`8000006P3o000f0?oo00T0003o00<0
ool00000o`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool01`3oool002D0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`14
0?ooo`030000003oool0000001T0o`00=@3oo`060000o`D0ool000<0003o0?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`040000003oool0oooo
000001P0o`00=@3oo`020000o`T0ool000<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`0T
0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`040000003oool0oooo000001P0o`00@03oo`00
0`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo
08/0oooo00D000000?ooo`3oool0oooo0000000G0?l00400ool000<0003o0?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo
0080oooo00<000000?l0003o0000503o00100?oo00030000o`3oool0oooo02l0oooo00<000000?oo
o`3oool0903oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`030?ooo`03
0000003o0000o`0001<0o`00@03oo`000`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo02@0
oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0103oool00`000000o`00
0?l0000B0?l00400ool000<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`0T0?ooo`009@3o
ool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00D0oooo00<000000?l0003o0000403o
00110?oo00030000o`3oool0oooo02l0oooo00<000000?ooo`3oool0903oool002D0oooo00<00000
0?ooo`3oool0R`3oool00`000000oooo0?ooo`050?ooo`030000003o0000o`000100o`00@@3oo`00
0`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo
08/0oooo00<000000?ooo`3oool01P3oool00`000000o`000?l0000?0?l00440ool000<0003o0?oo
o`3oool0;`3oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`03
0000003oool0oooo00L0oooo00<000000?l0003o00003@3o00120?oo00030000o`3oool0oooo02l0
oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`080?ooo`030000003o0000o`0000`0o`00@P3oo`000`000?l0oooo0?ooo`0_0?ooo`030000
003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo08/0oooo0P00000:0?ooo`030000003o
0000o`0000X0o`00@`3oo`000`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo02@0oooo000U
0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool02P3oool00`000000o`000?l00008
0?l004@0ool000<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`00
0000oooo0?ooo`2;0?ooo`030000003oool0oooo00/0oooo00<000000?l0003o00001`3o00140?oo
00030000o`3oool0oooo02l0oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3o
ool0R`3oool00`000000oooo0?ooo`0;0?ooo`030000003o0000o`0000H0o`00A@3oo`000`000?l0
oooo0?ooo`0^0?ooo`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0oooo08X0oooo
00<000000?ooo`3oool0303oool00`000000o`000?l000050?l004D0ool000<0003o0?ooo`3oool0
;P3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000003o
ool0oooo00d0oooo00<000000?l0003o00000`3o00160?oo00030000o`3oool0oooo02h0oooo00<0
00000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0>
0?ooo`040000003o0000o`000?l004L0ool000<0003o0?ooo`3oool0;P3oool00`000000oooo0?oo
o`0U0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00l0oooo00<00000
0?l0003oo`00A`3oo`000`000?l0oooo0?ooo`0^0?ooo`030000003oool0oooo02D0oooo000V0?oo
o`030000003oool0oooo08X0oooo00<000000?ooo`3oool0403oool00`000000ool00?oo00160?oo
00030000o`3oool0oooo02h0oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`0@0?ooo`030000003oo`00ool004H0ool000<0003o0?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000
003oool0oooo0140oooo00<000000?oo003oo`00A@3oo`000`000?l0oooo0?ooo`0]0?ooo`030000
003oool0oooo02H0oooo000W0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool04P3o
ool00`000000ool00?oo00140?oo00030000o`3oool0oooo02d0oooo00<000000?ooo`3oool09P3o
ool002L0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0C0?ooo`030000003oo`00
ool004<0ool000<0003o0?ooo`3oool0;@3oool00`000000oooo0?ooo`0V0?ooo`009`3oool00`00
0000oooo0?ooo`290?ooo`030000003oool0oooo01@0oooo00<000000?oo003oo`00@P3oo`000`00
0?l0oooo0?ooo`0]0?ooo`030000003oool0oooo02H0oooo000W0?ooo`030000003oool0oooo08T0
oooo0P00000F0?ooo`030000003oo`00ool00440ool000<0003o0?ooo`3oool0;@3oool00`000000
oooo0?ooo`0V0?ooo`009`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo01D0oooo
00<000000?oo003oo`00@@3oo`000`000?l0oooo0?ooo`0/0?ooo`030000003oool0oooo02L0oooo
000X0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool05P3oool00`000000ool00?oo
00100?oo00030000o`3oool0oooo02`0oooo00<000000?ooo`3oool09`3oool002P0oooo00<00000
0?ooo`3oool0R03oool00`000000oooo0?ooo`0G0?ooo`030000003oo`00ool003l0ool000<0003o
0?ooo`3oool0;03oool00`000000oooo0?ooo`0W0?ooo`00:03oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo01P0oooo00<000000?oo003oo`00?P3oo`000`000?l0oooo0?ooo`0/0?oo
o`030000003oool0oooo02L0oooo000Y0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3o
ool06@3oool00`000000ool00?oo000m0?oo00030000o`3oool0oooo02/0oooo00<000000?ooo`3o
ool0:03oool002T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0J0?ooo`030000
003oo`00ool003`0ool000<0003o0?ooo`3oool0:`3oool00`000000oooo0?ooo`0X0?ooo`00:@3o
ool00`000000oooo0?ooo`270?ooo`030000003oool0oooo01/0oooo00<000000?oo003oo`00>`3o
o`000`000?l0oooo0?ooo`0[0?ooo`030000003oool0oooo02P0oooo000Y0?ooo`030000003oool0
oooo08L0oooo00<000000?ooo`3oool06`3oool00`000000ool00?oo000k0?oo00030000o`3oool0
oooo02/0oooo00<000000?ooo`3oool0:03oool002T0oooo00<000000?ooo`3oool0Q`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oo`00ool003X0ool000<0003o0?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0X0?ooo`00:@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo01d0
oooo00<000000?oo003oo`00>@3oo`000`000?l0oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0
oooo000Z0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool07P3oool00`000000ool0
0?oo000h0?oo00030000o`3oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool002X0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`0O0?ooo`030000003oo`00ool003L0ool000<0
003o0?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`00:P3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo0200oooo00<000000?oo003oo`00=P3oo`000`000?l0oooo0?ooo`0Y
0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo08D0oooo00<000000?oo
o`3oool0803oool00`000000ool00?oo000f0?oo00030000o`3oool0oooo02T0oooo00<000000?oo
o`3oool0:P3oool002/0oooo00<000000?ooo`3oool0Q@3oool200000280oooo00<000000?oo003o
o`00=@3oo`000`000?l0oooo0?ooo`0Y0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000
003oool0oooo08D0oooo00<000000?ooo`3oool08P3oool00`000000ool00?oo000d0?oo00030000
o`3oool0oooo02T0oooo00<000000?ooo`3oool0:P3oool002`0oooo00<000000?ooo`3oool0Q03o
ool00`000000oooo0?ooo`0S0?ooo`030000003oo`00ool003<0ool000<0003o0?ooo`3oool0:03o
ool00`000000oooo0?ooo`0[0?ooo`00;03oool00`000000oooo0?ooo`240?ooo`030000003oool0
oooo02@0oooo00<000000?oo003oo`00<P3oo`000`000?l0oooo0?ooo`0W0?ooo`030000003oool0
oooo02`0oooo000]0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool09@3oool00`00
0000ool00?oo000a0?oo00030000o`3oool0oooo02L0oooo00<000000?ooo`3oool0;03oool002d0
oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0V0?ooo`030000003oo`00ool00300
ool000<0003o0?ooo`3oool09`3oool00`000000oooo0?ooo`0/0?ooo`00;@3oool00`000000oooo
0?ooo`230?ooo`030000003oool0oooo02H0oooo00<000000?oo003oo`00<03oo`000`000?l0oooo
0?ooo`0W0?ooo`030000003oool0oooo02`0oooo000^0?ooo`030000003oool0oooo0880oooo00<0
00000?ooo`3oool09`3oool00`000000ool00?oo000_0?oo00030000o`3oool0oooo02H0oooo00<0
00000?ooo`3oool0;@3oool002h0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`0X
0?ooo`030000003oo`00ool002h0ool000<0003o0?ooo`3oool09P3oool00`000000oooo0?ooo`0]
0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo02T0oooo00<000000?oo
003oo`00;@3oo`000`000?l0oooo0?ooo`0V0?ooo`030000003oool0oooo02d0oooo000^0?ooo`03
0000003oool0oooo0880oooo00<000000?ooo`3oool0:P3oool00`000000ool00?oo000/0?oo0003
0000o`3oool0oooo02D0oooo00<000000?ooo`3oool0;P3oool002l0oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`0[0?ooo`030000003oo`00ool002/0ool000<0003o0?ooo`3oool0
9@3oool00`000000oooo0?ooo`0^0?ooo`00<03oool00`000000oooo0?ooo`200?ooo`030000003o
ool0oooo02/0oooo00<000000?oo003oo`00:`3oo`000`000?l0oooo0?ooo`0T0?ooo`030000003o
ool0oooo02l0oooo000`0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0;03oool0
0`000000ool00?oo000Z0?oo00030000o`3oool0oooo02@0oooo00<000000?ooo`3oool0;`3oool0
0300oooo00<000000?ooo`3oool0P03oool2000002h0oooo00<000000?oo003oo`00:@3oo`000`00
0?l0oooo0?ooo`0T0?ooo`030000003oool0oooo02l0oooo000`0?ooo`030000003oool0oooo0800
oooo00<000000?ooo`3oool0;P3oool00`000000ool00?oo000X0?oo00030000o`3oool0oooo02<0
oooo00<000000?ooo`3oool0<03oool00340oooo00<000000?ooo`3oool0O`3oool00`000000oooo
0?ooo`0_0?ooo`030000003oo`00ool002L0ool000<0003o0?ooo`3oool08`3oool00`000000oooo
0?ooo`0`0?ooo`00<P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0300oooo00<0
00000?oo003oo`009P3oo`000`000?l0oooo0?ooo`0R0?ooo`030000003oool0oooo0340oooo000b
0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0<03oool00`000000ool00?oo000V
0?oo00030000o`3oool0oooo0240oooo00<000000?ooo`3oool0<P3oool003<0oooo00<000000?oo
o`3oool0O@3oool00`000000oooo0?ooo`0a0?ooo`030000003oo`00ool002D0ool000<0003o0?oo
o`3oool08@3oool00`000000oooo0?ooo`0b0?ooo`00<`3oool00`000000oooo0?ooo`1m0?ooo`03
0000003oool0oooo0380oooo00<000000?oo003oo`00903oo`000`000?l0oooo0?ooo`0Q0?ooo`03
0000003oool0oooo0380oooo000c0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0
<`3oool00`000000ool00?oo000S0?oo00030000o`3oool0oooo0200oooo00<000000?ooo`3oool0
<`3oool003@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0d0?ooo`030000003o
o`00ool00280ool000<0003o0?ooo`3oool0803oool00`000000oooo0?ooo`0c0?ooo`00=03oool0
0`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo00<000000?oo003oo`008@3oo`00
0`000?l0oooo0?ooo`0O0?ooo`030000003oool0oooo03@0oooo000e0?ooo`030000003oool0oooo
07/0oooo00<000000?ooo`3oool0=P3oool00`000000ool00?oo000P0?oo00030000o`3oool0oooo
01l0oooo00<000000?ooo`3oool0=03oool003H0oooo00<000000?ooo`3oool0NP3oool00`000000
oooo0?ooo`0f0?ooo`030000003oo`00ool00200ool000<0003o0?ooo`3oool07P3oool00`000000
oooo0?ooo`0e0?ooo`00=P3oool00`000000oooo0?ooo`1V0?ooo`0:0;md00000000001809cOo`3o
ool0oono07A8W03Oool0oooo0;md0080000000<0B9cO0?ooo`3oool01@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oo`00ool001l0ool000<0003o0?ooo`3oool07@3oool00`000000oooo0?oo
o`0f0?ooo`00=`3oool00`000000oooo0?ooo`1T0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo
0`3oool01P3o_g@0B9cO0?ooo`3oool0gia807Boo`H0oooo00<000000?ooo`3oool0>03oool00`00
0000ool00?oo000N0?oo00030000o`3oool0oooo01d0oooo00<000000?ooo`3oool0=P3oool003P0
oooo00<000000?ooo`3oool0H`3oool01P3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`L0oooo00<0okmd
04RLg`3oool01@3oool3000003T0oooo00<000000?oo003oo`007@3oo`000`000?l0oooo0?ooo`0L
0?ooo`030000003oool0oooo03L0oooo000h0?ooo`030000003oool0oooo06<0oooo00H0gia807Bo
o`3oool0oooO09a8M02oool30?ooo`060?noM00007@0_ooo0?ooo`3OW4P0M;oo1P3oool00`000000
oooo0?ooo`0j0?ooo`030000003oo`00ool001`0ool000<0003o0?ooo`3oool06`3oool00`000000
oooo0?ooo`0h0?ooo`00>@3oool00`000000oooo0?ooo`1R0?ooo`060=nLB018W=l0oooo0?oo_`1d
07@0_ooo0`3oool01@3ookl0M4Q804P00000000007Bo00L0oooo00<000000?ooo`3oool0>`3oool0
0`000000ool00?oo000K0?oo00030000o`3oool0oooo01/0oooo00<000000?ooo`3oool0>03oool0
03T0oooo00<000000?ooo`3oool0HP3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00<0
oooO09a8B02Lgol02@3oool00`000000oooo0?ooo`0k0?ooo`030000003oo`00ool001/0ool000<0
003o0?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`00>P3oool00`000000oooo0?ooo`1R
0?ooo`040;md00000000001809cOo`D0oooo00D0_g@0000000000000001809cOo`060?ooo`030000
003oool0oooo03`0oooo00<000000?oo003oo`006P3oo`000`000?l0oooo0?ooo`0J0?ooo`030000
003oool0oooo03T0oooo000j0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0?@3o
ool00`000000ool00?oo000I0?oo00030000o`3oool0oooo01X0oooo00<000000?ooo`3oool0>@3o
ool003/0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0n0?ooo`030000003oo`00
ool001P0ool000<0003o0?ooo`3oool06@3oool00`000000oooo0?ooo`0j0?ooo`00?03oool00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo03l0oooo00<000000?oo003oo`005`3oo`000`00
0?l0oooo0?ooo`0H0?ooo`030000003oool0oooo03/0oooo000l0?ooo`030000003oool0oooo07@0
oooo00<000000?ooo`3oool0@03oool00`000000ool00?oo000F0?oo00030000o`3oool0oooo01P0
oooo00<000000?ooo`3oool0>`3oool003d0oooo00<000000?ooo`3oool0L`3oool00`000000oooo
0?ooo`110?ooo`030000003oo`00ool001D0ool000<0003o0?ooo`3oool05`3oool00`000000oooo
0?ooo`0l0?ooo`00?P3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0440oooo00<0
00000?oo003oo`005@3oo`000`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo03d0oooo000n
0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0@P3oool00`000000ool00?oo000D
0?oo00030000o`3oool0oooo01H0oooo00<000000?ooo`3oool0?@3oool003l0oooo00<000000?oo
o`3oool0L@3oool00`000000oooo0?ooo`130?ooo`030000003oo`00ool001<0ool000<0003o0?oo
o`3oool05@3oool00`000000oooo0?ooo`0n0?ooo`00@03oool00`000000oooo0?ooo`1`0?ooo`03
0000003oool0oooo04@0oooo00<000000?oo003oo`004P3oo`000`000?l0oooo0?ooo`0D0?ooo`03
0000003oool0oooo03l0oooo00100?ooo`030000003oool0oooo0700oooo0P0000160?ooo`030000
003oo`00ool00140ool000<0003o0?ooo`3oool0503oool00`000000oooo0?ooo`0o0?ooo`00@@3o
ool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo04H0oooo00<000000?oo003oo`00403o
o`000`000?l0oooo0?ooo`0C0?ooo`030000003oool0oooo0400oooo00120?ooo`030000003oool0
oooo06h0oooo00<000000?ooo`3oool0AP3oool00`000000ool00?oo000@0?oo00030000o`3oool0
oooo0180oooo00<000000?ooo`3oool0@@3oool004<0oooo00<000000?ooo`3oool0K@3oool00`00
0000oooo0?ooo`170?ooo`030000003oo`00ool000l0ool000<0003o0?ooo`3oool04@3oool00`00
0000oooo0?ooo`120?ooo`00A03oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo04P0
oooo00<000000?oo003oo`003P3oo`000`000?l0oooo0?ooo`0@0?ooo`030000003oool0oooo04<0
oooo00150?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0B@3oool00`000000ool0
0?oo000=0?oo00030000o`3oool0oooo00l0oooo00<000000?ooo`3oool0A03oool004D0oooo00<0
00000?ooo`3oool0J`3oool00`000000oooo0?ooo`1:0?ooo`030000003oo`00ool000`0ool000<0
003o0?ooo`3oool03`3oool00`000000oooo0?ooo`140?ooo`00AP3oool00`000000oooo0?ooo`1Z
0?ooo`030000003oool0oooo04/0oooo00<000000?oo003oo`002`3oo`000`000?l0oooo0?ooo`0>
0?ooo`030000003oool0oooo04D0oooo00170?ooo`030000003oool0oooo06T0oooo00<000000?oo
o`3oool0B`3oool00`000000ool00?oo000;0?oo00030000o`3oool0oooo00d0oooo00<000000?oo
o`3oool0AP3oool004P0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`1<0?ooo`03
0000003oo`00ool000X0ool000<0003o0?ooo`3oool0303oool00`000000oooo0?ooo`170?ooo`00
B@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo04d0oooo00<000000?oo003oo`00
2@3oo`000`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo04P0oooo001:0?ooo`030000003o
ool0oooo06H0oooo00<000000?ooo`3oool0CP3oool00`000000ool00?oo00080?oo00030000o`3o
ool0oooo00X0oooo00<000000?ooo`3oool0B@3oool004/0oooo00<000000?ooo`3oool0I@3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oo`00ool000L0ool000<0003o0?ooo`3oool02@3oool0
0`000000oooo0?ooo`1:0?ooo`00C03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo
0500oooo00<000000?oo003oo`000`3oo`020000o`040?oo00000?l0oooo0000o`P0oooo00<00000
0?ooo`3oool0B`3oool004d0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`1A0?oo
o`030000003oo`00ool00080ool01P000?l70?ooo`030000003oool0oooo04`0oooo001>0?ooo`03
0000003oool0oooo0680oooo0P00001B0?ooo`030000003oo`00ool000<0ool01@000?l60?ooo`03
0000003oool0oooo04d0oooo001?0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0
DP3oool00`000000ool00?oo00020?oo00@0003o1P3oool00`000000oooo0?ooo`1>0?ooo`00D03o
ool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo05<0oooo00@000000?oo003oo`00ool0
10000?l50?ooo`030000003oool0oooo04l0oooo001A0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool0E03oool00`000000ool00?oo00040000o`@0oooo00<000000?ooo`3oool0D03o
ool00580oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1E0?ooo`030000003oo`00
ool000<0003o0`3oool00`000000oooo0?ooo`1A0?ooo`00D`3oool00`000000oooo0?ooo`1M0?oo
o`030000003oool0oooo05H0oooo00<000000?oo00000?l00P000?l20?ooo`030000003oool0oooo
0580oooo001D0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0EP3oool00`000000
ool00000o`020000o`030?ooo`000000oooo05@0oooo001E0?ooo`030000003oool0oooo05/0oooo
00<000000?ooo`3oool0E`3oool01@000000003o0000o`3oool0000005H0oooo001F0?ooo`030000
003oool0oooo05X0oooo00<000000?ooo`3oool0F03oool00`000000003o0000001G0?ooo`00E`3o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05T0oooo00<0003o0?ooo`3oool0EP3o
ool005P0oooo0P00001I0?ooo`030000003oool0oooo05L0oooo0P00001I0?ooo`00FP3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0F@3oool005/0
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05X0
oooo001L0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`1K0?ooo`00G@3oool00`000000oooo0?ooo`1C0?ooo`800000E03oool01@000000oooo0?oo
_`1d0000B9cO05X0oooo001N0?ooo`800000D`3oool00`000000oooo0?ooo`1A0?ooo`8000000P3o
ool00`3ookl0M00004RLg`1J0?ooo`00H03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo0500oooo00<000000?ooo`3oool00P3oool00`3ookl0M00004RLg`1J0?ooo`00H@3oool20000
0500oooo00<000000?ooo`3oool0CP3oool2000000D0oooo00<0oono07@0000000000P0000000`00
M;l0oooo0?ooo`1E0?ooo`00H`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool01@3oool01`3ookl0M00004RLg`3oool0omnL04P00018W=l0EP3oool0
06@0oooo0P00001=0?ooo`030000003oool0oooo04/0oooo0P0000080?ooo`070?oo_`1d0000B9cO
0?ooo`3ookl0M000001d_`1F0?ooo`00IP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool0203oool01`3ookl0M00004RLg`3oool0omnL04P00018W=l0
EP3oool006L0oooo0P00001:0?ooo`030000003oool0oooo04P0oooo0P00000;0?ooo`030?oo_`1d
000000000080000000<004RL0=ooo`3oool0E@3oool006T0oooo0P0000180?ooo`030000003oool0
oooo04H0oooo0P00001Z0?ooo`00J`3oool2000004H0oooo00<000000?ooo`3oool0A03oool20000
06`0oooo001]0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`1/0?ooo`00KP3oool2000004<0oooo00<000000?ooo`3oool0@@3oool2000006l0oooo
001`0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`1_0?ooo`00L@3oool200000400oooo00<000000?ooo`3oool0?P3oool200000780oooo001c0?oo
o`<00000?@3oool2000003`0oooo0`00001d0?ooo`00MP3oool2000003/0oooo00<000000?ooo`3o
ool0>@3oool2000007L0oooo001h0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`1g0?ooo`00N@3oool4000003H0oooo00<000000?ooo`3oool0=03o
ool4000007X0oooo001m0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`1l0?ooo`00OP3oool400000340oooo00<000000?ooo`3oool0;`3oool40000
07l0oooo00220?ooo`<00000;P3oool00`000000oooo0?ooo`0/0?ooo`<00000P`3oool008D0oooo
0P00000/0?ooo`030000003oool0oooo02X0oooo0P0000260?ooo`00Q`3oool3000002T0oooo00<0
00000?ooo`3oool09`3oool3000008P0oooo002:0?ooo`<000009P3oool00`000000oooo0?ooo`0T
0?ooo`<00000R`3oool008d0oooo1P00000P0?ooo`030000003oool0oooo01h0oooo1P00002>0?oo
o`00T`3oool3000001d0oooo00<000000?ooo`3oool06`3oool3000009@0oooo002F0?ooo`D00000
3@3oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo01H0oooo1@00002G0?ooo`00V`3o
ool7000000H0oooo00<0oooO09a8M02oool0203oool00`000000oooo0?ooo`0?0?ooo`L00000W03o
ool00:80oooo8`00002S0?ooo`00Z03oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo
0;80oooo002V0?ooo`050?oog`2LW;l0oooO09a8M02oool0203oool00`000000oooo0?ooo`2b0?oo
o`00Y`3oool0103o_g@000000000M02oool80?ooo`030000003oool0oooo0;80oooo002X0?ooo`03
0?oo_`1d07@0_ooo00P0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0
/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo
00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<00000
0?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool00;<0oooo0P00002c0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?oo
o`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?oo
o`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3o
ool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`00
0000oooo0?ooo`2b0?ooo`00/`3oool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?oo
o`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000
003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0
oooo0;80oooo0000\
\>"],
  ImageRangeCache->{{{112.438, 370.625}, {536.063, 277.875}} -> {-2.35746, \
1.45217, 0.00878441, 0.00878441}},
  CellTags->"figura1"]
}, Closed]],

Cell[CellGroupData[{

Cell["Dimostrazione dell'identit\[AGrave] fondamentale", "Subsubsection"],

Cell[TextData[{
  "Riportiamo le definizioni di carattere geometrico delle principali \
funzioni goniometriche discusse in un precedente notebook e, assieme, \
forniamo le  relazioni che le legano tra di loro al medesimo angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ". I segmenti ",
  Cell[BoxData[
      FormBox[
        StyleBox["OQ",
          FontSlant->"Italic"], TraditionalForm]]],
  " e ",
  Cell[BoxData[
      FormBox[
        StyleBox["QP",
          FontSlant->"Italic"], TraditionalForm]]],
  " vanno considerati come segmenti orientati (o componenti del vettore ",
  Cell[BoxData[
      FormBox[
        StyleBox["OP",
          FontWeight->"Bold"], TraditionalForm]]],
  "). ",
  Cell[BoxData[
      FormBox[
        StyleBox["OP",
          FontSlant->"Italic"], TraditionalForm]]],
  " \[EGrave] invece la misura (positiva) del raggio della circonferenza \
associata al sistema cartesiano di ",
  ButtonBox["figura",
    ButtonData:>"figura1",
    ButtonStyle->"Hyperlink"],
  " (o anche il modulo di ",
  Cell[BoxData[
      FormBox[
        StyleBox["OP",
          FontWeight->"Bold"], TraditionalForm]]],
  "). \[CapitalEGrave] questo l'insieme di \"regole\" da cui iniziamo."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Join[{QP/OP == sen[\[Alpha]], OQ/OP == cos[\[Alpha]], 
          QP/OQ == tan[\[Alpha]]}, toIdentita /@ {id1, id2, id3}] // 
      TableForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(QP\/OP \[Equal] sen[\[Alpha]]\)},
          {\(OQ\/OP \[Equal] cos[\[Alpha]]\)},
          {\(QP\/OQ \[Equal] tan[\[Alpha]]\)},
          {\(tan[\[Alpha]] \[Equal] sen[\[Alpha]]\/cos[\[Alpha]]\)},
          {\(cot[\[Alpha]] \[Equal] cos[\[Alpha]]\/sen[\[Alpha]]\)},
          {\(1\/tan[\[Alpha]] \[Equal] cot[\[Alpha]]\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Times[ 
            Power[ OP, -1], QP], 
          sen[ \[Alpha]]], 
        Equal[ 
          Times[ 
            Power[ OP, -1], OQ], 
          cos[ \[Alpha]]], 
        Equal[ 
          Times[ 
            Power[ OQ, -1], QP], 
          tan[ \[Alpha]]], 
        Equal[ 
          tan[ \[Alpha]], 
          Times[ 
            Power[ 
              cos[ \[Alpha]], -1], 
            sen[ \[Alpha]]]], 
        Equal[ 
          cot[ \[Alpha]], 
          Times[ 
            cos[ \[Alpha]], 
            Power[ 
              sen[ \[Alpha]], -1]]], 
        Equal[ 
          Power[ 
            tan[ \[Alpha]], -1], 
          cot[ \[Alpha]]]}]]], "Output"]
}, Closed]],

Cell[TextData[{
  "L'applicazione del teorema di Pitagora al triangolo ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["OQP",
            FontSlant->"Italic"], Cell[""]}], TraditionalForm]]],
  "permette di scrivere"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(OP\^2 \[Equal] OQ\^2 + QP\^2\)], "Input"],

Cell[BoxData[
    \(OP\^2 \[Equal] OQ\^2 + QP\^2\)], "Output"]
}, Closed]],

Cell[TextData[{
  "per cui sostituendo le espressioni di ",
  Cell[BoxData[
      FormBox[
        StyleBox["OQ",
          FontSlant->"Italic"], TraditionalForm]]],
  " e ",
  Cell[BoxData[
      FormBox[
        StyleBox["QP",
          FontSlant->"Italic"], TraditionalForm]]],
  " dedotte dalle definizioni di seno e coseno si ha"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {OQ \[Rule] OP\ sen[\[Alpha]], 
        QP \[Rule] OP\ cos[\[Alpha]]}\)], "Input"],

Cell[BoxData[
    \(OP\^2 \[Equal] 
      OP\^2\ cos[\[Alpha]]\^2 + OP\^2\ sen[\[Alpha]]\^2\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Eliminando ora il termine ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["OP",
            FontSlant->"Italic"], "2"], TraditionalForm]]],
  "comune ai due membri si ottiene"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(%/OP\^2 // Simplify\)], "Input"],

Cell[BoxData[
    \(cos[\[Alpha]]\^2 + sen[\[Alpha]]\^2 \[Equal] 1\)], "Output"]
}, Closed]],

Cell[TextData[{
  "relazione che costituisce l'",
  StyleBox["identit\[AGrave] fondamentale",
    FontSlant->"Italic"],
  " della Goniometria."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ la\ funzione, \ qui\ usata\ per\ la\ prima\ volta, \ 
      aggiunge\ all' 
        insieme\ di\ regole\ iniziali\ quella\ appena\ dimostrata . \ 
          Ad\ ogni\ regola\ si\ associa\ in\ tal\ modo\ un\ nome\ mnemonico\ \
per\ poterla\ usare\ successivamente . \ 
          Per\ due\ tabelle\ comprensive\ di\ tutti\ i\ nomi\ si\ veda\ la\ \
sezione\ riassuntiva\ finale\ *) \)\(\[IndentingNewLine]\)\(idFondamentale = 
      toRule[%]\)\)\)], "Input"],

Cell[BoxData[
    \(cos[\[Alpha]]\^2 + sen[\[Alpha]]\^2 \[RuleDelayed] 1\)], "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Funzioni goniometriche in termini di una di esse", "Section"],

Cell[CellGroupData[{

Cell["Identita dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\(idFondamentale = 
        cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 1;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Nota la funzione ",
  Cell[BoxData[
      \(TraditionalForm\`sen[\[Alpha]]\)]]
}], "Subsection"],

Cell[TextData[{
  "Per determinare il coseno e la tangente in termini del seno dello stesso \
angolo facciamo uso dell'identit\[AGrave] appena dimostrata esplicitando \
dapprima il coseno ossia sottraendo ",
  Cell[BoxData[
      \(TraditionalForm\`sen[\[Alpha]]\^2\)]],
  " ad entrambi i membri"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(toIdentita[idFondamentale] - sen[\[Alpha]]^2\)], "Input"],

Cell[BoxData[
    \(cos[\[Alpha]]\^2 \[Equal] 1 - sen[\[Alpha]]\^2\)], "Output"]
}, Closed]],

Cell["L'estrazione della radice quadrata fornisce", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sqrt /@ %\)], "Input"],

Cell[BoxData[
    \(\@cos[\[Alpha]]\^2 \[Equal] \@\(1 - sen[\[Alpha]]\^2\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "ma dato che ",
  Cell[BoxData[
      \(TraditionalForm\`\@cos[\[Alpha]]\^2 = \(\(|\)\(cos[\[Alpha]]\)\(|\)\)\
\)]],
  " risulta"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MapAt[Abs, %, {1}]\)], "Input",
  CellTags->"cosNotosen"],

Cell[BoxData[
    \(Abs[cos[\[Alpha]]] \[Equal] \@\(1 - sen[\[Alpha]]\^2\)\)], "Output",
  CellTags->"cosNotosen"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cosNotosen = toRule[%]\)], "Input"],

Cell[BoxData[
    \(Abs[
        cos[\[Alpha]]] \[RuleDelayed] \@\(1 - sen[\[Alpha]]\^2\)\)], "Output"]
}, Closed]],

Cell["La funzione tangente invece si ottiene partendo dalla", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(toIdentita[id1]\)], "Input"],

Cell[BoxData[
    \(tan[\[Alpha]] \[Equal] sen[\[Alpha]]\/cos[\[Alpha]]\)], "Output"]
}, Closed]],

Cell["e considerandola in valore assoluto", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Abs[tan[\[Alpha]]] \[Equal] 
      Abs[sen[\[Alpha]]]\/Abs[cos[\[Alpha]]]\)], "Input"],

Cell[BoxData[
    \(Abs[tan[\[Alpha]]] \[Equal] 
      Abs[sen[\[Alpha]]]\/Abs[cos[\[Alpha]]]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Sostituendo il risultato ",
  ButtonBox["precedente",
    ButtonData:>"cosNotosen",
    ButtonStyle->"Hyperlink"],
  " giungiamo alla relazione cercata"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. cosNotosen\)], "Input"],

Cell[BoxData[
    \(Abs[tan[\[Alpha]]] \[Equal] 
      Abs[sen[\[Alpha]]]\/\@\(1 - sen[\[Alpha]]\^2\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tanNotosen = toRule[%]\)], "Input"],

Cell[BoxData[
    \(Abs[tan[\[Alpha]]] \[RuleDelayed] 
      Abs[sen[\[Alpha]]]\/\@\(1 - sen[\[Alpha]]\^2\)\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Nota la funzione ",
  Cell[BoxData[
      \(TraditionalForm\`cos[\[Alpha]]\)]]
}], "Subsection"],

Cell["\<\
In modo del tutto analogo si procede se si intende esprimere il seno e \
tangente in termini del coseno: riportiamo senza commento la procedura.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(toIdentita[idFondamentale] - cos[\[Alpha]]^2\)], "Input"],

Cell[BoxData[
    \(sen[\[Alpha]]\^2 \[Equal] 1 - cos[\[Alpha]]\^2\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sqrt /@ %\)], "Input"],

Cell[BoxData[
    \(\@sen[\[Alpha]]\^2 \[Equal] \@\(1 - cos[\[Alpha]]\^2\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MapAt[Abs, %, {1}]\)], "Input"],

Cell[BoxData[
    \(Abs[sen[\[Alpha]]] \[Equal] \@\(1 - cos[\[Alpha]]\^2\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(senNotocos = toRule[%]\)], "Input"],

Cell[BoxData[
    \(Abs[
        sen[\[Alpha]]] \[RuleDelayed] \@\(1 - cos[\[Alpha]]\^2\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(toIdentita[id1]\)], "Input"],

Cell[BoxData[
    \(tan[\[Alpha]] \[Equal] sen[\[Alpha]]\/cos[\[Alpha]]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Abs[tan[\[Alpha]]] \[Equal] 
      Abs[sen[\[Alpha]]]\/Abs[cos[\[Alpha]]]\)], "Input"],

Cell[BoxData[
    \(Abs[tan[\[Alpha]]] \[Equal] 
      Abs[sen[\[Alpha]]]\/Abs[cos[\[Alpha]]]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. senNotocos\)], "Input"],

Cell[BoxData[
    \(Abs[
        tan[\[Alpha]]] \[Equal] \@\(1 - \
cos[\[Alpha]]\^2\)\/Abs[cos[\[Alpha]]]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tanNotocos = toRule[%]\)], "Input"],

Cell[BoxData[
    \(Abs[
        tan[\[Alpha]]] \[RuleDelayed] \@\(1 - cos[\[Alpha]]\^2\)\/Abs[cos[\
\[Alpha]]]\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Nota la funzione ",
  Cell[BoxData[
      \(TraditionalForm\`tan[\[Alpha]]\)]]
}], "Subsection"],

Cell[TextData[{
  "Ritenendo conosciuto il valore di ",
  Cell[BoxData[
      \(TraditionalForm\`tan[\[Alpha]]\)]],
  " iniziamo dalla evidente identit\[AGrave]"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(HoldForm[sen[\[Alpha]]\^2] \[Equal] sen[\[Alpha]]\^2\)], "Input"],

Cell[BoxData[
    RowBox[{
      TagBox[\(sen[\[Alpha]]\^2\),
        HoldForm], "\[Equal]", \(sen[\[Alpha]]\^2\)}]], "Output"]
}, Closed]],

Cell[TextData[{
  "e riscriviamo il denominatore (",
  Cell[BoxData[
      \(TraditionalForm\`\(\(=\)\(1\)\)\)]],
  ") del secondo membro sfruttando l'identit\[AGrave] fondamentale"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MapAt[#/\((sen[\[Alpha]]^2 + cos[\[Alpha]]^2)\) &, %, 2]\)], "Input"],

Cell[BoxData[
    RowBox[{
      TagBox[\(sen[\[Alpha]]\^2\),
        HoldForm], 
      "\[Equal]", \(sen[\[Alpha]]\^2\/\(cos[\[Alpha]]\^2 + 
            sen[\[Alpha]]\^2\)\)}]], "Output"]
}, Closed]],

Cell[TextData[{
  "Dividiamo ora il numeratore e denominatore del secondo membro per ",
  Cell[BoxData[
      \(TraditionalForm\`cos[\[Alpha]]\^2 \[NotEqual] 0\)]],
  " supponendo quindi che ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] \[NotEqual] \[Pi]\/2 + k\ \[Pi]\)]],
  " "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(applicaND[%, HoldForm[#/cos[\[Alpha]]^2] &]\)], "Input"],

Cell[BoxData[
    RowBox[{
      TagBox[\(sen[\[Alpha]]\^2\),
        HoldForm], "\[Equal]", 
      FractionBox[
        TagBox[\(sen[\[Alpha]]\^2\/cos[\[Alpha]]\^2\),
          HoldForm], 
        TagBox[\(\(cos[\[Alpha]]\^2 + sen[\[Alpha]]\^2\)\/cos[\[Alpha]]\^2\),
          HoldForm]]}]], "Output"]
}, Closed]],

Cell[TextData[{
  "Applicando la propriet\[AGrave] distributiva e sapendo che ",
  Cell[BoxData[
      \(TraditionalForm\`tan[\[Alpha]] = sen[\[Alpha]]/cos[\[Alpha]]\)]],
  " otteniamo"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(applicaND[%, Apart[rilascia[#]] &] //. id4\)], "Input"],

Cell[BoxData[
    RowBox[{
      TagBox[\(sen[\[Alpha]]\^2\),
        HoldForm], 
      "\[Equal]", \(tan[\[Alpha]]\^2\/\(1 + tan[\[Alpha]]\^2\)\)}]], "Output"]
}, Closed]],

Cell["\<\
da cui l'estrazione della radice quadrata in entrambi i membri fornisce\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rilascia[Sqrt /@ %]\)], "Input"],

Cell[BoxData[
    \(\@sen[\[Alpha]]\^2 \[Equal] \@\(tan[\[Alpha]]\^2\/\(1 + \
tan[\[Alpha]]\^2\)\)\)], "Output"]
}, Closed]],

Cell["per cui risulta", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MapAt[Abs, %, 1]\)], "Input"],

Cell[BoxData[
    \(Abs[
        sen[\[Alpha]]] \[Equal] \@\(tan[\[Alpha]]\^2\/\(1 + \
tan[\[Alpha]]\^2\)\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(senNototan = toRule[%]\)], "Input"],

Cell[BoxData[
    \(Abs[
        sen[\[Alpha]]] \[RuleDelayed] \@\(tan[\[Alpha]]\^2\/\(1 + \
tan[\[Alpha]]\^2\)\)\)], "Output"]
}, Closed]],

Cell["\<\
Con la stessa successione di passaggi si ottiene il valore assoluto del \
coseno in termini della tangente: sinteticamente\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(HoldForm[cos[\[Alpha]]\^2] \[Equal] cos[\[Alpha]]\^2\)], "Input"],

Cell[BoxData[
    RowBox[{
      TagBox[\(cos[\[Alpha]]\^2\),
        HoldForm], "\[Equal]", \(cos[\[Alpha]]\^2\)}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MapAt[#/\((sen[\[Alpha]]^2 + cos[\[Alpha]]^2)\) &, %, 2]\)], "Input"],

Cell[BoxData[
    RowBox[{
      TagBox[\(cos[\[Alpha]]\^2\),
        HoldForm], 
      "\[Equal]", \(cos[\[Alpha]]\^2\/\(cos[\[Alpha]]\^2 + 
            sen[\[Alpha]]\^2\)\)}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(applicaND[%, HoldForm[#/cos[\[Alpha]]^2] &]\)], "Input"],

Cell[BoxData[
    RowBox[{
      TagBox[\(cos[\[Alpha]]\^2\),
        HoldForm], "\[Equal]", 
      FractionBox[
        TagBox[\(cos[\[Alpha]]\^2\/cos[\[Alpha]]\^2\),
          HoldForm], 
        TagBox[\(\(cos[\[Alpha]]\^2 + sen[\[Alpha]]\^2\)\/cos[\[Alpha]]\^2\),
          HoldForm]]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(applicaND[%, Apart[rilascia[#]] &] //. id4\)], "Input"],

Cell[BoxData[
    RowBox[{
      TagBox[\(cos[\[Alpha]]\^2\),
        HoldForm], "\[Equal]", \(1\/\(1 + tan[\[Alpha]]\^2\)\)}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rilascia[Sqrt /@ %]\)], "Input"],

Cell[BoxData[
    \(\@cos[\[Alpha]]\^2 \[Equal] \@\(1\/\(1 + tan[\[Alpha]]\^2\)\)\)], \
"Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MapAt[Abs, %, 1]\)], "Input"],

Cell[BoxData[
    \(Abs[
        cos[\[Alpha]]] \[Equal] \@\(1\/\(1 + tan[\[Alpha]]\^2\)\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cosNototan = toRule[%]\)], "Input"],

Cell[BoxData[
    \(Abs[
        cos[\[Alpha]]] \[RuleDelayed] \@\(1\/\(1 + tan[\[Alpha]]\^2\)\)\)], \
"Output"]
}, Closed]],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[TextData[{
  "In definitiva abbiamo ottenuto le seguenti identit\[AGrave] in termini \
dell'angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\({idFondamentale, cosNotosen, tanNotosen, senNotocos, tanNotocos, 
          senNototan, 
          cosNototan} = {cos[\[Alpha]]\^2 + sen[\[Alpha]]\^2 \[RuleDelayed] 
            1, Abs[cos[\[Alpha]]] \[RuleDelayed] \@\(1 - sen[\[Alpha]]\^2\), 
          Abs[tan[\[Alpha]]] \[RuleDelayed] 
            Abs[sen[\[Alpha]]]\/\@\(1 - sen[\[Alpha]]\^2\), 
          Abs[sen[\[Alpha]]] \[RuleDelayed] \@\(1 - cos[\[Alpha]]\^2\), 
          Abs[tan[\[Alpha]]] \[RuleDelayed] \@\(1 - \
cos[\[Alpha]]\^2\)\/Abs[cos[\[Alpha]]], 
          Abs[sen[\[Alpha]]] \[RuleDelayed] \@\(tan[\[Alpha]]\^2\/\(1 + tan[\
\[Alpha]]\^2\)\), 
          Abs[cos[\[Alpha]]] \[RuleDelayed] \@\(1\/\(1 + \
tan[\[Alpha]]\^2\)\)};\)\), "\[IndentingNewLine]", 
    \(\(Transpose[{{"\<idFondamentale\>", "\<cosNotosen\>", "\<tanNotosen\>", \
"\<senNotocos\>", "\<tanNotocos\>", "\<senNototan\>", "\<cosNototan\>"}, 
            toIdentita /@ {idFondamentale, cosNotosen, tanNotosen, 
                senNotocos, tanNotocos, senNototan, cosNototan}}] // 
        TableForm\) // TraditionalForm\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {"\<\"idFondamentale\"\>", \(\(cos(\[Alpha])\)\^2 + \
\(sen(\[Alpha])\)\^2 \[Equal] 1\)},
            {"\<\"cosNotosen\"\>", \(\[LeftBracketingBar]cos(\[Alpha])\
\[RightBracketingBar] \[Equal] \@\(1 - \(sen(\[Alpha])\)\^2\)\)},
            {"\<\"tanNotosen\"\>", \(\[LeftBracketingBar]tan(\[Alpha])\
\[RightBracketingBar] \[Equal] \[LeftBracketingBar]sen(\[Alpha])\
\[RightBracketingBar]\/\@\(1 - \(sen(\[Alpha])\)\^2\)\)},
            {"\<\"senNotocos\"\>", \(\[LeftBracketingBar]sen(\[Alpha])\
\[RightBracketingBar] \[Equal] \@\(1 - \(cos(\[Alpha])\)\^2\)\)},
            {"\<\"tanNotocos\"\>", \(\[LeftBracketingBar]tan(\[Alpha])\
\[RightBracketingBar] \[Equal] \@\(1 - \(cos(\[Alpha])\)\^2\)\/\
\[LeftBracketingBar]cos(\[Alpha])\[RightBracketingBar]\)},
            {"\<\"senNototan\"\>", \(\[LeftBracketingBar]sen(\[Alpha])\
\[RightBracketingBar] \[Equal] \
\@\(\(tan(\[Alpha])\)\^2\/\(\(tan(\[Alpha])\)\^2 + 1\)\)\)},
            {"\<\"cosNototan\"\>", \(\[LeftBracketingBar]cos(\[Alpha])\
\[RightBracketingBar] \[Equal] \@\(1\/\(\(tan(\[Alpha])\)\^2 + 1\)\)\)}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ BoxForm`e$]]], TraditionalForm]], "Output"]
}, Closed]],

Cell["\<\
Nel seguito riprenderemo, di queste, solo l'identit\[AGrave] fondamentale in \
quanto solo questa si dimostrer\[AGrave] necessaria.\
\>", "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Angoli associati e relative identit\[AGrave]", "Section"],

Cell[CellGroupData[{

Cell["Angoli complementari", "Subsection"],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[{
    \(\[Alpha] = 20  Degree; \[Beta] = \((\[Pi]/2 - \[Alpha])\);\), "\n", 
    \(pP = {Cos[\[Alpha]], Sin[\[Alpha]]}; pQ = {Cos[\[Alpha]], 0}; 
    origine = {0, 0}; pR = {Cos[\[Beta]], Sin[\[Beta]]}; 
    pS = {Cos[\[Beta]], 0};\), "\[IndentingNewLine]", 
    \(Show[
      Graphics[{Circle[origine, 1], Line[{{\(-1.2\), 0}, {1.2, 0}}], 
          Line[{{0, \(-1.2\)}, {0, 1.2}}], 
          Line[{pP, origine, pR}]}], \[IndentingNewLine]Graphics[{colBlu, 
          Arrow[origine, pQ, stileVet], 
          Arrow[pQ, pP, stileVet]}], \[IndentingNewLine]Graphics[{colBlu, 
          Arrow[origine, pS, stileVet], 
          Arrow[pS, pR, 
            stileVet]}], \[IndentingNewLine]Graphics[{Text["\<O\>", 
            origine, {1, 1}, TextStyle \[Rule] stileTesto], 
          Text["\<Q\>", pQ, {0, 1}, TextStyle \[Rule] stileTesto], 
          Text["\<P\>", pP, {0, \(-1\)}, TextStyle \[Rule] stileTesto], 
          Text["\<S\>", pS, {0, 1}, TextStyle \[Rule] stileTesto], 
          Text["\<R\>", pR, {0, \(-1\)}, TextStyle \[Rule] stileTesto]}], 
      Prolog -> {{colGiallo, Polygon[{origine, pQ, pP}], 
            Polygon[{origine, pS, pR}]}, {colVerde, 
            Disk[origine,  .3, {0, \[Beta]}]}, {colRosso, 
            Disk[origine,  .2, {0, \[Alpha]}]}}, 
      AspectRatio \[Rule] Automatic, Axes \[Rule] True]; 
    Clear[\[Alpha], \[Beta]];\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Grafico", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.396825 0.5 0.396825 [
[.10317 .4875 -6.96875 -10.9375 ]
[.10317 .4875 6.96875 0 ]
[.30159 .4875 -10.3125 -10.9375 ]
[.30159 .4875 10.3125 0 ]
[.69841 .4875 -7.5625 -10.9375 ]
[.69841 .4875 7.5625 0 ]
[.89683 .4875 -4.21875 -10.9375 ]
[.89683 .4875 4.21875 0 ]
[.4875 .10317 -13.9375 -5.46875 ]
[.4875 .10317 0 5.46875 ]
[.4875 .30159 -20.625 -5.46875 ]
[.4875 .30159 0 5.46875 ]
[.4875 .69841 -15.125 -5.46875 ]
[.4875 .69841 0 5.46875 ]
[.4875 .89683 -8.4375 -5.46875 ]
[.4875 .89683 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .5 m
.10317 .50625 L
s
gsave
.10317 .4875 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.30159 .5 m
.30159 .50625 L
s
gsave
.30159 .4875 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.69841 .5 m
.69841 .50625 L
s
gsave
.69841 .4875 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.89683 .5 m
.89683 .50625 L
s
gsave
.89683 .4875 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.14286 .5 m
.14286 .50375 L
s
.18254 .5 m
.18254 .50375 L
s
.22222 .5 m
.22222 .50375 L
s
.2619 .5 m
.2619 .50375 L
s
.34127 .5 m
.34127 .50375 L
s
.38095 .5 m
.38095 .50375 L
s
.42063 .5 m
.42063 .50375 L
s
.46032 .5 m
.46032 .50375 L
s
.53968 .5 m
.53968 .50375 L
s
.57937 .5 m
.57937 .50375 L
s
.61905 .5 m
.61905 .50375 L
s
.65873 .5 m
.65873 .50375 L
s
.7381 .5 m
.7381 .50375 L
s
.77778 .5 m
.77778 .50375 L
s
.81746 .5 m
.81746 .50375 L
s
.85714 .5 m
.85714 .50375 L
s
.06349 .5 m
.06349 .50375 L
s
.02381 .5 m
.02381 .50375 L
s
.93651 .5 m
.93651 .50375 L
s
.97619 .5 m
.97619 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .10317 m
.50625 .10317 L
s
gsave
.4875 .10317 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .30159 m
.50625 .30159 L
s
gsave
.4875 .30159 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .69841 m
.50625 .69841 L
s
gsave
.4875 .69841 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .89683 m
.50625 .89683 L
s
gsave
.4875 .89683 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .14286 m
.50375 .14286 L
s
.5 .18254 m
.50375 .18254 L
s
.5 .22222 m
.50375 .22222 L
s
.5 .2619 m
.50375 .2619 L
s
.5 .34127 m
.50375 .34127 L
s
.5 .38095 m
.50375 .38095 L
s
.5 .42063 m
.50375 .42063 L
s
.5 .46032 m
.50375 .46032 L
s
.5 .53968 m
.50375 .53968 L
s
.5 .57937 m
.50375 .57937 L
s
.5 .61905 m
.50375 .61905 L
s
.5 .65873 m
.50375 .65873 L
s
.5 .7381 m
.50375 .7381 L
s
.5 .77778 m
.50375 .77778 L
s
.5 .81746 m
.50375 .81746 L
s
.5 .85714 m
.50375 .85714 L
s
.5 .06349 m
.50375 .06349 L
s
.5 .02381 m
.50375 .02381 L
s
.5 .93651 m
.50375 .93651 L
s
.5 .97619 m
.50375 .97619 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto fill
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto
-0.03 0.0075 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
1 1 0 r
.5 .5 m
.87289 .5 L
.87289 .63572 L
F
.5 .5 m
.63572 .5 L
.63572 .87289 L
F
0 1 0 r
.5 .5 m
.5 .5 .11905 0 70 arc
F
1 0 0 r
.5 .5 m
.5 .5 .07937 0 20 arc
F
0 g
.5 Mabswid
newpath
.5 .5 .39683 0 365.73 arc
s
.02381 .5 m
.97619 .5 L
s
.5 .02381 m
.5 .97619 L
s
.87289 .63572 m
.5 .5 L
.63572 .87289 L
s
0 0 1 r
.5 .5 m
.87289 .5 L
s
% Start of user PostScript
0 0 0.939693 0 MAarrowhead1
% End of user PostScript
.87289 .5 m
.87289 .63572 L
s
% Start of user PostScript
0.939693 0 0.939693 0.34202 MAarrowhead1
% End of user PostScript
.5 .5 m
.63572 .5 L
s
% Start of user PostScript
0 0 0.34202 0 MAarrowhead1
% End of user PostScript
.63572 .5 m
.63572 .87289 L
s
% Start of user PostScript
0.34202 0 0.34202 0.939693 MAarrowhead1
% End of user PostScript
0 g
gsave
.5 .5 -71.9375 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.87289 .5 -66.4688 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Q) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.87289 .63572 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
69.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.63572 .5 -66 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.63572 .87289 -66.2188 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(R) show
69.438 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  Magnification->0.9,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?oo
o`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?oo
o`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3o
ool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo
0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?oo
o`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000
003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0
oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80
oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<00000
0?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3o
ool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0
oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<0
00000?ooo`3oool0/P3oool00:P0oooo00<0oooO09a8M02oool0203oool00`000000oooo0?ooo`2b
0?ooo`00Z03oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo0;80oooo002P0?ooo`03
0?noM000000000000080000000H004RL0=ooo`3oool0oooO09a8M02oool80?ooo`030000003oool0
oooo0;80oooo002S0?ooob400000Y03oool009`0oooo1`0000030?ooo`050?oog`2LW;l0oooO09a8
M02oool0203oool00`000000oooo0?ooo`0>0?ooo`L00000W@3oool009L0oooo1@00000;0?ooo`04
0?noM0000000001d0;ooo`P0oooo00<000000?ooo`3oool05@3oool5000009P0oooo002C0?ooo`@0
00004@3oool00`3ookl0M01d0;ooo`080?ooo`030000003oool0oooo01X0oooo1000002D0?ooo`00
SP3oool500000200oooo00<000000?ooo`3oool07P3oool5000008l0oooo002;0?ooo`<000009@3o
ool00`000000oooo0?ooo`0S0?ooo`<00000S03oool008L0oooo1000000X0?ooo`030000003oool0
oooo02H0oooo100000280?ooo`00QP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0Q@3oool00880oooo1000000]0?ooo`030000003oool0oooo02/0
oooo100000230?ooo`00O`3oool300000340oooo00<000000?ooo`3oool0;`3oool300000800oooo
001m0?ooo`800000=03oool00`000000oooo0?ooo`0b0?ooo`800000OP3oool007X0oooo0`00000f
0?ooo`030000003oool0oooo03@0oooo0`00001k0?ooo`00N03oool2000003T0oooo00<000000?oo
o`3oool0=`3oool2000007T0oooo001g0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`1f0?ooo`00M03oool3000003`0oooo0P00000k0?ooo`<00000
M@3oool00780oooo0P00000o0?ooo`030000003oool0oooo03d0oooo0P00001c0?ooo`00L03oool2
00000440oooo00<000000?ooo`3oool0?`3oool200000740oooo001_0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1^0?ooo`00K@3oool2000004@0
oooo00<000000?ooo`3oool0@P3oool2000006h0oooo001/0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1[0?ooo`00J@3oool3000004L0oooo00<0
00000?ooo`3oool0A@3oool3000006X0oooo001W0?ooo`800000BP3oool00`000000oooo0?ooo`18
0?ooo`800000J03oool006H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo06D0oooo001T0?ooo`800000C@3oool00`000000oooo0?ooo`1;0?ooo`80
0000I@3oool006<0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo0680oooo001Q0?ooo`800000D03oool00`000000oooo0?ooo`1>0?ooo`800000HP3o
ool00600oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo05l0oooo001N0?ooo`800000D`3oool00`000000oooo0?ooo`1A0?ooo`800000G`3oool005d0
oooo00<000000?ooo`3oool0D`3oool2000005@0oooo00<000000?ooo`3oool0G03oool005`0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05/0oooo
001K0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`1J0?ooo`00FP3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool0F@3oool005P0oooo0P00001I0?ooo`030000003oool0oooo05L0oooo0P00001I0?oo
o`00E`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0EP3oool005H0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo05D0oooo001E0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`1D0?ooo`00E03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo05`0oooo00<000000?ooo`3oool0D`3oool005<0oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`1M0?ooo`030000003oool0oooo0580oooo001B0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1A0?ooo`00D@3oool00`000000oooo
0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0D03oool00500oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo04l0oooo001?
0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1>
0?ooo`00CP3oool00`000000oooo0?ooo`1R0?ooo`800000H`3oool00`000000oooo0?ooo`1=0?oo
o`00C@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool0C03oool004`0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1T0?ooo`030000
003oool0oooo04/0oooo001;0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`1:0?ooo`00BP3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0
oooo06H0oooo00<000000?ooo`3oool0B@3oool004T0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`1W0?ooo`030000003oool0oooo04P0oooo00180?ooo`030000003oool0oooo06P0
oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`170?ooo`00A`3oool00`000000oooo
0?ooo`1Y0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0AP3oool004H0oooo00<0
00000?ooo`3oool0JP3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo04D0oooo0015
0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`14
0?ooo`00A@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0A03oool004@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo04<0oooo00130?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0
K@3oool00`000000oooo0?ooo`120?ooo`00@P3oool00`000000oooo0?ooo`1^0?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool0@@3oool00440oooo00<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0400oooo00100?ooo`030000003oool0oooo
0700oooo0P00001a0?ooo`030000003oool0oooo03l0oooo00100?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0o0?ooo`00?`3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0?P3oool003h0oooo00<0
00000?ooo`3oool0LP3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo03d0oooo000n
0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0m
0?ooo`00?@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool0?03oool003`0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo03/0oooo000l0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`0k0?ooo`00>`3oool00`000000oooo0?ooo`1e0?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool0>P3oool003X0oooo00<000000?ooo`3oool0MP3oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo03T0oooo000j0?ooo`030000003oool0oooo
07H0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0i0?ooo`00>@3oool00`000000
oooo0?ooo`1S0?ooo`0:0;md00000000001809cOo`3oool0oono07A8W03Oool0oooo0;md00800000
00<0B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo03P0oooo
000i0?ooo`030000003oool0oooo0680oooo00H0okmd0018W03Oool0okmd0018W03Oool30?ooo`06
0?noM018W=l0oooo0?ooo`3OW4P0M;oo1P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0
oooo03P0oooo000h0?ooo`030000003oool0oooo05`0oooo00<0okmd0000000000000P0000002000
B9`0gooo0=nLB018W=l0oooo0?oo_`1d07@0_ooo1`3oool00`3o_g@0B9cO0?ooo`050?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool0>03oool003P0oooo00<000000?ooo`3oool0H`3o
ool01P3OW4P0M;oo0?ooo`3ooml0W4Qd0;ooo`<0oooo00H0okmd0000M02oool0oooo0=nLB01d_ol6
0?ooo`<00000N03oool00`000000oooo0?ooo`0g0?ooo`00=`3oool00`000000oooo0?ooo`1T0?oo
o`060=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q804P00000000007Bo00L0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0f0?ooo`00=P3oool00`000000oooo0?oo
o`1U0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool00`3ooml0W4Q809cOo`090?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0
IP3oool0102oM00000000000B02Lgol50?ooo`050;md0000000000000000B02Lgol01P3oool00`00
0000oooo0?ooo`1j0?ooo`030000003oool0oooo03D0oooo000e0?ooo`030000003oool0oooo07/0
oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0d0?ooo`00=03oool00`000000oooo
0?ooo`1l0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0=03oool003@0oooo00<0
00000?ooo`3oool0O03oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03<0oooo000c
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0c
0?ooo`00<`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo07d0oooo00<000000?oo
o`3oool0<P3oool003<0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`1m0?ooo`03
0000003oool0oooo0380oooo000b0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0b0?ooo`00<P3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo07h0oooo00<000000?ooo`3oool0<@3oool00340oooo00<000000?ooo`3oool0O`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0300oooo000`0?ooo`030000003oool0oooo
0800oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0`0?ooo`00<03oool00`000000
oooo0?ooo`200?ooo`800000P@3oool00`000000oooo0?ooo`0_0?ooo`00<03oool00`000000oooo
0?ooo`200?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0;`3oool00300oooo00<0
00000?ooo`3oool0P03oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo02l0oooo000_
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0^
0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0840oooo00<000000?oo
o`3oool0;P3oool002h0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`220?ooo`03
0000003oool0oooo02d0oooo000^0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0
PP3oool00`000000oooo0?ooo`0]0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000003o
ool0oooo0880oooo00<000000?ooo`3oool0;@3oool002d0oooo00<000000?ooo`3oool0P`3oool0
0`000000oooo0?ooo`230?ooo`030000003oool0oooo02`0oooo000]0?ooo`030000003oool0oooo
08<0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0/0?ooo`00;@3oool00`000000
oooo0?ooo`230?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0;03oool002`0oooo
00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo02`0oooo
000/0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?oo
o`0[0?ooo`00:`3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0Q@3oool2000008H0oooo00<000000?oo
o`3oool0:P3oool002/0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`250?ooo`03
0000003oool0oooo02X0oooo000Z0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
Q@3oool00`000000oooo0?ooo`0Z0?ooo`00:P3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0:@3oool002X0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo02T0oooo000Y0?ooo`030000003oool0oooo
08L0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0Y0?ooo`00:@3oool00`000000
oooo0?ooo`270?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0:03oool002T0oooo
00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo02P0oooo
000Y0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?oo
o`0X0?ooo`00:@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo08L0oooo00<00000
0?ooo`3oool0:03oool002T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`270?oo
o`030000003oool0oooo02P0oooo000X0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool0R03oool00`000000oooo0?ooo`0W0?ooo`00:03oool00`000000oooo0?ooo`280?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool09`3oool002P0oooo00<000000?ooo`3oool0R03o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo02L0oooo000W0?ooo`030000003oool0
oooo08T0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0W0?ooo`009`3oool00`00
0000oooo0?ooo`290?ooo`800000RP3oool00`000000oooo0?ooo`0V0?ooo`009`3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool09P3oool002L0oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo02H0oooo
000W0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?oo
o`0V0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo08T0oooo00<00000
0?ooo`3oool09P3oool002H0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`2:0?oo
o`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000
003oool0oooo08X0oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool0RP3o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0
oooo08X0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`00
0000oooo0?ooo`2:0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool09@3oool002D0
oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02D0
oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo08/0oooo00<0
00000?ooo`3oool0903oool002D0oooo00D000000?ooo`3ooml0W4Qd0;ooo`0o0?ooo`0:0;md0000
0000001809cOo`3oool0oono07A8W03Oool0oooo0;md0080000000<0B9cO0?ooo`3oool0>`3oool2
000003l0oooo00X0_g@00000000004P0W=oo0?ooo`3ookl0M4RL0=ooo`3oool0_g@00P0000000`18
W=l0oooo0?ooo`0n0?ooo`030000002LB7@0_ooo02@0oooo000U0?ooo`050000003oool0oooO09a8
M02oool0?P3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00H0okmd04RLg`3oool0oooo
0=nLB01d_oll0?ooo`030000003oool0oooo03d0oooo00H0okmd0018W03Oool0okmd0018W03Oool3
0?ooo`060?noM018W=l0oooo0?ooo`3OW4P0M;oo?`3oool00`000000W4Qd0;ooo`0T0?ooo`007P3o
ool00`3o_g@0000000000002000000070018W03Oool000000?ooo`3ooml0W4Qd0;ooo`0g0?ooo`03
0?noM000000000000080000000P004RL0=ooo`3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`L0oooo00<0
okmd04RLg`3oool0>`3oool00`000000oooo0?ooo`0m0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0
_ooo1`3oool00`3o_g@0B9cO0?ooo`0h0?ooo`030?noM000M;l0oooo00<0oooo00<0000009a8M02o
ool0903oool002D0oooo00D000000?ooo`3ooml0W4Qd0;ooo`0n0?ooo`060=nLB01d_ol0oooo0?oo
g`2LB7@0_ooo0`3oool01P3o_g@0001d0;ooo`3oool0gia807Booc80oooo00H0oono07@000000000
00000000M02oool40?ooo`030000003oool0oooo02/0oooo00H0oono07@00000000000000018W03O
ool<0?ooo`060=nLB01d_ol0oooo0?oog`2LB7@0_ooo0`3oool01P3o_g@0001d0;ooo`3oool0gia8
07Booc@0oooo00<0oono07@0000000000P0000000`0007@0_ooo0?ooo`030?ooo`030000002LB7@0
_ooo02@0oooo000U0?ooo`050000002LW;l0oooO09a8M02oool0?P3oool01P3OW4P0B9cO0?ooo`3o
okl0M01d0;ooo`<0oooo00D0oono07A8B01800000000001d_`0b0?ooo`080?oo_`1d000004RL0=oo
o`3ooml0W4P00000M02oool30?ooo`030000003oool0oooo02/0oooo00H0_g@00000M02oool0omnL
04P00018W=l<0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q804P00000
000007Bo03@0oooo00P0oono07@00000B9`0gooo0;md00000000001809cOo`80oooo00D0oooO09bL
_`000000W4Qd0;ooo`0T0?ooo`009@3oool01@000000okmd0000000007@0_ooo03h0oooo00H0okmd
0018W03Oool0okmd0018W03Oool30?ooo`030?oog`2LB4P0W=oo03@0oooo00<0okmd0000B02Lgol0
0P3oool00`3ogi`0B00007Boo`030?ooo`030000003oool0oooo02h0oooo00<0oono07@00018W=l0
303oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00<0oooO09a8B02Lgol0=P3oool0203o
_g@0001809cOo`3ogi`0B4RL0=oOW0180000B9cO0`3oool0103o_g@000000000M02ooolT0?ooo`00
9@3oool01@000000oooo0?oo_`1d07@0_ooo03l0oooo00@0_g@00000000004P0W=oo1@3oool01@2o
M00000000000000004P0W=oo0340oooo00<0gia80000M02oool00P3oool00`3ookl0M00004RLg`03
0?ooo`030000003oool0oooo02d0oooo00@0_g@00000000004P0W=oo3@3oool0102oM00000000000
B02Lgol50?ooo`050;md0000000000000000B02Lgol0<`3oool00`3OW4P0001d0;ooo`020?ooo`03
0?oo_`1d0000B9cO00@0oooo00<0000007@0M02oool0903oool002D0oooo00<000000?ooo`3oool0
P03oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo00<000000?ooo`3oool0
:`3oool0103ookl0M00000000000M;m@0?ooo`030=nLB00007@0_ooo0080oooo00<0oono07@00018
W=l0103oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`200?ooo`030?no
M00004P0W=oo0080oooo00<0omnL04P0001d_ol00`3oool00`000000oooo0?ooo`0[0?ooo`030?no
M00004P0W=oo0540oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`040?ooo`030000
003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo0800oooo00<0oono07@00000M;l00P3o
ool00`2oM000001d0;ooo`030?ooo`030000003oool0oooo02/0oooo00H0okmd0000B02Lgol0gia8
0000B02Lgom>0?ooo`080?oo_`1d000004RL0=ooo`3oool0_g@00018W03Oool40?ooo`030000003o
ool0oooo02@0oooo000U0?ooo`030000003oool0oooo0840oooo00H0oono07@00000000000000000
M02oool40?ooo`030000003oool0oooo02`0oooo00@0_g@0000000000000B9cOD03oool01P3ookl0
M00000000000000004RL0=ooo`D0oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?oo
o`3oool0R`3oool00`000000oooo0?ooo`0S0?ooo`80003oD`3oool20000oa40oooo00<000000?oo
o`3oool0903oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0S0?ooo`H0
003oC`3oool60000o`d0oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0
R`3oool00`000000oooo0?ooo`0T0?ooo`T0003oC03oool90000o`T0oooo00<000000?ooo`3oool0
903oool00;<00000Q`000?l^00000000203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool02`3oool00`0000000?l000000002000001L0o`002`00o`09
0000o`030?oo00000?l0ool004T0ool02@000?l00`3oo`00003o0?ooo`060?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`009@3oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo04@0oooo0P000003003o008000005@3o000:003o
00H0003o1@3oo`000`000?l0ool00?oo00170?oo00H0003o1@3oo`000`000?l0oooo0?ooo`050?oo
o`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo08/0oooo0P000005003o00<0
00004P3o000:003o0080003o0`00o`060?oo00030000o`3oo`00ool004L0ool00P000?l90?oo0003
0000o`3oool0oooo00D0oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0
R`3oool2000000P00?l00`00000?0?l000l00?l01P3oo`000`000?l0ool00?oo001B0?oo00030000
o`3oool0oooo00D0oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0R`3o
ool00`000000oooo0000000:003o00<00000303o000>003o00L0ool000<0003o0?oo003oo`00DP3o
o`000`000?l0oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0
oooo08/0oooo00<000000?ooo`0000003@00o`02000000X0o`003P00o`070?oo00030000o`3oo`00
ool00580ool000<0003o0?ooo`3oool01@3oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`00
0000oooo0?ooo`2;0?ooo`040000003oool0oooo000000h00?l00`0000070?l000h00?l01`3oo`00
0`000?l0ool00?oo001B0?oo00030000o`3oool0oooo00D0oooo00<000000?ooo`3oool0903oool0
02D0oooo00<000000?ooo`3oool0R`3oool010000000oooo0?ooo`00000A003o00<00000103o000>
003o00L0ool000<0003o0?oo003oo`00DP3oo`000`000?l0oooo0?ooo`050?ooo`030000003oool0
oooo02@0oooo000U0?ooo`030000003oool0oooo08/0oooo00@000000?ooo`3oool000005000o`02
00000080o`003P00o`070?oo00030000o`3oo`00ool00580ool000<0003o0?ooo`3oool01@3oool0
0`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`050000003oool0oooo
0?ooo`0000005@00o`03000000d00?l01`3oo`000`000?l0ool00?oo001B0?oo00030000o`3oool0
oooo00D0oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0R`3oool01@00
0000oooo0?ooo`3oool0000001P00?l00`000009003o00P0ool000<0003o0?oo003oo`00DP3oo`00
0`000?l0oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo
08/0oooo00D000000?ooo`3oool0oooo0000000K003o00<000001P00o`080?oo00030000o`3oo`00
ool00580ool000<0003o0?ooo`3oool01@3oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`00
0000oooo0?ooo`2;0?ooo`030000003oool0oooo0080oooo00<00000003o0000o`006`00o`020000
00@00?l0203oo`000`000?l0ool00?oo001B0?oo00030000o`3oool0oooo00D0oooo00<000000?oo
o`3oool0903oool002D0oooo00<000000?ooo`3oool0R`3oool2000000<0oooo00<00000003o0000
o`007@00o`03000000T0ool000<0003o0?oo003oo`00DP3oo`000`000?l0oooo0?ooo`050?ooo`03
0000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0
0P3oool00`0000000?l0003o000P003o00<000001P3oo`000`000?l0ool00?oo001B0?oo00030000
o`3oool0oooo00D0oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0R`3o
ool00`000000oooo0?ooo`030?ooo`0300000000o`000?l001l00?l00`3oo`03000000<0ool000<0
003o0?oo003oo`00DP3oo`000`000?l0oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo000U
0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool00`3oool00`0000000?l0003o000O
003o00H0ool00P0000000`3oo`00003o0?oo001C0?oo00030000o`3oool0oooo00@0oooo00<00000
0?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?oo
o`0300000000o`000?l001d00?l02@3oo`000`000000003o0000001C0?oo00030000o`3oool0oooo
00@0oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool0RP3oool00`000000
oooo0?ooo`040?ooo`0300000000o`000?l001`00?l02`3oo`000`000?l0oooo0000000200000500
ool000<0003o0?ooo`3oool0103oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo
0?ooo`2:0?ooo`030000003oool0oooo00@0oooo00<00000003o0000o`007000o`0;0?oo00030000
o`3oool0oooo0080oooo0`00001=0?oo00030000o`3oool0oooo00@0oooo00<000000?ooo`3oool0
9@3oool002H0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`050?ooo`0300000000
o`000?l001/00?l02`3oo`000`000?l0oooo0?ooo`050?ooo`800000B`3oo`000`000?l0oooo0?oo
o`040?ooo`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0oooo08X0oooo00<00000
0?ooo`3oool01@3oool00`0000000?l0003o000J003o00`0ool000<0003o0?ooo`3oool01`3oool3
000004P0ool000<0003o0?ooo`3oool0103oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`00
0000oooo0?ooo`2:0?ooo`030000003oool0oooo00D0oooo00<00000003o0000o`006P00o`0<0?oo
00030000o`3oool0oooo00X0oooo0`0000150?oo00030000o`3oool0oooo00@0oooo00<000000?oo
o`3oool09@3oool002H0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`060?ooo`03
00000000o`000?l001P00?l03@3oo`000`000?l0oooo0?ooo`0=0?ooo`800000@`3oo`000`000?l0
oooo0?ooo`030?ooo`030000003oool0oooo02H0oooo000W0?ooo`030000003oool0oooo08T0oooo
00<000000?ooo`3oool01P3oool00`0000000?l0003o000G003o00h0ool000<0003o0?ooo`3oool0
3`3oool300000400ool000<0003o0?ooo`3oool00`3oool00`000000oooo0?ooo`0V0?ooo`009`3o
ool00`000000oooo0?ooo`290?ooo`030000003oool0oooo00L0oooo00<00000003o0000o`005@00
o`0?0?oo00030000o`3oool0oooo0180oooo0`00000m0?oo00030000o`3oool0oooo00<0oooo00<0
00000?ooo`3oool09P3oool002L0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`07
0?ooo`0300000000o`000?l001@00?l0403oo`000`000?l0oooo0?ooo`0E0?ooo`<00000>P3oo`00
0`000?l0oooo0?ooo`030?ooo`030000003oool0oooo02H0oooo000W0?ooo`030000003oool0oooo
08T0oooo0P0000080?ooo`0300000000o`000?l001@00?l0403oo`000`000?l0oooo0?ooo`0H0?oo
o`800000>03oo`000`000?l0oooo0?ooo`030?ooo`030000003oool0oooo02H0oooo000W0?ooo`03
0000003oool0oooo08T0oooo00<000000?ooo`3oool0203oool00`0000000?l0003o000B003o0140
ool000<0003o0?ooo`3oool06P3oool3000003D0ool000<0003o0?ooo`3oool00P3oool00`000000
oooo0?ooo`0W0?ooo`00:03oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo
00<00000003o0000o`004@00o`0B0?oo00030000o`3oool0oooo01d0oooo0`00000b0?oo00030000
o`3oool0oooo0080oooo00<000000?ooo`3oool09`3oool002P0oooo00<000000?ooo`3oool0R03o
ool00`000000oooo0?ooo`080?ooo`0300000000o`000?l001000?l04`3oo`000`000?l0oooo0?oo
o`0P0?ooo`<00000;`3oo`000`000?l0oooo0?ooo`020?ooo`030000003oool0oooo02L0oooo000X
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool02@3oool00`0000000?l0003o000>
003o01@0ool000<0003o0?ooo`3oool08`3oool2000002d0ool000<0003o0?ooo`3oool00P3oool0
0`000000oooo0?ooo`0W0?ooo`00:@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo
00T0oooo00<00000003o0000o`003@00o`0E0?oo00030000o`3oool0oooo02D0oooo0`00000Z0?oo
00050000o`3oool0oooo0?ooo`000000:P3oool002T0oooo00<000000?ooo`3oool0Q`3oool00`00
0000oooo0?ooo`090?ooo`0300000000o`000?l000/00?l05`3oo`000`000?l0oooo0?ooo`0X0?oo
o`<000009`3oo`001@000?l0oooo0?ooo`3oool0000002X0oooo000Y0?ooo`030000003oool0oooo
08L0oooo00<000000?ooo`3oool02P3oool00`0000000?l0003o0009003o01P0ool000<0003o0?oo
o`3oool0:`3oool3000002@0ool000D0003o0?ooo`3oool0oooo0000000Z0?ooo`00:@3oool00`00
0000oooo0?ooo`270?ooo`030000003oool0oooo00X0oooo00<00000003o0000o`001`00o`0J0?oo
00030000o`3oool0oooo02h0oooo0P00000R0?oo00050000o`3oool0oooo0?ooo`000000:P3oool0
02T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0;0?ooo`0300000000o`000?l0
00@00?l0703oo`000`000?l0oooo0?ooo`0`0?ooo`<000007`3oo`001@000?l0oooo0?ooo`3oool0
000002X0oooo000Y0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool02`3oool00`00
00000?l0003o0003003o01d0ool000<0003o0?ooo`3oool0<`3oool3000001T0ool00P000?l00`3o
o`00003o0?ooo`020000ob/0oooo000Z0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool02`3oool0100000000?l0003o0000o`0O0?oo00030000o`3oool0oooo03H0oooo0`00000F0?oo
00L0003o:`3oool002X0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oo`00ool001l0ool000<0003o0?ooo`3oool0>@3oool2000001D0ool01@000?l00`000000
oooo0?ooo`0Y0?ooo`00:P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00`0oooo
00<000000?oo003oo`007`3oo`000`000?l0oooo0?ooo`0k0?ooo`<000004P3oo`050000ob`0oooo
000[0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0303oool00`000000ool00?oo
000O0?oo00030000o`3oool0oooo03h0oooo0`00000?0?oo00D0003o;03oool002/0oooo00<00000
0?ooo`3oool0Q@3oool2000000h0oooo00<000000?oo003oo`007P3oo`000`000?l0oooo0?ooo`11
0?ooo`8000003@3oo`050000ob`0oooo000[0?ooo`030000003oool0oooo08D0oooo00<000000?oo
o`3oool03@3oool00`000000ool00?oo000N0?oo00030000o`3oool0oooo04<0oooo0`00000;0?oo
00<0003o00<000000?ooo`3oool0:P3oool002`0oooo00<000000?ooo`3oool0Q03oool00`000000
oooo0?ooo`0=0?ooo`030000003oo`00ool001h0ool000<0003o0?ooo`3oool0AP3oool3000000P0
ool00`000?l]0?ooo`00;03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo00h0oooo
00<000000?oo003oo`007@3oo`000`000?l0oooo0?ooo`190?ooo`<000001@3oo`030000obd0oooo
000]0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool03P3oool00`000000ool00?oo
000M0?oo00030000o`3oool0oooo04`0oooo0P0000030?oo00<0003o;@3oool002d0oooo00<00000
0?ooo`3oool0P`3oool00`000000oooo0?ooo`0?0?ooo`030000003oo`00ool001`0ool000<0003o
0?ooo`3oool0CP3oool3000000030?oo00000?l0oooo02d0oooo000]0?ooo`030000003oool0oooo
08<0oooo00<000000?ooo`3oool03`3oool00`000000ool00?oo000L0?oo00030000o`3oool0oooo
0540oooo00<000000000o`3oool0;@3oool002h0oooo00<000000?ooo`3oool0PP3oool00`000000
oooo0?ooo`0?0?ooo`030000003oo`00ool001`0ool000<0003o0?ooo`3oool0D@3oool00`000000
oooo0?ooo`0]0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0100oooo
00<000000?oo003oo`006`3oo`000`000?l0oooo0?ooo`1A0?ooo`030000003oool0oooo02d0oooo
000^0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0403oool00`000000ool00?oo
000K0?oo00030000o`3oool0oooo0540oooo00<000000?ooo`3oool0;@3oool002h0oooo00<00000
0?ooo`3oool0PP3oool00`000000oooo0?ooo`0@0?ooo`030000003oo`00ool001/0ool000<0003o
0?ooo`3oool0D03oool00`000000oooo0?ooo`0^0?ooo`00;`3oool00`000000oooo0?ooo`210?oo
o`030000003oool0oooo0140oooo00<000000?oo003oo`006P3oo`000`000?l0oooo0?ooo`1>0?oo
o`030?oo_`1d000000000300oooo000`0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3o
ool04@3oool00`000000ool00?oo000J0?oo00030000o`3oool0oooo04h0oooo00<0oono00000018
W=l0<03oool00300oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`0A0?ooo`030000
003oo`00ool001X0ool000<0003o0?ooo`3oool0CP3oool00`3ookl0000004RLg`0`0?ooo`00<03o
ool00`000000oooo0?ooo`200?ooo`8000004`3oool00`000000ool00?oo000I0?oo00030000o`3o
ool0oooo04h0oooo00<0oono0000000000000P0000000`00M;l0oooo0?ooo`0[0?ooo`00<03oool0
0`000000oooo0?ooo`200?ooo`030000003oool0oooo0180oooo00<000000?oo003oo`006@3oo`00
0`000?l0oooo0?ooo`1>0?ooo`070000001d0000B9cO0?ooo`3ogi`0B00004RLg`0/0?ooo`00<@3o
ool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo01<0oooo00<000000?oo003oo`00603o
o`000`000?l0oooo0?ooo`1>0?ooo`070000001d0000B9cO0?ooo`3ookl0M000001d_`0/0?ooo`00
<P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo01<0oooo00<000000?oo003oo`00
603oo`000`000?l0oooo0?ooo`1=0?ooo`080000003ookl0M00004RLg`3oool0omnL04P00018W=l/
0?ooo`00<P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo01<0oooo00<000000?oo
003oo`00603oo`000`000?l0oooo0?ooo`1<0?ooo`040000003oool0oono07@000<0000000<004RL
0=ooo`3oool0:`3oool003<0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0D0?oo
o`030000003oo`00ool001L0ool000<0003o0?ooo`3oool0C03oool00`000000oooo0?ooo`0b0?oo
o`00<`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo01@0oooo00<000000?oo003o
o`005`3oo`000`000?l0oooo0?ooo`1<0?ooo`030000003oool0oooo0380oooo000c0?ooo`030000
003oool0oooo07d0oooo00<000000?ooo`3oool0503oool00`000000ool00?oo000G0?oo00030000
o`3oool0oooo04/0oooo00<000000?ooo`3oool0<`3oool003@0oooo00<000000?ooo`3oool0O03o
ool00`000000oooo0?ooo`0E0?ooo`030000003oo`00ool001H0ool000<0003o0?ooo`3oool0B`3o
ool00`000000oooo0?ooo`0c0?ooo`00=03oool00`000000oooo0?ooo`1l0?ooo`030000003oool0
oooo01D0oooo00<000000?oo003oo`005P3oo`000`000?l0oooo0?ooo`1:0?ooo`030000003oool0
oooo03@0oooo000e0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool05@3oool00`00
0000ool00?oo000F0?oo00030000o`3oool0oooo04X0oooo00<000000?ooo`3oool0=03oool003H0
oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0F0?ooo`030000003oo`00ool001D0
ool000<0003o0?ooo`3oool0B@3oool00`000000oooo0?ooo`0e0?ooo`00=P3oool00`000000oooo
0?ooo`1V0?ooo`0:0;md00000000001809cOo`3oool0oono07A8W03Oool0oooo0;md0080000000<0
B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`030000003oo`00ool001D0ool000<0
003o0?ooo`3oool0B03oool00`000000oooo0?ooo`0f0?ooo`00=`3oool00`000000oooo0?ooo`1T
0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool01P3o_g@0B9cO0?ooo`3oool0gia807Bo
o`H0oooo00<000000?ooo`3oool05`3oool00`000000ool00?oo000D0?oo00030000o`3oool0oooo
04P0oooo00<000000?ooo`3oool0=P3oool003P0oooo00<000000?ooo`3oool0H`3oool01P3OW4P0
B9cO0?ooo`3ookl0M01d0;ooo`L0oooo00<0okmd04RLg`3oool01@3oool3000001L0oooo00<00000
0?oo003oo`00503oo`000`000?l0oooo0?ooo`170?ooo`030000003oool0oooo03L0oooo000h0?oo
o`030000003oool0oooo06<0oooo00H0gia807Boo`3oool0oooO09a8M02oool30?ooo`060?noM000
07@0_ooo0?ooo`3OW4P0M;oo1P3oool00`000000oooo0?ooo`0G0?ooo`030000003oo`00ool001@0
ool000<0003o0?ooo`3oool0AP3oool00`000000oooo0?ooo`0h0?ooo`00>@3oool00`000000oooo
0?ooo`1R0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q804P000000000
07Bo00L0oooo00<000000?ooo`3oool0603oool00`000000ool00?oo000C0?oo00030000o`3oool0
oooo04H0oooo00<000000?ooo`3oool0>03oool003T0oooo00<000000?ooo`3oool0HP3oool01P3o
_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00<0oooO09a8B02Lgol02@3oool00`000000oooo0?oo
o`0H0?ooo`030000003oo`00ool001<0ool000<0003o0?ooo`3oool0AP3oool00`000000oooo0?oo
o`0h0?ooo`00>P3oool00`000000oooo0?ooo`1R0?ooo`040;md00000000001809cOo`D0oooo00D0
_g@0000000000000001809cOo`060?ooo`030000003oool0oooo01P0oooo00<000000?oo003oo`00
4`3oo`000`000?l0oooo0?ooo`150?ooo`030000003oool0oooo03T0oooo000j0?ooo`030000003o
ool0oooo07H0oooo00<000000?ooo`3oool06@3oool00`000000ool00?oo000B0?oo00030000o`3o
ool0oooo04D0oooo00<000000?ooo`3oool0>@3oool003/0oooo00<000000?ooo`3oool0M@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oo`00ool00180ool000<0003o0?ooo`3oool0A03oool0
0`000000oooo0?ooo`0j0?ooo`00?03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
01X0oooo00<000000?oo003oo`004@3oo`000`000?l0oooo0?ooo`130?ooo`030000003oool0oooo
03/0oooo000l0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool06P3oool00`000000
ool00?oo000A0?oo00030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0>`3oool003d0oooo
00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0J0?ooo`030000003oo`00ool00140ool0
00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`0l0?ooo`00?P3oool00`000000oooo0?oo
o`1b0?ooo`030000003oool0oooo01/0oooo00<000000?oo003oo`00403oo`000`000?l0oooo0?oo
o`110?ooo`030000003oool0oooo03d0oooo000n0?ooo`030000003oool0oooo0780oooo00<00000
0?ooo`3oool06`3oool00`000000ool00?oo000@0?oo00030000o`3oool0oooo0440oooo00<00000
0?ooo`3oool0?@3oool003l0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oo`00ool00100ool000<0003o0?ooo`3oool0@03oool00`000000oooo0?ooo`0n0?oo
o`00@03oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo01`0oooo00<000000?oo003o
o`003`3oo`000`000?l0oooo0?ooo`0o0?ooo`030000003oool0oooo03l0oooo00100?ooo`030000
003oool0oooo0700oooo0P00000M0?ooo`030000003oo`00ool000l0ool000<0003o0?ooo`3oool0
?`3oool00`000000oooo0?ooo`0o0?ooo`00@@3oool00`000000oooo0?ooo`1_0?ooo`030000003o
ool0oooo01`0oooo00<000000?oo003oo`003`3oo`000`000?l0oooo0?ooo`0n0?ooo`030000003o
ool0oooo0400oooo00120?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool07@3oool0
0`000000ool00?oo000>0?oo00030000o`3oool0oooo03d0oooo00<000000?ooo`3oool0@@3oool0
04<0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0M0?ooo`030000003oo`00ool0
00h0ool000<0003o0?ooo`3oool0?03oool00`000000oooo0?ooo`120?ooo`00A03oool00`000000
oooo0?ooo`1/0?ooo`030000003oool0oooo01h0oooo00<000000?oo003oo`003@3oo`000`000?l0
oooo0?ooo`0k0?ooo`030000003oool0oooo04<0oooo00150?ooo`030000003oool0oooo06/0oooo
00<000000?ooo`3oool07P3oool00`000000ool00?oo000=0?oo00030000o`3oool0oooo03X0oooo
00<000000?ooo`3oool0A03oool004D0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?oo
o`0N0?ooo`030000003oo`00ool000d0ool000<0003o0?ooo`3oool0>P3oool00`000000oooo0?oo
o`140?ooo`00AP3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo01l0oooo00<00000
0?oo003oo`00303oo`000`000?l0oooo0?ooo`0i0?ooo`030000003oool0oooo04D0oooo00170?oo
o`030000003oool0oooo06T0oooo00<000000?ooo`3oool07`3oool00`000000ool00?oo000<0?oo
00030000o`3oool0oooo03P0oooo00<000000?ooo`3oool0AP3oool004P0oooo00<000000?ooo`3o
ool0J03oool00`000000oooo0?ooo`0O0?ooo`030000003oo`00ool000`0ool000<0003o0?ooo`3o
ool0=`3oool00`000000oooo0?ooo`170?ooo`00B@3oool00`000000oooo0?ooo`1W0?ooo`030000
003oool0oooo0200oooo00<000000?oo003oo`002`3oo`000`000?l0oooo0?ooo`0f0?ooo`030000
003oool0oooo04P0oooo001:0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0803o
ool00`000000ool00?oo000;0?oo00030000o`3oool0oooo03D0oooo00<000000?ooo`3oool0B@3o
ool004/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0P0?ooo`030000003oo`00
ool000/0ool000<0003o0?ooo`3oool0=03oool00`000000oooo0?ooo`1:0?ooo`00C03oool00`00
0000oooo0?ooo`1T0?ooo`030000003oool0oooo0240oooo00<000000?oo003oo`002P3oo`000`00
0?l0oooo0?ooo`0c0?ooo`030000003oool0oooo04/0oooo001=0?ooo`030000003oool0oooo06<0
oooo00<000000?ooo`3oool08@3oool00`000000ool00?oo000:0?oo00030000o`3oool0oooo0380
oooo00<000000?ooo`3oool0C03oool004h0oooo00<000000?ooo`3oool0HP3oool2000002<0oooo
00<000000?oo003oo`002@3oo`000`000?l0oooo0?ooo`0a0?ooo`030000003oool0oooo04d0oooo
001?0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool08P3oool00`000000ool00?oo
00090?oo00030000o`3oool0oooo0300oooo00<000000?ooo`3oool0CP3oool00500oooo00<00000
0?ooo`3oool0H03oool00`000000oooo0?ooo`0R0?ooo`030000003oo`00ool000T0ool000<0003o
0?ooo`3oool0;`3oool00`000000oooo0?ooo`1?0?ooo`00D@3oool00`000000oooo0?ooo`1O0?oo
o`030000003oool0oooo02<0oooo00<000000?oo003oo`00203oo`000`000?l0oooo0?ooo`0^0?oo
o`030000003oool0oooo0500oooo001B0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3o
ool08`3oool00`000000ool00?oo00080?oo00030000o`3oool0oooo02d0oooo00<000000?ooo`3o
ool0D@3oool005<0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0S0?ooo`030000
003oo`00ool000P0ool000<0003o0?ooo`3oool0;03oool00`000000oooo0?ooo`1B0?ooo`00E03o
ool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo02@0oooo00<000000?oo003oo`001`3o
o`000`000?l0oooo0?ooo`0[0?ooo`030000003oool0oooo05<0oooo001E0?ooo`030000003oool0
oooo05/0oooo00<000000?ooo`3oool0903oool00`000000ool00?oo00070?oo00030000o`3oool0
oooo02X0oooo00<000000?ooo`3oool0E03oool005H0oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oo`00ool000L0ool000<0003o0?ooo`3oool0:@3oool00`00
0000oooo0?ooo`1E0?ooo`00E`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02D0
oooo00<000000?oo003oo`001P3oo`000`000?l0oooo0?ooo`0X0?ooo`030000003oool0oooo05H0
oooo001H0?ooo`800000F@3oool00`000000oooo0?ooo`0U0?ooo`030000003oo`00ool000H0ool0
00<0003o0?ooo`3oool09P3oool2000005T0oooo001J0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool09P3oool00`000000ool00?oo00050?oo00030000o`3oool0oooo02D0oooo00<0
00000?ooo`3oool0F@3oool005/0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0V
0?ooo`030000003oo`00ool000D0ool000<0003o0?ooo`3oool0903oool00`000000oooo0?ooo`1J
0?ooo`00G03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo02H0oooo00<000000?oo
003oo`001@3oo`000`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo05/0oooo001M0?ooo`03
0000003oool0oooo05<0oooo0P00000X0?ooo`030000003oo`00ool000@0ool000<0003o0?ooo`3o
ool08P3oool00`000000oooo0?ooo`1L0?ooo`00GP3oool2000005<0oooo00<000000?ooo`3oool0
9`3oool00`000000ool00?oo00040?oo00030000o`3oool0oooo0200oooo0P00001O0?ooo`00H03o
ool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo02L0oooo00<000000?oo003oo`00103o
o`000`000?l0oooo0?ooo`0O0?ooo`030000003oool0oooo05l0oooo001Q0?ooo`800000D03oool0
0`000000oooo0?ooo`0X0?ooo`030000003oo`00ool000<0ool000<0003o0?ooo`3oool07@3oool2
00000680oooo001S0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0:03oool00`00
0000ool00?oo00030?oo00030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0HP3oool006@0
oooo0P00001=0?ooo`030000003oool0oooo02T0oooo00<000000?oo003oo`000P3oo`000`000?l0
oooo0?ooo`0J0?ooo`800000I@3oool006H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oo`00ool00080ool000<0003o0?ooo`3oool06@3oool00`000000oooo
0?ooo`1U0?ooo`00I`3oool2000004X0oooo00<000000?ooo`3oool0:@3oool00`000000ool00?oo
00020?oo00030000o`3oool0oooo01L0oooo0P00001X0?ooo`00J@3oool2000004P0oooo00<00000
0?ooo`3oool0:P3oool01@000000ool00?oo003oo`00003o01L0oooo0P00001Z0?ooo`00J`3oool2
000004H0oooo00<000000?ooo`3oool0:P3oool01`000000003o0000o`3oo`00003o0?ooo`000?l0
4`3oool2000006`0oooo001]0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0:P3o
ool00`000000003o0000o`040000oa80oooo00<000000?ooo`3oool0K03oool006h0oooo0P000013
0?ooo`030000003oool0oooo02/0oooo00<000000000o`000?l00`000?l@0?ooo`800000K`3oool0
0700oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0[0?ooo`03000000000?l0003o
0080003o403oool00`000000oooo0?ooo`1_0?ooo`00L@3oool200000400oooo00<000000?ooo`3o
ool0:`3oool00`000000003o0000o`020000o`h0oooo0P00001b0?ooo`00L`3oool3000003d0oooo
0P00000]0?ooo`@0003o2`3oool3000007@0oooo001f0?ooo`800000>`3oool00`000000oooo0?oo
o`0/0?ooo`04000000000?l0003o0000o`T0oooo0P00001g0?ooo`00N03oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo02d0oooo0`000?l80?ooo`030000003oool0oooo07L0oooo001i
0?ooo`@00000=P3oool00`000000oooo0?ooo`0]0?ooo`<0003o103oool4000007X0oooo001m0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool0;@3oool20000o`@0oooo00<000000?oo
o`3oool0O03oool007h0oooo1000000a0?ooo`030000003oool0oooo02h0oooo00<0003o00000000
00000P00001o0?ooo`00PP3oool3000002h0oooo00<000000?ooo`3oool0;03oool2000000030000
o`3oool0oooo0840oooo00250?ooo`800000;03oool00`000000oooo0?ooo`0Z0?ooo`800000QP3o
ool008L0oooo0`00000Y0?ooo`030000003oool0oooo02L0oooo0`0000280?ooo`00RP3oool30000
02H0oooo00<000000?ooo`3oool0903oool3000008/0oooo002=0?ooo`H00000803oool00`000000
oooo0?ooo`0N0?ooo`H00000SP3oool009<0oooo0`00000M0?ooo`030000003oool0oooo01/0oooo
0`00000<0?ooo`070?oOW0180000M;oo0?ooo`3ookl0M000001d_`210?ooo`00UP3oool5000000d0
oooo00<0oooO09a8M02oool0203oool00`000000oooo0?ooo`0F0?ooo`D000003`3oool01`3ogi`0
B00007Boo`3oool0gia80000B02Lgol0P@3oool009/0oooo1`0000060?ooo`030?oog`2LB7@0_ooo
00P0oooo00<000000?ooo`3oool03`3oool7000001@0oooo00H0omnL04P0001d_ol0omnL04P00018
W=n20?ooo`00XP3ooolS000001/0oooo00<0omnL04P0000000000P0000000`18W=l0oooo0?ooo`20
0?ooo`00Z03oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo02X0oooo00L0omnL04P0
001d_ol0oooo0?noM0000000M;oo0840oooo002V0?ooo`050?oog`2LW;l0oooO09a8M02oool0203o
ool00`000000oooo0?ooo`0Z0?ooo`070?oOW0180000M;oo0?ooo`3ogi`0B00004RLg`210?ooo`00
Y`3oool0103o_g@000000000M02oool80?ooo`030000003oool0oooo02X0oooo00L0omnL04P0001d
_ol0oooo0?noM0000000M;oo0840oooo002X0?ooo`030?oo_`1d07@0_ooo00P0oooo00<000000?oo
o`3oool0:P3oool00`3ogi`0B0000000000200000003001d_`3oool0oooo0800oooo002c0?ooo`03
0000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003o
ool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo
0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?oo
o`030000003oool0oooo0;80oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?ooo`3oool0
/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo
00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<00000
0?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3o
ool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo0P00002c0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?oo
o`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?oo
o`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3o
ool00`000000oooo0?ooo`2b0?ooo`00\
\>"],
  ImageRangeCache->{{{112.438, 370.625}, {345.813, 87.625}} -> {-2.35746, \
-0.404754, 0.00878441, 0.00878441}},
  CellTags->"figura2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\({idFondamentale} = {cos[\[Alpha]_]\^2 + 
              sen[\[Alpha]_]\^2 \[RuleDelayed] 1};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Seno di un angolo complementare", "Subsubsection"],

Cell[TextData[{
  "Sia ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " l'ampiezza di un angolo orientato. Questo individua nella circonferenza \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " con centro nell'origine ",
  Cell[BoxData[
      \(TraditionalForm\`O\)]],
  " di un sistema cartesiano il triangolo ",
  Cell[BoxData[
      FormBox[
        StyleBox["OQP",
          FontSlant->"Italic"], TraditionalForm]]],
  ". In ",
  ButtonBox["fig. 2",
    ButtonData:>"figura2",
    ButtonStyle->"Hyperlink"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ", per comodit\[AGrave], appare un angolo compreso nel I quadrante (in \
rosso) ma le relazioni che dedurremo si dimostrano valide qualsiasi sia il \
suo valore. L'angolo complementare, di ampiezza ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/2 - \[Alpha]\)]],
  " che si associa ad ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " definisce a sua volta il triangolo ",
  Cell[BoxData[
      FormBox[
        StyleBox["OSR",
          FontSlant->"Italic"], TraditionalForm]]],
  ": siamo interessati ad esprimere le funzioni goniometriche di quest'ultimo \
in termini di quelle dell'angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ". Dalla definizione discende quindi che"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sen[\[Pi]/2 - \[Alpha]] \[Equal] SR/OR\)], "Input"],

Cell[BoxData[
    \(sen[\[Pi]\/2 - \[Alpha]] \[Equal] SR\/OR\)], "Output"]
}, Closed]],

Cell[TextData[{
  "ma la congruenza tra i triangoli ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[EmptyUpTriangle]", 
              StyleBox["OQP",
                FontSlant->"Italic"]}]], "\[TildeFullEqual]", 
          RowBox[{
            StyleBox["\<\"\"\>",
              "\n\"MR\""], 
            StyleBox[
              RowBox[{"\[EmptyUpTriangle]", 
                StyleBox["OSR",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " comporta che si abbia, anche in segno, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["SR",
            FontSlant->"Italic"], 
          StyleBox["=",
            FontSlant->"Plain"], 
          StyleBox["OQ",
            FontSlant->"Italic"]}], TraditionalForm]]],
  " e ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["OR",
            FontSlant->"Italic"], 
          StyleBox["=",
            FontSlant->"Plain"], 
          StyleBox["OP",
            FontSlant->"Italic"]}], TraditionalForm]]],
  ". Pertanto sostituendo queste uguaglianze nella precedente"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {SR \[Rule] OQ, OR \[Rule] OP}\)], "Input"],

Cell[BoxData[
    \(sen[\[Pi]\/2 - \[Alpha]] \[Equal] OQ\/OP\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Ma per la definizione delle funzioni goniometriche relative all'angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ", in particolare quella del coseno, risulta che"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. defs\)], "Input"],

Cell[BoxData[
    \(sen[\[Pi]\/2 - \[Alpha]] \[Equal] cos[\[Alpha]]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(senCompl = toRule[%]\)], "Input"],

Cell[BoxData[
    \(sen[\[Pi]\/2 - \[Alpha]] \[RuleDelayed] cos[\[Alpha]]\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\({idFondamentale, 
          senCompl} = {cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 
            1, sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] 
            cos[\[Alpha]]};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Coseno di un angolo complementare", "Subsubsection"],

Cell[TextData[{
  "Procediamo nello stesso modo per determinare ",
  Cell[BoxData[
      \(TraditionalForm\`cos[\[Pi]\/2 - \[Alpha]]\)]],
  " in termini di funzioni dell'angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cos[\[Pi]/2 - \[Alpha]] \[Equal] OS/OR\)], "Input"],

Cell[BoxData[
    \(cos[\[Pi]\/2 - \[Alpha]] \[Equal] OS\/OR\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Osservata la validit\[AGrave] di ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["OS",
            FontSlant->"Italic"], 
          StyleBox["=",
            FontSlant->"Plain"], 
          StyleBox["QP",
            FontSlant->"Italic"]}], TraditionalForm]]],
  " (",
  ButtonBox["fig.2",
    ButtonData:>"figura2",
    ButtonStyle->"Hyperlink"],
  ") discende"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {OS \[Rule] QP, OR \[Rule] OP}\)], "Input"],

Cell[BoxData[
    \(cos[\[Pi]\/2 - \[Alpha]] \[Equal] QP\/OP\)], "Output"]
}, Closed]],

Cell[TextData[{
  "e utilizzando la definzione di ",
  Cell[BoxData[
      \(TraditionalForm\`sen[\[Alpha]]\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. defs\)], "Input"],

Cell[BoxData[
    \(cos[\[Pi]\/2 - \[Alpha]] \[Equal] sen[\[Alpha]]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cosCompl = toRule[%]\)], "Input"],

Cell[BoxData[
    \(cos[\[Pi]\/2 - \[Alpha]] \[RuleDelayed] sen[\[Alpha]]\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\({idFondamentale, senCompl, 
          cosCompl} = {cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 
            1, sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] 
            sen[\[Alpha]]};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Tangente di un angolo complementare", "Subsubsection"],

Cell["\<\
Infine, la definizione di tangente per l'angolo complementare comporta \
l'uguaglianza\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tan[\[Pi]/2 - \[Alpha]] == SR/OS\)], "Input"],

Cell[BoxData[
    \(tan[\[Pi]\/2 - \[Alpha]] \[Equal] SR\/OS\)], "Output"]
}, Closed]],

Cell[TextData[{
  "ma la congruenza dei triangoli gi\[AGrave] esposta assicura che ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["SR",
            FontSlant->"Italic"], 
          StyleBox["=",
            FontSlant->"Plain"], 
          StyleBox["OQ",
            FontSlant->"Italic"]}], TraditionalForm]]],
  " e ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["OS",
            FontSlant->"Italic"], 
          StyleBox["=",
            FontSlant->"Plain"], 
          StyleBox["QP",
            FontSlant->"Italic"]}], TraditionalForm]]],
  " (",
  ButtonBox["fig. 2",
    ButtonData:>"figura2",
    ButtonStyle->"Hyperlink"],
  ") per cui"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {SR \[Rule] OQ, OS \[Rule] QP}\)], "Input"],

Cell[BoxData[
    \(tan[\[Pi]\/2 - \[Alpha]] \[Equal] OQ\/QP\)], "Output"]
}, Closed]],

Cell["che \[EGrave] equivalente alla", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(%\ QP/OQ\)], "Input"],

Cell[BoxData[
    \(\(QP\ tan[\[Pi]\/2 - \[Alpha]]\)\/OQ \[Equal] 1\)], "Output"]
}, Closed]],

Cell["Per la definizione di tangente risulta anche", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. defs\)], "Input"],

Cell[BoxData[
    \(tan[\[Pi]\/2 - \[Alpha]]\ tan[\[Alpha]] \[Equal] 1\)], "Output"]
}, Closed]],

Cell[TextData[{
  "da cui, dividendo per ",
  Cell[BoxData[
      \(TraditionalForm\`tan[\[Alpha]]\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(%/tan[\[Alpha]]\)], "Input"],

Cell[BoxData[
    \(tan[\[Pi]\/2 - \[Alpha]] \[Equal] 1\/tan[\[Alpha]]\)], "Output"]
}, Closed]],

Cell["che si pu\[OGrave] riscrivere nei due modi seguenti", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. id3\)], "Input"],

Cell[BoxData[
    \(tan[\[Pi]\/2 - \[Alpha]] \[Equal] cot[\[Alpha]]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. id2\)], "Input"],

Cell[BoxData[
    \(tan[\[Pi]\/2 - \[Alpha]] \[Equal] 
      cos[\[Alpha]]\/sen[\[Alpha]]\)], "Output"]
}, Closed]],

Cell["In alternativa", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tan[\[Pi]/2 - \[Alpha]] \[Equal] 
      sen[\[Pi]/2 - \[Alpha]]/cos[\[Pi]/2 - \[Alpha]]\)], "Input"],

Cell[BoxData[
    \(tan[\[Pi]\/2 - \[Alpha]] \[Equal] 
      sen[\[Pi]\/2 - \[Alpha]]\/cos[\[Pi]\/2 - \[Alpha]]\)], "Output"]
}, Closed]],

Cell["\<\
per cui sfruttando le identit\[AGrave] gi\[AGrave] dimostrate per seno e \
coseno, riesce\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(% /. senCompl\) /. cosCompl\)], "Input"],

Cell[BoxData[
    \(tan[\[Pi]\/2 - \[Alpha]] \[Equal] 
      cos[\[Alpha]]\/sen[\[Alpha]]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tanCompl = toRule[%]\)], "Input"],

Cell[BoxData[
    \(tan[\[Pi]\/2 - \[Alpha]] \[RuleDelayed] 
      cos[\[Alpha]]\/sen[\[Alpha]]\)], "Output"]
}, Closed]],

Cell["Abbiamo pertanto dimostrato le identit\[AGrave]:", "Text"],

Cell[BoxData[{
    \(TraditionalForm\`Angoli\ complementari\), "\[IndentingNewLine]", 
    \(TraditionalForm\`sen(\[Pi]\/2 - \[Alpha]) = 
      cos(\[Alpha])\), "\[IndentingNewLine]", 
    \(TraditionalForm\`cos(\[Pi]\/2 - \[Alpha]) = 
      sen(\[Alpha])\), "\[IndentingNewLine]", 
    \(TraditionalForm\`tan(\[Pi]\/2 - \[Alpha]) = \(cot(\[Alpha]) = 
        1\/\(tan(\[Alpha])\)\)\)}], "Definition",
  FontFamily->"Courier"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Angoli che differiscono per un angolo retto", "Subsection"],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\({idFondamentale, senCompl, cosCompl, 
          tanCompl} = {cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 
            1, sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          tan[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] 
            cot[\[Alpha]]};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[{
    \(\[Alpha] = 20  Degree; \[Beta] = \[Pi]/2 + \[Alpha];\), "\n", 
    \(pP = {Cos[\[Alpha]], Sin[\[Alpha]]}; pQ = {Cos[\[Alpha]], 0}; 
    origine = {0, 0}; pR = {Cos[\[Beta]], Sin[\[Beta]]}; 
    pS = {Cos[\[Beta]], 0};\), "\n", 
    \(Show[
      Graphics[{Circle[origine, 1], Line[{{\(-1.2\), 0}, {1.2, 0}}], 
          Line[{{0, \(-1.2\)}, {0, 1.2}}], 
          Line[{pP, origine, pR}]}], \[IndentingNewLine]Graphics[{colBlu, 
          Arrow[origine, pQ, stileVet], 
          Arrow[pQ, pP, stileVet]}], \[IndentingNewLine]Graphics[{colBlu, 
          Arrow[origine, pS, stileVet], 
          Arrow[pS, pR, 
            stileVet]}], \[IndentingNewLine]Graphics[{Text["\<O\>", 
            origine, {1, 1}, TextStyle \[Rule] stileTesto], 
          Text["\<Q\>", pQ, {0, 1}, TextStyle \[Rule] stileTesto], 
          Text["\<P\>", pP, {0, \(-1\)}, TextStyle \[Rule] stileTesto], 
          Text["\<S\>", pS, {0, 1}, TextStyle \[Rule] stileTesto], 
          Text["\<R\>", pR, {0, \(-1\)}, TextStyle \[Rule] stileTesto]}], 
      Prolog -> {{colGiallo, Polygon[{origine, pQ, pP}], 
            Polygon[{origine, pS, pR}]}, {colVerde, 
            Disk[origine,  .3, {0, \[Beta]}]}, {colRosso, 
            Disk[origine,  .2, {0, \[Alpha]}]}}, 
      AspectRatio \[Rule] Automatic, Axes \[Rule] True]; 
    Clear[\[Alpha], \[Beta]];;\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Grafico", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.396825 0.5 0.396825 [
[.10317 .4875 -6.96875 -10.9375 ]
[.10317 .4875 6.96875 0 ]
[.30159 .4875 -10.3125 -10.9375 ]
[.30159 .4875 10.3125 0 ]
[.69841 .4875 -7.5625 -10.9375 ]
[.69841 .4875 7.5625 0 ]
[.89683 .4875 -4.21875 -10.9375 ]
[.89683 .4875 4.21875 0 ]
[.4875 .10317 -13.9375 -5.46875 ]
[.4875 .10317 0 5.46875 ]
[.4875 .30159 -20.625 -5.46875 ]
[.4875 .30159 0 5.46875 ]
[.4875 .69841 -15.125 -5.46875 ]
[.4875 .69841 0 5.46875 ]
[.4875 .89683 -8.4375 -5.46875 ]
[.4875 .89683 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .5 m
.10317 .50625 L
s
gsave
.10317 .4875 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.30159 .5 m
.30159 .50625 L
s
gsave
.30159 .4875 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.69841 .5 m
.69841 .50625 L
s
gsave
.69841 .4875 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.89683 .5 m
.89683 .50625 L
s
gsave
.89683 .4875 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.14286 .5 m
.14286 .50375 L
s
.18254 .5 m
.18254 .50375 L
s
.22222 .5 m
.22222 .50375 L
s
.2619 .5 m
.2619 .50375 L
s
.34127 .5 m
.34127 .50375 L
s
.38095 .5 m
.38095 .50375 L
s
.42063 .5 m
.42063 .50375 L
s
.46032 .5 m
.46032 .50375 L
s
.53968 .5 m
.53968 .50375 L
s
.57937 .5 m
.57937 .50375 L
s
.61905 .5 m
.61905 .50375 L
s
.65873 .5 m
.65873 .50375 L
s
.7381 .5 m
.7381 .50375 L
s
.77778 .5 m
.77778 .50375 L
s
.81746 .5 m
.81746 .50375 L
s
.85714 .5 m
.85714 .50375 L
s
.06349 .5 m
.06349 .50375 L
s
.02381 .5 m
.02381 .50375 L
s
.93651 .5 m
.93651 .50375 L
s
.97619 .5 m
.97619 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .10317 m
.50625 .10317 L
s
gsave
.4875 .10317 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .30159 m
.50625 .30159 L
s
gsave
.4875 .30159 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .69841 m
.50625 .69841 L
s
gsave
.4875 .69841 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .89683 m
.50625 .89683 L
s
gsave
.4875 .89683 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .14286 m
.50375 .14286 L
s
.5 .18254 m
.50375 .18254 L
s
.5 .22222 m
.50375 .22222 L
s
.5 .2619 m
.50375 .2619 L
s
.5 .34127 m
.50375 .34127 L
s
.5 .38095 m
.50375 .38095 L
s
.5 .42063 m
.50375 .42063 L
s
.5 .46032 m
.50375 .46032 L
s
.5 .53968 m
.50375 .53968 L
s
.5 .57937 m
.50375 .57937 L
s
.5 .61905 m
.50375 .61905 L
s
.5 .65873 m
.50375 .65873 L
s
.5 .7381 m
.50375 .7381 L
s
.5 .77778 m
.50375 .77778 L
s
.5 .81746 m
.50375 .81746 L
s
.5 .85714 m
.50375 .85714 L
s
.5 .06349 m
.50375 .06349 L
s
.5 .02381 m
.50375 .02381 L
s
.5 .93651 m
.50375 .93651 L
s
.5 .97619 m
.50375 .97619 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto fill
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto
-0.03 0.0075 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
1 1 0 r
.5 .5 m
.87289 .5 L
.87289 .63572 L
F
.5 .5 m
.36428 .5 L
.36428 .87289 L
F
0 1 0 r
.5 .5 m
.5 .5 .11905 0 110 arc
F
1 0 0 r
.5 .5 m
.5 .5 .07937 0 20 arc
F
0 g
.5 Mabswid
newpath
.5 .5 .39683 0 365.73 arc
s
.02381 .5 m
.97619 .5 L
s
.5 .02381 m
.5 .97619 L
s
.87289 .63572 m
.5 .5 L
.36428 .87289 L
s
0 0 1 r
.5 .5 m
.87289 .5 L
s
% Start of user PostScript
0 0 0.939693 0 MAarrowhead1
% End of user PostScript
.87289 .5 m
.87289 .63572 L
s
% Start of user PostScript
0.939693 0 0.939693 0.34202 MAarrowhead1
% End of user PostScript
.5 .5 m
.36428 .5 L
s
% Start of user PostScript
0 0 -0.34202 0 MAarrowhead1
% End of user PostScript
.36428 .5 m
.36428 .87289 L
s
% Start of user PostScript
-0.34202 0 -0.34202 0.939693 MAarrowhead1
% End of user PostScript
0 g
gsave
.5 .5 -71.9375 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.87289 .5 -66.4688 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Q) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.87289 .63572 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
69.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.36428 .5 -66 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.36428 .87289 -66.2188 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(R) show
69.438 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  Magnification->0.9,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?oo
o`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?oo
o`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3o
ool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo
0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?oo
o`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000
003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0
oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80
oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<00000
0?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3o
ool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0
oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<0
00000?ooo`3oool0/P3oool00:P0oooo00<0oooO09a8M02oool0203oool00`000000oooo0?ooo`2b
0?ooo`00Z03oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo0;80oooo002P0?ooo`03
0?noM000000000000080000000H004RL0=ooo`3oool0oooO09a8M02oool80?ooo`030000003oool0
oooo0;80oooo002S0?ooob400000Y03oool009`0oooo1`0000030?ooo`050?oog`2LW;l0oooO09a8
M02oool0203oool00`000000oooo0?ooo`0>0?ooo`L00000W@3oool009L0oooo1@00000;0?ooo`04
0?noM0000000001d0;ooo`P0oooo00<000000?ooo`3oool05@3oool5000009P0oooo002C0?ooo`@0
00004@3oool00`3ookl0M01d0;ooo`080?ooo`030000003oool0oooo01X0oooo1000002D0?ooo`00
SP3oool500000200oooo00<000000?ooo`3oool07P3oool5000008l0oooo002;0?ooo`<000009@3o
ool00`000000oooo0?ooo`0S0?ooo`<00000S03oool008L0oooo1000000X0?ooo`030000003oool0
oooo02H0oooo100000280?ooo`00QP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0Q@3oool00880oooo1000000]0?ooo`030000003oool0oooo02/0
oooo100000230?ooo`00O`3oool300000340oooo00<000000?ooo`3oool0;`3oool300000800oooo
001m0?ooo`800000=03oool00`000000oooo0?ooo`0b0?ooo`800000OP3oool007X0oooo0`00000f
0?ooo`030000003oool0oooo03@0oooo0`00001k0?ooo`00N03oool2000003T0oooo00<000000?oo
o`3oool0=`3oool2000007T0oooo001g0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`1f0?ooo`00M03oool3000003`0oooo0P00000k0?ooo`<00000
M@3oool00780oooo0P00000o0?ooo`030000003oool0oooo03d0oooo0P00001c0?ooo`00L03oool2
00000440oooo00<000000?ooo`3oool0?`3oool200000740oooo001_0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1^0?ooo`00K@3oool2000004@0
oooo00<000000?ooo`3oool0@P3oool2000006h0oooo001/0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1[0?ooo`00J@3oool3000004L0oooo00<0
00000?ooo`3oool0A@3oool3000006X0oooo001W0?ooo`800000BP3oool00`000000oooo0?ooo`18
0?ooo`800000J03oool006H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo06D0oooo001T0?ooo`800000C@3oool00`000000oooo0?ooo`1;0?ooo`80
0000I@3oool006<0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo0680oooo001Q0?ooo`800000D03oool00`000000oooo0?ooo`1>0?ooo`800000HP3o
ool00600oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo05l0oooo001N0?ooo`800000D`3oool00`000000oooo0?ooo`1A0?ooo`800000G`3oool005d0
oooo00<000000?ooo`3oool0D`3oool2000005@0oooo00<000000?ooo`3oool0G03oool005`0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05/0oooo
001K0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`1J0?ooo`00FP3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool0F@3oool005P0oooo0P00001I0?ooo`030000003oool0oooo05L0oooo0P00001I0?oo
o`00E`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0EP3oool005H0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo05D0oooo001E0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`1D0?ooo`00E03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo05`0oooo00<000000?ooo`3oool0D`3oool005<0oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`1M0?ooo`030000003oool0oooo0580oooo001B0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1A0?ooo`00D@3oool00`000000oooo
0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0D03oool00500oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo04l0oooo001?
0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1>
0?ooo`00CP3oool00`000000oooo0?ooo`1R0?ooo`800000H`3oool00`000000oooo0?ooo`1=0?oo
o`00C@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool0C03oool004`0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1T0?ooo`030000
003oool0oooo04/0oooo001;0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`1:0?ooo`00BP3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0
oooo06H0oooo00<000000?ooo`3oool0B@3oool004T0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`1W0?ooo`030000003oool0oooo04P0oooo00180?ooo`030000003oool0oooo06P0
oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`170?ooo`00A`3oool00`000000oooo
0?ooo`1Y0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0AP3oool004H0oooo00<0
00000?ooo`3oool0JP3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo04D0oooo0015
0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`14
0?ooo`00A@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0A03oool004@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo04<0oooo00130?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0
K@3oool00`000000oooo0?ooo`120?ooo`00@P3oool00`000000oooo0?ooo`1^0?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool0@@3oool00440oooo00<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0400oooo00100?ooo`030000003oool0oooo
0700oooo0P00001a0?ooo`030000003oool0oooo03l0oooo00100?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0o0?ooo`00?`3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0?P3oool003h0oooo00<0
00000?ooo`3oool0LP3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo03d0oooo000n
0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0m
0?ooo`00?@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool0?03oool003`0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo03/0oooo000l0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`0k0?ooo`00>`3oool00`000000oooo0?ooo`1e0?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool0>P3oool003X0oooo00<000000?ooo`3oool0MP3oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo03T0oooo000j0?ooo`030000003oool0oooo
07H0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0i0?ooo`00>@3oool00`000000
oooo0?ooo`1S0?ooo`0:0;md00000000001809cOo`3oool0oono07A8W03Oool0oooo0;md00800000
00<0B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo03P0oooo
000i0?ooo`030000003oool0oooo0680oooo00H0okmd0018W03Oool0okmd0018W03Oool30?ooo`06
0?noM018W=l0oooo0?ooo`3OW4P0M;oo1P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0
oooo03P0oooo000h0?ooo`030000003oool0oooo05`0oooo00<0okmd0000000000000P0000002000
B9`0gooo0=nLB018W=l0oooo0?oo_`1d07@0_ooo1`3oool00`3o_g@0B9cO0?ooo`050?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool0>03oool003P0oooo00<000000?ooo`3oool0H`3o
ool01P3OW4P0M;oo0?ooo`3ooml0W4Qd0;ooo`<0oooo00H0okmd0000M02oool0oooo0=nLB01d_ol6
0?ooo`<00000N03oool00`000000oooo0?ooo`0g0?ooo`00=`3oool00`000000oooo0?ooo`1T0?oo
o`060=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q804P00000000007Bo00L0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0f0?ooo`00=P3oool00`000000oooo0?oo
o`1U0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool00`3ooml0W4Q809cOo`090?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0
IP3oool0102oM00000000000B02Lgol50?ooo`050;md0000000000000000B02Lgol01P3oool00`00
0000oooo0?ooo`1j0?ooo`030000003oool0oooo03D0oooo000e0?ooo`030000003oool0oooo07/0
oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0d0?ooo`00=03oool00`000000oooo
0?ooo`1l0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0=03oool003@0oooo00<0
00000?ooo`3oool0O03oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03<0oooo000c
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0c
0?ooo`00<`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo07d0oooo00<000000?oo
o`3oool0<P3oool003<0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`1m0?ooo`03
0000003oool0oooo0380oooo000b0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0b0?ooo`00<P3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo07h0oooo00<000000?ooo`3oool0<@3oool00340oooo00<000000?ooo`3oool0O`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0300oooo000`0?ooo`030000003oool0oooo
0800oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0`0?ooo`00<03oool00`000000
oooo0?ooo`200?ooo`800000P@3oool00`000000oooo0?ooo`0_0?ooo`00<03oool00`000000oooo
0?ooo`200?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0;`3oool00300oooo00<0
00000?ooo`3oool0P03oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo02l0oooo000_
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0^
0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0840oooo00<000000?oo
o`3oool0;P3oool002h0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`220?ooo`03
0000003oool0oooo02d0oooo000^0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0
PP3oool00`000000oooo0?ooo`0]0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000003o
ool0oooo0880oooo00<000000?ooo`3oool0;@3oool002d0oooo00<000000?ooo`3oool0P`3oool0
0`000000oooo0?ooo`230?ooo`030000003oool0oooo02`0oooo000]0?ooo`030000003oool0oooo
08<0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0/0?ooo`00;@3oool00`000000
oooo0?ooo`230?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0;03oool002`0oooo
00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo02`0oooo
000/0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?oo
o`0[0?ooo`00:`3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0Q@3oool2000008H0oooo00<000000?oo
o`3oool0:P3oool002/0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`250?ooo`03
0000003oool0oooo02X0oooo000Z0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
Q@3oool00`000000oooo0?ooo`0Z0?ooo`00:P3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0:@3oool002X0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo02T0oooo000Y0?ooo`030000003oool0oooo
08L0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0Y0?ooo`00:@3oool00`000000
oooo0?ooo`270?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0:03oool002T0oooo
00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo02P0oooo
000Y0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?oo
o`0X0?ooo`00:@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo08L0oooo00<00000
0?ooo`3oool0:03oool002T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`270?oo
o`030000003oool0oooo02P0oooo000X0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool0R03oool00`000000oooo0?ooo`0W0?ooo`00:03oool00`000000oooo0?ooo`280?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool09`3oool002P0oooo00<000000?ooo`3oool0R03o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo02L0oooo000W0?ooo`030000003oool0
oooo08T0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0W0?ooo`009`3oool00`00
0000oooo0?ooo`290?ooo`800000RP3oool00`000000oooo0?ooo`0V0?ooo`009`3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool09P3oool002L0oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo02H0oooo
000W0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?oo
o`0V0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo08T0oooo00<00000
0?ooo`3oool09P3oool002H0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`2:0?oo
o`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000
003oool0oooo08X0oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool0RP3o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0
oooo08X0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`00
0000oooo0?ooo`2:0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool09@3oool002D0
oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02D0
oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo08/0oooo00<0
00000?ooo`3oool0903oool002D0oooo00D000000?ooo`3ooml0W4Qd0;ooo`0o0?ooo`0:0;md0000
0000001809cOo`3oool0oono07A8W03Oool0oooo0;md0080000000<0B9cO0?ooo`3oool0>`3oool2
000003l0oooo00X0_g@00000000004P0W=oo0?ooo`3ookl0M4RL0=ooo`3oool0_g@00P0000000`18
W=l0oooo0?ooo`0n0?ooo`030000002LB7@0_ooo02@0oooo000U0?ooo`050000003oool0oooO09a8
M02oool0?P3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00H0okmd04RLg`3oool0oooo
0=nLB01d_oll0?ooo`030000003oool0oooo03d0oooo00H0okmd0018W03Oool0okmd0018W03Oool3
0?ooo`060?noM018W=l0oooo0?ooo`3OW4P0M;oo?`3oool00`000000W4Qd0;ooo`0T0?ooo`007P3o
ool00`3o_g@0000000000002000000070018W03Oool000000?ooo`3ooml0W4Qd0;ooo`0g0?ooo`03
0?noM000000000000080000000P004RL0=ooo`3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`L0oooo00<0
okmd04RLg`3oool0>`3oool00`000000oooo0?ooo`0m0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0
_ooo1`3oool00`3o_g@0B9cO0?ooo`0h0?ooo`030?noM000M;l0oooo00<0oooo00<0000009a8M02o
ool0903oool002D0oooo00D000000?ooo`3ooml0W4Qd0;ooo`0n0?ooo`060=nLB01d_ol0oooo0?oo
g`2LB7@0_ooo0`3oool01P3o_g@0001d0;ooo`3oool0gia807Boo`T0oooo00H0oono07@000000000
00000018W03OoolS0?ooo`060?oo_`1d000000000000000007@0_ooo103oool00`000000oooo0?oo
o`0m0?ooo`060=nLB01d_ol0oooo0?oog`2LB7@0_ooo0`3oool01P3o_g@0001d0;ooo`3oool0gia8
07Booc@0oooo00<0oono07@0000000000P0000000`0007@0_ooo0?ooo`030?ooo`030000002LB7@0
_ooo02@0oooo000U0?ooo`050000002LW;l0oooO09a8M02oool0?P3oool01P3OW4P0B9cO0?ooo`3o
okl0M01d0;ooo`<0oooo00D0oono07A8B01800000000001d_`0:0?ooo`060;md000007@0_ooo0?oO
W0180000B9cO8P3oool0203ookl0M0000018W03Oool0oooO09a8000007@0_ooo0`3oool00`000000
oooo0?ooo`0m0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q804P00000
000007Bo03@0oooo00P0oono07@00000B9`0gooo0;md00000000001809cOo`80oooo00D0oooO09bL
_`000000W4Qd0;ooo`0T0?ooo`009@3oool01@000000okmd0000000007@0_ooo03h0oooo00H0okmd
0018W03Oool0okmd0018W03Oool30?ooo`030?oog`2LB4P0W=oo00l0oooo00<0oono07@00018W=l0
8P3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00<0oooo00<000000?ooo`3oool0
?@3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00<0oooO09a8B02Lgol0=P3oool0203o
_g@0001809cOo`3ogi`0B4RL0=oOW0180000B9cO0`3oool0103o_g@000000000M02ooolT0?ooo`00
9@3oool01@000000oooo0?oo_`1d07@0_ooo03l0oooo00@0_g@00000000004P0W=oo1@3oool01@2o
M00000000000000004P0W=oo00/0oooo00@0_g@00000000004P0W=oo8P3oool00`3OW4P0001d0;oo
o`020?ooo`030?oo_`1d0000B9cO00<0oooo00<000000?ooo`3oool0?P3oool0102oM00000000000
B02Lgol50?ooo`050;md0000000000000000B02Lgol0<`3oool00`3OW4P0001d0;ooo`020?ooo`03
0?oo_`1d0000B9cO00@0oooo00<0000007@0M02oool0903oool002D0oooo00<000000?ooo`3oool0
F03oool0103ookl0M00000000000M;lT0?ooo`030=nLB00007@0_ooo0080oooo00<0oono07@00018
W=l00`3oool00`000000oooo0?ooo`1o0?ooo`030=nLB00007@0_ooo0080oooo00<0oono07@00018
W=l0103oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`1H0?ooo`030?no
M00004P0W=oo02D0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`030?ooo`030000
003oool0oooo07l0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`040?ooo`030000
003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo05P0oooo00H0okmd0000B02Lgol0gia8
0000B02LgolR0?ooo`030?oo_`1d000007Bo0080oooo00<0_g@00000M02oool00`3oool00`000000
oooo0?ooo`1o0?ooo`080?oo_`1d000004RL0=ooo`3oool0_g@00018W03Oool40?ooo`030000003o
ool0oooo02@0oooo000U0?ooo`030000003oool0oooo05T0oooo00@0_g@0000000000000B9cO903o
ool01P3ookl0M000000000000000001d0;ooo`@0oooo00<000000?ooo`3oool0P03oool01P3ookl0
M00000000000000004RL0=ooo`D0oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?oo
o`3oool0I03oool20000obD0oooo00<000000?ooo`3oool0N03oool20000oa40oooo00<000000?oo
o`3oool0903oool002D0oooo00<000000?ooo`3oool0H03oool60000obD0oooo00<000000?ooo`3o
ool0N03oool60000o`d0oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0
G03oool90000obH0oooo00<000000?ooo`3oool0N@3oool90000o`T0oooo00<000000?ooo`3oool0
903oool008800000^0000?l^00000000203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool01@3oool00`000?l0ool00000o`080000obH0ool000<00000
003o000000000P00000G0?l000l00?l0D@3oo`090000o`030?oo00000?l0oooo00H0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo000U0?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool04`3oool00`000?l0ool00?oo00030?oo
00H0003o903oo`02000000@00?l00P00000E0?l000l00?l0D03oo`060000o`D0ool000<0003o0?oo
o`3oool01@3oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`1J0?ooo`03
0000o`3oo`00ool000L0ool00P000?lT0?oo008000001P00o`0300000180o`003`00o`1@0?oo0080
003o2@3oo`000`000?l0oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000
003oool0oooo05X0oooo00<0003o0?oo003oo`00;@3oo`02000000T00?l00`00000?0?l000l00?l0
F`3oo`000`000?l0oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003o
ool0oooo05X0oooo00<0003o0?oo003oo`00;03oo`000`0000000?l00000000<003o00<00000303o
000>003o05`0ool000<0003o0?ooo`3oool01@3oool00`000000oooo0?ooo`0T0?ooo`009@3oool0
0`000000oooo0?ooo`1J0?ooo`030000o`3oo`00ool002`0ool000<00000003o000000003`00o`02
000000X0o`003P00o`1L0?oo00030000o`3oool0oooo00D0oooo00<000000?ooo`3oool0903oool0
02D0oooo00<000000?ooo`3oool0FP3oool00`000?l0ool00?oo000[0?oo000400000000o`000?l0
000001400?l00`0000070?l000h00?l0G03oo`000`000?l0oooo0?ooo`050?ooo`030000003oool0
oooo02@0oooo000U0?ooo`030000003oool0oooo05X0oooo00<0003o0?oo003oo`00:`3oo`001000
00000?l0003o0000000D003o00<00000103o000>003o05`0ool000<0003o0?ooo`3oool01@3oool0
0`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`1J0?ooo`030000o`3oo`00ool0
02/0ool000@00000003o0000o`0000005`00o`0200000080o`003P00o`1L0?oo00030000o`3oool0
oooo00D0oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0FP3oool00`00
0?l0ool00?oo000Z0?oo000500000000o`000?l0003o000000006@00o`03000000d00?l0G03oo`00
0`000?l0oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo
05X0oooo00<0003o0?oo003oo`00:P3oo`001@0000000?l0003o0000o`00000001`00?l00`00000:
003o05`0ool000<0003o0?ooo`3oool01@3oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`00
0000oooo0?ooo`1J0?ooo`030000o`3oo`00ool002X0ool000D00000003o0000o`000?l00000000O
003o00<000001`00o`1L0?oo00030000o`3oool0oooo00D0oooo00<000000?ooo`3oool0903oool0
02D0oooo00<000000?ooo`3oool0FP3oool00`000?l0ool00?oo000Y0?oo000300000000o`000?l0
00800?l000<00000003o0000o`008000o`02000000@00?l0G@3oo`000`000?l0oooo0?ooo`050?oo
o`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo05X0oooo00<0003o0?oo003o
o`00:@3oo`000`0000000?l0003o0002003o000300000000o`000?l002800?l00`0000000`00o`00
ool00?oo001K0?oo00030000o`3oool0oooo00D0oooo00<000000?ooo`3oool0903oool002D0oooo
00<000000?ooo`3oool0FP3oool00`000?l0ool00?oo000Y0?oo000300000000o`000?l000800?l0
00<00000003o0000o`009@00o`03000005/0ool000<0003o0?ooo`3oool01@3oool00`000000oooo
0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`1J0?ooo`030000o`3oo`00ool002P0ool000<0
0000003o0000o`000`00o`000`0000000?l0003o000U003o00<0oooo0`00001H0?oo00030000o`3o
ool0oooo00D0oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0FP3oool0
0`000?l0ool00?oo000X0?oo000300000000o`000?l000<00?l000<00000003o0000o`009000o`07
0?ooo`800000EP3oo`000`000?l0oooo0?ooo`040?ooo`030000003oool0oooo02D0oooo000V0?oo
o`030000003oool0oooo05T0oooo00<0003o0?oo003oo`009`3oo`000`0000000?l0003o0004003o
000300000000o`000?l002@00?l02@3oool3000005<0ool000<0003o0?ooo`3oool0103oool00`00
0000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`1I0?ooo`030000o`3oo`00ool002L0
ool000<00000003o0000o`001000o`000`0000000?l0003o000T003o00`0oooo0`00001@0?oo0003
0000o`3oool0oooo00@0oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool0
F@3oool00`000?l0ool00?oo000W0?oo000300000000o`000?l000@00?l000<00000003o0000o`00
8`00o`0@0?ooo`<00000C@3oo`000`000?l0oooo0?ooo`040?ooo`030000003oool0oooo02D0oooo
000V0?ooo`030000003oool0oooo05T0oooo00<0003o0?oo003oo`009P3oo`000`0000000?l0003o
0005003o000300000000o`000?l002<00?l04`3oool2000004/0ool000<0003o0?ooo`3oool0103o
ool00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`1I0?ooo`030000o`3oo`00
ool002H0ool000<00000003o0000o`001@00o`000`0000000?l0003o000R003o01H0oooo0`000018
0?oo00030000o`3oool0oooo00@0oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?oo
o`3oool0F@3oool00`000?l0ool00?oo000V0?oo000300000000o`000?l000D00?l000<00000003o
0000o`008@00o`0J0?ooo`<00000A@3oo`000`000?l0oooo0?ooo`040?ooo`030000003oool0oooo
02D0oooo000V0?ooo`030000003oool0oooo05T0oooo00<0003o0?oo003oo`009@3oo`000`000000
0?l0003o0006003o000300000000o`000?l002000?l07P3oool2000004<0ool000<0003o0?ooo`3o
ool00`3oool00`000000oooo0?ooo`0V0?ooo`009`3oool00`000000oooo0?ooo`1H0?ooo`030000
o`3oo`00ool002D0ool000<00000003o0000o`001P00o`000`0000000?l0003o000P003o0200oooo
0`0000100?oo00030000o`3oool0oooo00<0oooo00<000000?ooo`3oool09P3oool002L0oooo00<0
00000?ooo`3oool0F03oool00`000?l0ool00?oo000T0?oo000300000000o`000?l000L00?l000<0
0000003o0000o`007`00o`0T0?ooo`<00000?@3oo`000`000?l0oooo0?ooo`030?ooo`030000003o
ool0oooo02H0oooo000W0?ooo`030000003oool0oooo05P0oooo00<0003o0?oo003oo`00903oo`00
0`0000000?l0003o0007003o000300000000o`000?l001h00?l0:03oool3000003X0ool000<0003o
0?ooo`3oool00`3oool00`000000oooo0?ooo`0V0?ooo`009`3oool00`000000oooo0?ooo`1H0?oo
o`030000o`3oo`00ool002@0ool000<00000003o0000o`001`00o`000`0000000?l0003o000M003o
02`0oooo0P00000h0?oo00030000o`3oool0oooo00<0oooo00<000000?ooo`3oool09P3oool002L0
oooo00<000000?ooo`3oool0F03oool00`000?l0ool00?oo000S0?oo000300000000o`000?l000P0
0?l000<00000003o0000o`007000o`0_0?ooo`<00000=@3oo`000`000?l0oooo0?ooo`020?ooo`03
0000003oool0oooo02L0oooo000X0?ooo`030000003oool0oooo05L0oooo00<0003o0?oo003oo`00
8`3oo`000`0000000?l0003o0008003o000300000000o`000?l001/00?l0<`3oool300000380ool0
00<0003o0?ooo`3oool00P3oool00`000000oooo0?ooo`0W0?ooo`00:03oool00`000000oooo0?oo
o`1G0?ooo`030000o`3oo`00ool002<0ool000<00000003o0000o`002000o`000`0000000?l0003o
000K003o03H0oooo0`00000_0?oo00030000o`3oool0oooo0080oooo00<000000?ooo`3oool09`3o
ool002P0oooo00<000000?ooo`3oool0E`3oool00`000?l0ool00?oo000R0?oo000300000000o`00
0?l000T00?l000<00000003o0000o`006P00o`0j0?ooo`800000;@3oo`000`000?l0oooo0?ooo`02
0?ooo`030000003oool0oooo02L0oooo000Y0?ooo`030000003oool0oooo05H0oooo00<0003o0?oo
003oo`008P3oo`000`0000000?l0003o0009003o000300000000o`000?l001P00?l0?P3oool30000
02X0ool000D0003o0?ooo`3oool0oooo0000000Z0?ooo`00:@3oool00`000000oooo0?ooo`1F0?oo
o`030000o`3oo`00ool00280ool000<00000003o0000o`002@00o`000`0000000?l0003o000G003o
0480oooo0`00000W0?oo00050000o`3oool0oooo0?ooo`000000:P3oool002T0oooo00<000000?oo
o`3oool0EP3oool00`000?l0ool00?oo000Q0?oo000300000000o`000?l000X00?l000<00000003o
0000o`005P00o`160?ooo`<00000903oo`001@000?l0oooo0?ooo`3oool0000002X0oooo000Y0?oo
o`030000003oool0oooo05H0oooo00<0003o0?oo003oo`008@3oo`000`0000000?l0003o000:003o
000300000000o`000?l001<00?l0C03oool200000280ool000D0003o0?ooo`3oool0oooo0000000Z
0?ooo`00:@3oool00`000000oooo0?ooo`1F0?ooo`030000o`3oo`00ool00200ool000<00000003o
0000o`002`00o`000`0000000?l0003o000B003o04l0oooo0`00000O0?oo00050000o`3oool0oooo
0?ooo`000000:P3oool002T0oooo00<000000?ooo`3oool0EP3oool00`000?l0ool00?oo000P0?oo
000300000000o`000?l000/00?l000<00000003o0000o`004@00o`1C0?ooo`<000006@3oo`020000
o`030?oo00000?l0oooo0080003o:`3oool002X0oooo00<000000?ooo`3oool0E@3oool00`000?l0
ool00?oo000P0?oo000300000000o`000?l000/00?l000<00000003o0000o`003`00o`1H0?ooo`<0
00005P3oo`070000ob/0oooo000Z0?ooo`030000003oool0oooo05D0oooo00<0003o0?oo003oo`00
7`3oo`000`0000000?l0003o000<003o000300000000o`000?l000`00?l0GP3oool2000001D0ool0
1@000?l00`000000oooo0?ooo`0Y0?ooo`00:P3oool00`000000oooo0?ooo`1E0?ooo`030000o`3o
o`00ool001l0ool000<000000?ooo`3oool03000o`000`0000000?l0003o000:003o0680oooo0`00
000B0?oo00D0003o;03oool002/0oooo00<000000?ooo`3oool0E03oool00`000?l0ool00?oo000O
0?oo00030000003oool0oooo0080oooo2P00o`000`0000000?l0003o0005003o06X0oooo0`00000?
0?oo00D0003o;03oool002/0oooo00<000000?ooo`3oool0E03oool00`000?l0ool00?oo000N0?oo
00030000003oool0oooo00/0oooo0P00o`000`0000000?l0003o001b0?ooo`8000003@3oo`050000
ob`0oooo000[0?ooo`030000003oool0oooo05@0oooo00<0003o0?oo003oo`007P3oo`000`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo07@0oooo0`00000;0?oo00<0003o00<000000?ooo`3o
ool0:P3oool002`0oooo00<000000?ooo`3oool0D`3oool00`000?l0ool00?oo000N0?oo00030000
003oool0oooo00d0oooo00<000000?ooo`3oool0M`3oool3000000P0ool00`000?l]0?ooo`00;03o
ool00`000000oooo0?ooo`1C0?ooo`030000o`3oo`00ool001d0ool000<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`1j0?ooo`<000001@3oo`030000obd0oooo000]0?ooo`030000003oool0
oooo0580oooo00<0003o0?oo003oo`007@3oo`000`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo07d0oooo0P0000030?oo00<0003o;@3oool002d0oooo00<000000?ooo`3oool0DP3oool00`00
0?l0ool00?oo000L0?oo00030000003oool0oooo00l0oooo00<000000?ooo`3oool0O`3oool30000
00030?oo00000?l0oooo02d0oooo000]0?ooo`030000003oool0oooo0580oooo00<0003o0?oo003o
o`00703oo`000`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0880oooo00<000000000o`3o
ool0;@3oool002h0oooo00<000000?ooo`3oool0D@3oool00`000?l0ool00?oo000L0?oo00030000
003oool0oooo00l0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`0]0?ooo`00;P3o
ool00`000000oooo0?ooo`1A0?ooo`030000o`3oo`00ool001/0ool000<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`220?ooo`030000003oool0oooo02d0oooo000^0?ooo`030000003oool0
oooo0540oooo00<0003o0?oo003oo`006`3oo`000`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0880oooo00<000000?ooo`3oool0;@3oool002h0oooo00<000000?ooo`3oool0D@3oool00`00
0?l0ool00?oo000K0?oo00030000003oool0oooo0100oooo00<000000?ooo`3oool0P@3oool00`00
0000oooo0?ooo`0^0?ooo`00;`3oool00`000000oooo0?ooo`1@0?ooo`030000o`3oo`00ool001X0
ool000<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1o0?ooo`030?oo_`1d000000000300
oooo000`0?ooo`030000003oool0oooo04l0oooo00<0003o0?oo003oo`006P3oo`000`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo07l0oooo00<0oono00000018W=l0<03oool00300oooo00<0
00000?ooo`3oool0C`3oool00`000?l0ool00?oo000J0?oo00030000003oool0oooo0140oooo00<0
00000?ooo`3oool0O`3oool00`3ookl0000004RLg`0`0?ooo`00<03oool00`000000oooo0?ooo`1?
0?ooo`030000o`3oo`00ool001T0ool000<000000?ooo`3oool04P3oool200000800oooo00<0oono
0000000000000P0000000`00M;l0oooo0?ooo`0[0?ooo`00<03oool00`000000oooo0?ooo`1?0?oo
o`030000o`3oo`00ool001T0ool000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1o0?oo
o`070000001d0000B9cO0?ooo`3ogi`0B00004RLg`0/0?ooo`00<@3oool00`000000oooo0?ooo`1>
0?ooo`030000o`3oo`00ool001P0ool000<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1o
0?ooo`070000001d0000B9cO0?ooo`3ookl0M000001d_`0/0?ooo`00<P3oool00`000000oooo0?oo
o`1=0?ooo`030000o`3oo`00ool001P0ool000<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`1n0?ooo`080000003ookl0M00004RLg`3oool0omnL04P00018W=l/0?ooo`00<P3oool00`000000
oooo0?ooo`1=0?ooo`030000o`3oo`00ool001P0ool000<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`1m0?ooo`040000003oool0oono07@000<0000000<004RL0=ooo`3oool0:`3oool003<0
oooo00<000000?ooo`3oool0C03oool00`000?l0ool00?oo000G0?oo00030000003oool0oooo01@0
oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0b0?ooo`00<`3oool00`000000oooo
0?ooo`1<0?ooo`030000o`3oo`00ool001L0ool000<000000?ooo`3oool0503oool00`000000oooo
0?ooo`1m0?ooo`030000003oool0oooo0380oooo000c0?ooo`030000003oool0oooo04`0oooo00<0
003o0?oo003oo`005`3oo`000`000000oooo0?ooo`0D0?ooo`030000003oool0oooo07`0oooo00<0
00000?ooo`3oool0<`3oool003@0oooo00<000000?ooo`3oool0B`3oool00`000?l0ool00?oo000F
0?oo00030000003oool0oooo01D0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0c
0?ooo`00=03oool00`000000oooo0?ooo`1;0?ooo`030000o`3oo`00ool001H0ool000<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo03@0oooo000e0?ooo`03
0000003oool0oooo04X0oooo00<0003o0?oo003oo`005@3oo`000`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo07/0oooo00<000000?ooo`3oool0=03oool003H0oooo00<000000?ooo`3oool0
B@3oool00`000?l0ool00?oo000E0?oo00030000003oool0oooo01H0oooo00<000000?ooo`3oool0
NP3oool00`000000oooo0?ooo`0e0?ooo`00=P3oool00`000000oooo0?ooo`190?ooo`030000o`3o
o`00ool001D0ool000<000000?ooo`3oool00P3oool02P2oM00000000000B02Lgol0oooo0?oo_`1d
B9`0gooo0?ooo`2oM0020000000304RLg`3oool0oooo00D0oooo00<000000?ooo`3oool0N@3oool0
0`000000oooo0?ooo`0f0?ooo`00=`3oool00`000000oooo0?ooo`180?ooo`030000o`3oo`00ool0
01@0ool000<000000?ooo`3oool00P3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00H0
okmd04RLg`3oool0oooo0=nLB01d_ol60?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool0=P3oool003P0oooo00<000000?ooo`3oool0A`3oool00`000?l0ool00?oo000D0?oo00030000
003oool0oooo0080oooo00H0gia804RLg`3oool0oono07@0M02oool70?ooo`030?noM018W=l0oooo
00D0oooo0`00001h0?ooo`030000003oool0oooo03L0oooo000h0?ooo`030000003oool0oooo04L0
oooo00<0003o0?oo003oo`00503oo`000`000000oooo0?ooo`020?ooo`060=nLB01d_ol0oooo0?oo
g`2LB7@0_ooo0`3oool01P3o_g@0001d0;ooo`3oool0gia807Boo`H0oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`0h0?ooo`00>@3oool00`000000oooo0?ooo`160?ooo`030000o`3o
o`00ool001<0ool000<000000?ooo`3oool00`3oool01P3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`<0
oooo00D0oono07A8B01800000000001d_`070?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool0>03oool003T0oooo00<000000?ooo`3oool0AP3oool00`000?l0ool00?oo000C0?oo0003
0000003oool0oooo00<0oooo00H0okmd0018W03Oool0okmd0018W03Oool30?ooo`030?oog`2LB4P0
W=oo00T0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0h0?ooo`00>P3oool00`00
0000oooo0?ooo`150?ooo`030000o`3oo`00ool001<0ool000<000000?ooo`3oool0103oool0102o
M00000000000B02Lgol50?ooo`050;md0000000000000000B02Lgol01P3oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo03T0oooo000j0?ooo`030000003oool0oooo04D0oooo00<0003o
0?oo003oo`004P3oo`000`000000oooo0?ooo`0I0?ooo`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool0>@3oool003/0oooo00<000000?ooo`3oool0A03oool00`000?l0ool00?oo000B0?oo
00030000003oool0oooo01T0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0j0?oo
o`00?03oool00`000000oooo0?ooo`130?ooo`030000o`3oo`00ool00140ool000<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo03/0oooo000l0?ooo`030000
003oool0oooo04<0oooo00<0003o0?oo003oo`004@3oo`000`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo07@0oooo00<000000?ooo`3oool0>`3oool003d0oooo00<000000?ooo`3oool0@P3o
ool00`000?l0ool00?oo000A0?oo00030000003oool0oooo01X0oooo00<000000?ooo`3oool0L`3o
ool00`000000oooo0?ooo`0l0?ooo`00?P3oool00`000000oooo0?ooo`110?ooo`030000o`3oo`00
ool00100ool000<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0
oooo03d0oooo000n0?ooo`030000003oool0oooo0440oooo00<0003o0?oo003oo`00403oo`000`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0?@3oool003l0
oooo00<000000?ooo`3oool0@03oool00`000?l0ool00?oo000@0?oo00030000003oool0oooo01/0
oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0n0?ooo`00@03oool00`000000oooo
0?ooo`0o0?ooo`030000o`3oo`00ool000l0ool000<000000?ooo`3oool0703oool00`000000oooo
0?ooo`1`0?ooo`030000003oool0oooo03l0oooo00100?ooo`030000003oool0oooo03l0oooo00<0
003o0?oo003oo`003`3oo`000`000000oooo0?ooo`0L0?ooo`800000L@3oool00`000000oooo0?oo
o`0o0?ooo`00@@3oool00`000000oooo0?ooo`0n0?ooo`030000o`3oo`00ool000l0ool000<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0400oooo00120?oo
o`030000003oool0oooo03d0oooo00<0003o0?oo003oo`003P3oo`000`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo06h0oooo00<000000?ooo`3oool0@@3oool004<0oooo00<000000?ooo`3o
ool0?03oool00`000?l0ool00?oo000>0?oo00030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0K@3oool00`000000oooo0?ooo`120?ooo`00A03oool00`000000oooo0?ooo`0k0?ooo`030000
o`3oo`00ool000d0ool000<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1/0?ooo`030000
003oool0oooo04<0oooo00150?ooo`030000003oool0oooo03X0oooo00<0003o0?oo003oo`003@3o
o`000`000000oooo0?ooo`0N0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0A03o
ool004D0oooo00<000000?ooo`3oool0>P3oool00`000?l0ool00?oo000=0?oo00030000003oool0
oooo01h0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`140?ooo`00AP3oool00`00
0000oooo0?ooo`0i0?ooo`030000o`3oo`00ool000`0ool000<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`1Z0?ooo`030000003oool0oooo04D0oooo00170?ooo`030000003oool0oooo03P0
oooo00<0003o0?oo003oo`00303oo`000`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool0AP3oool004P0oooo00<000000?ooo`3oool0=`3oool00`000?l0ool0
0?oo000<0?oo00030000003oool0oooo01l0oooo00<000000?ooo`3oool0J03oool00`000000oooo
0?ooo`170?ooo`00B@3oool00`000000oooo0?ooo`0f0?ooo`030000o`3oo`00ool000/0ool000<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo04P0oooo001:
0?ooo`030000003oool0oooo03D0oooo00<0003o0?oo003oo`002`3oo`000`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0B@3oool004/0oooo00<000000?oo
o`3oool0=03oool00`000?l0ool00?oo000;0?oo00030000003oool0oooo0200oooo00<000000?oo
o`3oool0I@3oool00`000000oooo0?ooo`1:0?ooo`00C03oool00`000000oooo0?ooo`0c0?ooo`03
0000o`3oo`00ool000X0ool000<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1T0?ooo`03
0000003oool0oooo04/0oooo001=0?ooo`030000003oool0oooo0380oooo00<0003o0?oo003oo`00
2P3oo`000`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0
C03oool004h0oooo00<000000?ooo`3oool0<@3oool00`000?l0ool00?oo00090?oo00030000003o
ool0oooo0280oooo0P00001S0?ooo`030000003oool0oooo04d0oooo001?0?ooo`030000003oool0
oooo0300oooo00<0003o0?oo003oo`002@3oo`000`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo0640oooo00<000000?ooo`3oool0CP3oool00500oooo00<000000?ooo`3oool0;`3oool00`00
0?l0ool00?oo00090?oo00030000003oool0oooo0280oooo00<000000?ooo`3oool0H03oool00`00
0000oooo0?ooo`1?0?ooo`00D@3oool00`000000oooo0?ooo`0^0?ooo`030000o`3oo`00ool000P0
ool000<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0500
oooo001B0?ooo`030000003oool0oooo02d0oooo00<0003o0?oo003oo`00203oo`000`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0D@3oool005<0oooo00<0
00000?ooo`3oool0;03oool00`000?l0ool00?oo00080?oo00030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0G@3oool00`000000oooo0?ooo`1B0?ooo`00E03oool00`000000oooo0?ooo`0[
0?ooo`030000o`3oo`00ool000L0ool000<000000?ooo`3oool0903oool00`000000oooo0?ooo`1L
0?ooo`030000003oool0oooo05<0oooo001E0?ooo`030000003oool0oooo02X0oooo00<0003o0?oo
003oo`001`3oo`000`000000oooo0?ooo`0T0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0E03oool005H0oooo00<000000?ooo`3oool0:@3oool00`000?l0ool00?oo00070?oo0003
0000003oool0oooo02@0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1E0?ooo`00
E`3oool00`000000oooo0?ooo`0X0?ooo`030000o`3oo`00ool000H0ool000<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05H0oooo001H0?ooo`800000:03o
ool00`000?l0ool00?oo00060?oo00030000003oool0oooo02D0oooo00<000000?ooo`3oool0E`3o
ool2000005T0oooo001J0?ooo`030000003oool0oooo02D0oooo00<0003o0?oo003oo`001@3oo`00
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0F@3oool0
05/0oooo00<000000?ooo`3oool0903oool00`000?l0ool00?oo00050?oo00030000003oool0oooo
02H0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1J0?ooo`00G03oool00`000000
oooo0?ooo`0S0?ooo`030000o`3oo`00ool000D0ool000<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo05/0oooo001M0?ooo`030000003oool0oooo0280oooo
00<0003o0?oo003oo`00103oo`000`000000oooo0?ooo`0W0?ooo`800000E03oool00`000000oooo
0?ooo`1L0?ooo`00GP3oool200000280oooo00<0003o0?oo003oo`00103oo`000`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo0540oooo0P00001O0?ooo`00H03oool00`000000oooo0?ooo`0O
0?ooo`030000o`3oo`00ool000@0ool000<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo05l0oooo001Q0?ooo`8000007`3oool00`000?l0ool00?oo00030?oo
00030000003oool0oooo02P0oooo00<000000?ooo`3oool0CP3oool200000680oooo001S0?ooo`03
0000003oool0oooo01`0oooo00<0003o0?oo003oo`000`3oo`000`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool0HP3oool006@0oooo0P00000L0?ooo`030000
o`3oo`00ool00080ool000<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1;0?ooo`800000
I@3oool006H0oooo00<000000?ooo`3oool06@3oool00`000?l0ool00?oo00020?oo00030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1U0?ooo`00I`3oool2
000001T0oooo00<0003o0?oo003oo`000P3oo`000`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo04P0oooo0P00001X0?ooo`00J@3oool2000001L0oooo00D0003o0?oo003oo`00ool00000000/
0?ooo`030000003oool0oooo04H0oooo0P00001Z0?ooo`00J`3oool2000001<0oooo00@0003o0?oo
o`000?l0ool00P000?l00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo04@0oooo0P00001/
0?ooo`00K@3oool00`000000oooo0?ooo`0@0?ooo`H0003o00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`130?ooo`030000003oool0oooo06`0oooo001^0?ooo`800000403oool50000o`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0@@3oool2000006l0oooo001`0?ooo`030000
003oool0oooo00h0oooo10000?l00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool0K`3oool00740oooo0P00000>0?ooo`@0003o00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`0n0?ooo`800000LP3oool007<0oooo0`00000;0?ooo`@0003o;P3oool2
000003`0oooo0`00001d0?ooo`00MP3oool2000000T0oooo0`000?l00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo03T0oooo0P00001g0?ooo`00N03oool00`000000oooo0?ooo`060?ooo`<0
003o;`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo07L0oooo001i0?ooo`@00000
103oool30000obl0oooo00<000000?ooo`3oool0=03oool4000007X0oooo001m0?ooo`030000003o
ool0oooo0080oooo0P000?l_0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0O03o
ool007h0oooo100000000`000?l0oooo0?ooo`0^0?ooo`030000003oool0oooo02l0oooo1000001o
0?ooo`00PP3oool00`000?l000000000000^0?ooo`030000003oool0oooo02`0oooo0`0000230?oo
o`00Q@3oool2000002`0oooo00<000000?ooo`3oool0:P3oool2000008H0oooo00270?ooo`<00000
:@3oool00`000000oooo0?ooo`0W0?ooo`<00000R03oool008X0oooo0`00000V0?ooo`030000003o
ool0oooo02@0oooo0`00002;0?ooo`00S@3oool600000200oooo00<000000?ooo`3oool07P3oool6
000008h0oooo001n0?ooo`070?oOW0180000M;oo0?ooo`3ookl0M000001d_`0>0?ooo`<000007@3o
ool00`000000oooo0?ooo`0K0?ooo`<00000U03oool007h0oooo00L0omnL04P0001d_ol0oooo0=nL
B00004P0W=oo0140oooo1@00000=0?ooo`030?oog`2LB7@0_ooo00P0oooo00<000000?ooo`3oool0
5P3oool5000009L0oooo001n0?ooo`060?oOW0180000M;oo0?oOW0180000B9cO5`3oool7000000H0
oooo00<0oooO09a8M02oool0203oool00`000000oooo0?ooo`0?0?ooo`L00000W03oool007h0oooo
00<0omnL04P0000000000P0000000`18W=l0oooo0?ooo`0L0?ooob<00000X`3oool007h0oooo00L0
omnL04P0001d_ol0oooo0?noM0000000M;oo02<0oooo00<0oooO09a8M02oool0203oool00`000000
oooo0?ooo`2b0?ooo`00OP3oool01`3ogi`0B00007Boo`3oool0omnL04P00018W=l08@3oool01@3o
oml0W9bo0?oog`2LB7@0_ooo00P0oooo00<000000?ooo`3oool0/P3oool007h0oooo00L0omnL04P0
001d_ol0oooo0?noM0000000M;oo0280oooo00@0okmd0000000007@0_ooo203oool00`000000oooo
0?ooo`2b0?ooo`00OP3oool00`3ogi`0B0000000000200000003001d_`3oool0oooo0280oooo00<0
oono07@0M02oool0203oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b
0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00
/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?oo
o`2b0?ooo`00/`3oool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`03
0000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003o
ool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo
0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?oo
o`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000
003oool0oooo0;80oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo
00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<00000
0?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool00001\
\>"],
  ImageRangeCache->{{{112.438, 370.625}, {668.313, 410.125}} -> {-2.35746, \
2.74299, 0.00878441, 0.00878441}},
  CellTags->"figura3"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Seno di un angolo che differisce di ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/2\)]]
}], "Subsubsection"],

Cell[TextData[{
  "Angoli che differiscono per un angolo retto danno origine alla \
configurazione geometrica di ",
  ButtonBox["fig. 3",
    ButtonData:>"figura3",
    ButtonStyle->"Hyperlink"],
  ". Ancora \[EGrave] soddisfatta la congruenza di tipo geometrico ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[EmptyUpTriangle]", 
              StyleBox["OQP",
                FontSlant->"Italic"]}]], "\[TildeFullEqual]", 
          StyleBox[
            RowBox[{"\[EmptyUpTriangle]", 
              StyleBox["OSR",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  " mentre, osservando i versi delle componenti, risulta ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["SR",
            FontSlant->"Italic"], 
          StyleBox["=",
            FontSlant->"Plain"], 
          StyleBox["OQ",
            FontSlant->"Italic"]}], TraditionalForm]]],
  " e ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["OS",
            FontSlant->"Italic"], "=", 
          RowBox[{"-", 
            StyleBox["QP",
              FontSlant->"Italic"]}]}], TraditionalForm]]],
  ". Ne segue  "
}], "Text",
  CellTags->"osservazione1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sen[\[Pi]/2 + \[Alpha]] \[Equal] SR/OR\)], "Input"],

Cell[BoxData[
    \(sen[\[Pi]\/2 + \[Alpha]] \[Equal] SR\/OR\)], "Output"]
}, Closed]],

Cell["che si riscrive", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {SR \[Rule] OQ, OR \[Rule] OP}\)], "Input"],

Cell[BoxData[
    \(sen[\[Pi]\/2 + \[Alpha]] \[Equal] OQ\/OP\)], "Output"]
}, Closed]],

Cell["e, in base alla definizione, risulta", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. defs\)], "Input"],

Cell[BoxData[
    \(sen[\[Pi]\/2 + \[Alpha]] \[Equal] cos[\[Alpha]]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(senDiffPi2 = toRule[%]\)], "Input"],

Cell[BoxData[
    \(sen[\[Pi]\/2 + \[Alpha]] \[RuleDelayed] cos[\[Alpha]]\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\({idFondamentale, senCompl, cosCompl, tanCompl, 
          senDiffPi2} = {cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 
            1, sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          tan[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cot[\[Alpha]], 
          sen[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] 
            cos[\[Alpha]]};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Coseno di un angolo che differisce di ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/2\)]]
}], "Subsubsection"],

Cell["Dalla definizione", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cos[\[Pi]/2 + \[Alpha]] \[Equal] OS/OR\)], "Input"],

Cell[BoxData[
    \(cos[\[Pi]\/2 + \[Alpha]] \[Equal] OS\/OR\)], "Output"]
}, Closed]],

Cell[TextData[{
  "ma per quanto osservato ",
  ButtonBox["sopra",
    ButtonData:>"osservazione1",
    ButtonStyle->"Hyperlink"],
  " nel caso del seno diviene"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {OS \[Rule] \(-QP\), OR \[Rule] OP}\)], "Input"],

Cell[BoxData[
    \(cos[\[Pi]\/2 + \[Alpha]] \[Equal] \(-\(QP\/OP\)\)\)], "Output"]
}, Closed]],

Cell["per cui", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. defs\)], "Input"],

Cell[BoxData[
    \(cos[\[Pi]\/2 + \[Alpha]] \[Equal] \(-sen[\[Alpha]]\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cosDiffPi2 = toRule[%]\)], "Input"],

Cell[BoxData[
    \(cos[\[Pi]\/2 + \[Alpha]] \[RuleDelayed] \(-sen[\[Alpha]]\)\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\({idFondamentale, senCompl, cosCompl, tanCompl, senDiffPi2, 
          cosDiffPi2} = {cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 
            1, sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          tan[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cot[\[Alpha]], 
          sen[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\)};\)\)], \
"Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Tangente di un angolo che differisce di ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/2\)]]
}], "Subsubsection"],

Cell["Con le medesime osservazioni e iniziando dalla definizione ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tan[\[Pi]/2 + \[Alpha]] \[Equal] SR/OS\)], "Input"],

Cell[BoxData[
    \(tan[\[Pi]\/2 + \[Alpha]] \[Equal] SR\/OS\)], "Output"]
}, Closed]],

Cell["risulta che l'espressione precedente si modifica in", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {SR \[Rule] OQ, OS \[Rule] \(-QP\)}\)], "Input"],

Cell[BoxData[
    \(tan[\[Pi]\/2 + \[Alpha]] \[Equal] \(-\(OQ\/QP\)\)\)], "Output"]
}, Closed]],

Cell["da cui, moltiplicando per il reciproco del secondo membro", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(%\ \((QP/OQ)\)\)], "Input"],

Cell[BoxData[
    \(\(QP\ tan[\[Pi]\/2 + \[Alpha]]\)\/OQ \[Equal] \(-1\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "si ottiene un'espressione dove appare la definizione di ",
  Cell[BoxData[
      \(TraditionalForm\`tan[\[Alpha]]\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. defs\)], "Input"],

Cell[BoxData[
    \(tan[\[Alpha]]\ tan[\[Pi]\/2 + \[Alpha]] \[Equal] \(-1\)\)], "Output"]
}, Closed]],

Cell["Dividendo per tale funzione si ha", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(%/tan[\[Alpha]]\)], "Input"],

Cell[BoxData[
    \(tan[\[Pi]\/2 + \[Alpha]] \[Equal] \(-\(1\/tan[\[Alpha]]\)\)\)], "Output"]
}, Closed]],

Cell["che si pu\[OGrave] riscrivere anche come", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(% /. id3\) /. id2\)], "Input"],

Cell[BoxData[
    \(tan[\[Pi]\/2 + \[Alpha]] \[Equal] \(-\(cos[\[Alpha]]\/sen[\[Alpha]]\)\)\
\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tanDiffPi2 = toRule[%]\)], "Input"],

Cell[BoxData[
    \(tan[\[Pi]\/2 + \[Alpha]] \[RuleDelayed] \
\(-\(cos[\[Alpha]]\/sen[\[Alpha]]\)\)\)], "Output"]
}, Closed]],

Cell["Riassumiamo in riquadro quanto ottenuto", "Text"],

Cell[BoxData[{
    \(TraditionalForm\`Angoli\ che\ differiscono\ per\ un\ angolo\ retto\), "\
\[IndentingNewLine]", 
    \(TraditionalForm\`sen(\[Pi]\/2 + \[Alpha]) = 
      cos(\[Alpha])\), "\[IndentingNewLine]", 
    \(TraditionalForm\`cos(\[Pi]\/2 + \[Alpha]) = \(-\(sen(\[Alpha])\)\)\), "\
\[IndentingNewLine]", 
    \(TraditionalForm\`tan(\[Pi]\/2 + \[Alpha]) = \(\(-\(cot(\[Alpha])\)\) = \
\(-\(1\/\(tan(\[Alpha])\)\)\)\)\)}], "Definition",
  FontFamily->"Courier"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Angoli supplementari", "Subsection"],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[{
    \(\[Alpha] = 30  Degree; \[Beta] = \[Pi] - \[Alpha];\), "\n", 
    \(pP = {Cos[\[Alpha]], Sin[\[Alpha]]}; pQ = {Cos[\[Alpha]], 0}; 
    origine = {0, 0}; pR = {Cos[\[Beta]], Sin[\[Beta]]}; 
    pS = {Cos[\[Beta]], 0};\), "\n", 
    \(Show[
      Graphics[{Circle[origine, 1], Line[{{\(-1.2\), 0}, {1.2, 0}}], 
          Line[{{0, \(-1.2\)}, {0, 1.2}}], 
          Line[{pP, origine, pR}]}], \[IndentingNewLine]Graphics[{colBlu, 
          Arrow[origine, pQ, stileVet], 
          Arrow[pQ, pP, stileVet]}], \[IndentingNewLine]Graphics[{colBlu, 
          Arrow[origine, pS, stileVet], 
          Arrow[pS, pR, 
            stileVet]}], \[IndentingNewLine]Graphics[{Text["\<O\>", 
            origine, {1, 1}, TextStyle \[Rule] stileTesto], 
          Text["\<Q\>", pQ, {0, 1}, TextStyle \[Rule] stileTesto], 
          Text["\<P\>", pP, {0, \(-1\)}, TextStyle \[Rule] stileTesto], 
          Text["\<S\>", pS, {0, 1}, TextStyle \[Rule] stileTesto], 
          Text["\<R\>", pR, {0, \(-1\)}, TextStyle \[Rule] stileTesto]}], 
      Prolog -> {{colGiallo, Polygon[{origine, pQ, pP}], 
            Polygon[{origine, pS, pR}]}, {colVerde, 
            Disk[{0, 0},  .3, {0, \[Beta]}]}, {colRosso, 
            Disk[origine,  .2, {0, \[Alpha]}]}}, 
      AspectRatio \[Rule] Automatic, Axes \[Rule] True]; 
    Clear[\[Alpha], \[Beta]];\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Grafico", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.396825 0.5 0.396825 [
[.10317 .4875 -6.96875 -10.9375 ]
[.10317 .4875 6.96875 0 ]
[.30159 .4875 -10.3125 -10.9375 ]
[.30159 .4875 10.3125 0 ]
[.69841 .4875 -7.5625 -10.9375 ]
[.69841 .4875 7.5625 0 ]
[.89683 .4875 -4.21875 -10.9375 ]
[.89683 .4875 4.21875 0 ]
[.4875 .10317 -13.9375 -5.46875 ]
[.4875 .10317 0 5.46875 ]
[.4875 .30159 -20.625 -5.46875 ]
[.4875 .30159 0 5.46875 ]
[.4875 .69841 -15.125 -5.46875 ]
[.4875 .69841 0 5.46875 ]
[.4875 .89683 -8.4375 -5.46875 ]
[.4875 .89683 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .5 m
.10317 .50625 L
s
gsave
.10317 .4875 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.30159 .5 m
.30159 .50625 L
s
gsave
.30159 .4875 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.69841 .5 m
.69841 .50625 L
s
gsave
.69841 .4875 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.89683 .5 m
.89683 .50625 L
s
gsave
.89683 .4875 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.14286 .5 m
.14286 .50375 L
s
.18254 .5 m
.18254 .50375 L
s
.22222 .5 m
.22222 .50375 L
s
.2619 .5 m
.2619 .50375 L
s
.34127 .5 m
.34127 .50375 L
s
.38095 .5 m
.38095 .50375 L
s
.42063 .5 m
.42063 .50375 L
s
.46032 .5 m
.46032 .50375 L
s
.53968 .5 m
.53968 .50375 L
s
.57937 .5 m
.57937 .50375 L
s
.61905 .5 m
.61905 .50375 L
s
.65873 .5 m
.65873 .50375 L
s
.7381 .5 m
.7381 .50375 L
s
.77778 .5 m
.77778 .50375 L
s
.81746 .5 m
.81746 .50375 L
s
.85714 .5 m
.85714 .50375 L
s
.06349 .5 m
.06349 .50375 L
s
.02381 .5 m
.02381 .50375 L
s
.93651 .5 m
.93651 .50375 L
s
.97619 .5 m
.97619 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .10317 m
.50625 .10317 L
s
gsave
.4875 .10317 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .30159 m
.50625 .30159 L
s
gsave
.4875 .30159 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .69841 m
.50625 .69841 L
s
gsave
.4875 .69841 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .89683 m
.50625 .89683 L
s
gsave
.4875 .89683 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .14286 m
.50375 .14286 L
s
.5 .18254 m
.50375 .18254 L
s
.5 .22222 m
.50375 .22222 L
s
.5 .2619 m
.50375 .2619 L
s
.5 .34127 m
.50375 .34127 L
s
.5 .38095 m
.50375 .38095 L
s
.5 .42063 m
.50375 .42063 L
s
.5 .46032 m
.50375 .46032 L
s
.5 .53968 m
.50375 .53968 L
s
.5 .57937 m
.50375 .57937 L
s
.5 .61905 m
.50375 .61905 L
s
.5 .65873 m
.50375 .65873 L
s
.5 .7381 m
.50375 .7381 L
s
.5 .77778 m
.50375 .77778 L
s
.5 .81746 m
.50375 .81746 L
s
.5 .85714 m
.50375 .85714 L
s
.5 .06349 m
.50375 .06349 L
s
.5 .02381 m
.50375 .02381 L
s
.5 .93651 m
.50375 .93651 L
s
.5 .97619 m
.50375 .97619 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto fill
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto
-0.03 0.0075 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
1 1 0 r
.5 .5 m
.84366 .5 L
.84366 .69841 L
F
.5 .5 m
.15634 .5 L
.15634 .69841 L
F
0 1 0 r
.5 .5 m
.5 .5 .11905 0 150 arc
F
1 0 0 r
.5 .5 m
.5 .5 .07937 0 30 arc
F
0 g
.5 Mabswid
newpath
.5 .5 .39683 0 365.73 arc
s
.02381 .5 m
.97619 .5 L
s
.5 .02381 m
.5 .97619 L
s
.84366 .69841 m
.5 .5 L
.15634 .69841 L
s
0 0 1 r
.5 .5 m
.84366 .5 L
s
% Start of user PostScript
0 0 0.866025 0 MAarrowhead1
% End of user PostScript
.84366 .5 m
.84366 .69841 L
s
% Start of user PostScript
0.866025 0 0.866025 0.5 MAarrowhead1
% End of user PostScript
.5 .5 m
.15634 .5 L
s
% Start of user PostScript
0 0 -0.866025 0 MAarrowhead1
% End of user PostScript
.15634 .5 m
.15634 .69841 L
s
% Start of user PostScript
-0.866025 0 -0.866025 0.5 MAarrowhead1
% End of user PostScript
0 g
gsave
.5 .5 -71.9375 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.84366 .5 -66.4688 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Q) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.84366 .69841 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
69.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.15634 .5 -66 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.15634 .69841 -66.2188 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(R) show
69.438 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  Magnification->0.9,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?oo
o`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?oo
o`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3o
ool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo
0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?oo
o`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000
003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0
oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80
oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<00000
0?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3o
ool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0
oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<0
00000?ooo`3oool0/P3oool00:P0oooo00<0oooO09a8M02oool0203oool00`000000oooo0?ooo`2b
0?ooo`00Z03oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo0;80oooo002P0?ooo`03
0?noM000000000000080000000H004RL0=ooo`3oool0oooO09a8M02oool80?ooo`030000003oool0
oooo0;80oooo002S0?ooob400000Y03oool009`0oooo1`0000030?ooo`050?oog`2LW;l0oooO09a8
M02oool0203oool00`000000oooo0?ooo`0>0?ooo`L00000W@3oool009L0oooo1@00000;0?ooo`04
0?noM0000000001d0;ooo`P0oooo00<000000?ooo`3oool05@3oool5000009P0oooo002C0?ooo`@0
00004@3oool00`3ookl0M01d0;ooo`080?ooo`030000003oool0oooo01X0oooo1000002D0?ooo`00
SP3oool500000200oooo00<000000?ooo`3oool07P3oool5000008l0oooo002;0?ooo`<000009@3o
ool00`000000oooo0?ooo`0S0?ooo`<00000S03oool008L0oooo1000000X0?ooo`030000003oool0
oooo02H0oooo100000280?ooo`00QP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0Q@3oool00880oooo1000000]0?ooo`030000003oool0oooo02/0
oooo100000230?ooo`00O`3oool300000340oooo00<000000?ooo`3oool0;`3oool300000800oooo
001m0?ooo`800000=03oool00`000000oooo0?ooo`0b0?ooo`800000OP3oool007X0oooo0`00000f
0?ooo`030000003oool0oooo03@0oooo0`00001k0?ooo`00N03oool2000003T0oooo00<000000?oo
o`3oool0=`3oool2000007T0oooo001g0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`1f0?ooo`00M03oool3000003`0oooo0P00000k0?ooo`<00000
M@3oool00780oooo0P00000o0?ooo`030000003oool0oooo03d0oooo0P00001c0?ooo`00L03oool2
00000440oooo00<000000?ooo`3oool0?`3oool200000740oooo001_0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1^0?ooo`00K@3oool2000004@0
oooo00<000000?ooo`3oool0@P3oool2000006h0oooo001/0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1[0?ooo`00J@3oool3000004L0oooo00<0
00000?ooo`3oool0A@3oool3000006X0oooo001W0?ooo`800000BP3oool00`000000oooo0?ooo`18
0?ooo`800000J03oool006H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo06D0oooo001T0?ooo`800000C@3oool00`000000oooo0?ooo`1;0?ooo`80
0000I@3oool006<0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo0680oooo001Q0?ooo`800000D03oool00`000000oooo0?ooo`1>0?ooo`800000HP3o
ool00600oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo05l0oooo001N0?ooo`800000D`3oool00`000000oooo0?ooo`1A0?ooo`800000G`3oool005d0
oooo00<000000?ooo`3oool0D`3oool2000005@0oooo00<000000?ooo`3oool0G03oool005`0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05/0oooo
001K0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`1J0?ooo`00FP3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool0F@3oool005P0oooo0P00001I0?ooo`030000003oool0oooo05L0oooo0P00001I0?oo
o`00E`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0EP3oool005H0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo05D0oooo001E0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`1D0?ooo`00E03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo05`0oooo00<000000?ooo`3oool0D`3oool005<0oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`1M0?ooo`030000003oool0oooo0580oooo001B0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1A0?ooo`00D@3oool00`000000oooo
0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0D03oool00500oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo04l0oooo001?
0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1>
0?ooo`00CP3oool00`000000oooo0?ooo`1R0?ooo`800000H`3oool00`000000oooo0?ooo`1=0?oo
o`00C@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool0C03oool004`0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1T0?ooo`030000
003oool0oooo04/0oooo001;0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`1:0?ooo`00BP3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0
oooo06H0oooo00<000000?ooo`3oool0B@3oool004T0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`1W0?ooo`030000003oool0oooo04P0oooo00180?ooo`030000003oool0oooo06P0
oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`170?ooo`00A`3oool00`000000oooo
0?ooo`1Y0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0AP3oool004H0oooo00<0
00000?ooo`3oool0JP3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo04D0oooo0015
0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`14
0?ooo`00A@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0A03oool004@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo04<0oooo00130?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0
K@3oool00`000000oooo0?ooo`120?ooo`00@P3oool00`000000oooo0?ooo`1^0?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool0@@3oool00440oooo00<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0400oooo00100?ooo`030000003oool0oooo
0700oooo0P00001a0?ooo`030000003oool0oooo03l0oooo00100?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0o0?ooo`00?`3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0?P3oool003h0oooo00<0
00000?ooo`3oool0LP3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo03d0oooo000n
0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0m
0?ooo`00?@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool0?03oool003`0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo03/0oooo000l0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`0k0?ooo`00>`3oool00`000000oooo0?ooo`1e0?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool0>P3oool003X0oooo00<000000?ooo`3oool0MP3oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo03T0oooo000j0?ooo`030000003oool0oooo
07H0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0i0?ooo`00>@3oool00`000000
oooo0?ooo`1S0?ooo`0:0;md00000000001809cOo`3oool0oono07A8W03Oool0oooo0;md00800000
00<0B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo03P0oooo
000i0?ooo`030000003oool0oooo0680oooo00H0okmd0018W03Oool0okmd0018W03Oool30?ooo`06
0?noM018W=l0oooo0?ooo`3OW4P0M;oo1P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0
oooo03P0oooo000h0?ooo`030000003oool0oooo05`0oooo00<0okmd0000000000000P0000002000
B9`0gooo0=nLB018W=l0oooo0?oo_`1d07@0_ooo1`3oool00`3o_g@0B9cO0?ooo`050?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool0>03oool003P0oooo00<000000?ooo`3oool0H`3o
ool01P3OW4P0M;oo0?ooo`3ooml0W4Qd0;ooo`<0oooo00H0okmd0000M02oool0oooo0=nLB01d_ol6
0?ooo`<00000N03oool00`000000oooo0?ooo`0g0?ooo`00=`3oool00`000000oooo0?ooo`1T0?oo
o`060=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q804P00000000007Bo00L0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0f0?ooo`00=P3oool00`000000oooo0?oo
o`1U0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool00`3ooml0W4Q809cOo`090?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0
IP3oool0102oM00000000000B02Lgol50?ooo`050;md0000000000000000B02Lgol01P3oool00`00
0000oooo0?ooo`1j0?ooo`030000003oool0oooo03D0oooo000e0?ooo`030000003oool0oooo07/0
oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0d0?ooo`00=03oool00`000000oooo
0?ooo`1l0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0=03oool003@0oooo00<0
00000?ooo`3oool0O03oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03<0oooo000c
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0c
0?ooo`00<`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo07d0oooo00<000000?oo
o`3oool0<P3oool003<0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`1m0?ooo`03
0000003oool0oooo0380oooo000b0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0b0?ooo`00<P3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo07h0oooo00<000000?ooo`3oool0<@3oool00340oooo00<000000?ooo`3oool0O`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0300oooo000`0?ooo`030000003oool0oooo
0800oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0`0?ooo`00<03oool00`000000
oooo0?ooo`200?ooo`800000P@3oool00`000000oooo0?ooo`0_0?ooo`00<03oool00`000000oooo
0?ooo`200?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0;`3oool00300oooo00<0
00000?ooo`3oool0P03oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo02l0oooo000_
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0^
0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0840oooo00<000000?oo
o`3oool0;P3oool002h0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`220?ooo`03
0000003oool0oooo02d0oooo000^0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0
PP3oool00`000000oooo0?ooo`0]0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000003o
ool0oooo0880oooo00<000000?ooo`3oool0;@3oool002d0oooo00<000000?ooo`3oool0P`3oool0
0`000000oooo0?ooo`230?ooo`030000003oool0oooo02`0oooo000]0?ooo`030000003oool0oooo
08<0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0/0?ooo`00;@3oool00`000000
oooo0?ooo`230?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0;03oool002`0oooo
00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo02`0oooo
000/0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?oo
o`0[0?ooo`00:`3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0Q@3oool2000008H0oooo00<000000?oo
o`3oool0:P3oool002/0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`250?ooo`03
0000003oool0oooo02X0oooo000Z0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
Q@3oool00`000000oooo0?ooo`0Z0?ooo`00:P3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0:@3oool002X0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo02T0oooo000Y0?ooo`030000003oool0oooo
08L0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0Y0?ooo`00:@3oool00`000000
oooo0?ooo`270?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0:03oool002T0oooo
00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo02P0oooo
000Y0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?oo
o`0X0?ooo`00:@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo08L0oooo00<00000
0?ooo`3oool0:03oool002T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`270?oo
o`030000003oool0oooo02P0oooo000X0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool0R03oool00`000000oooo0?ooo`0W0?ooo`00:03oool00`000000oooo0?ooo`280?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool09`3oool002P0oooo00<000000?ooo`3oool0R03o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo02L0oooo000W0?ooo`030000003oool0
oooo08T0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0W0?ooo`009`3oool00`00
0000oooo0?ooo`290?ooo`800000RP3oool00`000000oooo0?ooo`0V0?ooo`009`3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool09P3oool002L0oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo02H0oooo
000W0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?oo
o`0V0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo08T0oooo00<00000
0?ooo`3oool09P3oool002H0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`2:0?oo
o`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000
003oool0oooo08X0oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool0RP3o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0
oooo08X0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`00
0000oooo0?ooo`2:0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool09@3oool002D0
oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02D0
oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo08/0oooo00<0
00000?ooo`3oool0903oool002D0oooo00D000000?ooo`3ooml0W4Qd0;ooo`0o0?ooo`0:0;md0000
0000001809cOo`3oool0oono07A8W03Oool0oooo0;md0080000000<0B9cO0?ooo`3oool0>`3oool2
000003l0oooo00X0_g@00000000004P0W=oo0?ooo`3ookl0M4RL0=ooo`3oool0_g@00P0000000`18
W=l0oooo0?ooo`0n0?ooo`030000002LB7@0_ooo02@0oooo000U0?ooo`050000003oool0oooO09a8
M02oool0?P3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00H0okmd04RLg`3oool0oooo
0=nLB01d_oll0?ooo`030000003oool0oooo03d0oooo00H0okmd0018W03Oool0okmd0018W03Oool3
0?ooo`060?noM018W=l0oooo0?ooo`3OW4P0M;oo?`3oool00`000000W4Qd0;ooo`0T0?ooo`007P3o
ool00`3o_g@0000000000002000000070018W03Oool000000?ooo`3ooml0W4Qd0;ooo`0g0?ooo`03
0?noM000000000000080000000P004RL0=ooo`3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`L0oooo00<0
okmd04RLg`3oool0>`3oool00`000000oooo0?ooo`0m0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0
_ooo1`3oool00`3o_g@0B9cO0?ooo`0]0?ooo`030?noM000M;l0oooo00h0oooo00<0000009a8M02o
ool0903oool002D0oooo00D000000?ooo`3ooml0W4Qd0;ooo`0;0?ooo`060?oo_`1d000000000000
0000B9`0gooo;@3oool01P3OW4P0M;oo0?ooo`3ooml0W4Qd0;ooo`<0oooo00H0okmd0000M02oool0
oooo0=nLB01d_olb0?ooo`060?oo_`1d000000000000000007@0_ooo103oool00`000000oooo0?oo
o`0m0?ooo`060=nLB01d_ol0oooo0?oog`2LB7@0_ooo0`3oool01P3o_g@0001d0;ooo`3oool0gia8
07BoobT0oooo00<0oono07@0000000000P0000000`0007@0_ooo0?ooo`0>0?ooo`030000002LB7@0
_ooo02@0oooo000U0?ooo`050000002LW;l0oooO09a8M02oool02`3oool01P2oM000001d0;ooo`3o
gi`0B00004RLgbd0oooo00H0gia804RLg`3oool0oono07@0M02oool30?ooo`050?oo_`1dB4P0B000
00000000M;l0<P3oool0203ookl0M0000018W03Oool0oooO09a8000007@0_ooo0`3oool00`000000
oooo0?ooo`0m0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q804P00000
000007Bo02T0oooo00P0oono07@00000B9`0gooo0;md00000000001809cOo`d0oooo00D0oooO09bL
_`000000W4Qd0;ooo`0T0?ooo`009@3oool01@000000okmd0000000007@0_ooo00h0oooo00<0oono
07@00018W=l0;@3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00<0oooO09a8B02Lgol0
=03oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00<0oooo00<000000?ooo`3oool0
?@3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00<0oooO09a8B02Lgol0:`3oool0203o
_g@0001809cOo`3ogi`0B4RL0=oOW0180000B9cO3P3oool0103o_g@000000000M02ooolT0?ooo`00
9@3oool01@000000oooo0?oo_`1d07@0_ooo00d0oooo00@0_g@00000000004P0W=oo;P3oool0102o
M00000000000B02Lgol50?ooo`050;md0000000000000000B02Lgol0<@3oool00`3OW4P0001d0;oo
o`020?ooo`030?oo_`1d0000B9cO00<0oooo00<000000?ooo`3oool0?P3oool0102oM00000000000
B02Lgol50?ooo`050;md0000000000000000B02Lgol0:03oool00`3OW4P0001d0;ooo`020?ooo`03
0?oo_`1d0000B9cO00l0oooo00<0000007@0M02oool0903oool002D0oooo00<000000?ooo`3oool0
3@3oool0103ookl0M00000000000M;m_0?ooo`030=nLB00007@0_ooo0080oooo00<0oono07@00018
W=l00`3oool00`000000oooo0?ooo`1d0?ooo`030=nLB00007@0_ooo0080oooo00<0oono07@00018
W=l03`3oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`0=0?ooo`030?no
M00004P0W=oo0700oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`030?ooo`030000
003oool0oooo07@0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0?0?ooo`030000
003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo00d0oooo00H0okmd0000B02Lgol0gia8
0000B02Lgom]0?ooo`030?oo_`1d000007Bo0080oooo00<0_g@00000M02oool00`3oool00`000000
oooo0?ooo`1d0?ooo`080?oo_`1d000004RL0=ooo`3oool0_g@00018W03Oool?0?ooo`030000003o
ool0oooo02@0oooo000U0?ooo`030000003oool0oooo00h0oooo00@0_g@0000000000000B9cOK`3o
ool01P3ookl0M000000000000000001d0;ooo`@0oooo00<000000?ooo`3oool0M@3oool01P3ookl0
M00000000000000004RL0=oooa00oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?oo
o`3oool06@3oool20000og00oooo00<000000?ooo`3oool0KP3oool20000oa/0oooo00<000000?oo
o`3oool0903oool002D0oooo00<000000?ooo`3oool05P3oool50000og00oooo00<000000?ooo`3o
ool0KP3oool50000oaP0oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0
4P3oool80000og40oooo00<000000?ooo`3oool0K`3oool80000oa@0oooo00<000000?ooo`3oool0
903oool003P00000m`000?li00000000203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000o`3oo`00
003o00L0003oK`3oo`05000001T0o`003`00o`170?oo00P0003o00<0ool00000o`3oool00`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`070?ooo`009@3oool00`000000oooo0?ooo`0@0?ooo`030000o`3oo`00ool0
0080ool01P000?m/0?oo008000000P00o`000`0000000?l0003o0002000001L0o`003`00o`160?oo
00H0003o103oo`000`000?l0oooo0?ooo`0@0?ooo`030000003oool0oooo02@0oooo000U0?ooo`03
0000003oool0oooo0100oooo00<0003o0?oo003oo`001P3oo`020000ofX0ool00P000004003o0003
00000000o`000?l000800?l00P00000E0?l000l00?l0AP3oo`020000o`P0ool000<0003o0?ooo`3o
ool0403oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`0@0?ooo`030000
o`3oo`00ool00740ool000<00000003o0000o`001000o`000`0000000?l0003o0004003o00030000
003o0000o`000180o`003`00o`1@0?oo00030000o`3oool0oooo0100oooo00<000000?ooo`3oool0
903oool002D0oooo00<000000?ooo`3oool0403oool00`000?l0ool00?oo001_0?oo008000001`00
o`000`0000000?l0003o0005003o008000004P3o000>003o0540ool000<0003o0?ooo`3oool0403o
ool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`0@0?ooo`030000o`3oo`00
ool006d0ool00P000009003o000300000000o`000?l000L00?l00P00000@0?l000h00?l0D@3oo`00
0`000?l0oooo0?ooo`0@0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo
0100oooo00<0003o0?oo003oo`00K03oo`000`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<000000?l0003o00003@3o000>003o0540ool000<0003o0?ooo`3oool0403oool00`00
0000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`0@0?ooo`030000o`3oo`00ool006X0
ool00P00000<003o000300000000o`000?l000X00?l00P00000=0?l000h00?l0D@3oo`000`000?l0
oooo0?ooo`0@0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo0100oooo
00<0003o0?oo003oo`00J03oo`02000000h00?l000<00000003o0000o`003000o`02000000X0o`00
3`00o`1A0?oo00030000o`3oool0oooo0100oooo00<000000?ooo`3oool0903oool002D0oooo00<0
00000?ooo`3oool0403oool00`000?l0ool00?oo001V0?oo008000004000o`000`0000000?l0003o
000>003o00800000203o000>003o0580ool000<0003o0?ooo`3oool0403oool00`000000oooo0?oo
o`0T0?ooo`009@3oool00`000000oooo0?ooo`0@0?ooo`030000o`3oo`00ool006D0ool000<00000
003o0000o`004000o`000`0000000?l0003o000@003o00030000003o0000o`0000@0o`003`00o`1B
0?oo00030000o`3oool0oooo0100oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?oo
o`3oool0403oool00`000?l0ool00?oo001S0?oo008000004`00o`000`0000000?l0003o000A003o
00800000103o000?003o0580ool000<0003o0?ooo`3oool0403oool00`000000oooo0?ooo`0T0?oo
o`009@3oool00`000000oooo0?ooo`0@0?ooo`030000o`3oo`00ool00640ool00P00000E003o0003
00000000o`000?l001<00?l00P0000020?l000l00?l0DP3oo`000`000?l0oooo0?ooo`0@0?ooo`03
0000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo0100oooo00<0003o0?oo003oo`00
G`3oo`02000001L00?l000<00000003o0000o`005@00o`02000000h00?l0D`3oo`000`000?l0oooo
0?ooo`0@0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo0100oooo00<0
003o0?oo003oo`00GP3oo`000`0000000?l0003o000G003o000300000000o`000?l001L00?l000<0
0000003o0000o`002`00o`1C0?oo00030000o`3oool0oooo0100oooo00<000000?ooo`3oool0903o
ool002D0oooo00<000000?ooo`3oool0403oool00`000?l0ool00?oo001L0?oo008000006P00o`00
0`0000000?l0003o000H003o008000002`00o`1C0?oo00030000o`3oool0oooo0100oooo00<00000
0?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0403oool00`000?l0ool00?oo001J0?oo
008000007000o`000`0000000?l0003o000J003o008000002000o`1D0?oo00030000o`3oool0oooo
00l0oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool03`3oool00`000?l0
ool00?oo001H0?oo008000007P00o`000`0000000?l0003o000L003o008000001P00o`1D0?oo0003
0000o`3oool0oooo00l0oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool0
3`3oool00`000?l0ool00?oo001G0?oo000300000000o`000?l001h00?l000<00000003o0000o`00
7P00o`000`0000000?l0003o0002003o05D0ool000<0003o0?ooo`3oool03`3oool00`000000oooo
0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`0?0?ooo`030000o`3oo`00ool005D0ool00P00
000Q003o000300000000o`000?l001l00?l00P000002003o05D0ool000<0003o0?ooo`3oool03`3o
ool00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`0?0?ooo`030000o`3oo`00
ool005<0ool00P00000S003o000300000000o`000?l002400?l00P00001E0?oo00030000o`3oool0
oooo00l0oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool03`3oool00`00
0?l0ool00?oo001B0?oo00030000003oool00?l002<00?l000<00000003o0000o`008P00o`000`3o
ool000000?oo001C0?oo00030000o`3oool0oooo00l0oooo00<000000?ooo`3oool09@3oool002H0
oooo00<000000?ooo`3oool03`3oool00`000?l0ool00?oo001@0?oo008000000`3ooolS003o0003
00000000o`000?l002400?l00`3oool200000580ool000<0003o0?ooo`3oool03`3oool00`000000
oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`0?0?ooo`030000o`3oo`00ool004h0ool0
0P0000050?ooob<00?l000<00000003o0000o`008@00o`050?ooo`800000D03oo`000`000?l0oooo
0?ooo`0>0?ooo`030000003oool0oooo02H0oooo000W0?ooo`030000003oool0oooo00h0oooo00<0
003o0?oo003oo`00C03oo`02000000P0oooo8P00o`000`0000000?l0003o000P003o00P0oooo0P00
001>0?oo00030000o`3oool0oooo00h0oooo00<000000?ooo`3oool09P3oool002L0oooo00<00000
0?ooo`3oool03P3oool00`000?l0ool00?oo001;0?oo00030000003oool0oooo00T0oooo8@00o`00
0`0000000?l0003o000O003o00/0oooo00<000000?oo003oo`00B`3oo`000`000?l0oooo0?ooo`0>
0?ooo`030000003oool0oooo02H0oooo000W0?ooo`030000003oool0oooo00h0oooo00<0003o0?oo
003oo`00B@3oo`02000000`0oooo8@00o`000`0000000?l0003o000O003o00`0oooo0P00001;0?oo
00030000o`3oool0oooo00h0oooo00<000000?ooo`3oool09P3oool002L0oooo00<000000?ooo`3o
ool03P3oool00`000?l0ool00?oo00170?oo008000003`3ooolP003o000300000000o`000?l001h0
0?l03`3oool2000004T0ool000<0003o0?ooo`3oool03P3oool00`000000oooo0?ooo`0V0?ooo`00
9`3oool00`000000oooo0?ooo`0>0?ooo`030000o`3oo`00ool004D0ool00P00000B0?oooal00?l0
00<00000003o0000o`007@00o`0B0?ooo`800000A`3oo`000`000?l0oooo0?ooo`0=0?ooo`030000
003oool0oooo02L0oooo000X0?ooo`030000003oool0oooo00d0oooo00<0003o0?oo003oo`00A03o
o`000`000000oooo0?ooo`0B0?oooal00?l000<00000003o0000o`007000o`0E0?ooo`030000003o
o`00ool004@0ool000<0003o0?ooo`3oool03@3oool00`000000oooo0?ooo`0W0?ooo`00:03oool0
0`000000oooo0?ooo`0=0?ooo`030000o`3oo`00ool00480ool00P00000G0?oooad00?l000<00000
003o0000o`006P00o`0H0?ooo`800000A03oo`000`000?l0oooo0?ooo`0=0?ooo`030000003oool0
oooo02L0oooo000X0?ooo`030000003oool0oooo00d0oooo00<0003o0?oo003oo`00@03oo`020000
01X0oooo7000o`000`0000000?l0003o000I003o01/0oooo0P0000120?oo00030000o`3oool0oooo
00d0oooo00<000000?ooo`3oool09`3oool002T0oooo00<000000?ooo`3oool0303oool00`000?l0
ool00?oo000n0?oo008000007P3ooolJ003o000300000000o`000?l001P00?l07P3oool200000400
ool000<0003o0?ooo`3oool0303oool00`000000oooo0?ooo`0X0?ooo`00:@3oool00`000000oooo
0?ooo`0<0?ooo`030000o`3oo`00ool003d0ool000<000000?ooo`3oool07`3ooolI003o00030000
0000o`000?l001L00?l08@3oool00`000000ool00?oo000m0?oo00030000o`3oool0oooo00`0oooo
00<000000?ooo`3oool0:03oool002T0oooo00<000000?ooo`3oool0303oool00`000?l0ool00?oo
000k0?oo008000008`3ooolH003o000300000000o`000?l001H00?l08`3oool2000003d0ool000<0
003o0?ooo`3oool0303oool00`000000oooo0?ooo`0X0?ooo`00:@3oool00`000000oooo0?ooo`0<
0?ooo`030000o`3oo`00ool003T0ool00P00000V0?oooaL00?l000<00000003o0000o`005@00o`0V
0?ooo`800000>`3oo`000`000?l0oooo0?ooo`0<0?ooo`030000003oool0oooo02P0oooo000Y0?oo
o`030000003oool0oooo00`0oooo00<0003o0?oo003oo`00>03oo`000`000000oooo0?ooo`0X0?oo
oaD00?l000<00000003o0000o`004P00o`0[0?ooo`030000003oo`00ool003P0ool000<0003o0?oo
o`3oool0303oool00`000000oooo0?ooo`0X0?ooo`00:@3oool00`000000oooo0?ooo`0<0?ooo`03
0000o`3oo`00ool003H0ool00P00000/0?oooa@00?l000<00000003o0000o`004000o`0^0?ooo`80
0000>03oo`000`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo02T0oooo000Z0?ooo`030000
003oool0oooo00/0oooo00<0003o0?oo003oo`00=03oo`0200000300oooo4P00o`000`0000000?l0
003o000?003o0340oooo0P00000f0?oo00030000o`3oool0oooo00/0oooo00<000000?ooo`3oool0
:@3oool002X0oooo00<000000?ooo`3oool02`3oool00`000?l0ool00?oo000b0?oo00800000=@3o
ool?003o000300000000o`000?l000d00?l0=@3oool2000003@0ool000<0003o0?ooo`3oool02`3o
ool00`000000oooo0?ooo`0Y0?ooo`00:P3oool00`000000oooo0?ooo`0;0?ooo`030000o`3oo`00
ool00340ool000<000000?ooo`3oool0=`3oool=003o000300000000o`000?l000X00?l0>P3oool0
0`000000ool00?oo000a0?oo00030000o`3oool0oooo00X0oooo00<000000?ooo`3oool0:P3oool0
02/0oooo00<000000?ooo`3oool02P3oool00`000?l0ool00?oo000_0?oo00800000?@3oool:003o
000300000000o`000?l000H00?l0?`3oool200000340ool000<0003o0?ooo`3oool02P3oool00`00
0000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0:0?ooo`030000o`3oo`00ool002d0
ool00P0000160?ooo`<00?l000@00000003o0000o`000?l0AP3oool2000002l0ool000<0003o0?oo
o`3oool02P3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0:0?ooo`03
0000o`3oo`00ool002/0ool00P00001;0?ooo`030000003oool0oooo04T0oooo0P00000]0?oo0003
0000o`3oool0oooo00X0oooo00<000000?ooo`3oool0:P3oool002`0oooo00<000000?ooo`3oool0
2@3oool00`000?l0ool00?oo000Z0?oo00030000003oool0oooo04/0oooo00<000000?ooo`3oool0
B`3oool00`000000ool00?oo000Z0?oo00030000o`3oool0oooo00T0oooo00<000000?ooo`3oool0
:`3oool002`0oooo00<000000?ooo`3oool02@3oool00`000?l0ool00?oo000X0?oo00800000CP3o
ool00`000000oooo0?ooo`1<0?ooo`800000:P3oo`000`000?l0oooo0?ooo`080?ooo`030000003o
ool0oooo02`0oooo000]0?ooo`030000003oool0oooo00P0oooo00<0003o0?oo003oo`009P3oo`02
00000500oooo00<000000?ooo`3oool0CP3oool2000002P0ool000<0003o0?ooo`3oool0203oool0
0`000000oooo0?ooo`0/0?ooo`00;@3oool00`000000oooo0?ooo`080?ooo`030000o`3oo`00ool0
02@0ool00P00001B0?ooo`030000003oool0oooo0500oooo0P00000V0?oo00030000o`3oool0oooo
00P0oooo00<000000?ooo`3oool0;03oool002d0oooo00<000000?ooo`3oool0203oool00`000?l0
ool00?oo000S0?oo00030000003oool0oooo0580oooo00<000000?ooo`3oool0DP3oool00`000000
ool00?oo000S0?oo00030000o`3oool0oooo00P0oooo00<000000?ooo`3oool0;03oool002h0oooo
00<000000?ooo`3oool01`3oool00`000?l0ool00?oo000Q0?oo00800000E@3oool00`000000oooo
0?ooo`1C0?ooo`8000008`3oo`000`000?l0oooo0?ooo`070?ooo`030000003oool0oooo02d0oooo
000^0?ooo`030000003oool0oooo00L0oooo00<0003o0?oo003oo`007`3oo`02000005L0oooo00<0
00000?ooo`3oool0E@3oool200000240ool000<0003o0?ooo`3oool01`3oool00`000000oooo0?oo
o`0]0?ooo`00;P3oool00`000000oooo0?ooo`070?ooo`030000o`3oo`00ool001h0ool000<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`1G0?ooo`030000003oo`00ool001h0ool000<0003o
0?ooo`3oool01`3oool00`000000oooo0?ooo`0]0?ooo`00;P3oool00`000000oooo0?ooo`070?oo
o`030000o`3oo`00ool001`0ool00P00001J0?ooo`030000003oool0oooo05P0oooo0P00000N0?oo
00030000o`3oool0oooo00H0oooo00<000000?ooo`3oool0;P3oool002l0oooo00<000000?ooo`3o
ool01P3oool00`000?l0ool00?oo000J0?oo00800000G03oool00`000000oooo0?ooo`1J0?ooo`80
0000703oo`000`000?l0oooo0?ooo`060?ooo`030000003oool0oooo02h0oooo000`0?ooo`030000
003oool0oooo00D0oooo00<0003o0?oo003oo`00603oo`02000005h0oooo00<000000?ooo`3oool0
G03oool2000001X0ool000<0003o0?ooo`3oool01@3oool00`000000oooo0?ooo`0_0?ooo`00<03o
ool00`000000oooo0?ooo`050?ooo`030000o`3oo`00ool001L0ool000<000000?ooo`3oool0GP3o
ool00`000000oooo0?ooo`1N0?ooo`030000003oo`00ool001L0ool000<0003o0?ooo`3oool01@3o
ool00`000000oooo0?ooo`0_0?ooo`00<03oool00`000000oooo0?ooo`050?ooo`030000o`3oo`00
ool001D0ool00P00001Q0?ooo`800000H03oool2000001L0ool000<0003o0?ooo`3oool01@3oool0
0`000000oooo0?ooo`0_0?ooo`00<03oool00`000000oooo0?ooo`050?ooo`030000o`3oo`00ool0
01<0ool00P00001S0?ooo`030000003oool0oooo0640oooo0P00000E0?oo00030000o`3oool0oooo
00@0oooo00<000000?ooo`3oool0<03oool00340oooo00<000000?ooo`3oool0103oool00`000?l0
ool00?oo000A0?oo00800000I@3oool00`000000oooo0?ooo`1S0?ooo`8000004`3oo`000`000?l0
oooo0?ooo`040?ooo`030000003oool0oooo0300oooo000b0?ooo`040000003oool0oooo0000o`80
oooo00<0003o0?oo00000?l0403oo`000`000000oooo0?ooo`1U0?ooo`030000003oool0oooo06D0
oooo00<000000?oo003oo`003P3oo`000`000?l0ool00000o`020?ooo`040000o`3oool0oooo0000
03<0oooo000b0?ooo`030000003oool0oooo00H0003o3P3oo`02000006P0oooo00<000000?ooo`3o
ool0IP3oool2000000h0ool01P000?l00`3oool000000?ooo`0c0?ooo`00<`3oool00`000000oooo
0?ooo`050000o``0ool00P00001Z0?ooo`030000003oool0oooo06P0oooo0P00000<0?oo00D0003o
0P3oool00`000000oooo0?ooo`0b0?ooo`00<`3oool00`000000oooo0?ooo`040000o`/0ool00P00
001/0?ooo`030000003oool0oooo06X0oooo0P00000;0?oo00@0003o0P3oool00`000000oooo0?oo
o`0b0?ooo`00<`3oool00`000000oooo0?ooo`040000o`X0ool000<000000?ooo`3oool0K03oool0
0`000000oooo0?ooo`1/0?ooo`030000003oo`00ool000P0ool010000?l00`3oool000000?ooo`0d
0?ooo`00=03oool00`000000oooo0000o`030000o`P0ool00P00001_0?ooo`030000003oool0oooo
06d0oooo0P0000080?oo00@0003o00<0oooo0000003oool0=03oool003@0oooo00<000000?ooo`3o
ool00`000?l60?oo00800000L@3oool00`000000oooo0?ooo`1_0?ooo`8000001P3oo`030000o`03
0?ooo`000000oooo03D0oooo000e0?ooo`030000003oool0003o0080003o1@3oo`000`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo0740oooo00<000000?oo003oo`000`3oo`030000o`030?oo
o`000000oooo03D0oooo000f0?ooo`04000000000?l0003o0000o`<0ool00P00001d0?ooo`030000
003oool0oooo0780oooo0P0000030?oo00<0003o00<000000?ooo`3oool0=@3oool003H0oooo00<0
00000000o`000?l00P3oo`0200000680oooo00X0_g@00000000004P0W=oo0?ooo`3ookl0M4RL0=oo
o`3oool0_g@00P0000000`18W=l0oooo0?ooo`050?ooo`030000003oool0oooo07@0oooo0P000002
0?oo0080003o>03oool003L0oooo00@000000000o`0000000000H`3oool01P3o_g@004RL0=ooo`3o
_g@004RL0=ooo`<0oooo00H0okmd04RLg`3oool0oooo0=nLB01d_ol60?ooo`030000003oool0oooo
07H0oooo0P0000000`000?l000000?ooo`0g0?ooo`00>03oool00`000?l0oooo0?ooo`1S0?ooo`06
0=nLB018W=l0oooo0?oo_`1d07@0_ooo1`3oool00`3o_g@0B9cO0?ooo`050?ooo`<00000N03oool0
0`000?l0oooo0?ooo`0g0?ooo`00>03oool00`000000oooo0?ooo`1S0?ooo`060=nLB01d_ol0oooo
0?oog`2LB7@0_ooo0`3oool01P3o_g@0001d0;ooo`3oool0gia807Boo`H0oooo00<000000?ooo`3o
ool0M`3oool00`000000oooo0?ooo`0h0?ooo`00>@3oool00`000000oooo0?ooo`1R0?ooo`060=nL
B018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q804P00000000007Bo00L0oooo00<00000
0?ooo`3oool0M`3oool00`000000oooo0?ooo`0h0?ooo`00>@3oool00`000000oooo0?ooo`1R0?oo
o`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool00`3ooml0W4Q809cOo`090?ooo`030000003o
ool0oooo07L0oooo00<000000?ooo`3oool0>03oool003X0oooo00<000000?ooo`3oool0HP3oool0
102oM00000000000B02Lgol50?ooo`050;md0000000000000000B02Lgol01P3oool00`000000oooo
0?ooo`1f0?ooo`030000003oool0oooo03T0oooo000d0?ooo`070?oOW0180000M;oo0?ooo`3ookl0
M0000000001h0?ooo`030000003oool0oooo07D0oooo00<0oono00000018W=l0>P3oool003@0oooo
00P0omnL04P0001d_ol0oooo0=nLB00004P0W=oo000007L0oooo00<000000?ooo`3oool0M@3oool0
0`000000M00004RLg`0j0?ooo`00=03oool01P3ogi`0B00007Boo`3ogi`0B00004RLg`80oooo00<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`1d0?ooo`040000003ookl0M00004RLgcX0oooo
000d0?ooo`030?oOW018000000000080000000@0B9cO0?ooo`3oool00000MP3oool00`000000oooo
0?ooo`1d0?ooo`030000003ookl0M00000<0000000<007Bo0?ooo`3oool0=@3oool003@0oooo00L0
omnL04P0001d_ol0oooo0?noM0000000M;oo0080oooo00<000000?ooo`3oool0L`3oool00`000000
oooo0?ooo`1c0?ooo`090000003oool0oono07@00018W=l0oooo0?oOW0180000B9cO03H0oooo000d
0?ooo`070?oOW0180000M;oo0?ooo`3ogi`0B00004RLg`030?ooo`030000003oool0oooo0780oooo
00<000000?ooo`3oool0LP3oool02P000000oooo0?ooo`3ookl0M00004RLg`3oool0oono07@00000
M;lf0?ooo`00=03oool01`3ogi`0B00007Boo`3oool0okmd0000001d_ol00`3oool00`000000oooo
0?ooo`1b0?ooo`030000003oool0oooo0780oooo00X000000?ooo`3oool0oono07@00018W=l0oooo
0?oOW0180000B9cO=P3oool003@0oooo00<0omnL04P0000000000P0000000`00M;l0oooo0?ooo`03
0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0L@3oool01P000000oooo0?ooo`3o
ool0oono07@000<0000000<004RL0=ooo`3oool0=@3oool00400oooo00<000000?ooo`3oool0L03o
ool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo03l0oooo00100?ooo`030000003oool0
oooo0700oooo0P00001a0?ooo`030000003oool0oooo03l0oooo00110?ooo`030000003oool0oooo
06l0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`100?ooo`00@P3oool00`000000
oooo0?ooo`1^0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0@@3oool004<0oooo
00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0480oooo
00140?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?oo
o`130?ooo`00A@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo06/0oooo00<00000
0?ooo`3oool0A03oool004D0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1[0?oo
o`030000003oool0oooo04@0oooo00160?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3o
ool0JP3oool00`000000oooo0?ooo`150?ooo`00A`3oool00`000000oooo0?ooo`1Y0?ooo`030000
003oool0oooo06T0oooo00<000000?ooo`3oool0AP3oool004P0oooo00<000000?ooo`3oool0J03o
ool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo04L0oooo00190?ooo`030000003oool0
oooo06L0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`180?ooo`00BP3oool00`00
0000oooo0?ooo`1V0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0B@3oool004/0
oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo04X0
oooo001<0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0I03oool00`000000oooo
0?ooo`1;0?ooo`00C@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo06<0oooo00<0
00000?ooo`3oool0C03oool004h0oooo00<000000?ooo`3oool0HP3oool2000006<0oooo00<00000
0?ooo`3oool0C@3oool004l0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1Q0?oo
o`030000003oool0oooo04h0oooo001@0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool0H03oool00`000000oooo0?ooo`1?0?ooo`00D@3oool00`000000oooo0?ooo`1O0?ooo`030000
003oool0oooo05l0oooo00<000000?ooo`3oool0D03oool00580oooo00<000000?ooo`3oool0GP3o
ool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0540oooo001C0?ooo`030000003oool0
oooo05d0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`1B0?ooo`00E03oool00`00
0000oooo0?ooo`1L0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0D`3oool005D0
oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo05@0
oooo001F0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0FP3oool00`000000oooo
0?ooo`1E0?ooo`00E`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05T0oooo00<0
00000?ooo`3oool0EP3oool005P0oooo0P00001I0?ooo`030000003oool0oooo05L0oooo0P00001I
0?ooo`00FP3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool0F@3oool005/0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo05X0oooo001L0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`1K0?ooo`00G@3oool00`000000oooo0?ooo`1C0?ooo`800000E03o
ool00`000000oooo0?ooo`1L0?ooo`00GP3oool2000005<0oooo00<000000?ooo`3oool0D@3oool2
000005l0oooo001P0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0D03oool00`00
0000oooo0?ooo`1O0?ooo`00H@3oool200000500oooo00<000000?ooo`3oool0CP3oool200000680
oooo001S0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0C@3oool00`000000oooo
0?ooo`1R0?ooo`00I03oool2000004d0oooo00<000000?ooo`3oool0B`3oool2000006D0oooo001V
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1U
0?ooo`00I`3oool2000004X0oooo00<000000?ooo`3oool0B03oool2000006P0oooo001Y0?ooo`80
0000B03oool00`000000oooo0?ooo`160?ooo`800000JP3oool006/0oooo0P0000160?ooo`030000
003oool0oooo04@0oooo0P00001/0?ooo`00K@3oool00`000000oooo0?ooo`130?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool0K03oool006h0oooo0P0000130?ooo`030000003oool0
oooo0440oooo0P00001_0?ooo`00L03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool0K`3oool00740oooo0P0000100?ooo`030000003oool0oooo03h0
oooo0P00001b0?ooo`00L`3oool3000003d0oooo0P00000l0?ooo`<00000M03oool007H0oooo0P00
000k0?ooo`030000003oool0oooo03T0oooo0P00001g0?ooo`00N03oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0M`3oool007T0oooo1000000f0?oo
o`030000003oool0oooo03@0oooo1000001j0?ooo`00O@3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool0O03oool007h0oooo1000000a0?ooo`030000
003oool0oooo02l0oooo1000001o0?ooo`00PP3oool3000002h0oooo00<000000?ooo`3oool0;03o
ool3000008<0oooo00250?ooo`800000;03oool00`000000oooo0?ooo`0Z0?ooo`800000QP3oool0
08L0oooo0`00000Y0?ooo`030000003oool0oooo02L0oooo0`0000280?ooo`00RP3oool3000002H0
oooo00<000000?ooo`3oool0903oool3000008/0oooo002=0?ooo`H00000803oool00`000000oooo
0?ooo`0N0?ooo`H00000SP3oool009<0oooo0`00000M0?ooo`030000003oool0oooo01/0oooo0`00
002D0?ooo`00UP3oool5000000d0oooo00<0oooO09a8M02oool0203oool00`000000oooo0?ooo`0F
0?ooo`D00000U`3oool009/0oooo1`0000060?ooo`030?oog`2LB7@0_ooo00P0oooo00<000000?oo
o`3oool03`3oool7000009`0oooo002R0?ooob<00000X`3oool00:P0oooo00<0oooO09a8M02oool0
203oool00`000000oooo0?ooo`2b0?ooo`00YP3oool01@3ooml0W9bo0?oog`2LB7@0_ooo00P0oooo
00<000000?ooo`3oool0/P3oool00:L0oooo00@0okmd0000000007@0_ooo203oool00`000000oooo
0?ooo`2b0?ooo`00Z03oool00`3ookl0M01d0;ooo`080?ooo`030000003oool0oooo0;80oooo002c
0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`03
0000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003o
ool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo
0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?oo
o`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0
/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo
00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<00000
0?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo0P00002c0?ooo`00/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?oo
o`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?oo
o`00/`3oool00`000000oooo0?ooo`2b0?ooo`00\
\>"],
  ImageRangeCache->{{{112.438, 370.625}, {557.188, 299}} -> {-2.35746, \
1.65836, 0.00878441, 0.00878441}},
  CellTags->"figura4"]
}, Closed]],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\({idFondamentale, senCompl, cosCompl, tanCompl, senDiffPi2, 
          cosDiffPi2, 
          tanDiffPi2} = {cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 
            1, sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          tan[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cot[\[Alpha]], 
          sen[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          tan[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-\(cos[\[Alpha]]\/sen[\
\[Alpha]]\)\)};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Seno di un angolo supplementare", "Subsubsection"],

Cell[TextData[{
  "Ancora una volta l'espressione delle funzioni goniometriche di un angolo \
associato ad ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ", in tal caso l'angolo supplementare, si basa sull'osservazione della \
congruenza dei triangoli individuati dai lati terminali dei due angoli, nel \
caso in esame, ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[EmptyUpTriangle]", 
            StyleBox["OSR",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " e ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[EmptyUpTriangle]", 
            StyleBox["OQP",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " (",
  ButtonBox["fig. 4",
    ButtonData:>"figura4",
    ButtonStyle->"Hyperlink"],
  "). Valgono pertanto le relazioni tra componenti ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["OS",
            FontSlant->"Italic"], 
          StyleBox["=",
            FontSlant->"Plain"], 
          RowBox[{
            StyleBox["-",
              FontSlant->"Plain"], 
            StyleBox["OQ",
              FontSlant->"Italic"]}]}], TraditionalForm]]],
  " e ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["SR",
            FontSlant->"Italic"], 
          StyleBox["=",
            FontSlant->"Plain"], 
          StyleBox["QP",
            FontSlant->"Italic"]}], TraditionalForm]]],
  " e di conseguenza discende"
}], "Text",
  CellTags->"osservazione2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sen[\[Pi] - \[Alpha]] \[Equal] SR/OR\)], "Input"],

Cell[BoxData[
    \(sen[\[Pi] - \[Alpha]] \[Equal] SR\/OR\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {SR \[Rule] QP, OR \[Rule] OP}\)], "Input"],

Cell[BoxData[
    \(sen[\[Pi] - \[Alpha]] \[Equal] QP\/OP\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. defs\)], "Input"],

Cell[BoxData[
    \(sen[\[Pi] - \[Alpha]] \[Equal] sen[\[Alpha]]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(senSuppl = toRule[%]\)], "Input"],

Cell[BoxData[
    \(sen[\[Pi] - \[Alpha]] \[RuleDelayed] sen[\[Alpha]]\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\({idFondamentale, senCompl, cosCompl, tanCompl, senDiffPi2, 
          cosDiffPi2, tanDiffPi2, 
          senSuppl} = {cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 
            1, sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          tan[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cot[\[Alpha]], 
          sen[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          tan[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-\(cos[\[Alpha]]\/sen[\
\[Alpha]]\)\), 
          sen[\[Pi] - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]]};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Coseno di un angolo supplementare", "Subsubsection"],

Cell["Nello stesso modo", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cos[\[Pi] - \[Alpha]] \[Equal] OS/OR\)], "Input"],

Cell[BoxData[
    \(cos[\[Pi] - \[Alpha]] \[Equal] OS\/OR\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {OS \[Rule] \(-OQ\), OR \[Rule] OP}\)], "Input"],

Cell[BoxData[
    \(cos[\[Pi] - \[Alpha]] \[Equal] \(-\(OQ\/OP\)\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. defs\)], "Input"],

Cell[BoxData[
    \(cos[\[Pi] - \[Alpha]] \[Equal] \(-cos[\[Alpha]]\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cosSuppl = toRule[%]\)], "Input"],

Cell[BoxData[
    \(cos[\[Pi] - \[Alpha]] \[RuleDelayed] \(-cos[\[Alpha]]\)\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\({idFondamentale, senCompl, cosCompl, tanCompl, senDiffPi2, 
          cosDiffPi2, tanDiffPi2, senSuppl, 
          cosSuppl} = {cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 
            1, sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          tan[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cot[\[Alpha]], 
          sen[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          tan[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-\(cos[\[Alpha]]\/sen[\
\[Alpha]]\)\), sen[\[Pi] - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          cos[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\)};\)\)], \
"Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Tangente di un angolo supplementare", "Subsubsection"],

Cell["Infine, la definizione di tangente implica", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tan[\[Pi] - \[Alpha]] \[Equal] SR/OS\)], "Input"],

Cell[BoxData[
    \(tan[\[Pi] - \[Alpha]] \[Equal] SR\/OS\)], "Output"]
}, Closed]],

Cell[TextData[{
  "e le osservazioni fatte ",
  ButtonBox["inizialmente",
    ButtonData:>"osservazione2",
    ButtonStyle->"Hyperlink"],
  " permettono di riscriverla come"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {SR \[Rule] QP, OS \[Rule] \(-OQ\)}\)], "Input"],

Cell[BoxData[
    \(tan[\[Pi] - \[Alpha]] \[Equal] \(-\(QP\/OQ\)\)\)], "Output"]
}, Closed]],

Cell["da cui", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. defs\)], "Input"],

Cell[BoxData[
    \(tan[\[Pi] - \[Alpha]] \[Equal] \(-tan[\[Alpha]]\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tanSuppl = toRule[%]\)], "Input"],

Cell[BoxData[
    \(tan[\[Pi] - \[Alpha]] \[RuleDelayed] \(-tan[\[Alpha]]\)\)], "Output"]
}, Closed]],

Cell["Abbiamo dimostrato quindi le ulteriori tre relazioni", "Text"],

Cell[BoxData[{
    \(TraditionalForm\`Angoli\ supplementari\), "\[IndentingNewLine]", 
    \(TraditionalForm\`sen(\[Pi] - \[Alpha]) = 
      sen(\[Alpha])\), "\[IndentingNewLine]", 
    \(TraditionalForm\`cos(\[Pi] - \[Alpha]) = \(-\(cos(\[Alpha])\)\)\), "\
\[IndentingNewLine]", 
    \(TraditionalForm\`tan(\[Pi] - \[Alpha]) = \(-\(tan(\[Alpha])\)\)\)}], \
"Definition",
  FontFamily->"Courier"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Angoli che differiscono di \[Pi]", "Subsection"],

Cell[CellGroupData[{

Cell["Istruzione grafiche", "Subsubsection"],

Cell[BoxData[{
    \(\[Alpha] = 30  Degree; \[Beta] = \[Pi] + \[Alpha];\), "\n", 
    \(pP = {Cos[\[Alpha]], Sin[\[Alpha]]}; pQ = {Cos[\[Alpha]], 0}; 
    origine = {0, 0}; pR = {Cos[\[Beta]], Sin[\[Beta]]}; 
    pS = {Cos[\[Beta]], 0};\), "\n", 
    \(Show[
      Graphics[{Circle[origine, 1], Line[{{\(-1.2\), 0}, {1.2, 0}}], 
          Line[{{0, \(-1.2\)}, {0, 1.2}}], 
          Line[{pP, origine, pR}]}], \[IndentingNewLine]Graphics[{colBlu, 
          Arrow[origine, pQ, stileVet], 
          Arrow[pQ, pP, stileVet]}], \[IndentingNewLine]Graphics[{colBlu, 
          Arrow[origine, pS, stileVet], 
          Arrow[pS, pR, 
            stileVet]}], \[IndentingNewLine]Graphics[{Text["\<O\>", 
            origine, {1, 1}, TextStyle \[Rule] stileTesto], 
          Text["\<Q\>", pQ, {0, 1}, TextStyle \[Rule] stileTesto], 
          Text["\<P\>", pP, {0, \(-1\)}, TextStyle \[Rule] stileTesto], 
          Text["\<S\>", pS, {0, \(-1\)}, TextStyle \[Rule] stileTesto], 
          Text["\<R\>", pR, {0, 1}, TextStyle \[Rule] stileTesto]}], 
      Prolog -> {{colGiallo, Polygon[{origine, pQ, pP}], 
            Polygon[{origine, pS, pR}]}, {colVerde, 
            Disk[origine,  .3, {0, \[Beta]}]}, {colRosso, 
            Disk[origine,  .2, {0, \[Alpha]}]}}, 
      AspectRatio \[Rule] Automatic, Axes \[Rule] True]; 
    Clear[\[Alpha], \[Beta]];\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Grafico", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.396825 0.5 0.396825 [
[.10317 .4875 -6.96875 -10.9375 ]
[.10317 .4875 6.96875 0 ]
[.30159 .4875 -10.3125 -10.9375 ]
[.30159 .4875 10.3125 0 ]
[.69841 .4875 -7.5625 -10.9375 ]
[.69841 .4875 7.5625 0 ]
[.89683 .4875 -4.21875 -10.9375 ]
[.89683 .4875 4.21875 0 ]
[.4875 .10317 -13.9375 -5.46875 ]
[.4875 .10317 0 5.46875 ]
[.4875 .30159 -20.625 -5.46875 ]
[.4875 .30159 0 5.46875 ]
[.4875 .69841 -15.125 -5.46875 ]
[.4875 .69841 0 5.46875 ]
[.4875 .89683 -8.4375 -5.46875 ]
[.4875 .89683 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .5 m
.10317 .50625 L
s
gsave
.10317 .4875 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.30159 .5 m
.30159 .50625 L
s
gsave
.30159 .4875 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.69841 .5 m
.69841 .50625 L
s
gsave
.69841 .4875 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.89683 .5 m
.89683 .50625 L
s
gsave
.89683 .4875 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.14286 .5 m
.14286 .50375 L
s
.18254 .5 m
.18254 .50375 L
s
.22222 .5 m
.22222 .50375 L
s
.2619 .5 m
.2619 .50375 L
s
.34127 .5 m
.34127 .50375 L
s
.38095 .5 m
.38095 .50375 L
s
.42063 .5 m
.42063 .50375 L
s
.46032 .5 m
.46032 .50375 L
s
.53968 .5 m
.53968 .50375 L
s
.57937 .5 m
.57937 .50375 L
s
.61905 .5 m
.61905 .50375 L
s
.65873 .5 m
.65873 .50375 L
s
.7381 .5 m
.7381 .50375 L
s
.77778 .5 m
.77778 .50375 L
s
.81746 .5 m
.81746 .50375 L
s
.85714 .5 m
.85714 .50375 L
s
.06349 .5 m
.06349 .50375 L
s
.02381 .5 m
.02381 .50375 L
s
.93651 .5 m
.93651 .50375 L
s
.97619 .5 m
.97619 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .10317 m
.50625 .10317 L
s
gsave
.4875 .10317 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .30159 m
.50625 .30159 L
s
gsave
.4875 .30159 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .69841 m
.50625 .69841 L
s
gsave
.4875 .69841 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .89683 m
.50625 .89683 L
s
gsave
.4875 .89683 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .14286 m
.50375 .14286 L
s
.5 .18254 m
.50375 .18254 L
s
.5 .22222 m
.50375 .22222 L
s
.5 .2619 m
.50375 .2619 L
s
.5 .34127 m
.50375 .34127 L
s
.5 .38095 m
.50375 .38095 L
s
.5 .42063 m
.50375 .42063 L
s
.5 .46032 m
.50375 .46032 L
s
.5 .53968 m
.50375 .53968 L
s
.5 .57937 m
.50375 .57937 L
s
.5 .61905 m
.50375 .61905 L
s
.5 .65873 m
.50375 .65873 L
s
.5 .7381 m
.50375 .7381 L
s
.5 .77778 m
.50375 .77778 L
s
.5 .81746 m
.50375 .81746 L
s
.5 .85714 m
.50375 .85714 L
s
.5 .06349 m
.50375 .06349 L
s
.5 .02381 m
.50375 .02381 L
s
.5 .93651 m
.50375 .93651 L
s
.5 .97619 m
.50375 .97619 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto fill
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto
-0.03 0.0075 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
1 1 0 r
.5 .5 m
.84366 .5 L
.84366 .69841 L
F
.5 .5 m
.15634 .5 L
.15634 .30159 L
F
0 1 0 r
.5 .5 m
.5 .5 .11905 0 210 arc
F
1 0 0 r
.5 .5 m
.5 .5 .07937 0 30 arc
F
0 g
.5 Mabswid
newpath
.5 .5 .39683 0 365.73 arc
s
.02381 .5 m
.97619 .5 L
s
.5 .02381 m
.5 .97619 L
s
.84366 .69841 m
.5 .5 L
.15634 .30159 L
s
0 0 1 r
.5 .5 m
.84366 .5 L
s
% Start of user PostScript
0 0 0.866025 0 MAarrowhead1
% End of user PostScript
.84366 .5 m
.84366 .69841 L
s
% Start of user PostScript
0.866025 0 0.866025 0.5 MAarrowhead1
% End of user PostScript
.5 .5 m
.15634 .5 L
s
% Start of user PostScript
0 0 -0.866025 0 MAarrowhead1
% End of user PostScript
.15634 .5 m
.15634 .30159 L
s
% Start of user PostScript
-0.866025 0 -0.866025 -0.5 MAarrowhead1
% End of user PostScript
0 g
gsave
.5 .5 -71.9375 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.84366 .5 -66.4688 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Q) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.84366 .69841 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
69.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.15634 .5 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.15634 .30159 -66.2188 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(R) show
69.438 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  Magnification->0.9,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?oo
o`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?oo
o`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3o
ool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo
0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?oo
o`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000
003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0
oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80
oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<00000
0?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3o
ool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0
oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<0
00000?ooo`3oool0/P3oool00:P0oooo00<0oooO09a8M02oool0203oool00`000000oooo0?ooo`2b
0?ooo`00Z03oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo0;80oooo002P0?ooo`03
0?noM000000000000080000000H004RL0=ooo`3oool0oooO09a8M02oool80?ooo`030000003oool0
oooo0;80oooo002S0?ooob400000Y03oool009`0oooo1`0000030?ooo`050?oog`2LW;l0oooO09a8
M02oool0203oool00`000000oooo0?ooo`0>0?ooo`L00000W@3oool009L0oooo1@00000;0?ooo`04
0?noM0000000001d0;ooo`P0oooo00<000000?ooo`3oool05@3oool5000009P0oooo002C0?ooo`@0
00004@3oool00`3ookl0M01d0;ooo`080?ooo`030000003oool0oooo01X0oooo1000002D0?ooo`00
SP3oool500000200oooo00<000000?ooo`3oool07P3oool5000008l0oooo002;0?ooo`<000009@3o
ool00`000000oooo0?ooo`0S0?ooo`<00000S03oool008L0oooo1000000X0?ooo`030000003oool0
oooo02H0oooo100000280?ooo`00QP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0Q@3oool00880oooo1000000]0?ooo`030000003oool0oooo02/0
oooo100000230?ooo`00O`3oool300000340oooo00<000000?ooo`3oool0;`3oool300000800oooo
001m0?ooo`800000=03oool00`000000oooo0?ooo`0b0?ooo`800000OP3oool007X0oooo0`00000f
0?ooo`030000003oool0oooo03@0oooo0`00001k0?ooo`00N03oool2000003T0oooo00<000000?oo
o`3oool0=`3oool2000007T0oooo001g0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`1f0?ooo`00M03oool3000003`0oooo0P00000k0?ooo`<00000
M@3oool00780oooo0P00000o0?ooo`030000003oool0oooo03d0oooo0P00001c0?ooo`00L03oool2
00000440oooo00<000000?ooo`3oool0?`3oool200000740oooo001_0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1^0?ooo`00K@3oool2000004@0
oooo00<000000?ooo`3oool0@P3oool2000006h0oooo001/0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1[0?ooo`00J@3oool3000004L0oooo00<0
00000?ooo`3oool0A@3oool3000006X0oooo001W0?ooo`800000BP3oool00`000000oooo0?ooo`18
0?ooo`800000J03oool006H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo06D0oooo001T0?ooo`800000C@3oool00`000000oooo0?ooo`1;0?ooo`80
0000I@3oool006<0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo0680oooo001Q0?ooo`800000D03oool00`000000oooo0?ooo`1>0?ooo`800000HP3o
ool00600oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo05l0oooo001N0?ooo`800000D`3oool00`000000oooo0?ooo`1A0?ooo`800000G`3oool005d0
oooo00<000000?ooo`3oool0D`3oool2000005@0oooo00<000000?ooo`3oool0G03oool005`0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05/0oooo
001K0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`1J0?ooo`00FP3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool0F@3oool005P0oooo0P00001I0?ooo`030000003oool0oooo05L0oooo0P00001I0?oo
o`00E`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0EP3oool005H0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo05D0oooo001E0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`1D0?ooo`00E03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo05`0oooo00<000000?ooo`3oool0D`3oool005<0oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`1M0?ooo`030000003oool0oooo0580oooo001B0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1A0?ooo`00D@3oool00`000000oooo
0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0D03oool00500oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo04l0oooo001?
0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1>
0?ooo`00CP3oool00`000000oooo0?ooo`1R0?ooo`800000H`3oool00`000000oooo0?ooo`1=0?oo
o`00C@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool0C03oool004`0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1T0?ooo`030000
003oool0oooo04/0oooo001;0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`1:0?ooo`00BP3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0
oooo06H0oooo00<000000?ooo`3oool0B@3oool004T0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`1W0?ooo`030000003oool0oooo04P0oooo00180?ooo`030000003oool0oooo06P0
oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`170?ooo`00A`3oool00`000000oooo
0?ooo`1Y0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0AP3oool004H0oooo00<0
00000?ooo`3oool0JP3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo04D0oooo0015
0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`14
0?ooo`00A@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0A03oool004@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo04<0oooo00130?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0
K@3oool00`000000oooo0?ooo`120?ooo`00@P3oool00`000000oooo0?ooo`1^0?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool0@@3oool00440oooo00<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0400oooo00100?ooo`030000003oool0oooo
0700oooo0P00001a0?ooo`030000003oool0oooo03l0oooo00100?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0o0?ooo`00?`3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0?P3oool003@0oooo00L0
omnL04P0001d_ol0oooo0?oo_`1d000007Bo00<0oooo00<000000?ooo`3oool0LP3oool00`000000
oooo0?ooo`1b0?ooo`030000003oool0oooo03d0oooo000d0?ooo`070?oOW0180000M;oo0?ooo`3O
W4P0001809cOo`030?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0LP3oool00`00
0000oooo0?ooo`0m0?ooo`00=03oool01P3ogi`0B00007Boo`3ogi`0B00004RLg`<0oooo00<00000
0?ooo`3oool0L`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo03`0oooo000d0?oo
o`030?oOW018000000000080000000@0B9cO0?ooo`3oool00000MP3oool00`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo03/0oooo000d0?ooo`090?oOW0180000M;oo0?ooo`3o_g@0000007Bo
o`3oool0000007H0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0k0?ooo`00=03o
ool0203ogi`0B00007Boo`3oool0omnL04P00018W=l00000M`3oool00`000000oooo0?ooo`1e0?oo
o`030000003oool0oooo03X0oooo000d0?ooo`050?oOW0180000M;oo0?ooo`3o_g@00P00001h0?oo
o`030000003oool0oooo07H0oooo00<000000?ooo`3oool0>@3oool003@0oooo00<0omnL04P00000
00000P0000000`00M;l000000?ooo`1g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3o
ool0>@3oool003T0oooo00<000000?ooo`3oool0H`3oool02P2oM00000000000B02Lgol0oooo0?oo
_`1dB9`0gooo0?ooo`2oM0020000000304RLg`3oool0oooo00D0oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`0h0?ooo`00>@3oool00`000000oooo0?ooo`1R0?ooo`060?noM000B9`0
gooo0?noM000B9`0gooo0`3oool01P3o_g@0B9cO0?ooo`3oool0gia807Boo`H0oooo00<000000?oo
o`3oool0M`3oool00`000000oooo0?ooo`0h0?ooo`00>03oool00`000000oooo0?ooo`1L0?ooo`03
0?noM000000000000080000000P004RL0=ooo`3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`L0oooo00<0
okmd04RLg`3oool01@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo03P0oooo000h
0?ooo`030000o`3oool0oooo06<0oooo00H0gia807Boo`3oool0oooO09a8M02oool30?ooo`060?no
M00007@0_ooo0?ooo`3OW4P0M;oo1P3oool3000007P0oooo00<000000?ooo`3oool0=`3oool003L0
oooo00@000000000o`0000000000H`3oool01P3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`<0oooo00D0
oono07A8B01800000000001d_`070?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
=P3oool003H0oooo00<000000000o`000?l00P3oo`0200000640oooo00H0okmd0018W03Oool0okmd
0018W03Oool30?ooo`030?oog`2LB4P0W=oo00T0oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`0f0?ooo`00=P3oool010000000003o0000o`000?l30?oo00800000H03oool0102oM000
00000000B02Lgol50?ooo`050;md0000000000000000B02Lgol01P3oool00`000000oooo0?ooo`1j
0?ooo`030000003oool0oooo03D0oooo000e0?ooo`030000003oool0003o0080003o1@3oo`000`00
0000oooo0?ooo`1a0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0=03oool003@0
oooo00<000000?ooo`3oool00`000?l60?oo00800000L@3oool00`000000oooo0?ooo`1k0?ooo`03
0000003oool0oooo03@0oooo000d0?ooo`030000003oool0003o00<0003o203oo`02000006l0oooo
00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0c0?ooo`00<`3oool00`000000oooo0?oo
o`040000o`X0ool000<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1l0?ooo`030000003o
ool0oooo03<0oooo000c0?ooo`030000003oool0oooo00@0003o2`3oo`02000006`0oooo00<00000
0?ooo`3oool0O@3oool00`000000oooo0?ooo`0b0?ooo`00<`3oool00`000000oooo0?ooo`050000
o``0ool00P00001Z0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0<P3oool00380
oooo00<000000?ooo`3oool01P000?l>0?oo00800000J03oool00`000000oooo0?ooo`1m0?ooo`03
0000003oool0oooo0380oooo000b0?ooo`030000003oool0oooo0080003o00@0oooo0000o`000?l0
003o403oo`000`000000oooo0?ooo`1U0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3o
ool0<@3oool00340oooo00<000000?ooo`3oool0103oool00`000?l0ool00?oo000A0?oo00800000
I@3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0300oooo000`0?ooo`030000003o
ool0oooo00D0oooo00<0003o0?oo003oo`004`3oo`02000006<0oooo00<000000?ooo`3oool0O`3o
ool00`000000oooo0?ooo`0`0?ooo`00<03oool00`000000oooo0?ooo`050?ooo`030000o`3oo`00
ool001D0ool00P00001Q0?ooo`800000P@3oool00`000000oooo0?ooo`0_0?ooo`00<03oool00`00
0000oooo0?ooo`050?ooo`030000o`3oo`00ool001L0ool000<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`200?ooo`030000003oool0oooo02l0oooo000`0?ooo`030000003oool0oooo00D0
oooo00<0003o0?oo003oo`00603oo`02000005h0oooo00<000000?ooo`3oool0P03oool00`000000
oooo0?ooo`0_0?ooo`00;`3oool00`000000oooo0?ooo`060?ooo`030000o`3oo`00ool001X0ool0
0P00001L0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0;P3oool002h0oooo00<0
00000?ooo`3oool01`3oool00`000?l0ool00?oo000L0?oo00800000FP3oool00`000000oooo0?oo
o`210?ooo`030000003oool0oooo02h0oooo000^0?ooo`030000003oool0oooo00L0oooo00<0003o
0?oo003oo`007P3oo`000`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0880oooo00<00000
0?ooo`3oool0;@3oool002h0oooo00<000000?ooo`3oool01`3oool00`000?l0ool00?oo000O0?oo
00800000E`3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo02d0oooo000^0?ooo`03
0000003oool0oooo00L0oooo00<0003o0?oo003oo`008@3oo`02000005D0oooo00<000000?ooo`3o
ool0PP3oool00`000000oooo0?ooo`0]0?ooo`00;@3oool00`000000oooo0?ooo`080?ooo`030000
o`3oo`00ool002<0ool000<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`230?ooo`030000
003oool0oooo02`0oooo000]0?ooo`030000003oool0oooo00P0oooo00<0003o0?oo003oo`00903o
o`0200000580oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0/0?ooo`00;@3oool0
0`000000oooo0?ooo`080?ooo`030000o`3oo`00ool002H0ool00P00001@0?ooo`030000003oool0
oooo08<0oooo00<000000?ooo`3oool0;03oool002`0oooo00<000000?ooo`3oool02@3oool00`00
0?l0ool00?oo000X0?oo00800000CP3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo
02`0oooo000/0?ooo`030000003oool0oooo00T0oooo00<0003o0?oo003oo`00:P3oo`000`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0:`3oool002/0oooo
00<000000?ooo`3oool02P3oool00`000?l0ool00?oo000[0?oo00800000B`3oool00`000000oooo
0?ooo`250?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo00X0oooo00<0
003o0?oo003oo`00;@3oo`02000004T0oooo0P0000260?ooo`030000003oool0oooo02X0oooo000[
0?ooo`030000003oool0oooo00X0oooo00<0003o0?oo003oo`00;`3oo`02000004L0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0Z0?ooo`00:P3oool00`000000oooo0?ooo`0;0?oo
o`030000o`3oo`00ool00340ool000<000000?ooo`3oool0A03oool00`000000oooo0?ooo`250?oo
o`030000003oool0oooo02X0oooo000Z0?ooo`030000003oool0oooo00/0oooo00<0003o0?oo003o
o`00<P3oo`02000004@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0Y0?ooo`00
:P3oool00`000000oooo0?ooo`0;0?ooo`030000o`3oo`00ool003@0ool00P0000120?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool0:@3oool002T0oooo00<000000?ooo`3oool0303o
ool00`000?l0ool00?oo000f0?oo00800000@03oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo02T0oooo000Y0?ooo`030000003oool0oooo00`0oooo00<0003o0?oo003oo`00>03oo`00
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0:03oool0
02T0oooo00<000000?ooo`3oool0303oool00`000?l0ool00?oo000i0?oo00800000?@3oool00`00
0000oooo0?ooo`270?ooo`030000003oool0oooo02P0oooo000Y0?ooo`030000003oool0oooo00`0
oooo00<0003o0?oo003oo`00>`3oo`02000003/0oooo00<000000?ooo`3oool0Q`3oool00`000000
oooo0?ooo`0X0?ooo`00:@3oool00`000000oooo0?ooo`0<0?ooo`030000o`3oo`00ool003d0ool0
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo02P0oooo
000Y0?ooo`030000003oool0oooo00`0oooo00<0003o0?oo003oo`00?P3oo`02000003P0oooo00<0
00000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0X0?ooo`00:03oool00`000000oooo0?ooo`0=
0?ooo`030000o`3oo`00ool00400ool00P00000f0?ooo`030000003oool0oooo08P0oooo00<00000
0?ooo`3oool09`3oool002P0oooo00<000000?ooo`3oool03@3oool00`000?l0ool00?oo00120?oo
00800000=03oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo02L0oooo000X0?ooo`03
0000003oool0oooo00d0oooo00<0003o0?oo003oo`00A03oo`000`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool09`3oool002L0oooo00<000000?ooo`3oool0
3P3oool00`000?l0ool00?oo00150?oo00800000<@3oool00`000000oooo0?ooo`280?ooo`030000
003oool0oooo02L0oooo000W0?ooo`030000003oool0oooo00h0oooo00<0003o0?oo003oo`00A`3o
o`02000002l0oooo0P00002:0?ooo`030000003oool0oooo02H0oooo000W0?ooo`030000003oool0
oooo00h0oooo00<0003o0?oo003oo`00B@3oo`02000002d0oooo00<000000?ooo`3oool0R@3oool0
0`000000oooo0?ooo`0V0?ooo`009`3oool00`000000oooo0?ooo`0>0?ooo`030000o`3oo`00ool0
04/0ool000<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo
02H0oooo000W0?ooo`030000003oool0oooo00h0oooo00<0003o0?oo003oo`00C03oo`02000002X0
oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0V0?ooo`009P3oool00`000000oooo
0?ooo`0?0?ooo`030000o`3oo`00ool004h0ool00P00000X0?ooo`030000003oool0oooo08T0oooo
00<000000?ooo`3oool09P3oool002H0oooo00<000000?ooo`3oool03`3oool00`000?l0ool00?oo
001@0?oo008000009P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02D0oooo000V
0?ooo`030000003oool0oooo00l0oooo00<0003o0?oo003oo`00DP3oo`000`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?oo
o`3oool03`3oool00`000?l0ool00?oo001C0?oo008000008`3oool00`000000oooo0?ooo`2:0?oo
o`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0oooo00l0oooo00<0003o0?oo003o
o`00D`3oo`02003o008000008@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02D0
oooo000V0?ooo`030000003oool0oooo00l0oooo00<0003o0?oo003oo`00DP3oo`05003o00030000
003oool0oooo01h0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0U0?ooo`009P3o
ool00`000000oooo0?ooo`0?0?ooo`030000o`3oo`00ool00580ool01P00o`02000001h0oooo00<0
00000?ooo`3oool0RP3oool00`000000oooo0?ooo`0U0?ooo`009@3oool00`000000oooo0?ooo`0@
0?ooo`030000o`3oo`00ool00540ool02@00o`02000001`0oooo00<000000?ooo`3oool0RP3oool0
0`000000oooo0?ooo`0U0?ooo`009@3oool00`000000oooo0?ooo`0@0?ooo`030000o`3oo`00ool0
0540ool02`00o`02000001X0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0T0?oo
o`009@3oool00`000000oooo0?ooo`0@0?ooo`030000o`3oo`00ool00500ool03P00o`000`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0903oool002D0oooo
00D000000?ooo`3ooml0W4Qd0;ooo`0>0?ooo`030000o`3oo`00ool00500ool03`00o`02000001L0
oooo0P00000o0?ooo`0:0;md00000000001809cOo`3oool0oono07A8W03Oool0oooo0;md00800000
00<0B9cO0?ooo`3oool0?P3oool00`000000W4Qd0;ooo`0T0?ooo`009@3oool01@000000oooo0?oo
g`2LB7@0_ooo00h0oooo00<0003o0?oo003oo`00D03oo`0A003o008000005@3oool00`000000oooo
0?ooo`0m0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool01P3o_g@0B9cO0?ooo`3oool0
gia807Boocl0oooo00<0000009a8M02oool0903oool001h0oooo00<0okmd0000000000000P000000
1`00B9`0gooo0000003oool0oooO09a8M02oool03P3oool00`000?l0ool00?oo001?0?oo01@00?l0
0P00000C0?ooo`030000003oool0oooo03d0oooo00H0gia804RLg`3oool0oono07@0M02oool70?oo
o`030?noM018W=l0oooo02d0oooo00<0okmd001d_`3oool03P3oool00`000000W4Qd0;ooo`0T0?oo
o`009@3oool01@000000oooo0?oog`2LB7@0_ooo00h0oooo00<0003o0?oo003oo`00C`3oo`0F003o
00030000003oool0oooo00H0oooo00H0oono07@00000000000000000M02oool40?ooo`030000003o
ool0oooo03d0oooo00H0gia807Boo`3oool0oooO09a8M02oool30?ooo`060?noM00007@0_ooo0?oo
o`3OW4P0M;oo:@3oool00`3ookl0M00000000002000000030000M02oool0oooo00h0oooo00<00000
09a8M02oool0903oool002D0oooo00D0000009bL_`3ooml0W4Qd0;ooo`0>0?ooo`030000o`3oo`00
ool004h0ool06000o`02000000D0oooo00P0oono07@00000B9`0gooo0?oog`2LB000001d0;ooo`<0
oooo00<000000?ooo`3oool0?@3oool01P3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`<0oooo00D0oono
07A8B01800000000001d_`0Y0?ooo`080?oo_`1d000004RL0=ooo`2oM00000000000B02Lgol=0?oo
o`050?oog`2LW;l0000009a8M02oool0903oool002D0oooo00D000000?noM0000000001d0;ooo`0>
0?ooo`030000o`3oo`00ool004h0ool06P00o`02000000<0oooo00<0okmd0000B02Lgol00P3oool0
0`3ogi`0B00007Boo`030?ooo`030000003oool0oooo03d0oooo00H0okmd0018W03Oool0okmd0018
W03Oool30?ooo`030?oog`2LB4P0W=oo02/0oooo00P0okmd0000B02Lgol0omnL04Q8W03Ogi`0B000
04RLg`h0oooo00@0okmd0000000007@0_ooo903oool002D0oooo00D000000?ooo`3ookl0M01d0;oo
o`0>0?ooo`030000o`3oo`00ool004h0ool07000o`02000000040?ooo`3OW4P0001d0;ooo`80oooo
00<0oono07@00018W=l00`3oool00`000000oooo0?ooo`0n0?ooo`040;md00000000001809cOo`D0
oooo00D0_g@0000000000000001809cOo`0X0?ooo`030=nLB00007@0_ooo0080oooo00<0oono07@0
0018W=l03`3oool00`000000M01d0;ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`0@0?ooo`03
0000o`3oo`00ool004h0ool07P00o`0010000000gia80000M02oool20?ooo`030?oo_`1d0000B9cO
00<0oooo00<000000?ooo`3oool0M03oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO
00l0oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0403oool00`000?l0
ool00?oo001>0?oo01l00?l00P0000001P2Lgol0oooo0?ooo`3ogi`0B00007Boo`<0oooo00<00000
0?ooo`3oool0M03oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00l0oooo00<00000
0?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0403oool00`000?l0ool00?oo001>0?oo
02000?l00`000000103oool0_g@00000M02oool30?ooo`030000003oool0oooo07@0oooo00P0oono
07@00000B9`0gooo0?ooo`2oM00004RL0=ooo`l0oooo00<000000?ooo`3oool0903oool002D0oooo
00<000000?ooo`3oool0403oool00`000?l0ool00?oo001>0?oo02400?l00`0000000`0007@0_ooo
0?ooo`030?ooo`030000003oool0oooo07D0oooo00H0oono07@00000000000000018W03Oool@0?oo
o`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo0100oooo00<0003o0?oo003o
o`001P3oo`020000odD0ool09@00o`02000000@0oooo00<000000?ooo`3oool0KP3oool20000oa/0
oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0403oool00`000?l0ool0
0?oo00030?oo00D0003oA@3oo`0W003o008000000P3oool00`000000oooo0?ooo`1^0?ooo`D0003o
603oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`0@0?ooo`030000o`3o
o`00003o00L0003oAP3oo`0Y003o00<00000L@3oool80000oa@0oooo00<000000?ooo`3oool0903o
ool003P00000m`000?li00000000203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`P0003o3@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0;0?ooob/00?l00`00000I0?l000l00?l0A`3oo`080000o`030?oo00000?l0oooo
00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool01`3oool002D0oooo00<000000?ooo`3oool05@3oool60000obT0
oooo00<000000?ooo`3oool06@3oool[003o000300000000o`000?l0008000005`3o000?003o04H0
ool01P000?l40?oo00030000o`3oool0oooo0100oooo00<000000?ooo`3oool0903oool002D0oooo
00<000000?ooo`3oool06@3oool20000odH0oooo:P00o`000`0000000?l0003o0002003o00800000
5@3o000?003o04H0ool00P000?l80?oo00030000o`3oool0oooo0100oooo00<000000?ooo`3oool0
903oool002D0oooo00<000000?ooo`3oool0H@3ooolZ003o000300000000o`000?l000@00?l000<0
00000?l0003o00004P3o000?003o0500ool000<0003o0?ooo`3oool0403oool00`000000oooo0?oo
o`0T0?ooo`009@3oool00`000000oooo0?ooo`0=0?ooo`060?oo_`1d0000000000000000B9`0gooo
CP3ooolZ003o000300000000o`000?l000D00?l00P00000B0?l000h00?l0D@3oo`000`000?l0oooo
0?ooo`0@0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo00d0oooo00H0
_g@00000M02oool0omnL04P00018W=m>0?ooobX00?l000<00000003o0000o`001`00o`0200000100
o`003P00o`1A0?oo00030000o`3oool0oooo0100oooo00<000000?ooo`3oool0903oool002D0oooo
00<000000?ooo`3oool0403oool00`3ookl0M00004RLg`1>0?ooobX00?l000<00000003o0000o`00
2@00o`000`000000o`000?l0000=0?l000h00?l0D@3oo`000`000?l0oooo0?ooo`0@0?ooo`030000
003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo00l0oooo00@0_g@00000000004P0W=oo
CP3ooolZ003o000300000000o`000?l000X00?l00P00000=0?l000h00?l0D@3oo`000`000?l0oooo
0?ooo`0@0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo00d0oooo00@0
oono07@00000000007BoD03ooolZ003o000300000000o`000?l000`00?l00P00000:0?l000l00?l0
D@3oo`000`000?l0oooo0?ooo`0@0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003o
ool0oooo00d0oooo00<0okmd0000B02Lgol0DP3ooolY003o000300000000o`000?l000h00?l00P00
00080?l000l00?l0D@3oo`000`000?l0oooo0?ooo`0@0?ooo`030000003oool0oooo02@0oooo000U
0?ooo`030000003oool0oooo00d0oooo00H0okmd0000B02Lgol0gia80000B02Lgom?0?ooobT00?l0
00<00000003o0000o`004000o`000`000000o`000?l000040?l001000?l0D@3oo`000`000?l0oooo
0?ooo`0@0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo00h0oooo00@0
_g@0000000000000B9cOD03ooolY003o000300000000o`000?l001400?l00P0000040?l000l00?l0
DP3oo`000`000?l0oooo0?ooo`0@0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003o
ool0oooo06<0oooo:000o`000`0000000?l0003o000C003o008000000P3o000?003o0580ool000<0
003o0?ooo`3oool0403oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`1S
0?ooobP00?l000<00000003o0000o`005@00o`02000000h00?l0D`3oo`000`000?l0oooo0?ooo`0@
0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo06@0oooo9`00o`000`00
00000?l0003o000G003o000300000000o`000?l000/00?l0D`3oo`000`000?l0oooo0?ooo`0@0?oo
o`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo06@0oooo9`00o`000`000000
0?l0003o000H003o008000002`00o`1C0?oo00030000o`3oool0oooo0100oooo00<000000?ooo`3o
ool0903oool002D0oooo00<000000?ooo`3oool0I@3ooolV003o000300000000o`000?l001X00?l0
0P000008003o05@0ool000<0003o0?ooo`3oool03`3oool00`000000oooo0?ooo`0U0?ooo`009P3o
ool00`000000oooo0?ooo`1T0?ooobH00?l000<00000003o0000o`007000o`02000000H00?l0E03o
o`000`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0
oooo06@0oooo9P00o`000`0000000?l0003o000N003o000300000000o`000?l000800?l0E@3oo`00
0`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0oooo
06D0oooo9@00o`000`0000000?l0003o000O003o008000000P00o`1E0?oo00030000o`3oool0oooo
00l0oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool0I@3ooolU003o0003
00000000o`000?l002400?l00P00001E0?oo00030000o`3oool0oooo00l0oooo00<000000?ooo`3o
ool09@3oool002H0oooo00<000000?ooo`3oool0IP3ooolT003o000300000000o`000?l002800?l0
00<0oooo0000003oo`00D`3oo`000`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo02D0oooo
000V0?ooo`030000003oool0oooo06H0oooo9000o`000`0000000?l0003o000Q003o00<0oooo0P00
001B0?oo00030000o`3oool0oooo00l0oooo00<000000?ooo`3oool09@3oool002H0oooo00<00000
0?ooo`3oool0I`3ooolS003o000300000000o`000?l002400?l01@3oool200000500ool000<0003o
0?ooo`3oool03P3oool00`000000oooo0?ooo`0V0?ooo`009`3oool00`000000oooo0?ooo`1V0?oo
ob<00?l000<00000003o0000o`008000o`080?ooo`800000CP3oo`000`000?l0oooo0?ooo`0>0?oo
o`030000003oool0oooo02H0oooo000W0?ooo`030000003oool0oooo06L0oooo8P00o`000`000000
0?l0003o000O003o00/0oooo00<000000?oo003oo`00B`3oo`000`000?l0oooo0?ooo`0>0?ooo`03
0000003oool0oooo02H0oooo000W0?ooo`030000003oool0oooo06P0oooo8@00o`000`0000000?l0
003o000N003o00d0oooo0P00001;0?oo00030000o`3oool0oooo00h0oooo00<000000?ooo`3oool0
9P3oool002L0oooo00<000000?ooo`3oool0J@3ooolP003o000300000000o`000?l001d00?l0403o
ool2000004T0ool000<0003o0?ooo`3oool03P3oool00`000000oooo0?ooo`0V0?ooo`009`3oool0
0`000000oooo0?ooo`1Y0?ooob000?l000<00000003o0000o`007000o`0C0?ooo`800000A`3oo`00
0`000?l0oooo0?ooo`0=0?ooo`030000003oool0oooo02L0oooo000X0?ooo`030000003oool0oooo
06X0oooo7P00o`000`0000000?l0003o000L003o01D0oooo00<000000?oo003oo`00A03oo`000`00
0?l0oooo0?ooo`0=0?ooo`030000003oool0oooo02L0oooo000X0?ooo`030000003oool0oooo06/0
oooo7@00o`000`0000000?l0003o000K003o01L0oooo0P0000140?oo00030000o`3oool0oooo00d0
oooo00<000000?ooo`3oool09`3oool002P0oooo00<000000?ooo`3oool0K03ooolL003o00030000
0000o`000?l001T00?l06`3oool200000480ool000<0003o0?ooo`3oool03@3oool00`000000oooo
0?ooo`0W0?ooo`00:@3oool00`000000oooo0?ooo`1/0?oooa/00?l000<00000003o0000o`006000
o`0N0?ooo`800000@03oo`000`000?l0oooo0?ooo`0<0?ooo`030000003oool0oooo02P0oooo000Y
0?ooo`030000003oool0oooo06d0oooo6P00o`000`0000000?l0003o000G003o0240oooo00<00000
0?oo003oo`00?@3oo`000`000?l0oooo0?ooo`0<0?ooo`030000003oool0oooo02P0oooo000Y0?oo
o`030000003oool0oooo06l0oooo6000o`000`0000000?l0003o000E003o02@0oooo0P00000m0?oo
00030000o`3oool0oooo00`0oooo00<000000?ooo`3oool0:03oool002T0oooo00<000000?ooo`3o
ool0L@3ooolF003o000300000000o`000?l001@00?l09`3oool2000003/0ool000<0003o0?ooo`3o
ool0303oool00`000000oooo0?ooo`0X0?ooo`00:@3oool00`000000oooo0?ooo`1b0?oooaD00?l0
00<00000003o0000o`004`00o`0Z0?ooo`030000003oo`00ool003P0ool000<0003o0?ooo`3oool0
303oool00`000000oooo0?ooo`0X0?ooo`00:@3oool00`000000oooo0?ooo`1c0?oooa@00?l000<0
0000003o0000o`004@00o`0]0?ooo`800000>03oo`000`000?l0oooo0?ooo`0;0?ooo`030000003o
ool0oooo02T0oooo000Z0?ooo`030000003oool0oooo07@0oooo4P00o`000`0000000?l0003o000?
003o0340oooo0P00000f0?oo00030000o`3oool0oooo00/0oooo00<000000?ooo`3oool0:@3oool0
02X0oooo00<000000?ooo`3oool0MP3oool@003o000300000000o`000?l000`00?l0=P3oool20000
03@0ool000<0003o0?ooo`3oool02`3oool00`000000oooo0?ooo`0Y0?ooo`00:P3oool00`000000
oooo0?ooo`1i0?ooo`d00?l000<00000003o0000o`002P00o`0j0?ooo`030000003oo`00ool00340
ool000<0003o0?ooo`3oool02P3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo
0?ooo`1l0?ooo`T00?l000<00000003o0000o`001@00o`100?ooo`800000<@3oo`000`000?l0oooo
0?ooo`0:0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0840oooo1000
o`000`0000000?l0003o00170?ooo`800000;`3oo`000`000?l0oooo0?ooo`0:0?ooo`030000003o
ool0oooo02X0oooo000[0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0B@3oool2
000002d0ool000<0003o0?ooo`3oool02P3oool00`000000oooo0?ooo`0Z0?ooo`00;03oool00`00
0000oooo0?ooo`240?ooo`030000003oool0oooo04/0oooo00<000000?oo003oo`00:P3oo`000`00
0?l0oooo0?ooo`090?ooo`030000003oool0oooo02/0oooo000/0?ooo`030000003oool0oooo08@0
oooo00<000000?ooo`3oool0C03oool2000002X0ool000<0003o0?ooo`3oool0203oool00`000000
oooo0?ooo`0/0?ooo`00;@3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo04h0oooo
0P00000X0?oo00030000o`3oool0oooo00P0oooo00<000000?ooo`3oool0;03oool002d0oooo00<0
00000?ooo`3oool0P`3oool00`000000oooo0?ooo`1@0?ooo`8000009P3oo`000`000?l0oooo0?oo
o`080?ooo`030000003oool0oooo02`0oooo000]0?ooo`030000003oool0oooo08<0oooo00<00000
0?ooo`3oool0DP3oool00`000000ool00?oo000S0?oo00030000o`3oool0oooo00P0oooo00<00000
0?ooo`3oool0;03oool002h0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`1C0?oo
o`8000008`3oo`000`000?l0oooo0?ooo`070?ooo`030000003oool0oooo02d0oooo000^0?ooo`03
0000003oool0oooo0880oooo00<000000?ooo`3oool0E@3oool200000240ool000<0003o0?ooo`3o
ool01`3oool00`000000oooo0?ooo`0]0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000
003oool0oooo05L0oooo00<000000?oo003oo`007P3oo`000`000?l0oooo0?ooo`070?ooo`030000
003oool0oooo02d0oooo000^0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0F03o
ool2000001h0ool000<0003o0?ooo`3oool01P3oool00`000000oooo0?ooo`0^0?ooo`00;`3oool0
0`000000oooo0?ooo`210?ooo`030000003oool0oooo05X0oooo0P00000L0?oo00030000o`3oool0
oooo00H0oooo00<000000?ooo`3oool0;P3oool00300oooo00<000000?ooo`3oool0P03oool00`00
0000oooo0?ooo`1L0?ooo`8000006P3oo`000`000?l0oooo0?ooo`050?ooo`030000003oool0oooo
02l0oooo000`0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0GP3oool00`000000
ool00?oo000G0?oo00030000o`3oool0oooo00D0oooo00<000000?ooo`3oool0;`3oool00300oooo
00<000000?ooo`3oool0P03oool200000600oooo0P00000G0?oo00030000o`3oool0oooo00D0oooo
00<000000?ooo`3oool0;`3oool00300oooo00<000000?ooo`3oool0P03oool00`000000oooo0?oo
o`1Q0?ooo`8000005@3oo`000`000?l0oooo0?ooo`040?ooo`030000003oool0oooo0300oooo000a
0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0H`3oool2000001<0ool000<0003o
0?ooo`3oool0103oool00`000000oooo0?ooo`0`0?ooo`00<P3oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo06D0oooo00<000000?oo003oo`003P3oo`000`000?l0ool00000o`020?oo
o`040000o`3oool0oooo000003<0oooo000b0?ooo`030000003oool0oooo07h0oooo00<000000?oo
o`3oool0IP3oool2000000h0ool01P000?l00`3oool000000?ooo`0c0?ooo`00<`3oool00`000000
oooo0?ooo`1m0?ooo`030000003oool0oooo06P0oooo0P00000<0?oo00D0003o0P3oool00`000000
oooo0?ooo`0b0?ooo`00<`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo06X0oooo
0P00000;0?oo00@0003o0P3oool00`000000oooo0?ooo`0b0?ooo`00<`3oool00`000000oooo0?oo
o`1m0?ooo`030000003oool0oooo06`0oooo00<000000?oo003oo`00203oo`040000o`030?ooo`00
0000oooo03@0oooo000d0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0K@3oool2
000000P0ool010000?l00`3oool000000?ooo`0d0?ooo`00=03oool00`000000oooo0?ooo`1l0?oo
o`030000003oool0oooo06l0oooo0P0000060?oo00<0003o00<0oooo0000003oool0=@3oool003D0
oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`1a0?ooo`030000003oo`00ool000<0
ool00`000?l00`3oool000000?ooo`0e0?ooo`00=P3oool00`000000oooo0?ooo`1j0?ooo`030000
003oool0oooo0780oooo0P0000030?oo00<0003o00<000000?ooo`3oool0=@3oool003H0oooo00<0
00000?ooo`3oool0IP3oool02P2oM00000000000B02Lgol0oooo0?oo_`1dB9`0gooo0?ooo`2oM002
0000000304RLg`3oool0oooo00D0oooo00<000000?ooo`3oool0M03oool200000080ool00P000?lh
0?ooo`00=`3oool00`000000oooo0?ooo`1T0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3o
ool01P3o_g@0B9cO0?ooo`3oool0gia807Boo`H0oooo00<000000?ooo`3oool0MP3oool200000003
0000o`000000oooo03L0oooo000h0?ooo`030000003oool0oooo06<0oooo00H0gia804RLg`3oool0
oono07@0M02oool70?ooo`030?noM018W=l0oooo00D0oooo0`00001h0?ooo`030000o`3oool0oooo
03L0oooo000h0?ooo`030000003oool0oooo06<0oooo00H0gia807Boo`3oool0oooO09a8M02oool3
0?ooo`060?noM00007@0_ooo0?ooo`3OW4P0M;oo1P3oool00`000000oooo0?ooo`1g0?ooo`030000
003oool0oooo03P0oooo000i0?ooo`030000003oool0oooo0680oooo00H0gia804RLg`3oool0oono
07@0M02oool30?ooo`050?oo_`1dB4P0B00000000000M;l01`3oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo03P0oooo000i0?ooo`030000003oool0oooo0680oooo00H0okmd0018W03O
ool0okmd0018W03Oool30?ooo`030?oog`2LB4P0W=oo00T0oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`0h0?ooo`00>P3oool00`000000oooo0?ooo`1R0?ooo`040;md000000000018
09cOo`D0oooo00D0_g@0000000000000001809cOo`060?ooo`030000003oool0oooo07H0oooo00<0
00000?ooo`3oool0>@3oool003X0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`1e
0?ooo`030?oo_`000000B9cO03X0oooo000k0?ooo`030000003oool0oooo07D0oooo00<000000?oo
o`3oool0M@3oool00`000000M00004RLg`0j0?ooo`00?03oool00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo07@0oooo00@000000?oo_`1d0000B9cO>P3oool003`0oooo00<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`1d0?ooo`030000003ookl0M00000<0000000<007Bo0?ooo`3o
ool0=@3oool003d0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1c0?ooo`090000
003oool0oono07@00018W=l0oooo0?oOW0180000B9cO03H0oooo000n0?ooo`030000003oool0oooo
0780oooo00<000000?ooo`3oool0LP3oool02P000000oooo0?ooo`3ookl0M00004RLg`3oool0oono
07@00000M;lf0?ooo`00?P3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0780oooo
00X000000?ooo`3oool0oono07@00018W=l0oooo0?oOW0180000B9cO=P3oool003l0oooo00<00000
0?ooo`3oool0L@3oool00`000000oooo0?ooo`1a0?ooo`060000003oool0oooo0?ooo`3ookl0M000
0`0000000`00B9`0gooo0?ooo`0e0?ooo`00@03oool00`000000oooo0?ooo`1`0?ooo`030000003o
ool0oooo0700oooo00<000000?ooo`3oool0?`3oool00400oooo00<000000?ooo`3oool0L03oool2
00000740oooo00<000000?ooo`3oool0?`3oool00440oooo00<000000?ooo`3oool0K`3oool00`00
0000oooo0?ooo`1_0?ooo`030000003oool0oooo0400oooo00120?ooo`030000003oool0oooo06h0
oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`110?ooo`00@`3oool00`000000oooo
0?ooo`1]0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0@P3oool004@0oooo00<0
00000?ooo`3oool0K03oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo04<0oooo0015
0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`14
0?ooo`00A@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0A03oool004H0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1Z0?ooo`03
0000003oool0oooo04D0oooo00170?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0
J@3oool00`000000oooo0?ooo`160?ooo`00B03oool00`000000oooo0?ooo`1X0?ooo`030000003o
ool0oooo06P0oooo00<000000?ooo`3oool0A`3oool004T0oooo00<000000?ooo`3oool0I`3oool0
0`000000oooo0?ooo`1W0?ooo`030000003oool0oooo04P0oooo001:0?ooo`030000003oool0oooo
06H0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`190?ooo`00B`3oool00`000000
oooo0?ooo`1U0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0BP3oool004`0oooo
00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo04/0oooo
001=0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?oo
o`1<0?ooo`00CP3oool00`000000oooo0?ooo`1R0?ooo`800000H`3oool00`000000oooo0?ooo`1=
0?ooo`00C`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0640oooo00<000000?oo
o`3oool0CP3oool00500oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1P0?ooo`03
0000003oool0oooo04l0oooo001A0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0
G`3oool00`000000oooo0?ooo`1@0?ooo`00DP3oool00`000000oooo0?ooo`1N0?ooo`030000003o
ool0oooo05h0oooo00<000000?ooo`3oool0D@3oool005<0oooo00<000000?ooo`3oool0G@3oool0
0`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0580oooo001D0?ooo`030000003oool0oooo
05`0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`1C0?ooo`00E@3oool00`000000
oooo0?ooo`1K0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0E03oool005H0oooo
00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo05D0oooo
001G0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?oo
o`1F0?ooo`00F03oool2000005T0oooo00<000000?ooo`3oool0E`3oool2000005T0oooo001J0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`1I0?oo
o`00F`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3o
ool0FP3oool005`0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo05/0oooo001M0?ooo`030000003oool0oooo05<0oooo0P00001D0?ooo`030000003o
ool0oooo05`0oooo001N0?ooo`800000D`3oool00`000000oooo0?ooo`1A0?ooo`800000G`3oool0
0600oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo
05l0oooo001Q0?ooo`800000D03oool00`000000oooo0?ooo`1>0?ooo`800000HP3oool006<0oooo
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0680oooo
001T0?ooo`800000C@3oool00`000000oooo0?ooo`1;0?ooo`800000I@3oool006H0oooo00<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo06D0oooo001W0?oo
o`800000BP3oool00`000000oooo0?ooo`180?ooo`800000J03oool006T0oooo0P0000180?ooo`03
0000003oool0oooo04H0oooo0P00001Z0?ooo`00J`3oool2000004H0oooo00<000000?ooo`3oool0
A03oool2000006`0oooo001]0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`1/0?ooo`00KP3oool2000004<0oooo00<000000?ooo`3oool0@@3oool2
000006l0oooo001`0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`1_0?ooo`00L@3oool200000400oooo00<000000?ooo`3oool0?P3oool200000780
oooo001c0?ooo`<00000?@3oool2000003`0oooo0`00001d0?ooo`00MP3oool2000003/0oooo00<0
00000?ooo`3oool0>@3oool2000007L0oooo001h0?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`1g0?ooo`00N@3oool4000003H0oooo00<000000?oo
o`3oool0=03oool4000007X0oooo001m0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`1l0?ooo`00OP3oool400000340oooo00<000000?ooo`3oool0
;`3oool4000007l0oooo00220?ooo`<00000;P3oool00`000000oooo0?ooo`0/0?ooo`<00000P`3o
ool008D0oooo0P00000/0?ooo`030000003oool0oooo02X0oooo0P0000260?ooo`00Q`3oool30000
02T0oooo00<000000?ooo`3oool09`3oool3000008P0oooo002:0?ooo`<000009P3oool00`000000
oooo0?ooo`0T0?ooo`<00000R`3oool008d0oooo1P00000P0?ooo`030000003oool0oooo01h0oooo
1P00002>0?ooo`00T`3oool3000001d0oooo00<000000?ooo`3oool06`3oool3000009@0oooo002F
0?ooo`D000003@3oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo01H0oooo1@00002G
0?ooo`00V`3oool7000000H0oooo00<0oooO09a8M02oool0203oool00`000000oooo0?ooo`0?0?oo
o`L00000W03oool00:80oooo8`00002S0?ooo`00Z03oool00`3ooml0W4Qd0;ooo`080?ooo`030000
003oool0oooo0;80oooo002V0?ooo`050?oog`2LW;l0oooO09a8M02oool0203oool00`000000oooo
0?ooo`2b0?ooo`00Y`3oool0103o_g@000000000M02oool80?ooo`030000003oool0oooo0;80oooo
002X0?ooo`030?oo_`1d07@0_ooo00P0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<00000
0?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3o
ool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0
oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<0
00000?ooo`3oool0/P3oool00;<0oooo0P00002c0?ooo`00/`3oool00`000000oooo0?ooo`2b0?oo
o`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3o
ool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`00
0000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo
0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b
0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00
/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool200000;<0oooo002c0?ooo`030000003oool0
oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80
oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c
0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`03
0000003oool0oooo0;80oooo0000\
\>"],
  ImageRangeCache->{{{112.438, 370.625}, {345.813, 87.625}} -> {-2.35746, \
-0.404754, 0.00878441, 0.00878441}},
  CellTags->"figura5"]
}, Closed]],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\({idFondamentale, senCompl, cosCompl, tanCompl, senDiffPi2, 
          cosDiffPi2, tanDiffPi2, senSuppl, cosSuppl, 
          tanSuppl} = {cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 
            1, sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          tan[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cot[\[Alpha]], 
          sen[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          tan[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-\(cos[\[Alpha]]\/sen[\
\[Alpha]]\)\), sen[\[Pi] - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          cos[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-tan[\[Alpha]]\)};\)\)], \
"Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Seno di un angolo che differisce di \[Pi] (angolo explementare)\
\>", "Subsubsection"],

Cell[TextData[{
  "Con riferimento alla ",
  ButtonBox["fig. 5",
    ButtonData:>"figura5",
    ButtonStyle->"Hyperlink"],
  " osserviamo al solito modo che ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["OS",
            FontSlant->"Italic"], 
          StyleBox["=",
            FontSlant->"Plain"], 
          StyleBox[\(-OQ\),
            FontSlant->"Italic"]}], TraditionalForm]]],
  " cos\[IGrave] come ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["SR",
            FontSlant->"Italic"], 
          StyleBox["=",
            FontSlant->"Plain"], 
          StyleBox[\(-QP\),
            FontSlant->"Italic"]}], TraditionalForm]]],
  ". Poich\[EAcute] per definizione risulta"
}], "Text",
  CellTags->"osservazione3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sen[\[Pi] + \[Alpha]] \[Equal] SR/OR\)], "Input"],

Cell[BoxData[
    \(sen[\[Pi] + \[Alpha]] \[Equal] SR\/OR\)], "Output"]
}, Closed]],

Cell["le precedenti danno luogo alla", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {SR \[Rule] \(-QP\), OR \[Rule] OP}\)], "Input"],

Cell[BoxData[
    \(sen[\[Pi] + \[Alpha]] \[Equal] \(-\(QP\/OP\)\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "e quindi, riprese le definizioni per l'angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ", segue"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. defs\)], "Input"],

Cell[BoxData[
    \(sen[\[Pi] + \[Alpha]] \[Equal] \(-sen[\[Alpha]]\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(senExpl = toRule[%]\)], "Input"],

Cell[BoxData[
    \(sen[\[Pi] + \[Alpha]] \[RuleDelayed] \(-sen[\[Alpha]]\)\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\({idFondamentale, senCompl, cosCompl, tanCompl, senDiffPi2, 
          cosDiffPi2, tanDiffPi2, senSuppl, cosSuppl, tanSuppl, 
          senExpl} = {cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 1, 
          sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          tan[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cot[\[Alpha]], 
          sen[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          tan[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-\(cos[\[Alpha]]\/sen[\
\[Alpha]]\)\), sen[\[Pi] - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          cos[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          sen[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\)};\)\)], \
"Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Coseno di un angolo che differisce di \[Pi] (angolo explementare)\
\>", "Subsubsection"],

Cell[TextData[{
  "La definizione di coseno implica per l'angolo explementare ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] + \[Pi]\)]],
  " (",
  ButtonBox["fig. 5",
    ButtonData:>"figura5",
    ButtonStyle->"Hyperlink"],
  ")"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cos[\[Pi] + \[Alpha]] \[Equal] OS/OR\)], "Input"],

Cell[BoxData[
    \(cos[\[Pi] + \[Alpha]] \[Equal] OS\/OR\)], "Output"]
}, Closed]],

Cell[TextData[{
  "ma le ",
  ButtonBox["relazioni",
    ButtonData:>"osservazione3",
    ButtonStyle->"Hyperlink"],
  " tra componenti gi\[AGrave] discusse permettono di scrivere"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {OS \[Rule] \(-OQ\), OR \[Rule] OP}\)], "Input"],

Cell[BoxData[
    \(cos[\[Pi] + \[Alpha]] \[Equal] \(-\(OQ\/OP\)\)\)], "Output"]
}, Closed]],

Cell["da cui", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. defs\)], "Input"],

Cell[BoxData[
    \(cos[\[Pi] + \[Alpha]] \[Equal] \(-cos[\[Alpha]]\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cosExpl = toRule[%]\)], "Input"],

Cell[BoxData[
    \(cos[\[Pi] + \[Alpha]] \[RuleDelayed] \(-cos[\[Alpha]]\)\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\({idFondamentale, senCompl, cosCompl, tanCompl, senDiffPi2, 
          cosDiffPi2, tanDiffPi2, senSuppl, cosSuppl, tanSuppl, senExpl, 
          cosExpl} = {cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 1, 
          sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          tan[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cot[\[Alpha]], 
          sen[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          tan[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-\(cos[\[Alpha]]\/sen[\
\[Alpha]]\)\), sen[\[Pi] - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          cos[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          sen[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\)};\)\)], \
"Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Tangente di un angolo che differisce di \[Pi] (angolo explementare)\
\>", "Subsubsection"],

Cell["Infine sfruttando ancora la definizione di tangente", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tan[\[Pi] + \[Alpha]] \[Equal] SR/OS\)], "Input"],

Cell[BoxData[
    \(tan[\[Pi] + \[Alpha]] \[Equal] SR\/OS\)], "Output"]
}, Closed]],

Cell[TextData[{
  "e le ",
  ButtonBox["relazioni",
    ButtonData:>"osservazione3",
    ButtonStyle->"Hyperlink"],
  " tra componenti"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {SR \[Rule] \(-QP\), OS \[Rule] \(-OQ\)}\)], "Input"],

Cell[BoxData[
    \(tan[\[Pi] + \[Alpha]] \[Equal] QP\/OQ\)], "Output"]
}, Closed]],

Cell["risulta", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. defs\)], "Input"],

Cell[BoxData[
    \(tan[\[Pi] + \[Alpha]] \[Equal] tan[\[Alpha]]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Questa identit\[AGrave] conferma e dimostra la periodicit\[AGrave] della \
funzione tangente: il suo periodo \[EGrave] pari a ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tanExpl = toRule[%]\)], "Input"],

Cell[BoxData[
    \(tan[\[Pi] + \[Alpha]] \[RuleDelayed] tan[\[Alpha]]\)], "Output"]
}, Closed]],

Cell["\<\
In definitiva abbiamo che le funzioni goniometriche di angoli esplementari \
sono collegate a quelle dell'angolo originario dalle seguenti \
identit\[AGrave]\
\>", "Text"],

Cell[BoxData[{
    \(TraditionalForm\`Angoli\ che\ differiscono\ di\ \[Pi]\), "\
\[IndentingNewLine]", 
    \(TraditionalForm\`sen(\[Pi] + \[Alpha]) = \(-\(sen(\[Alpha])\)\)\), "\
\[IndentingNewLine]", 
    \(TraditionalForm\`cos(\[Pi] + \[Alpha]) = \(-\(cos(\[Alpha])\)\)\), "\
\[IndentingNewLine]", 
    \(TraditionalForm\`tan(\[Pi] + \[Alpha]) = tan(\[Alpha])\)}], "Definition",\

  FontFamily->"Courier"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Angoli opposti", "Subsection"],

Cell[CellGroupData[{

Cell["Grafico", "Subsubsection"],

Cell[BoxData[{
    \(\[Alpha] = 30  Degree; \[Beta] = \(-\[Alpha]\);\), "\n", 
    \(pP = {Cos[\[Alpha]], Sin[\[Alpha]]}; pQ = {Cos[\[Alpha]], 0}; 
    origine = {0, 0}; pR = {Cos[\[Beta]], Sin[\[Beta]]}; 
    pS = {Cos[\[Beta]], 0};\), "\n", 
    \(Show[
      Graphics[{Circle[origine, 1], Line[{{\(-1.2\), 0}, {1.2, 0}}], 
          Line[{{0, \(-1.2\)}, {0, 1.2}}], 
          Line[{pP, origine, pR}]}], \[IndentingNewLine]Graphics[{colBlu, 
          Arrow[origine, pQ, stileVet], 
          Arrow[pQ, pP, stileVet]}], \[IndentingNewLine]Graphics[{colBlu, 
          Arrow[origine, pS, stileVet], 
          Arrow[pS, pR, 
            stileVet]}], \[IndentingNewLine]Graphics[{Text["\<O\>", 
            origine, {1, 1}, TextStyle \[Rule] stileTesto], 
          Text["\<Q\[Congruent]S\>", pQ - {0, 0.025}, {0, 1}, 
            TextStyle \[Rule] stileTesto], 
          Text["\<P\>", pP, {0, \(-1\)}, TextStyle \[Rule] stileTesto], 
          Text["\<R\>", pR, {0, 1}, TextStyle \[Rule] stileTesto]}], 
      Prolog -> {{colGiallo, Polygon[{origine, pQ, pP}], 
            Polygon[{origine, pS, pR}]}, {colVerde, 
            Disk[{0, 0},  .3, {\[Beta], 0}]}, {colRosso, 
            Disk[origine,  .2, {0, \[Alpha]}]}}, 
      AspectRatio \[Rule] Automatic, Axes \[Rule] True]; 
    Clear[\[Alpha], \[Beta]];\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Grafico", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.396825 0.5 0.396825 [
[.10317 .4875 -6.96875 -10.9375 ]
[.10317 .4875 6.96875 0 ]
[.30159 .4875 -10.3125 -10.9375 ]
[.30159 .4875 10.3125 0 ]
[.69841 .4875 -7.5625 -10.9375 ]
[.69841 .4875 7.5625 0 ]
[.89683 .4875 -4.21875 -10.9375 ]
[.89683 .4875 4.21875 0 ]
[.4875 .10317 -13.9375 -5.46875 ]
[.4875 .10317 0 5.46875 ]
[.4875 .30159 -20.625 -5.46875 ]
[.4875 .30159 0 5.46875 ]
[.4875 .69841 -15.125 -5.46875 ]
[.4875 .69841 0 5.46875 ]
[.4875 .89683 -8.4375 -5.46875 ]
[.4875 .89683 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .5 m
.10317 .50625 L
s
gsave
.10317 .4875 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.30159 .5 m
.30159 .50625 L
s
gsave
.30159 .4875 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.69841 .5 m
.69841 .50625 L
s
gsave
.69841 .4875 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.89683 .5 m
.89683 .50625 L
s
gsave
.89683 .4875 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.14286 .5 m
.14286 .50375 L
s
.18254 .5 m
.18254 .50375 L
s
.22222 .5 m
.22222 .50375 L
s
.2619 .5 m
.2619 .50375 L
s
.34127 .5 m
.34127 .50375 L
s
.38095 .5 m
.38095 .50375 L
s
.42063 .5 m
.42063 .50375 L
s
.46032 .5 m
.46032 .50375 L
s
.53968 .5 m
.53968 .50375 L
s
.57937 .5 m
.57937 .50375 L
s
.61905 .5 m
.61905 .50375 L
s
.65873 .5 m
.65873 .50375 L
s
.7381 .5 m
.7381 .50375 L
s
.77778 .5 m
.77778 .50375 L
s
.81746 .5 m
.81746 .50375 L
s
.85714 .5 m
.85714 .50375 L
s
.06349 .5 m
.06349 .50375 L
s
.02381 .5 m
.02381 .50375 L
s
.93651 .5 m
.93651 .50375 L
s
.97619 .5 m
.97619 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .10317 m
.50625 .10317 L
s
gsave
.4875 .10317 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .30159 m
.50625 .30159 L
s
gsave
.4875 .30159 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .69841 m
.50625 .69841 L
s
gsave
.4875 .69841 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .89683 m
.50625 .89683 L
s
gsave
.4875 .89683 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .14286 m
.50375 .14286 L
s
.5 .18254 m
.50375 .18254 L
s
.5 .22222 m
.50375 .22222 L
s
.5 .2619 m
.50375 .2619 L
s
.5 .34127 m
.50375 .34127 L
s
.5 .38095 m
.50375 .38095 L
s
.5 .42063 m
.50375 .42063 L
s
.5 .46032 m
.50375 .46032 L
s
.5 .53968 m
.50375 .53968 L
s
.5 .57937 m
.50375 .57937 L
s
.5 .61905 m
.50375 .61905 L
s
.5 .65873 m
.50375 .65873 L
s
.5 .7381 m
.50375 .7381 L
s
.5 .77778 m
.50375 .77778 L
s
.5 .81746 m
.50375 .81746 L
s
.5 .85714 m
.50375 .85714 L
s
.5 .06349 m
.50375 .06349 L
s
.5 .02381 m
.50375 .02381 L
s
.5 .93651 m
.50375 .93651 L
s
.5 .97619 m
.50375 .97619 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto fill
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto
-0.03 0.0075 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
1 1 0 r
.5 .5 m
.84366 .5 L
.84366 .69841 L
F
.5 .5 m
.84366 .5 L
.84366 .30159 L
F
0 1 0 r
.5 .5 m
.5 .5 .11905 -30 0 arc
F
1 0 0 r
.5 .5 m
.5 .5 .07937 0 30 arc
F
0 g
.5 Mabswid
newpath
.5 .5 .39683 0 365.73 arc
s
.02381 .5 m
.97619 .5 L
s
.5 .02381 m
.5 .97619 L
s
.84366 .69841 m
.5 .5 L
.84366 .30159 L
s
0 0 1 r
.5 .5 m
.84366 .5 L
s
% Start of user PostScript
0 0 0.866025 0 MAarrowhead1
% End of user PostScript
.84366 .5 m
.84366 .69841 L
s
% Start of user PostScript
0.866025 0 0.866025 0.5 MAarrowhead1
% End of user PostScript
.5 .5 m
.84366 .5 L
s
% Start of user PostScript
0 0 0.866025 0 MAarrowhead1
% End of user PostScript
.84366 .5 m
.84366 .30159 L
s
% Start of user PostScript
0.866025 0 0.866025 -0.5 MAarrowhead1
% End of user PostScript
0 g
gsave
.5 .5 -71.9375 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.84366 .49008 -72.5313 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Q) show
69.938 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\272) show
76.063 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
82.063 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.84366 .69841 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
69.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.84366 .30159 -66.2188 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(R) show
69.438 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  Magnification->0.9,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?oo
o`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?oo
o`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3o
ool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo
0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?oo
o`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000
003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0
oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80
oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<00000
0?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3o
ool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0
oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<0
00000?ooo`3oool0/P3oool00:P0oooo00<0oooO09a8M02oool0203oool00`000000oooo0?ooo`2b
0?ooo`00Z03oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo0;80oooo002P0?ooo`03
0?noM000000000000080000000H004RL0=ooo`3oool0oooO09a8M02oool80?ooo`030000003oool0
oooo0;80oooo002S0?ooob400000Y03oool009`0oooo1`0000030?ooo`050?oog`2LW;l0oooO09a8
M02oool0203oool00`000000oooo0?ooo`0>0?ooo`L00000W@3oool009L0oooo1@00000;0?ooo`04
0?noM0000000001d0;ooo`P0oooo00<000000?ooo`3oool05@3oool5000009P0oooo002C0?ooo`@0
00004@3oool00`3ookl0M01d0;ooo`080?ooo`030000003oool0oooo01X0oooo1000002D0?ooo`00
SP3oool500000200oooo00<000000?ooo`3oool07P3oool5000008l0oooo002;0?ooo`<000009@3o
ool00`000000oooo0?ooo`0S0?ooo`<00000S03oool008L0oooo1000000X0?ooo`030000003oool0
oooo02H0oooo100000280?ooo`00QP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0Q@3oool00880oooo1000000]0?ooo`030000003oool0oooo02/0
oooo100000230?ooo`00O`3oool300000340oooo00<000000?ooo`3oool0;`3oool300000800oooo
001m0?ooo`800000=03oool00`000000oooo0?ooo`0b0?ooo`800000OP3oool007X0oooo0`00000f
0?ooo`030000003oool0oooo03@0oooo0`00001k0?ooo`00N03oool2000003T0oooo00<000000?oo
o`3oool0=`3oool2000007T0oooo001g0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`1f0?ooo`00M03oool3000003`0oooo0P00000k0?ooo`<00000
M@3oool00780oooo0P00000o0?ooo`030000003oool0oooo03d0oooo0P00001c0?ooo`00L03oool2
00000440oooo00<000000?ooo`3oool0?`3oool200000740oooo001_0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1^0?ooo`00K@3oool2000004@0
oooo00<000000?ooo`3oool0@P3oool2000006h0oooo001/0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1[0?ooo`00J@3oool3000004L0oooo00<0
00000?ooo`3oool0A@3oool3000006X0oooo001W0?ooo`800000BP3oool00`000000oooo0?ooo`18
0?ooo`800000J03oool006H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo06D0oooo001T0?ooo`800000C@3oool00`000000oooo0?ooo`1;0?ooo`80
0000I@3oool006<0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo0680oooo001Q0?ooo`800000D03oool00`000000oooo0?ooo`1>0?ooo`800000HP3o
ool00600oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo05l0oooo001N0?ooo`800000D`3oool00`000000oooo0?ooo`1A0?ooo`800000G`3oool005d0
oooo00<000000?ooo`3oool0D`3oool2000005@0oooo00<000000?ooo`3oool0G03oool005`0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05/0oooo
001K0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`1J0?ooo`00FP3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool0F@3oool005P0oooo0P00001I0?ooo`030000003oool0oooo05L0oooo0P00001I0?oo
o`00E`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0EP3oool005H0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo05D0oooo001E0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`1D0?ooo`00E03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo05`0oooo00<000000?ooo`3oool0D`3oool005<0oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`1M0?ooo`030000003oool0oooo0580oooo001B0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1A0?ooo`00D@3oool00`000000oooo
0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0D03oool00500oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo04l0oooo001?
0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1>
0?ooo`00CP3oool00`000000oooo0?ooo`1R0?ooo`800000H`3oool00`000000oooo0?ooo`1=0?oo
o`00C@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool0C03oool004`0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1T0?ooo`030000
003oool0oooo04/0oooo001;0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`1:0?ooo`00BP3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0
oooo06H0oooo00<000000?ooo`3oool0B@3oool004T0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`1W0?ooo`030000003oool0oooo04P0oooo00180?ooo`030000003oool0oooo06P0
oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`170?ooo`00A`3oool00`000000oooo
0?ooo`1Y0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0AP3oool004H0oooo00<0
00000?ooo`3oool0JP3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo04D0oooo0015
0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`14
0?ooo`00A@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0A03oool004@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo04<0oooo00130?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0
K@3oool00`000000oooo0?ooo`120?ooo`00@P3oool00`000000oooo0?ooo`1^0?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool0@@3oool00440oooo00<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0400oooo00100?ooo`030000003oool0oooo
0700oooo0P00001a0?ooo`030000003oool0oooo03l0oooo00100?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0o0?ooo`00?`3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0?P3oool003h0oooo00<0
00000?ooo`3oool0LP3oool00`000000oooo0?ooo`1b0?ooo`090000003oool0omnL04P0001d_ol0
oooo0?oo_`1d000007Bo03L0oooo000n0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3o
ool0LP3oool02@000000oooo0?oOW0180000M;oo0?ooo`3OW4P0001809cOo`0g0?ooo`00?@3oool0
0`000000oooo0?ooo`1c0?ooo`030000003oool0oooo07<0oooo00L000000?oOW0180000M;oo0?oO
W0180000B9cO03P0oooo000l0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0M03o
ool00`000000B000000000020000000304RLg`3oool0oooo03H0oooo000l0?ooo`030000003oool0
oooo07@0oooo00<000000?ooo`3oool0M03oool01`000000B00007Boo`3oool0okmd0000001d_ol0
=`3oool003/0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1d0?ooo`070?oOW000
0000M;oo0?ooo`3ogi`0B00004RLg`0g0?ooo`00>P3oool00`000000oooo0?ooo`1f0?ooo`030000
003oool0oooo07@0oooo00L0omnL04P000000000oooo0?noM0000000M;oo03L0oooo000j0?ooo`03
0000003oool0oooo07H0oooo00<000000?ooo`3oool0M03oool00`3ogi`0B0000000000200000003
001d_`3oool0oooo03H0oooo000i0?ooo`030000003oool0oooo06<0oooo00X0_g@00000000004P0
W=oo0?ooo`3ookl0M4RL0=ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`050?ooo`030000003o
ool0oooo07L0oooo00<000000?ooo`3oool0>03oool003T0oooo00<000000?ooo`3oool0HP3oool0
1P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00H0okmd04RLg`3oool0oooo0=nLB01d_ol60?oo
o`030000003oool0oooo07L0oooo00<000000?ooo`3oool0>03oool003P0oooo00<000000?ooo`3o
ool0G03oool00`3o_g@0000000000002000000080018W03Oool0gia804RLg`3oool0oono07@0M02o
ool70?ooo`030?noM018W=l0oooo00D0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`0h0?ooo`00>03oool00`000000oooo0?ooo`1S0?ooo`060=nLB01d_ol0oooo0?oog`2LB7@0_ooo
0`3oool01P3o_g@0001d0;ooo`3oool0gia807Boo`H0oooo0`00001h0?ooo`030000o`3oool0oooo
03L0oooo000g0?ooo`030000003oool0oooo06@0oooo00H0gia804RLg`3oool0oono07@0M02oool3
0?ooo`050?oo_`1dB4P0B00000000000M;l01`3oool00`000000oooo0?ooo`1f0?ooo`80000000<0
003o0000003oool0=`3oool003H0oooo00<000000?ooo`3oool0I@3oool01P3o_g@004RL0=ooo`3o
_g@004RL0=ooo`<0oooo00<0oooO09a8B02Lgol02@3oool00`000000oooo0?ooo`1d0?ooo`800000
0P3oo`020000ocP0oooo000f0?ooo`030000003oool0oooo06H0oooo00@0_g@00000000004P0W=oo
1@3oool01@2oM00000000000000004P0W=oo00H0oooo00<000000?ooo`3oool0LP3oool2000000<0
ool00`000?l00`000000oooo0?ooo`0e0?ooo`00=@3oool00`000000oooo0?ooo`1k0?ooo`030000
003oool0oooo0740oooo00<000000?oo003oo`000`3oo`030000o`030?ooo`000000oooo03D0oooo
000d0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0K`3oool2000000H0ool00`00
0?l00`3oool000000?ooo`0e0?ooo`00=03oool00`000000oooo0?ooo`1l0?ooo`030000003oool0
oooo06d0oooo0P0000080?oo00@0003o00<0oooo0000003oool0=03oool003<0oooo00<000000?oo
o`3oool0O@3oool00`000000oooo0?ooo`1/0?ooo`030000003oo`00ool000P0ool010000?l00`3o
ool000000?ooo`0d0?ooo`00<`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo06X0
oooo0P00000;0?oo00@0003o0P3oool00`000000oooo0?ooo`0b0?ooo`00<`3oool00`000000oooo
0?ooo`1m0?ooo`030000003oool0oooo06P0oooo0P00000<0?oo00D0003o0P3oool00`000000oooo
0?ooo`0b0?ooo`00<P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo06H0oooo0P00
000>0?oo00H0003o00<0oooo0000003oool0<`3oool00380oooo00<000000?ooo`3oool0OP3oool0
0`000000oooo0?ooo`1U0?ooo`030000003oo`00ool000h0ool00`000?l00`3oool0003o0000o`02
0?ooo`030000003oool0oooo0340oooo000a0?ooo`030000003oool0oooo07l0oooo00<000000?oo
o`3oool0H`3oool2000001<0ool000<0003o0?ooo`3oool0103oool00`000000oooo0?ooo`0`0?oo
o`00<03oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0640oooo0P00000E0?oo0003
0000o`3oool0oooo00@0oooo00<000000?ooo`3oool0<03oool00300oooo00<000000?ooo`3oool0
P03oool200000600oooo0P00000G0?oo00030000o`3oool0oooo00D0oooo00<000000?ooo`3oool0
;`3oool00300oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`1N0?ooo`030000003o
o`00ool001L0ool000<0003o0?ooo`3oool01@3oool00`000000oooo0?ooo`0_0?ooo`00<03oool0
0`000000oooo0?ooo`200?ooo`030000003oool0oooo05`0oooo0P00000J0?oo00030000o`3oool0
oooo00D0oooo00<000000?ooo`3oool0;`3oool002l0oooo00<000000?ooo`3oool0P@3oool00`00
0000oooo0?ooo`1J0?ooo`800000703oo`000`000?l0oooo0?ooo`060?ooo`030000003oool0oooo
02h0oooo000^0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0F03oool2000001h0
ool000<0003o0?ooo`3oool01P3oool00`000000oooo0?ooo`0^0?ooo`00;P3oool00`000000oooo
0?ooo`220?ooo`030000003oool0oooo05L0oooo00<000000?oo003oo`007P3oo`000`000?l0oooo
0?ooo`070?ooo`030000003oool0oooo02d0oooo000^0?ooo`030000003oool0oooo0880oooo00<0
00000?ooo`3oool0E@3oool200000240ool000<0003o0?ooo`3oool01`3oool00`000000oooo0?oo
o`0]0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo05<0oooo0P00000S
0?oo00030000o`3oool0oooo00L0oooo00<000000?ooo`3oool0;@3oool002d0oooo00<000000?oo
o`3oool0P`3oool00`000000oooo0?ooo`1B0?ooo`030000003oo`00ool002<0ool000<0003o0?oo
o`3oool0203oool00`000000oooo0?ooo`0/0?ooo`00;@3oool00`000000oooo0?ooo`230?ooo`03
0000003oool0oooo0500oooo0P00000V0?oo00030000o`3oool0oooo00P0oooo00<000000?ooo`3o
ool0;03oool002d0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`1>0?ooo`800000
:03oo`000`000?l0oooo0?ooo`080?ooo`030000003oool0oooo02`0oooo000/0?ooo`030000003o
ool0oooo08@0oooo00<000000?ooo`3oool0C03oool2000002X0ool000<0003o0?ooo`3oool0203o
ool00`000000oooo0?ooo`0/0?ooo`00;03oool00`000000oooo0?ooo`240?ooo`030000003oool0
oooo04/0oooo00<000000?oo003oo`00:P3oo`000`000?l0oooo0?ooo`090?ooo`030000003oool0
oooo02/0oooo000[0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0B@3oool20000
02d0ool000<0003o0?ooo`3oool02P3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000
oooo0?ooo`250?ooo`800000B03oool2000002l0ool000<0003o0?ooo`3oool02P3oool00`000000
oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo04D0oooo
0P00000a0?oo00030000o`3oool0oooo00X0oooo00<000000?ooo`3oool0:P3oool002X0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`140?ooo`030000003oo`00ool00340ool000<0
003o0?ooo`3oool02P3oool00`000000oooo0?ooo`0Z0?ooo`00:P3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo0480oooo0P00000d0?oo00030000o`3oool0oooo00/0oooo00<00000
0?ooo`3oool0:@3oool002X0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`100?oo
o`800000=P3oo`000`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo02T0oooo000Y0?ooo`03
0000003oool0oooo08L0oooo00<000000?ooo`3oool0?P3oool2000003P0ool000<0003o0?ooo`3o
ool02`3oool00`000000oooo0?ooo`0Y0?ooo`00:@3oool00`000000oooo0?ooo`270?ooo`030000
003oool0oooo03d0oooo00<000000?oo003oo`00>03oo`000`000?l0oooo0?ooo`0<0?ooo`030000
003oool0oooo02P0oooo000Y0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0>`3o
ool2000003/0ool000<0003o0?ooo`3oool0303oool00`000000oooo0?ooo`0X0?ooo`00:@3oool0
0`000000oooo0?ooo`270?ooo`030000003oool0oooo03T0oooo0P00000m0?oo00030000o`3oool0
oooo00`0oooo00<000000?ooo`3oool0:03oool002T0oooo00<000000?ooo`3oool0Q`3oool00`00
0000oooo0?ooo`0h0?ooo`030000003oo`00ool003d0ool000<0003o0?ooo`3oool0303oool00`00
0000oooo0?ooo`0X0?ooo`00:@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo03H0
oooo0P0000100?oo00030000o`3oool0oooo00`0oooo00<000000?ooo`3oool0:03oool002P0oooo
00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0d0?ooo`800000@P3oo`000`000?l0oooo
0?ooo`0=0?ooo`030000003oool0oooo02L0oooo000X0?ooo`030000003oool0oooo08P0oooo00<0
00000?ooo`3oool0<P3oool2000004@0ool000<0003o0?ooo`3oool03@3oool00`000000oooo0?oo
o`0W0?ooo`00:03oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0340oooo00<00000
0?oo003oo`00A03oo`000`000?l0oooo0?ooo`0=0?ooo`030000003oool0oooo02L0oooo000W0?oo
o`030000003oool0oooo08T0oooo00<000000?ooo`3oool0;`3oool2000004L0ool000<0003o0?oo
o`3oool03@3oool00`000000oooo0?ooo`0W0?ooo`009`3oool00`000000oooo0?ooo`290?ooo`80
0000;P3oool2000004T0ool000<0003o0?ooo`3oool03P3oool00`000000oooo0?ooo`0V0?ooo`00
9`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo02/0oooo0P00001;0?oo00030000
o`3oool0oooo00h0oooo00<000000?ooo`3oool09P3oool002L0oooo00<000000?ooo`3oool0R@3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oo`00ool004/0ool000<0003o0?ooo`3oool03P3o
ool00`000000oooo0?ooo`0V0?ooo`009`3oool00`000000oooo0?ooo`290?ooo`030000003oool0
oooo02P0oooo0P00001>0?oo00030000o`3oool0oooo00h0oooo00<000000?ooo`3oool09P3oool0
02H0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0V0?ooo`800000D03oo`000`00
0?l0oooo0?ooo`0>0?ooo`030000003oool0oooo02H0oooo000V0?ooo`030000003oool0oooo08X0
oooo00<000000?ooo`3oool0903oool200000580ool000<0003o0?ooo`3oool03`3oool00`000000
oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02<0oooo
00<000000?oo003oo`00DP3oo`000`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo02D0oooo
000V0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool08@3oool2000005D0ool000<0
003o0?ooo`3oool03`3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`2:
0?ooo`030000003oool0oooo01l0oooo0P000002003o05D0ool000<0003o0?ooo`3oool03`3oool0
0`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo
01h0oooo00<00000003o0000o`000P00o`1E0?oo00030000o`3oool0oooo00l0oooo00<000000?oo
o`3oool09@3oool002H0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0L0?ooo`80
00001P00o`1D0?oo00030000o`3oool0oooo00l0oooo00<000000?ooo`3oool09@3oool002D0oooo
00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0J0?ooo`8000002000o`1D0?oo00030000
o`3oool0oooo00l0oooo00<000000?ooo`3oool09@3oool002D0oooo00<000000?ooo`3oool0R`3o
ool00`000000oooo0?ooo`0H0?ooo`8000002P00o`1D0?oo00030000o`3oool0oooo0100oooo00<0
00000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0G
0?ooo`0300000000o`000?l000/00?l0C@3oo`000`3o_`0007@00?oo00030?oo00030000o`3oool0
oooo0100oooo00<000000?ooo`3oool0903oool002D0oooo00D000000?ooo`3ooml0W4Qd0;ooo`0o
0?ooo`0:0;md00000000001809cOo`3oool0oono07A8W03Oool0oooo0;md0080000000<0B9cO0?oo
o`3oool0>`3oool2000001H0oooo0P00000>003o04T0ool000<0M0000000000000000P0000000`2o
o`00ool00?no00050000000507Boo`3oool0oooo0?oo_`1d00000P0000000`00B9`0gooo0?ooo`06
0?ooo`030000002LB7@0_ooo02@0oooo000U0?ooo`050000003oool0oooO09a8M02oool0?P3oool0
1P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00H0okmd04RLg`3oool0oooo0=nLB01d_oll0?oo
o`030000003oool0oooo01<0oooo0P00000A003o04L0ool000@0M0000018003Oo`00_g@00P000000
0`2Lg`00ool00?oo00020?oo00030000o`3oool0oooo00<0oooo00H0_g@00000M02oool0omnL04P0
0018W=l70?ooo`030000002LB7@0_ooo02@0oooo000N0?ooo`030?noM000000000000080000000L0
04RL0=ooo`000000oooo0?oog`2LB7@0_ooo03L0oooo00<0okmd0000000000000P0000002000B9`0
gooo0=nLB018W=l0oooo0?oo_`1d07@0_ooo1`3oool00`3o_g@0B9cO0?ooo`0k0?ooo`030000003o
ool0oooo0140oooo0P00000C003o04H0ool000X0okl00000002Lg`00oml004Q8003Og`00B00004RL
003oo`00okl01@0000000`1d_ol0oooo0?ooo`030?ooo`030?oo_`1d0000B9cO00L0oooo00<00000
09a8M02oool0903oool002D0oooo00D000000?ooo`3ooml0W4Qd0;ooo`0n0?ooo`060=nLB01d_ol0
oooo0?oog`2LB7@0_ooo0`3oool01P3o_g@0001d0;ooo`3oool0gia807Booc80oooo00H0oono07@0
0000000000000000M02oool40?ooo`030000003oool0oooo0100oooo00<00000003o0000o`004`00
o`160?oo00030=nL00000000_ol000<0ool000<0M00004RL003oo`000`3oo`000`000?l0oooo0?oo
o`050?ooo`040;md00000000001809cOo`L0oooo00<0000009a8M02oool0903oool002D0oooo00D0
000009bL_`3ooml0W4Qd0;ooo`0n0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3o
okl0M4Q804P00000000007Bo0380oooo00P0oono07@00000B9`0gooo0?oog`2LB000001d0;ooo`<0
oooo00<000000?ooo`3oool03P3oool2000001L00?l0A@3oo`000`3OW00000000;oo00030?oo0004
07@00018W000ool00?no00D0000000L0M;oo0?ooo`3oool0oono07@00000000007Bo00L0oooo00D0
oooO09bL_`000000W4Qd0;ooo`0T0?ooo`009@3oool01@000000okmd0000000007@0_ooo03h0oooo
00H0okmd0018W03Oool0okmd0018W03Oool30?ooo`030?oog`2LB4P0W=oo03@0oooo00<0okmd0000
B02Lgol00P3oool00`3ogi`0B00007Boo`030?ooo`030000003oool0oooo00`0oooo0P00000I003o
04D0ool000<0okl00000002Lg`000P3oo`000`3og`00B00007Bo00040?oo00030000o`3oool0oooo
00<0oooo00<0okmd0000B02Lgol02@3oool0103o_g@000000000M02ooolT0?ooo`009@3oool01@00
0000oooo0?oo_`1d07@0_ooo03l0oooo00@0_g@00000000004P0W=oo1@3oool01@2oM00000000000
000004P0W=oo0340oooo00<0gia80000M02oool00P3oool00`3ookl0M00004RLg`030?ooo`030000
003oool0oooo00X0oooo0P00000K003o04H0ool000L0M0000018003Oo`00ool00;md0000B000gol0
00@0ool000<0003o0?ooo`3oool00`3oool01P3o_g@0001809cOo`3OW4P0001809cOo`L0oooo00<0
000007@0M02oool0903oool002D0oooo00<000000?ooo`3oool0P03oool00`3OW4P0001d0;ooo`02
0?ooo`030?oo_`1d0000B9cO00<0oooo00<000000?ooo`3oool02@3oool00`0000000?l0003o000K
003o04L0ool000D0M00000000000000004P00=oo00050?oo00030000o`3oool0oooo00@0oooo00@0
_g@0000000000000B9cO203oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?oo
o`200?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol00`3oool00`000000oooo0?oo
o`070?ooo`8000007P00o`1A0?oo00030000o`3oool0oooo0100oooo00<000000?ooo`3oool0903o
ool002D0oooo00<000000?ooo`3oool0P03oool00`3ookl0M000001d_`020?ooo`030;md000007@0
_ooo00<0oooo00<000000?ooo`3oool01@3oool2000002400?l0D03oo`000`000?l0oooo0?ooo`0@
0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo0840oooo00H0oono07@0
0000000000000000M02oool40?ooo`030000003oool0oooo00@0oooo00<00000003o0000o`008@00
o`1@0?oo00030000o`3oool0oooo0100oooo00<000000?ooo`3oool0903oool002D0oooo00<00000
0?ooo`3oool0R`3oool00`000000oooo0?ooo`020?ooo`8000009000o`160?oo0080003o203oo`00
0`000?l0oooo0?ooo`0@0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo
08/0oooo00<000000?ooo`3oool00P00000V003o04H0ool01@000?l50?oo00030000o`3oool0oooo
0100oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0R`3oool3000002P0
0?l0A`3oo`080000o`030?oo00000?l0oooo0140oooo00<000000?ooo`3oool0903oool00;<00000
O0000?li00000000203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02`3oool3000001T0o`00EP3oo`080000o`030?oo00000?l0oooo00<0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool01`3oool002D0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo008000005`3o001E0?oo00H0003o103oo`000`000?l0oooo0?ooo`0@
0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?oo
o`3oool00P3oool2000001D0o`00E@3oo`020000o`P0ool000<0003o0?ooo`3oool0403oool00`00
0000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00@0
oooo00<000000?l0003o00004P3o001O0?oo00030000o`3oool0oooo0100oooo00<000000?ooo`3o
ool0903oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`050?ooo`800000
4P3o001O0?oo00030000o`3oool0oooo0100oooo00<000000?ooo`3oool0903oool002D0oooo00<0
00000?ooo`3oool0R`3oool00`000000oooo0?ooo`070?ooo`800000403o001O0?oo00030000o`3o
ool0oooo0100oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0R`3oool0
0`000000oooo0?ooo`090?ooo`030000003o0000o`0000d0o`00G`3oo`000`000?l0oooo0?ooo`0@
0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?oo
o`3oool02P3oool2000000d0o`00G`3oo`000`000?l0oooo0?ooo`0@0?ooo`030000003oool0oooo
02@0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0303oool2000000X0
o`00H03oo`000`000?l0oooo0?ooo`0@0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000
003oool0oooo08/0oooo00<000000?ooo`3oool03P3oool2000000P0o`00H03oo`000`000?l0oooo
0?ooo`0@0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo08/0oooo00<0
00000?ooo`3oool0403oool00`000000o`000?l000040?l00640ool000<0003o0?ooo`3oool0403o
ool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0
oooo0140oooo0P0000040?l00640ool000<0003o0?ooo`3oool0403oool00`000000oooo0?ooo`0T
0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo01<0oooo0P0000020?l0
0640ool000<0003o0?ooo`3oool0403oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000
oooo0?ooo`2;0?ooo`8000005P3oool200000640ool000<0003o0?ooo`3oool0403oool00`000000
oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo01L0oooo
00<000000?oo003oo`00GP3oo`000`000?l0oooo0?ooo`0@0?ooo`030000003oool0oooo02@0oooo
000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0603oool2000005h0ool000<0
003o0?ooo`3oool0403oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;
0?ooo`030000003oool0oooo01X0oooo0P00001L0?oo00030000o`3oool0oooo00l0oooo00<00000
0?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0L0?oo
o`800000FP3oo`000`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo02D0oooo000V0?ooo`03
0000003oool0oooo08X0oooo00<000000?ooo`3oool07P3oool00`000000ool00?oo001G0?oo0003
0000o`3oool0oooo00l0oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool0
RP3oool00`000000oooo0?ooo`0O0?ooo`800000E`3oo`000`000?l0oooo0?ooo`0?0?ooo`030000
003oool0oooo02D0oooo000V0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool08@3o
ool2000005D0ool000<0003o0?ooo`3oool03`3oool00`000000oooo0?ooo`0U0?ooo`009P3oool0
0`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02<0oooo00<000000?oo003oo`00DP3oo`00
0`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0oooo
08X0oooo00<000000?ooo`3oool0903oool200000580ool000<0003o0?ooo`3oool03`3oool00`00
0000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02H0
oooo0P00001@0?oo00030000o`3oool0oooo00h0oooo00<000000?ooo`3oool09P3oool002L0oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0X0?ooo`800000CP3oo`000`000?l0oooo
0?ooo`0>0?ooo`030000003oool0oooo02H0oooo000W0?ooo`030000003oool0oooo08T0oooo00<0
00000?ooo`3oool0:P3oool00`000000ool00?oo001;0?oo00030000o`3oool0oooo00h0oooo00<0
00000?ooo`3oool09P3oool002L0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0[
0?ooo`800000B`3oo`000`000?l0oooo0?ooo`0>0?ooo`030000003oool0oooo02H0oooo000W0?oo
o`030000003oool0oooo08T0oooo0P00000^0?ooo`800000B@3oo`000`000?l0oooo0?ooo`0>0?oo
o`030000003oool0oooo02H0oooo000W0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3o
ool0;`3oool2000004L0ool000<0003o0?ooo`3oool03@3oool00`000000oooo0?ooo`0W0?ooo`00
:03oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0340oooo00<000000?oo003oo`00
A03oo`000`000?l0oooo0?ooo`0=0?ooo`030000003oool0oooo02L0oooo000X0?ooo`030000003o
ool0oooo08P0oooo00<000000?ooo`3oool0<P3oool2000004@0ool000<0003o0?ooo`3oool03@3o
ool00`000000oooo0?ooo`0W0?ooo`00:03oool00`000000oooo0?ooo`280?ooo`030000003oool0
oooo03@0oooo0P0000120?oo00030000o`3oool0oooo00d0oooo00<000000?ooo`3oool09`3oool0
02T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0f0?ooo`800000@03oo`000`00
0?l0oooo0?ooo`0<0?ooo`030000003oool0oooo02P0oooo000Y0?ooo`030000003oool0oooo08L0
oooo00<000000?ooo`3oool0>03oool00`000000ool00?oo000m0?oo00030000o`3oool0oooo00`0
oooo00<000000?ooo`3oool0:03oool002T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo
0?ooo`0i0?ooo`800000?@3oo`000`000?l0oooo0?ooo`0<0?ooo`030000003oool0oooo02P0oooo
000Y0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0>`3oool2000003/0ool000<0
003o0?ooo`3oool0303oool00`000000oooo0?ooo`0X0?ooo`00:@3oool00`000000oooo0?ooo`27
0?ooo`030000003oool0oooo03d0oooo00<000000?oo003oo`00>03oo`000`000?l0oooo0?ooo`0<
0?ooo`030000003oool0oooo02P0oooo000Y0?ooo`030000003oool0oooo08L0oooo00<000000?oo
o`3oool0?P3oool2000003P0ool000<0003o0?ooo`3oool02`3oool00`000000oooo0?ooo`0Y0?oo
o`00:P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo0P00000f0?oo0003
0000o`3oool0oooo00/0oooo00<000000?ooo`3oool0:@3oool002X0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`120?ooo`800000=03oo`000`000?l0oooo0?ooo`0;0?ooo`030000
003oool0oooo02T0oooo000Z0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0A03o
ool00`000000ool00?oo000a0?oo00030000o`3oool0oooo00X0oooo00<000000?ooo`3oool0:P3o
ool002/0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`150?ooo`800000<@3oo`00
0`000?l0oooo0?ooo`0:0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo
08D0oooo0P0000180?ooo`800000;`3oo`000`000?l0oooo0?ooo`0:0?ooo`030000003oool0oooo
02X0oooo000[0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0B@3oool2000002d0
ool000<0003o0?ooo`3oool02P3oool00`000000oooo0?ooo`0Z0?ooo`00;03oool00`000000oooo
0?ooo`240?ooo`030000003oool0oooo04/0oooo00<000000?oo003oo`00:P3oo`000`000?l0oooo
0?ooo`090?ooo`030000003oool0oooo02/0oooo000/0?ooo`030000003oool0oooo08@0oooo00<0
00000?ooo`3oool0C03oool2000002X0ool000<0003o0?ooo`3oool0203oool00`000000oooo0?oo
o`0/0?ooo`00;@3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo04h0oooo0P00000X
0?oo00030000o`3oool0oooo00P0oooo00<000000?ooo`3oool0;03oool002d0oooo00<000000?oo
o`3oool0P`3oool00`000000oooo0?ooo`1@0?ooo`8000009P3oo`000`000?l0oooo0?ooo`080?oo
o`030000003oool0oooo02`0oooo000]0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3o
ool0DP3oool00`000000ool00?oo000S0?oo00030000o`3oool0oooo00P0oooo00<000000?ooo`3o
ool0;03oool002h0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`1C0?ooo`800000
8`3oo`000`000?l0oooo0?ooo`070?ooo`030000003oool0oooo02d0oooo000^0?ooo`030000003o
ool0oooo0880oooo00<000000?ooo`3oool0E@3oool200000240ool000<0003o0?ooo`3oool01`3o
ool00`000000oooo0?ooo`0]0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000003oool0
oooo05L0oooo00<000000?oo003oo`007P3oo`000`000?l0oooo0?ooo`070?ooo`030000003oool0
oooo02d0oooo000^0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0F03oool20000
01h0ool000<0003o0?ooo`3oool01P3oool00`000000oooo0?ooo`0^0?ooo`00;`3oool00`000000
oooo0?ooo`210?ooo`030000003oool0oooo05X0oooo0P00000L0?oo00030000o`3oool0oooo00H0
oooo00<000000?ooo`3oool0;P3oool00300oooo00<000000?ooo`3oool0P03oool00`000000oooo
0?ooo`1L0?ooo`8000006P3oo`000`000?l0oooo0?ooo`050?ooo`030000003oool0oooo02l0oooo
000`0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0GP3oool00`000000ool00?oo
000G0?oo00030000o`3oool0oooo00D0oooo00<000000?ooo`3oool0;`3oool00300oooo00<00000
0?ooo`3oool0P03oool200000600oooo0P00000G0?oo00030000o`3oool0oooo00D0oooo00<00000
0?ooo`3oool0;`3oool00300oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`1Q0?oo
o`8000005@3oo`000`000?l0oooo0?ooo`040?ooo`030000003oool0oooo0300oooo000a0?ooo`03
0000003oool0oooo07l0oooo00<000000?ooo`3oool0H`3oool2000001<0ool000<0003o0?ooo`3o
ool0103oool00`000000oooo0?ooo`0`0?ooo`00<P3oool00`000000oooo0?ooo`1n0?ooo`030000
003oool0oooo06D0oooo00<000000?oo003oo`003P3oo`000`000?l0ool00000o`020?ooo`040000
o`3oool0oooo000003<0oooo000b0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0
IP3oool2000000h0ool01P000?l00`3oool000000?ooo`0c0?ooo`00<`3oool00`000000oooo0?oo
o`1m0?ooo`030000003oool0oooo06P0oooo0P00000<0?oo00D0003o0P3oool00`000000oooo0?oo
o`0b0?ooo`00<`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo06X0oooo0P00000;
0?oo00@0003o0P3oool00`000000oooo0?ooo`0b0?ooo`00<`3oool00`000000oooo0?ooo`1m0?oo
o`030000003oool0oooo06`0oooo00<000000?oo003oo`00203oo`040000o`030?ooo`000000oooo
03@0oooo000d0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0K@3oool2000000P0
ool010000?l00`3oool000000?ooo`0d0?ooo`00=03oool00`000000oooo0?ooo`1l0?ooo`030000
003oool0oooo06l0oooo0P0000060?oo00<0003o00<0oooo0000003oool0=@3oool003D0oooo00<0
00000?ooo`3oool0N`3oool00`000000oooo0?ooo`1a0?ooo`030000003oo`00ool000<0ool00`00
0?l00`3oool000000?ooo`0e0?ooo`00=P3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0
oooo0780oooo0P0000030?oo00<0003o00<000000?ooo`3oool0=@3oool003H0oooo00<000000?oo
o`3oool0IP3oool02P2oM00000000000B02Lgol0oooo0?oo_`1dB9`0gooo0?ooo`2oM00200000003
04RLg`3oool0oooo00D0oooo00<000000?ooo`3oool0M03oool200000080ool00P000?lh0?ooo`00
=`3oool00`000000oooo0?ooo`1T0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool01P3o
_g@0B9cO0?ooo`3oool0gia807Boo`H0oooo00<000000?ooo`3oool0MP3oool2000000030000o`00
0000oooo03L0oooo000h0?ooo`030000003oool0oooo06<0oooo00H0gia804RLg`3oool0oono07@0
M02oool70?ooo`030?noM018W=l0oooo00D0oooo0`00001h0?ooo`030000o`3oool0oooo03L0oooo
000h0?ooo`030000003oool0oooo06<0oooo00H0gia807Boo`3oool0oooO09a8M02oool30?ooo`06
0?noM00007@0_ooo0?ooo`3OW4P0M;oo1P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0
oooo03P0oooo000i0?ooo`030000003oool0oooo0680oooo00H0gia804RLg`3oool0oono07@0M02o
ool30?ooo`050?oo_`1dB4P0B00000000000M;l01`3oool00`000000oooo0?ooo`1g0?ooo`030000
003oool0oooo03P0oooo000i0?ooo`030000003oool0oooo0680oooo00H0okmd0018W03Oool0okmd
0018W03Oool30?ooo`030?oog`2LB4P0W=oo00T0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`0h0?ooo`00>P3oool00`000000oooo0?ooo`1R0?ooo`040;md00000000001809cOo`D0
oooo00D0_g@0000000000000001809cOo`060?ooo`030000003oool0oooo07H0oooo00<000000?oo
o`3oool0>@3oool003X0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`1e0?ooo`03
0?oo_`000000B9cO03X0oooo000k0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0
M@3oool00`000000M00004RLg`0j0?ooo`00?03oool00`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo07@0oooo00@000000?oo_`1d0000B9cO>P3oool003`0oooo00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`1d0?ooo`030000003ookl0M00000<0000000<007Bo0?ooo`3oool0=@3o
ool003d0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1c0?ooo`090000003oool0
oono07@00018W=l0oooo0?oOW0180000B9cO03H0oooo000n0?ooo`030000003oool0oooo0780oooo
00<000000?ooo`3oool0LP3oool02P000000oooo0?ooo`3ookl0M00004RLg`3oool0oono07@00000
M;lf0?ooo`00?P3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0780oooo00X00000
0?ooo`3oool0oono07@00018W=l0oooo0?oOW0180000B9cO=P3oool003l0oooo00<000000?ooo`3o
ool0L@3oool00`000000oooo0?ooo`1a0?ooo`060000003oool0oooo0?ooo`3ookl0M0000`000000
0`00B9`0gooo0?ooo`0e0?ooo`00@03oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo
0700oooo00<000000?ooo`3oool0?`3oool00400oooo00<000000?ooo`3oool0L03oool200000740
oooo00<000000?ooo`3oool0?`3oool00440oooo00<000000?ooo`3oool0K`3oool00`000000oooo
0?ooo`1_0?ooo`030000003oool0oooo0400oooo00120?ooo`030000003oool0oooo06h0oooo00<0
00000?ooo`3oool0KP3oool00`000000oooo0?ooo`110?ooo`00@`3oool00`000000oooo0?ooo`1]
0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0@P3oool004@0oooo00<000000?oo
o`3oool0K03oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo04<0oooo00150?ooo`03
0000003oool0oooo06/0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`140?ooo`00
A@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0
A03oool004H0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1Z0?ooo`030000003o
ool0oooo04D0oooo00170?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0J@3oool0
0`000000oooo0?ooo`160?ooo`00B03oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo
06P0oooo00<000000?ooo`3oool0A`3oool004T0oooo00<000000?ooo`3oool0I`3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo04P0oooo001:0?ooo`030000003oool0oooo06H0oooo
00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`190?ooo`00B`3oool00`000000oooo0?oo
o`1U0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0BP3oool004`0oooo00<00000
0?ooo`3oool0I03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo04/0oooo001=0?oo
o`030000003oool0oooo06<0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`1<0?oo
o`00CP3oool00`000000oooo0?ooo`1R0?ooo`800000H`3oool00`000000oooo0?ooo`1=0?ooo`00
C`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0
CP3oool00500oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1P0?ooo`030000003o
ool0oooo04l0oooo001A0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0G`3oool0
0`000000oooo0?ooo`1@0?ooo`00DP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
05h0oooo00<000000?ooo`3oool0D@3oool005<0oooo00<000000?ooo`3oool0G@3oool00`000000
oooo0?ooo`1M0?ooo`030000003oool0oooo0580oooo001D0?ooo`030000003oool0oooo05`0oooo
00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`1C0?ooo`00E@3oool00`000000oooo0?oo
o`1K0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0E03oool005H0oooo00<00000
0?ooo`3oool0FP3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo05D0oooo001G0?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1F0?oo
o`00F03oool2000005T0oooo00<000000?ooo`3oool0E`3oool2000005T0oooo001J0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`1I0?ooo`00F`3o
ool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0FP3o
ool005`0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo05/0oooo001M0?ooo`030000003oool0oooo05<0oooo0P00001D0?ooo`030000003oool0oooo
05`0oooo001N0?ooo`800000D`3oool00`000000oooo0?ooo`1A0?ooo`800000G`3oool00600oooo
00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo05l0oooo
001Q0?ooo`800000D03oool00`000000oooo0?ooo`1>0?ooo`800000HP3oool006<0oooo00<00000
0?ooo`3oool0C@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0680oooo001T0?oo
o`800000C@3oool00`000000oooo0?ooo`1;0?ooo`800000I@3oool006H0oooo00<000000?ooo`3o
ool0BP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo06D0oooo001W0?ooo`800000
BP3oool00`000000oooo0?ooo`180?ooo`800000J03oool006T0oooo0P0000180?ooo`030000003o
ool0oooo04H0oooo0P00001Z0?ooo`00J`3oool2000004H0oooo00<000000?ooo`3oool0A03oool2
000006`0oooo001]0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0@`3oool00`00
0000oooo0?ooo`1/0?ooo`00KP3oool2000004<0oooo00<000000?ooo`3oool0@@3oool2000006l0
oooo001`0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`1_0?ooo`00L@3oool200000400oooo00<000000?ooo`3oool0?P3oool200000780oooo001c
0?ooo`<00000?@3oool2000003`0oooo0`00001d0?ooo`00MP3oool2000003/0oooo00<000000?oo
o`3oool0>@3oool2000007L0oooo001h0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`1g0?ooo`00N@3oool4000003H0oooo00<000000?ooo`3oool0
=03oool4000007X0oooo001m0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`1l0?ooo`00OP3oool400000340oooo00<000000?ooo`3oool0;`3oool4
000007l0oooo00220?ooo`<00000;P3oool00`000000oooo0?ooo`0/0?ooo`<00000P`3oool008D0
oooo0P00000/0?ooo`030000003oool0oooo02X0oooo0P0000260?ooo`00Q`3oool3000002T0oooo
00<000000?ooo`3oool09`3oool3000008P0oooo002:0?ooo`<000009P3oool00`000000oooo0?oo
o`0T0?ooo`<00000R`3oool008d0oooo1P00000P0?ooo`030000003oool0oooo01h0oooo1P00002>
0?ooo`00T`3oool3000001d0oooo00<000000?ooo`3oool06`3oool3000009@0oooo002F0?ooo`D0
00003@3oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo01H0oooo1@00002G0?ooo`00
V`3oool7000000H0oooo00<0oooO09a8M02oool0203oool00`000000oooo0?ooo`0?0?ooo`L00000
W03oool00:80oooo8`00002S0?ooo`00Z03oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0
oooo0;80oooo002V0?ooo`050?oog`2LW;l0oooO09a8M02oool0203oool00`000000oooo0?ooo`2b
0?ooo`00Y`3oool0103o_g@000000000M02oool80?ooo`030000003oool0oooo0;80oooo002X0?oo
o`030?oo_`1d07@0_ooo00P0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3o
ool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0
oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<0
00000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?oo
o`3oool0/P3oool00;<0oooo0P00002c0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3o
ool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`00
0000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo
0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b
0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00
/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool200000;<0oooo002c0?ooo`030000003oool0oooo0;80
oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c
0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`03
0000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003o
ool0oooo0;80oooo0000\
\>"],
  ImageRangeCache->{{{112.438, 370.625}, {660.813, 402.625}} -> {-2.35746, \
2.66979, 0.00878441, 0.00878441}},
  CellTags->"figura6"]
}, Closed]],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\({idFondamentale, senCompl, cosCompl, tanCompl, senDiffPi2, 
          cosDiffPi2, tanDiffPi2, senSuppl, cosSuppl, tanSuppl, senExpl, 
          cosExpl, 
          tanExpl} = {cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 1, 
          sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          tan[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cot[\[Alpha]], 
          sen[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          tan[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-\(cos[\[Alpha]]\/sen[\
\[Alpha]]\)\), sen[\[Pi] - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          cos[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          sen[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] + \[Alpha]_] \[RuleDelayed] tan[\[Alpha]]};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Seno di un angolo opposto", "Subsubsection"],

Cell[TextData[{
  "Dalla congruenza pi\[UGrave] volte notata ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[EmptyUpTriangle]", 
              StyleBox["OSR",
                FontSlant->"Italic"]}]], "\[TildeFullEqual]", 
          StyleBox[
            RowBox[{"\[EmptyUpTriangle]", 
              StyleBox["OQP",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  " discende ora ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["SR",
            FontSlant->"Italic"], 
          StyleBox["=",
            FontSlant->"Plain"], 
          RowBox[{
            StyleBox["-",
              FontSlant->"Plain"], 
            StyleBox["QP",
              FontSlant->"Italic"]}]}], TraditionalForm]]],
  " e ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["OS",
            FontSlant->"Italic"], 
          StyleBox["=",
            FontSlant->"Plain"], 
          StyleBox["OQ",
            FontSlant->"Italic"]}], TraditionalForm]]],
  " (",
  ButtonBox["fig. 6",
    ButtonData:>"figura6",
    ButtonStyle->"Hyperlink"],
  "). Ne deriva che"
}], "Text",
  CellTags->"osservazione4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sen[\(-\[Alpha]\)] \[Equal] SR/OR\)], "Input"],

Cell[BoxData[
    \(sen[\(-\[Alpha]\)] \[Equal] SR\/OR\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {SR \[Rule] \(-QP\), OR \[Rule] OP}\)], "Input"],

Cell[BoxData[
    \(sen[\(-\[Alpha]\)] \[Equal] \(-\(QP\/OP\)\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. defs\)], "Input",
  CellTags->"senodispari"],

Cell[BoxData[
    \(sen[\(-\[Alpha]\)] \[Equal] \(-sen[\[Alpha]]\)\)], "Output",
  CellTags->"senodispari"]
}, Closed]],

Cell[TextData[{
  "Questo risultato, valido per ",
  Cell[BoxData[
      \(TraditionalForm\`\[ForAll] \ \[Alpha] \[Element] \ \
\[DoubleStruckCapitalR]\)]],
  " stabilisce che la funzione seno \[EGrave] una ",
  StyleBox["funzione dispari:",
    FontSlant->"Italic"],
  " il suo grafico risulta pertanto simmetrico rispetto all'origine di un \
sistema cartesiano che abbia in ascissa la variabile angolare ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " e in ordinata il valore ",
  Cell[BoxData[
      \(TraditionalForm\`sen[\[Alpha]]\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(senOpp = toRule[%]\)], "Input"],

Cell[BoxData[
    \(sen[\(-\[Alpha]\)] \[RuleDelayed] \(-sen[\[Alpha]]\)\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\({idFondamentale, senCompl, cosCompl, tanCompl, senDiffPi2, 
          cosDiffPi2, tanDiffPi2, senSuppl, cosSuppl, tanSuppl, senExpl, 
          cosExpl, tanExpl, 
          senOpp} = {cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 1, 
          sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          tan[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cot[\[Alpha]], 
          sen[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          tan[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-\(cos[\[Alpha]]\/sen[\
\[Alpha]]\)\), sen[\[Pi] - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          cos[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          sen[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] + \[Alpha]_] \[RuleDelayed] tan[\[Alpha]], 
          sen[\(-\[Alpha]_\)] \[RuleDelayed] \(-sen[\[Alpha]]\)};\)\)], \
"Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Coseno di un angolo opposto", "Subsubsection"],

Cell[TextData[{
  "Analogamente a quanto finora visto e in base alla configurazione di ",
  ButtonBox["fig. 6",
    ButtonData:>"figura6",
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cos[\(-\[Alpha]\)] \[Equal] OS/OR\)], "Input"],

Cell[BoxData[
    \(cos[\(-\[Alpha]\)] \[Equal] OS\/OR\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {OS \[Rule] OQ, OR \[Rule] OP}\)], "Input"],

Cell[BoxData[
    \(cos[\(-\[Alpha]\)] \[Equal] OQ\/OP\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. defs\)], "Input",
  CellTags->"cosenopari"],

Cell[BoxData[
    \(cos[\(-\[Alpha]\)] \[Equal] cos[\[Alpha]]\)], "Output",
  CellTags->"cosenopari"]
}, Closed]],

Cell[TextData[{
  "Anche questa identit\[AGrave], valida per ",
  Cell[BoxData[
      \(TraditionalForm\`\[ForAll] \ \[Alpha] \[Element] \ \
\[DoubleStruckCapitalR]\)]],
  " codifica una propriet\[AGrave] importante della funzione coseno: questa \
\[EGrave] una ",
  StyleBox["funzione pari",
    FontSlant->"Italic"],
  " con grafico simmetrico rispetto all'asse delle ordinate del sistema \
cartesiano associato all'equazione ",
  Cell[BoxData[
      \(TraditionalForm\`y = cos[\[Alpha]]\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cosOpp = toRule[%]\)], "Input"],

Cell[BoxData[
    \(cos[\(-\[Alpha]\)] \[RuleDelayed] cos[\[Alpha]]\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\({idFondamentale, senCompl, cosCompl, tanCompl, senDiffPi2, 
          cosDiffPi2, tanDiffPi2, senSuppl, cosSuppl, tanSuppl, senExpl, 
          cosExpl, tanExpl, senOpp, 
          cosOpp} = {cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 1, 
          sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          tan[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cot[\[Alpha]], 
          sen[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          tan[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-\(cos[\[Alpha]]\/sen[\
\[Alpha]]\)\), sen[\[Pi] - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          cos[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          sen[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] + \[Alpha]_] \[RuleDelayed] tan[\[Alpha]], 
          sen[\(-\[Alpha]_\)] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\(-\[Alpha]_\)] \[RuleDelayed] cos[\[Alpha]]};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Tangente di un angolo opposto", "Subsubsection"],

Cell[TextData[{
  "Per la definizione di tangente e in base a quanto osservato ",
  ButtonBox["precedentemente",
    ButtonData:>"osservazione4",
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tan[\(-\[Alpha]\)] \[Equal] SR/OS\)], "Input"],

Cell[BoxData[
    \(tan[\(-\[Alpha]\)] \[Equal] SR\/OS\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {SR \[Rule] \(-QP\), OS \[Rule] OQ}\)], "Input"],

Cell[BoxData[
    \(tan[\(-\[Alpha]\)] \[Equal] \(-\(QP\/OQ\)\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. defs\)], "Input",
  CellTags->"tandispari"],

Cell[BoxData[
    \(tan[\(-\[Alpha]\)] \[Equal] \(-tan[\[Alpha]]\)\)], "Output",
  CellTags->"tandispari"]
}, Closed]],

Cell[TextData[{
  "Come gi\[AGrave] visto per la funzione seno, poich\[EAcute] l'identit\
\[AGrave] precedente vale per ",
  Cell[BoxData[
      \(TraditionalForm\`\[ForAll] \ \[Alpha] \[Element] \ 
            Dom(tan) = \ \[DoubleStruckCapitalR] - {\[Pi]\/2 + k\ \[Pi]}\)]],
  " stabilisce che pure la funzione tangente \[EGrave] una ",
  StyleBox["funzione dispari",
    FontSlant->"Italic"],
  " con grafico quindi simmetrico rispetto all'origine di un sistema \
cartesiano con in ascissa la variabile angolare e in ordinata il valore di ",
  Cell[BoxData[
      \(TraditionalForm\`tan[\[Alpha]]\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tanOpp = toRule[%]\)], "Input"],

Cell[BoxData[
    \(tan[\(-\[Alpha]\)] \[RuleDelayed] \(-tan[\[Alpha]]\)\)], "Output"]
}, Closed]],

Cell["Abbiamo ottenuto quindi", "Text"],

Cell[BoxData[{
    \(TraditionalForm\`Angoli\ opposti\), "\[IndentingNewLine]", 
    \(TraditionalForm\`sen(\(-\[Alpha]\)) = \(-\(sen(\[Alpha])\)\)\), "\
\[IndentingNewLine]", 
    \(TraditionalForm\`cos(\(-\[Alpha]\)) = 
      cos(\[Alpha])\), "\[IndentingNewLine]", 
    \(TraditionalForm\`tan(\(-\[Alpha]\)) = \(-\(tan(\[Alpha])\)\)\)}], \
"Definition",
  FontFamily->"Courier"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Introduzione grafica e prima identit\[AGrave]", "Section"],

Cell[CellGroupData[{

Cell["Analisi grafica", "Subsubsection"],

Cell[TextData[{
  "Affrontiamo in questa sezione la dimostrazione dell'identit\[AGrave] che \
lega il coseno di una differenza di angoli alle funzioni goniometriche degli \
angoli stessi. In base a questa relazione sar\[AGrave] possibile dedurre una \
(lunga) serie di identit\[AGrave] che specificano di volta in volta nuove \
propriet\[AGrave] delle funzioni goniometriche.\nDefiniamo nella \
circonferenza goniometrica ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " i due angoli ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 170\ \[Degree]\)]],
  "e ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] = 115\ \[Degree]\)]],
  ", il primo indicato in giallo nella ",
  ButtonBox["figura sottostante",
    ButtonData:>"figura7",
    ButtonStyle->"Hyperlink"],
  " e tale da ricoprire un intero settore circolare di ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " e il secondo in verde."
}], "Text"],

Cell[BoxData[{
    \(\(\[Alpha] = 170  Degree;\)\), "\[IndentingNewLine]", 
    \(\(\[Beta] = 115  Degree;\)\)}], "Input"],

Cell[TextData[{
  "I lati non coincidenti con il semiasse positivo delle ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " di questi angoli intersecano la circonferenza nei due punti, ",
  Cell[BoxData[
      \(TraditionalForm\`P(cos(\[Alpha]), sen(\[Alpha]))\)]],
  " e ",
  Cell[BoxData[
      \(TraditionalForm\`Q(cos(\[Beta]), sen(\[Beta]))\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(pP = {Cos[\[Alpha]], Sin[\[Alpha]]};\)\), "\[IndentingNewLine]", 
    \(\(pQ = {Cos[\[Beta]], Sin[\[Beta]]};\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[
    \(\(Show[
        Graphics[{{colGiallo, Disk[{0, 0}, 1, {0, \[Alpha]}]}, {colVerde, 
              Disk[{0, 0},  .2, {0, \[Beta]}]}, {colRosso, 
              Disk[{0, 0},  .4, {\[Beta], \[Alpha]}]}, Line[{pQ, {0, 0}}]}], 
        Graphics[{Circle[{0, 0}, 1], Line[{{\(-1.5\), 0}, {1.2, 0}}], 
            Line[{{0, \(-1.2\)}, {0, 1.2}}], Line[{pP, {0, 0}}], 
            Line[{{0, \(-1.2\)}, {0, 1.2}}]}], 
        Graphics[{colRosso, AbsolutePointSize[4], Point[pP], 
            Point[pQ]}], \
\[IndentingNewLine]Graphics[{Text["\<P(cos(\[Alpha]),sen(\[Alpha]))\>", 
              pP + {0, 0.04}, {0, \(-1\)}, TextStyle \[Rule] stileTesto], 
            Text["\<Q(cos(\[Beta]),sen(\[Beta]))\>", pQ, {1, \(-1\)}, 
              TextStyle \[Rule] stileTesto]}], AspectRatio \[Rule] Automatic, 
        Axes \[Rule] True];\)\)], "Input",
  CellTags->"figura1"]
}, Closed]],

Cell[CellGroupData[{

Cell["Grafico", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .88889 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.352734 0.444444 0.352734 [
[.02381 .43194 -10.3125 -10.9375 ]
[.02381 .43194 10.3125 0 ]
[.20018 .43194 -6.96875 -10.9375 ]
[.20018 .43194 6.96875 0 ]
[.37654 .43194 -10.3125 -10.9375 ]
[.37654 .43194 10.3125 0 ]
[.72928 .43194 -7.5625 -10.9375 ]
[.72928 .43194 7.5625 0 ]
[.90564 .43194 -4.21875 -10.9375 ]
[.90564 .43194 4.21875 0 ]
[.54041 .09171 -13.9375 -5.46875 ]
[.54041 .09171 0 5.46875 ]
[.54041 .26808 -20.625 -5.46875 ]
[.54041 .26808 0 5.46875 ]
[.54041 .62081 -15.125 -5.46875 ]
[.54041 .62081 0 5.46875 ]
[.54041 .79718 -8.4375 -5.46875 ]
[.54041 .79718 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 .88889 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .44444 m
.02381 .45069 L
s
gsave
.02381 .43194 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.20018 .44444 m
.20018 .45069 L
s
gsave
.20018 .43194 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.37654 .44444 m
.37654 .45069 L
s
gsave
.37654 .43194 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.72928 .44444 m
.72928 .45069 L
s
gsave
.72928 .43194 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.90564 .44444 m
.90564 .45069 L
s
gsave
.90564 .43194 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.05908 .44444 m
.05908 .44819 L
s
.09436 .44444 m
.09436 .44819 L
s
.12963 .44444 m
.12963 .44819 L
s
.1649 .44444 m
.1649 .44819 L
s
.23545 .44444 m
.23545 .44819 L
s
.27072 .44444 m
.27072 .44819 L
s
.306 .44444 m
.306 .44819 L
s
.34127 .44444 m
.34127 .44819 L
s
.41182 .44444 m
.41182 .44819 L
s
.44709 .44444 m
.44709 .44819 L
s
.48236 .44444 m
.48236 .44819 L
s
.51764 .44444 m
.51764 .44819 L
s
.58818 .44444 m
.58818 .44819 L
s
.62346 .44444 m
.62346 .44819 L
s
.65873 .44444 m
.65873 .44819 L
s
.694 .44444 m
.694 .44819 L
s
.76455 .44444 m
.76455 .44819 L
s
.79982 .44444 m
.79982 .44819 L
s
.8351 .44444 m
.8351 .44819 L
s
.87037 .44444 m
.87037 .44819 L
s
.94092 .44444 m
.94092 .44819 L
s
.97619 .44444 m
.97619 .44819 L
s
.25 Mabswid
0 .44444 m
1 .44444 L
s
.55291 .09171 m
.55916 .09171 L
s
gsave
.54041 .09171 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.55291 .26808 m
.55916 .26808 L
s
gsave
.54041 .26808 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.55291 .62081 m
.55916 .62081 L
s
gsave
.54041 .62081 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.55291 .79718 m
.55916 .79718 L
s
gsave
.54041 .79718 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.55291 .12698 m
.55666 .12698 L
s
.55291 .16226 m
.55666 .16226 L
s
.55291 .19753 m
.55666 .19753 L
s
.55291 .2328 m
.55666 .2328 L
s
.55291 .30335 m
.55666 .30335 L
s
.55291 .33862 m
.55666 .33862 L
s
.55291 .3739 m
.55666 .3739 L
s
.55291 .40917 m
.55666 .40917 L
s
.55291 .47972 m
.55666 .47972 L
s
.55291 .51499 m
.55666 .51499 L
s
.55291 .55026 m
.55666 .55026 L
s
.55291 .58554 m
.55666 .58554 L
s
.55291 .65608 m
.55666 .65608 L
s
.55291 .69136 m
.55666 .69136 L
s
.55291 .72663 m
.55666 .72663 L
s
.55291 .7619 m
.55666 .7619 L
s
.55291 .05644 m
.55666 .05644 L
s
.55291 .02116 m
.55666 .02116 L
s
.55291 .83245 m
.55666 .83245 L
s
.55291 .86772 m
.55666 .86772 L
s
.25 Mabswid
.55291 0 m
.55291 .88889 L
s
0 0 m
1 0 L
1 .88889 L
0 .88889 L
closepath
clip
newpath
1 1 0 r
.55291 .44444 m
.55291 .44444 .35273 0 170 arc
F
0 1 0 r
.55291 .44444 m
.55291 .44444 .07055 0 115 arc
F
1 0 0 r
.55291 .44444 m
.55291 .44444 .14109 115 170 arc
F
0 g
.5 Mabswid
.40384 .76413 m
.55291 .44444 L
s
newpath
.55291 .44444 .35273 0 365.73 arc
s
.02381 .44444 m
.97619 .44444 L
s
.55291 .02116 m
.55291 .86772 L
s
.20554 .5057 m
.55291 .44444 L
s
.55291 .02116 m
.55291 .86772 L
s
1 0 0 r
4 Mabswid
.20554 .5057 Mdot
.40384 .76413 Mdot
0 g
gsave
.20554 .51981 -97.75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.375 moveto
(H) show
72.125 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(cos) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.625 13.375 moveto
(H) show
90.750 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.375 13.375 moveto
(L) show
99.500 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
102.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sen) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.500 13.375 moveto
(H) show
120.625 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
126.250 13.375 moveto
(L) show
129.375 13.375 moveto
(L) show
132.500 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.40384 .76413 -136.063 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Q) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.938 13.375 moveto
(H) show
73.063 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(cos) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
88.563 13.375 moveto
(H) show
92.500 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
97.625 13.375 moveto
(L) show
100.750 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
103.250 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sen) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
118.750 13.375 moveto
(H) show
122.688 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
127.813 13.375 moveto
(L) show
130.938 13.375 moveto
(L) show
134.063 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{288, 256},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  Magnification->0.9,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001@2000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00b03oool00`000000oooo0?ooo`2M0?ooo`00b03oool00`000000oooo
0?ooo`2M0?ooo`00b03oool00`000000oooo0?ooo`2M0?ooo`00b03oool00`000000oooo0?ooo`2M
0?ooo`00b03oool00`000000oooo0?ooo`2M0?ooo`00b03oool00`000000oooo0?ooo`2M0?ooo`00
b03oool00`000000oooo0?ooo`2M0?ooo`00b03oool00`000000oooo0?ooo`2M0?ooo`00b03oool2
000009h0oooo00380?ooo`030000003oool0oooo09d0oooo00380?ooo`030000003oool0oooo09d0
oooo00380?ooo`030000003oool0oooo09d0oooo00380?ooo`030000003oool0oooo09d0oooo0038
0?ooo`030000003oool0oooo09d0oooo00380?ooo`030000003oool0oooo09d0oooo00380?ooo`03
0000003oool0oooo09d0oooo00380?ooo`030000003oool0oooo09d0oooo00380?ooo`030000003o
ool0oooo09d0oooo00380?ooo`030000003oool0oooo09d0oooo00380?ooo`030000003oool0oooo
09d0oooo00380?ooo`800000WP3oool00<P0oooo00<000000?ooo`3oool0W@3oool00<P0oooo00<0
00000?ooo`3oool0W@3oool00<P0oooo00<000000?ooo`3oool0W@3oool00<P0oooo00<000000?oo
o`3oool0W@3oool00<P0oooo00<000000?ooo`3oool0W@3oool00<P0oooo00<000000?ooo`3oool0
W@3oool00<P0oooo00<000000?ooo`3oool0W@3oool00<P0oooo00<000000?ooo`3oool0W@3oool0
0<P0oooo00<000000?ooo`3oool0W@3oool00<P0oooo00<000000?ooo`3oool0W@3oool00;h0oooo
00<0oooO09a8M02oool01`3oool00`000000oooo0?ooo`2M0?ooo`00_P3oool00`3ooml0W4Qd0;oo
o`070?ooo`030000003oool0oooo09d0oooo002e0?ooo`030?noM000000000000080000000<004RL
0=ooo`3oool05`00002D0?ooo`00]@3oool8000000040?ooo`3ooml0W4Qd0;ooo`L0oooo00<00000
0?ooo`3oool02@3oool8000008`0oooo002_0?ooo`H000001`3oool01@3ooml0W9bo0?oog`2LB7@0
_ooo00L0oooo00<000000?ooo`3oool04@3oool7000008D0oooo002[0?ooo`@000003P3oool0103o
_g@000000000M02oool70?ooo`030000003oool0oooo01P0oooo0`0000220?ooo`00Z03oool30000
01<0oooo00<0oono07@0M02oool01`3oool00`000000oooo0?ooo`0K0?ooo`<00000O`3oool00:80
oooo1P00000P0?ooo`030000003oool0oooo01h0oooo0`00001l0?ooo`00W`3oool3000002H0oooo
00<000000?ooo`3oool08@3oool6000007H0oooo002M0?ooo`800000:@3oool00`000000oooo0?oo
o`0W0?ooo`800000M03oool009/0oooo0P00000[0?ooo`030000003oool0oooo02T0oooo0P00001b
0?ooo`00V@3oool2000002d0oooo00<000000?ooo`3oool0:`3oool200000700oooo002G0?ooo`80
0000;`3oool00`000000oooo0?ooo`0]0?ooo`800000KP3oool009@0oooo0`00000a0?ooo`030000
003oool0oooo02l0oooo0`00001[0?ooo`00TP3oool2000003@0oooo0P00000c0?ooo`800000J@3o
ool00900oooo0P00000f0?ooo`030000003oool0oooo03@0oooo0P00001W0?ooo`00SP3oool20000
03P0oooo00<000000?ooo`3oool0=P3oool2000006D0oooo002<0?ooo`800000>P3oool00`000000
oooo0?ooo`0h0?ooo`800000H`3oool008X0oooo0P00000l0?ooo`030000003oool0oooo03X0oooo
0P00001Q0?ooo`00R@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool0GP3oool008L0oooo0P00000o0?ooo`030000003oool0oooo03d0oooo0P00001N
0?ooo`00Q@3oool200000440oooo00<000000?ooo`3oool0?`3oool2000005`0oooo00240?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1I0?ooo`00
P`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
F03oool00840oooo0P0000150?ooo`030000003oool0oooo04<0oooo0P00001H0?ooo`00O`3oool2
000004L0oooo00<000000?ooo`3oool0A@3oool2000005H0oooo001m0?ooo`800000B@3oool00`00
0000oooo0?ooo`170?ooo`800000E03oool007`0oooo00<000000?ooo`3oool0B@3oool2000004X0
oooo00<000000?ooo`3oool0D@3oool007/0oooo00<000000?ooo`3oool0BP3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo0500oooo001j0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`1?0?ooo`00N@3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0CP3oool007P0oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo04d0oooo001f0?ooo`80
0000D03oool00`000000oooo0?ooo`1>0?ooo`800000C@3oool007D0oooo00<000000?ooo`3oool0
D03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo04X0oooo001d0?ooo`030000003o
ool0oooo0540oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`190?ooo`00L`3oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0B03oool0
0780oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
04L0oooo001a0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`160?ooo`00L03oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0A@3oool006l0oooo00<000000?ooo`3oool0EP3oool2000005L0oooo00<0
00000?ooo`3oool0A03oool006h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo04<0oooo001]0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`120?ooo`00K03oool00`000000oooo0?ooo`1I0?ooo`03
0000003oool0oooo05T0oooo00<000000?ooo`3oool0@@3oool006/0oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0400oooo001Z0?ooo`030000003o
ool0oooo05/0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0o0?ooo`00J@3oool0
0`000000oooo0?ooo`1L0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0?P3oool0
06T0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo
03h0oooo001X0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0G@3oool00`000000
oooo0?ooo`0m0?ooo`00I`3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo05h0oooo
00<000000?ooo`3oool0?03oool006H0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?oo
o`1O0?ooo`030000003oool0oooo03/0oooo001U0?ooo`030000003oool0oooo0600oooo00<00000
0?ooo`3oool0H03oool00`000000oooo0?ooo`0j0?ooo`00I03oool00`000000oooo0?ooo`1Q0?oo
o`030000003oool0oooo0600oooo00<000000?ooo`3oool0>P3oool006<0oooo00<000000?ooo`3o
ool0HP3oool200000680oooo00<000000?ooo`3oool0>@3oool006<0oooo00<000000?ooo`3oool0
HP3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo03P0oooo001R0?ooo`030000003o
ool0oooo06<0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0g0?ooo`00HP3oool0
0`000000oooo0?ooo`1S0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0=`3oool0
0640oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo
03H0oooo001Q0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0I03oool00`000000
oooo0?ooo`0f0?ooo`00H03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo06D0oooo
00<000000?ooo`3oool0=@3oool005l0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`1V0?ooo`030000003oool0oooo03@0oooo001N0?ooo`030000003oool0oooo06L0oooo00<00000
0?ooo`3oool0I`3oool00`000000oooo0?ooo`0c0?ooo`00GP3oool00`000000oooo0?ooo`1W0?oo
o`030000003oool0oooo06L0oooo00<000000?ooo`3oool0<`3oool005d0oooo00<000000?ooo`3o
ool0E03oool02P2oM00000000000B02Lgol0oooo0?oo_`1dB9`0gooo0?ooo`2oM0020000000304RL
g`3oool0oooo00D0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0b0?ooo`00G03o
ool00`000000oooo0?ooo`1D0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool01P3o_g@0
B9cO0?ooo`3oool0gia807Boo`H0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0b
0?ooo`00G03oool00`000000oooo0?ooo`1=0?ooo`030?noM000000000000080000000P004RL0=oo
o`3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`L0oooo00<0okmd04RLg`3oool01@3oool3000006T0oooo
00<000000?ooo`3oool0<@3oool005/0oooo00<000000?ooo`3oool0E@3oool01P3OW4P0M;oo0?oo
o`3ooml0W4Qd0;ooo`<0oooo00H0okmd0000M02oool0oooo0=nLB01d_ol60?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool0<03oool005/0oooo00<000000?ooo`3oool0E@3oool01P3O
W4P0B9cO0?ooo`3ookl0M01d0;ooo`<0oooo00D0oono07A8B01800000000001d_`070?ooo`030000
003oool0oooo06X0oooo00<000000?ooo`3oool0<03oool005X0oooo00<000000?ooo`3oool0EP3o
ool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00<0oooO09a8B02Lgol02@3oool00`000000
oooo0?ooo`1[0?ooo`030000003oool0oooo02l0oooo001J0?ooo`030000003oool0oooo05L0oooo
00@0_g@00000000004P0W=oo1@3oool01@2oM00000000000000004P0W=oo00H0oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`0_0?ooo`00F@3oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo06`0oooo00<000000?ooo`3oool0;P3oool005T0oooo00<000000?ooo`3oool0
K03oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo02h0oooo001H0?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0]0?ooo`00F03oool0
0`000000oooo0?ooo`1]0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0;@3oool0
05L0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo
02`0oooo001G0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0KP3oool00`000000
oooo0?ooo`0/0?ooo`00EP3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo06l0oooo
00<000000?ooo`3oool0:`3oool005H0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?oo
o`1_0?ooo`030000003oool0oooo02/0oooo001E0?ooo`030000003oool0oooo0700oooo0P00001`
0?ooo`030000003oool0oooo02/0oooo001E0?ooo`030000003oool0oooo0700oooo00<000000?oo
o`3oool0L03oool00`000000oooo0?ooo`0Z0?ooo`00E@3oool00`000000oooo0?ooo`1`0?ooo`03
0000003oool0oooo0700oooo00<000000?ooo`3oool0:P3oool005@0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo02T0oooo001D0?ooo`030000003o
ool0oooo0740oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0Y0?ooo`00D`3oool0
0`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0:03oool0
05<0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo
02P0oooo001B0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0L`3oool00`000000
oooo0?ooo`0W0?ooo`00DP3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo07<0oooo
00<000000?ooo`3oool09`3oool00540oooo00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo02H0oooo001A0?ooo`030000003oool0oooo07@0oooo00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`0V0?ooo`00D@3oool00`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo07@0oooo00<000000?ooo`3oool09P3oool00500oooo00<000000?ooo`3o
ool0M@3oool2000007D0oooo00<000000?ooo`3oool09P3oool00500oooo00<000000?ooo`3oool0
M@3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo02H0oooo001@0?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0V0?ooo`00D03oool0
0`000000oooo0?ooo`1e0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool09@3oool0
0500oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo
02D0oooo001@0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0M@3oool00`000000
oooo0?ooo`0U0?ooo`00C`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo07H0oooo
00<000000?ooo`3oool0903oool004l0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo02@0oooo001>0?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool0MP3oool00`000000oooo0?ooo`0T0?ooo`00CP3oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo07L0oooo00<000000?ooo`3oool08`3oool004h0oooo00<000000?ooo`3o
ool0M`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo02<0oooo001>0?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0S0?ooo`00C@3o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool08`3o
ool004d0oooo00<000000?ooo`3oool0N03oool2000007T0oooo00<000000?ooo`3oool08P3oool0
04d0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo
0280oooo001=0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0N03oool00`000000
oooo0?ooo`0R0?ooo`00C@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo07P0oooo
00<000000?ooo`3oool08P3oool004d0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo0280oooo001=0?ooo`030000003oool0oooo07P0oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`0R0?ooo`00C03oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool08@3oool004`0oooo00<000000?ooo`3o
ool0N@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0240oooo001<0?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0Q0?ooo`00C03o
ool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool08@3o
ool004`0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0
oooo0240oooo000;0?ooo`090?oog`2LB7@0_ooo0?ooo`3ookl0M4RL0=ooo`3oool0_g@000800000
00<0B9cO0?ooo`3oool0<`3oool01@000000oooo0?oog`2LB7@0_ooo03H0oooo00X0_g@000000000
04P0W=oo0?ooo`3ookl0M4RL0=ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`0b0?ooo`030000
003oool0oooo03H0oooo00X0_g@00000000004P0W=oo0?ooo`3ookl0M4RL0=ooo`3oool0_g@00P00
00000`18W=l0oooo0?ooo`0d0?ooo`030000002LB7@0_ooo0240oooo000;0?ooo`030?oog`2LB7@0
_ooo00@0oooo00H0okmd04RLg`3oool0oooo0=nLB01d_old0?ooo`050000003oool0oooO09a8M02o
ool0=@3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00H0okmd04RLg`3oool0oooo0=nL
B01d_olc0?ooo`800000=P3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00H0okmd04RL
g`3oool0oooo0=nLB01d_ole0?ooo`030000002LB7@0_ooo0240oooo00020?ooo`030?noM0000000
00000080000000L004RL0=ooo`3oool0oooo0?oog`2LB7@0_ooo00P0oooo00<0okmd04RLg`3oool0
;03oool00`3o_g@0000000000002000000070018W03Oool000000?ooo`3ooml0W4Qd0;ooo`0^0?oo
o`030?noM000000000000080000000P004RL0=ooo`3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`L0oooo
00<0okmd04RLg`3oool0<P3oool00`000000oooo0?ooo`0e0?ooo`060=nLB018W=l0oooo0?oo_`1d
07@0_ooo1`3oool00`3o_g@0B9cO0?ooo`0d0?ooo`030000002LB7@0_ooo0240oooo000;0?ooo`03
0?oog`2LB7@0_ooo00@0oooo00H0okmd0000M02oool0oooo0=nLB01d_olc0?ooo`060000003oool0
oooo0?oog`2LB7@0_ooo=@3oool01P3OW4P0M;oo0?ooo`3ooml0W4Qd0;ooo`<0oooo00H0okmd0000
M02oool0oooo0=nLB01d_olc0?ooo`030000003oool0oooo03D0oooo00H0gia807Boo`3oool0oooO
09a8M02oool30?ooo`060?noM00007@0_ooo0?ooo`3OW4P0M;oo=@3oool00`3ooml000000;ooo`0Q
0?ooo`002@3oool01@3ooml0W9bo0?oog`2LB7@0_ooo00@0oooo00D0oono07A8B01800000000001d
_`0d0?ooo`060000003ooml0W9bo0?oog`2LB7@0_ooo=@3oool01P3OW4P0B9cO0?ooo`3ookl0M01d
0;ooo`<0oooo00D0oono07A8B01800000000001d_`0d0?ooo`030000003oool0oooo03D0oooo00H0
gia804RLg`3oool0oono07@0M02oool30?ooo`050?oo_`1dB4P0B00000000000M;l0=03oool01@3o
oml0W9bo0?oog`000000_ooo0240oooo000:0?ooo`040?noM0000000001d0;ooo`@0oooo00<0oooO
09a8B02Lgol0=P3oool01P000000oooo0?noM0000000001d0;ooocD0oooo00H0okmd0018W03Oool0
okmd0018W03Oool30?ooo`030?oog`2LB4P0W=oo03H0oooo00<000000?ooo`3oool0=@3oool01P3o
_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00<0oooO09a8B02Lgol0=`3oool0103o_g@000000000
002ooolQ0?ooo`002`3oool00`3ookl0M01d0;ooo`050?ooo`050;md0000000000000000B02Lgol0
<`3oool01P000000oooo0?ooo`3ookl0M01d0;ooocH0oooo00@0_g@00000000004P0W=oo1@3oool0
1@2oM00000000000000004P0W=oo03<0oooo00<000000?ooo`3oool0=P3oool0102oM00000000000
B02Lgol50?ooo`050;md0000000000000000B02Lgol0=@3oool00`3ookl000000;ooo`0Q0?ooo`00
B`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
803oool004/0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo0200oooo001;0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0NP3oool0
0`000000oooo0?ooo`0P0?ooo`00B`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo
07X0oooo00<000000?ooo`3oool0803oool004/0oooo00<000000?ooo`3oool0NP3oool00`000000
oooo0?ooo`1j0?ooo`030000003oool0oooo0200oooo001;0?ooo`030000003oool0oooo07X0oooo
00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0P0?ooo`00B`3oool00`000000oooo0?oo
o`1j0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0803oool000@0ooooo`00001U
00000000303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool00P3oool600000080o`0000<00000003o0000o`005P00o`1T0?oo00030000003oool0oooo
00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`00303oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0;`3oool5000000L0
o`000P00000H003o06@0ool000<000000?ooo`3oool0803oool004/0oooo00<000000?ooo`3oool0
I`3oool6000000`0o`000P00000H003o06@0ool000<000000?ooo`3oool0803oool004/0oooo00<0
00000?ooo`3oool0H@3oool600000140o`0000<00000003o000000006000o`1T0?oo00030000003o
ool0oooo0200oooo001;0?ooo`030000003oool0oooo05`0oooo1@00000G0?l0000300000000o`00
000001P00?l0I03oo`000`000000oooo0?ooo`0P0?ooo`00B`3oool00`000000oooo0?ooo`1F0?oo
o`H000006`3o0000100000000?l0003o0000000G003o06D0ool000<000000?ooo`3oool0803oool0
04/0oooo00<000000?ooo`3oool0D@3oool500000240o`0000@00000003o0000o`0000005`00o`1U
0?oo00030000003oool0oooo0200oooo001;0?ooo`030000003oool0oooo04/0oooo1P00000U0?l0
000500000000o`000?l0003o000000005`00o`1U0?oo00030000003oool0oooo0200oooo001;0?oo
o`030000003oool0oooo04D0oooo1P00000[0?l0000500000000o`000?l0003o000000005P00o`1V
0?oo00030000003oool0oooo0200oooo001;0?ooo`030000003oool0oooo0400oooo1@0000040?oo
02`0o`0000<00000003o0000o`000P00o`000`0000000?l0003o000D003o06H0ool000<000000?oo
o`3oool0803oool004/0oooo00<000000?ooo`3oool0>P3oool6000000T0ool0;03o00000`000000
0?l0003o0002003o000300000000o`000?l001@00?l0IP3oo`000`000000oooo0?ooo`0P0?ooo`00
C03oool00`000000oooo0?ooo`0d0?ooo`D000003`3oo`0[0?l0000300000000o`000?l000<00?l0
00<00000003o0000o`004`00o`1V0?oo00030000003oool0oooo0240oooo001<0?ooo`030000003o
ool0oooo02h0oooo1P00000E0?oo02X0o`0000<00000003o0000o`000`00o`000`0000000?l0003o
000C003o06H0ool000<000000?ooo`3oool08@3oool004`0oooo00<000000?ooo`3oool0:03oool6
000001/0ool0:@3o00000`0000000?l0003o0004003o000300000000o`000?l001800?l0I`3oo`00
0`000000oooo0?ooo`0Q0?ooo`00C03oool00`000000oooo0?ooo`0S0?ooo`D000008@3oo`0Y0?l0
000300000000o`000?l000@00?l000<00000003o0000o`004@00o`1X0?oo00030000003oool0oooo
0240oooo001<0?ooo`030000003oool0oooo01d0oooo1P00000W0?oo02L0o`0000<00000003o0000
o`001@00o`000`0000000?l0003o000@003o06T0ool000<000000?ooo`3oool08@3oool004`0oooo
00<000000?ooo`3oool0603oool5000002d0ool09`3o00000`0000000?l0003o0005003o00030000
0000o`000?l000l00?l0JP3oo`000`000000oooo0?ooo`0Q0?ooo`00C03oool00`000000oooo0?oo
o`0B0?ooo`H00000<`3oo`0V0?l0000300000000o`000?l000D00?l000<00000003o0000o`003P00
o`1[0?oo00030000003oool0oooo0240oooo001<0?ooo`030000003oool0oooo00`0oooo1P00000i
0?oo02D0o`0000<00000003o0000o`001P00o`000`0000000?l0003o000=003o06`0ool000<00000
0?ooo`3oool08@3oool004`0oooo0`3o00070?ooo`D00000?`3oo`0U0?l0000300000000o`000?l0
00H00?l000<00000003o0000o`003000o`1/0?oo00030000003oool0oooo0280oooo001;0?ooo`D0
o`001P0000150?oo02<0o`0000<00000003o0000o`001`00o`000`0000000?l0003o000:003o06h0
ool000<000000?ooo`3oool08P3oool004/0oooo1@3o001;0?oo02<0o`0000<00000003o0000o`00
1`00o`000`0000000?l0003o0009003o06l0ool000<000000?ooo`3oool08P3oool004/0oooo1@3o
001;0?oo0280o`0000<00000003o0000o`002000o`000`0000000?l0003o0008003o0700ool000<0
00000?ooo`3oool08P3oool004`0oooo0`3o001=0?oo0240o`0000<000000?oo003oo`002000o`00
0`0000000?l0003o0005003o07<0ool000<000000?ooo`3oool08P3oool004d0oooo00<000000?oo
003oo`00C@3oo`0O0?l000030000003oo`00ool000@0ool01@00o`000`0000000?l0003o0002003o
07H0ool000<000000?ooo`3oool08P3oool004h0oooo00<000000?oo003oo`00C@3oo`0N0?l00003
0000003oo`00ool000T0ool000<000000?oo003oo`00M`3oo`000`000000oooo0?ooo`0S0?ooo`00
CP3oool00`000000ool00?oo001>0?oo01`0o`0000<000000?oo003oo`002P3oo`000`000000ool0
0?oo001g0?oo00030000003oool0oooo02<0oooo001>0?ooo`030000003oo`00ool004h0ool0703o
00000`000000ool00?oo000:0?oo00030000003oo`00ool007L0ool000<000000?ooo`3oool08`3o
ool004h0oooo00<000000?oo003oo`00C`3oo`0J0?l000030000003oo`00ool000/0ool000<00000
0?oo003oo`00M`3oo`000`000000oooo0?ooo`0S0?ooo`00:`3oool00`3OW4P0M;oo0?ooo`0D0?oo
o`030=nLB01d_ol0oooo00H0oooo00H0okmd04RLg`3oool000000?oO0018M00G0?oo00030=nL001d
_`00ool000H0ool000D0okl004RL003oo`00okl004RL000Z0?oo01X0o`0000<000000?oo003oo`00
2`3oo`000`000000ool00?oo001f0?oo00030000003oool0oooo02@0oooo000Z0?ooo`030?oOW01d
W=l0oooo01@0oooo00<0omnL07BLg`3oool0203oool01P3OW4P0M;oo0?ooo`000000_g@009cO01D0
ool000<0oml007BL003oo`00203oo`001@3OW000M;l00?oo003OW000M;l002X0ool0603o00000`00
0000ool00?oo000<0?oo00030000003oo`00ool007H0ool000<000000?ooo`3oool0903oool00240
oooo00<0oono07@00018W=l01@3oool00`3ooml0W4Q809cOo`020?ooo`070;md0000000000000018
W03Oool0oooo0?noM0030000000407Boo`3oool0oooo0=nLB0<0000000/0B9cO0?oog`2LB4P0W=oo
0?ooo`3ogi`0B00000000018B4P00000001d_`020?ooo`080?oOW018B9`0gooo000000180000M;l0
0?oo003OW0030000000404RL003oo`00ool00?no00<000000140M;l00?oo003o_`00000007Bo003o
o`00oml004P0001d_`00W4P009cO003og`00B00000000018B0000000001d00030?oo00060?oO0018
B000gol00?oO0018B000gol0:P3oo`0G0?l000030000003oo`00ool000`0ool000<000000?oo003o
o`00MP3oo`000`000000oooo0?ooo`0T0?ooo`008@3oool00`3ookl0M00004RLg`050?ooo`170?oO
W01807@0_ooo0?ooo`3o_g@0001809cOo`3ookl0M00004RLg`3ogi`0B00004RLg`3oool0okmd0000
001d_ol0omnL04P00018W=l0oooo0?noM00004P0W<BL04P0M02oool0oooo0;md0000M;l0oooo0=nL
B018W=l0giad09cOo`3oool0oono07@0001d_ol0oml00000001d_`00oml004P00018W000ool00?no
00000000W=l00?oO0018000007@00?oo003o_`00000009cO003o_`00000007Bo003oo`00oml004P0
001dZ000B0000;oo002oM00007@00?oo003OW000B9`00=nL002Lg`000`3oo`001@1d0000M;l00?oo
001d0000M;l002X0ool05`3o00000`000000ool00?oo000<0?oo00030000003oo`00ool007D0ool0
00<000000?ooo`3oool09@3oool00240oooo00<0oono07@00018W=l01@3oool01`3o_g@0001d0;oo
o`3oool0_g@00000M02oool00`3oool01`3OW4P0001d0;ooo`3oool0oono07@00000M;l00P3oool0
3P3ookl0M0000000000007@0_kmd0000M02oool0oooo0;md0000M;l0oooo0?oOW01807@0_ooo0P3o
ool01@3ooml0W4P007Boo`3oool0000000@0ool000L0M000000000000000_ol00=nL00000000W=l0
00@0ool000l0okl00000001d_`00ool00?oO00180000M8l00000002oo`00_g@0001d003oo`00oml0
04P0002oo`00103oo`001@2LB000M;l00?oo002LB000M;l002/0ool05@3o00000`000000ool00?oo
000=0?oo00030000003oo`00ool007D0ool000<000000?ooo`3oool09@3oool00240oooo00<0oono
07@0000000000P0000002P00M;l0oooo0?ooo`3o_g@0001d0;ooo`3oool0_g@00000M02oool30?oo
o`090=nLB00007@0_ooo0?ooo`3ookl0M000001d_`3ooml0W4P00080000000`0M;oo0?ooo`3o_g@0
001d0;ooo`3oool0gia80018W03Oool0oono07@00018W=l20?ooo`050?oog`2LB000M;oo0?ooo`00
00000P3oo`00102LB00000000000001d_`020?oo00030=nL00000000000000<000000100B9`00?no
00000000M;l00?oo003og`00B00007B?00000000_ol00=nL0000B000gol00?oo001d0000B9`0103o
o`001@2LB000M;l00?oo002LB000M;l002`0ool0503o00000`000000ool00?oo000=0?oo00030000
003oo`00ool007D0ool000<000000?ooo`3oool09@3oool00240oooo04l0oono07@00018W=l0oooo
0?oOW0180000B9cO0?ooo`3ogi`0B01d0;ooo`3oool0okmd0000B02Lgol0omnL04P00018W=l0omnL
04P00018W=l0oooo0?noM0000000M;oo0?oOW0180000B9cO0?ooo`2oM00004RL0=oOW01807@0_ooo
0?ooo`3ookl0M00007Boo`3ookl0M01d07AdB02Lgol0oooo0?oo_`1d0000M;oo0?ooo`000000ool0
0?oO00180000B9`00?oo002oM00004P00=oo003og`00B00007Bo003oo`00oml004P0001d_`00okl0
00000000M000ool00?no00000000M:P004P0002oo`00ool007@0001d_`00ool007@0001dM000W=l0
00<0ool000D0M00007Bo003oo`00M00007Bo000]0?oo0180o`0000<000000?oo003oo`003P3oo`00
0`000000ool00?oo001d0?oo00030000003oool0oooo02H0oooo000Q0?ooo`0;0?oo_`1d0000B9cO
0?ooo`3ookl0M000001d_`3oool0oooO09a8B02Lgol00P3oool0102oM000000000000000M;l20?oo
o`050?noM000000000000000001d_ol00P3oool0203OW4P00000000000000000M;oo0?oog`2LB4P0
W=oo0P3oool0303ookl0M00000000000M;l0okmd001d_`3oool0omnL04Q8W03Oool0oooo00000080
ool000D0gi`0000000000000000007Bo00020?oo00090?no00000000000000000018W000ool00?no
00000000M7@00080000000@004P00=oo002LB000W=l00P3oo`001@1d00000000001d003o_`0007@0
0080ool000H0oml004Q8003Oo`00oml004Q8003Oo`0^0?oo0140o`0000<000000?oo003oo`003P3o
o`000`000000ool00?oo001d0?oo00030000003oool0oooo02H0oooo000Q0?ooo`070?oo_`1d0000
B9cO0?ooo`3ogi`0B00004RLg`020?ooo`030?oOW018B9`0gooo01@0oooo00<0omnL04Q8W03Oool0
203oool01@2oM000M;oo0?ooo`3oool0000001H0ool000<0oml004Q8003Oo`00203oo`001@2oM000
M;l00?oo002oM000M;l00340ool03P3o00000`000000ool00?oo000?0?oo00030000003oo`00ool0
07@0ool000<000000?ooo`3oool09P3oool00240oooo00<0oono07@0000000000P0000000`00B9`0
gooo0?ooo`020?ooo`030?oOW02L_ol0oooo01@0oooo00<0omnL09boo`3oool01P3oool00`3o_g@0
M;oo0?ooo`030?ooo`030000003oo`00ool001@0ool000<0oml009bo003oo`001P3oo`001@3o_`00
M;l00?oo003o_`00M;l003<0ool03@3o00000`000000ool00?oo000?0?oo00030000003oo`00ool0
07@0ool000<000000?ooo`3oool09P3oool00540oooo00<000000?oo003oo`00EP3oo`0;0?l00003
0000003oo`00ool00100ool000<000000?oo003oo`00M03oo`000`000000oooo0?ooo`0V0?ooo`00
D@3oool00`000000ool00?oo001G0?oo00X0o`0000<000000?oo003oo`00403oo`000`000000ool0
0?oo001d0?oo00030000003oool0oooo02H0oooo001B0?ooo`030000003oo`00ool005T0ool01P3o
00000`000000ool00?oo000A0?oo00030000003oo`00ool007<0ool000<000000?ooo`3oool09`3o
ool00580oooo00<000000?oo003oo`00FP3oo`050?l000030000003oo`00ool00140ool000<00000
0?oo003oo`00L`3oo`000`000000oooo0?ooo`0W0?ooo`00D`3oool00`000000ool00?oo001J0?oo
00<0o`0000<000000?oo003oo`004P3oo`000`000000ool00?oo001b0?oo00030000003oool0oooo
02P0oooo001C0?ooo`030000003oo`00ool005d0ool000<000000?oo003oo`004P3oo`000`000000
ool00?oo001b0?oo00030000003oool0oooo02P0oooo001D0?ooo`030000003oo`00ool005/0ool0
00<000000?oo003oo`004`3oo`000`000000ool00?oo001a0?oo00030000003oool0oooo02T0oooo
001D0?ooo`030000003oo`00ool005/0ool000<000000?oo003oo`004`3oo`000`000000ool00?oo
001a0?oo00030000003oool0oooo02T0oooo001E0?ooo`030000003oo`00ool005T0ool000<00000
0?oo003oo`00503oo`000`000000ool00?oo001`0?oo00030000003oool0oooo02X0oooo001E0?oo
o`030000003oo`00ool005T0ool000<000000?oo003oo`00503oo`000`000000ool00?oo001`0?oo
00030000003oool0oooo02X0oooo001E0?ooo`030000003oo`00ool005T0ool000<000000?oo003o
o`00503oo`000`000000ool00?oo001_0?oo00030000003oool0oooo02/0oooo001F0?ooo`030000
003oo`00ool005L0ool000<000000?oo003oo`005@3oo`000`000000ool00?oo001_0?oo00030000
003oool0oooo02/0oooo001F0?ooo`030000003oo`00ool005L0ool000<000000?oo003oo`005@3o
o`000`000000ool00?oo001_0?oo00030000003oool0oooo02/0oooo001G0?ooo`030000003oo`00
ool005D0ool000<000000?oo003oo`005P3oo`000`000000ool00?oo001^0?oo00030000003oool0
oooo02`0oooo001G0?ooo`030000003oo`00ool005D0ool000<000000?oo003oo`005P3oo`000`00
0000ool00?oo001^0?oo00030000003oool0oooo02`0oooo001H0?ooo`030000003oo`00ool005<0
ool000<000000?oo003oo`005`3oo`000`000000ool00?oo001]0?oo00030000003oool0oooo02d0
oooo001H0?ooo`030000003oo`00ool005<0ool000<000000?oo003oo`005`3oo`000`000000ool0
0?oo001]0?oo00030000003oool0oooo02d0oooo001I0?ooo`030000003oo`00ool00540ool000<0
00000?oo003oo`00603oo`000`000000ool00?oo001/0?oo00030000003oool0oooo02h0oooo001I
0?ooo`030000003oo`00ool00540ool000<000000?oo003oo`00603oo`000`000000ool00?oo001/
0?oo00030000003oool0oooo02h0oooo001J0?ooo`030000003oo`00ool004l0ool000<000000?oo
003oo`006@3oo`000`000000ool00?oo001[0?oo00030000003oool0oooo02l0oooo001J0?ooo`03
0000003oo`00ool004l0ool000<000000?oo003oo`006@3oo`000`000000ool00?oo001[0?oo0003
0000003oool0oooo02l0oooo001K0?ooo`030000003oo`00ool004d0ool000<000000?oo003oo`00
6P3oo`000`000000ool00?oo001Z0?oo00030000003oool0oooo0300oooo001K0?ooo`030000003o
o`00ool004d0ool000<000000?oo003oo`006P3oo`000`000000ool00?oo001Z0?oo00030000003o
ool0oooo0300oooo001L0?ooo`030000003oo`00ool004/0ool000<000000?oo003oo`006`3oo`00
0`000000ool00?oo001Y0?oo00030000003oool0oooo0340oooo001L0?ooo`030000003oo`00ool0
04/0ool000<000000?oo003oo`006`3oo`000`000000ool00?oo001X0?oo00030000003oool0oooo
0380oooo001M0?ooo`030000003oo`00ool004X0ool000<000000?oo003oo`006`3oo`000`000000
ool00?oo001X0?oo00030000003oool0oooo0380oooo001N0?ooo`030000003oo`00ool004P0ool0
00<000000?oo003oo`00703oo`000`000000ool00?oo001W0?oo00030000003oool0oooo03<0oooo
001N0?ooo`030000003oo`00ool004P0ool000<000000?oo003oo`00703oo`000`000000ool00?oo
001W0?oo00030000003oool0oooo03<0oooo001O0?ooo`030000003oo`00ool004H0ool000<00000
0?oo003oo`007@3oo`000`000000ool00?oo001V0?oo00030000003oool0oooo03@0oooo001P0?oo
o`030000003oo`00ool004D0ool000<000000?oo003oo`007@3oo`000`000000ool00?oo001U0?oo
00030000003oool0oooo03D0oooo001P0?ooo`030?oo00000000ool004@0ool000<000000?oo003o
o`007P3oo`000`000000ool00?oo001T0?oo00030000003oool0oooo03H0oooo001Q0?ooo`030000
003oo`00ool004<0ool000<000000?oo003oo`007P3oo`000`000000ool00?oo001T0?oo00030000
003oool0oooo03H0oooo001R0?ooo`030000003oo`00ool00440ool000<000000?oo003oo`007`3o
o`000`000000ool00?oo001S0?oo00030000003oool0oooo03L0oooo001R0?ooo`030000003oo`00
ool00440ool000<000000?oo003oo`007`3oo`000`000000ool00?oo001R0?oo00030?ooo`000000
oooo03P0oooo001S0?ooo`030000003oo`00ool003l0ool000<000000?oo003oo`00803oo`000`00
0000ool00?oo001R0?oo00030000003oool0oooo03P0oooo001T0?ooo`030000003oo`00ool003h0
ool000<000000?oo003oo`00803oo`000`000000ool00?oo001R0?oo00030000003oool0oooo03P0
oooo001U0?ooo`030000003oo`00ool003`0ool000<000000?oo003oo`008@3oo`000`000000ool0
0?oo001Q0?oo00030000003oool0oooo03T0oooo001U0?ooo`030000003oo`00ool003`0ool000<0
00000?oo003oo`008@3oo`000`000000ool00?oo001P0?oo00030000003oool0oooo03X0oooo001V
0?ooo`030000003oo`00ool003X0ool000<000000?oo003oo`008P3oo`000`000000ool00?oo001O
0?oo00030000003oool0oooo03/0oooo001W0?ooo`030000003oo`00ool003T0ool000<000000?oo
003oo`008P3oo`000`000000ool00?oo001N0?oo00030000003oool0oooo03`0oooo001X0?ooo`03
0000003oo`00ool003L0ool000<000000?oo003oo`008`3oo`000`000000ool00?oo001M0?oo0003
0000003oool0oooo03d0oooo001Y0?ooo`030000003oo`00ool003H0ool000<000000?oo003oo`00
8`3oo`000`000000ool00?oo001L0?oo00030000003oool0oooo03h0oooo001Y0?ooo`030000003o
o`00ool003H0ool000<000000?oo003oo`008`3oo`000`000000ool00?oo001K0?oo00030?ooo`00
0000oooo03l0oooo001Z0?ooo`030000003oo`00ool003@0ool000<000000?oo003oo`00903oo`00
0`000000ool00?oo001J0?oo00030?ooo`000000oooo0400oooo001[0?ooo`030000003oo`00ool0
03<0ool000<000000?oo003oo`00903oo`000`000000ool00?oo001I0?oo00030?ooo`000000oooo
0440oooo001/0?ooo`030000003oo`00ool00340ool000<000000?oo003oo`009@3oo`000`000000
ool00?oo001I0?oo00030000003oool0oooo0440oooo001]0?ooo`030000003oo`00ool00300ool0
00<000000?oo003oo`009@3oo`000`000000ool00?oo001H0?oo00030000003oool0oooo0480oooo
001^0?ooo`030000003oo`00ool002h0ool000<000000?oo003oo`009P3oo`000`000000ool00?oo
001G0?oo00030000003oool0oooo04<0oooo001_0?ooo`030000003oo`00ool002d0ool000<00000
0?oo003oo`009P3oo`000`000000ool00?oo001F0?oo00030000003oool0oooo04@0oooo001`0?oo
o`030000003oo`00ool002/0ool000<000000?oo003oo`009`3oo`000`000000ool00?oo001E0?oo
00030000003oool0oooo04D0oooo001a0?ooo`030000003oo`00ool002X0ool000<000000?oo003o
o`009`3oo`000`000000ool00?oo001D0?oo00030000003oool0oooo04H0oooo001b0?ooo`030000
003oo`00ool002P0ool000<000000?oo003oo`00:03oo`000`000000ool00?oo001C0?oo00030000
003oool0oooo04L0oooo001c0?ooo`030000003oo`00ool002L0ool000<000000?oo003oo`00:03o
o`000`000000ool00?oo001B0?oo00030000003oool0oooo04P0oooo001d0?ooo`030000003oo`00
ool002D0ool000<000000?oo003oo`00:@3oo`000`000000ool00?oo001A0?oo00030000003oool0
oooo04T0oooo001e0?ooo`030000003oo`00ool002@0ool000<000000?oo003oo`00:@3oo`000`00
0000ool00?oo001@0?oo00030000003oool0oooo04X0oooo001f0?ooo`8000008`3oo`000`000000
ool00?oo000Z0?oo00030000003oo`00ool004h0ool00P00001=0?ooo`00M`3oool00`3oo`000000
0?oo000Q0?oo00030000003oo`00ool002X0ool000<000000?oo003oo`00C@3oo`000`000000oooo
0?ooo`1=0?ooo`00N@3oool00`000000ool00?oo000O0?oo00030000003oo`00ool002X0ool000<0
00000?oo003oo`00C03oo`000`000000oooo0?ooo`1>0?ooo`00NP3oool00`000000ool00?oo000M
0?oo00030000003oo`00ool002/0ool000<000000?oo003oo`00BP3oo`000`3oool000000?ooo`1@
0?ooo`00N`3oool00`000000ool00?oo000L0?oo00030000003oo`00ool002/0ool000<000000?oo
003oo`00B@3oo`0200000580oooo001l0?ooo`030000003oo`00ool001X0ool000<000000?oo003o
o`00;03oo`000`000000ool00?oo00180?oo00030000003oool0oooo0580oooo001m0?ooo`800000
6P3oo`000`000000ool00?oo000/0?oo00030000003oo`00ool004L0ool000<000000?ooo`3oool0
D`3oool007l0oooo0P00000G0?oo00030000003oo`00ool002d0ool000<000000?oo003oo`00A@3o
o`02000005H0oooo00210?ooo`8000005@3oo`000`000000ool00?oo000]0?oo00030000003oo`00
ool004<0ool00P00001H0?ooo`00P`3oool00`000000ool00?oo000A0?oo00030000003oo`00ool0
02h0ool000<000000?oo003oo`00@P3oo`000`000000oooo0?ooo`1H0?ooo`00Q03oool00`000000
ool00?oo000@0?oo00030000003oo`00ool002h0ool000<000000?oo003oo`00@@3oo`000`000000
oooo0?ooo`1I0?ooo`00Q@3oool2000000l0ool000<000000?oo003oo`00;`3oo`000`000000ool0
0?oo000o0?oo00800000G03oool008L0oooo00<000000?oo003oo`00303oo`000`000000ool00?oo
000_0?oo00030000003oo`00ool003h0ool000<000000?ooo`3oool0G03oool008P0oooo0P00000;
0?oo00030000003oo`00ool00300ool000<000000?oo003oo`00?03oo`02000005l0oooo002:0?oo
o`8000002@3oo`000`000000ool00?oo000`0?oo00030000003oo`00ool003T0ool000<0oooo0000
00000000H@3oool008`0oooo0P0000060?oo00030000003oo`00ool00340ool000<000000?oo003o
o`00>03oo`02000006<0oooo002>0?ooo`8000000P3oo`030?l003<0ool000<000000?oo003oo`00
=P3oo`02000006D0oooo002?0?ooo`030?oo00000000o`0000@0o`00<P3oo`000`000000ool00?oo
000d0?oo00800000I`3oool00940oooo1@3o000b0?oo00030000003oo`00ool00380ool00P00001Y
0?ooo`00T@3oool50?l00380ool000<000000?oo003oo`00<03oo`02000006/0oooo002B0?ooo`<0
o`0000@0oooo0000000000000000;`3oo`000`000000ool00?oo000]0?oo00<00000K@3oool00480
oooo00<0gia807Boo`3oool05@3oool0103OW4P0M;oO09a80000M;l50?ooo`060?noM018W=l0oooo
0?ooo`3ogi`0B7Bo5`3oool00`3OW3l0B3D0001d_`060?ooo`060?noM018W=l0oooo0?ooo`3o_g@0
B9cO2P3oool2000002d0ool000<000000?oo003oo`00:`3oo`0200000700oooo000n0?ooo`050?no
M000M;l0oooo0?oOW01dW=l05P3oool01P3ogi`0M9cO0?ooo`3ogi`0B01d0;ooo`D0oooo00H0gia8
07Boo`3oool0oooo0;mdB02LgolE0?ooo`050?oOW01dW=l0omnL04P0M02oool01P3oool01P3OW4P0
M;oo0?ooo`3oool0gia807Boo`/0oooo0P00000[0?oo00030000003oo`00ool002T0ool00P00001b
0?ooo`00>@3oool00`3ookl0M00000000002000000050000M02oool0oooO09a8B02Lgol00P3oool0
1`2oM000000000000000B9`0gooo0?ooo`3o_g@00`000000101d_ol0oooo0?ooo`3OW4P300000008
04RLg`3oool0oooO09a8B02Lgol0oooo0?oog`2LB0030000000;04RLg`3oool0oooo0?oOW018B9`0
gooo0?oOW0180000M;oo0?ooo`3OW4P00`0000001018W=l0oooo0?ooo`3o_g@30000000=07Boo`3o
ool0okmd0000001d_ol0oooo0?oOW0180000M;oO09a8B02Lgol0oooO09a800030000000;04RLg`3o
ool0oooo0?ooo`3ogi`0B4RL0=ooo`3oool0omnL04Q8W03Oool0303oool2000002T0ool000<00000
0?oo003oo`009`3oo`02000007@0oooo000h0?ooo`0S0?oo_`1d000004RL0=ooo`2oM00000000000
B02Lgol0omnL04P0M02oool0oooo0?noM00004P0W=oo0?oo_`1d0000B9cO0?oOW0180000B9cO0?oo
o`3o_g@0000007Boo`3ogi`0B00004RLg`3oool0okmd0000B02Lgol0omnL04P0M02oool00P3oool0
:`2oM00004RL0=ooo`3ogi`0B00007Boo`3oool0oono07@0001d_ol0omnL04P0001d_ol0omnL04P0
0018W=l0oooo0?noM00004P0W=oo0?oOW018000007Bo0?ooo`3o_g@0001809cOo`3o_g@0000007Bo
o`3oool0omnL04P0001dZ9`0B01d0;ooo`3oool0_g@00018W03Oool0omnL04P0001d_ol00P3oool0
1`3ookl0M00007Boo`3oool0oono07@0001d_ol03P3oool6000002<0ool000<000000?oo003oo`00
903oo`03000007H0oooo000h0?ooo`0?0?noM00004P0W=oo0?oOW018B9`0gmnL04P00018W=l0okmd
0000M02oool0oooo0;md000007@0_ooo00<0oooo00L0gia80000M02oool0oooo0?oo_`1d000007Bo
0080oooo00P0oono07@000000000001d0;ooo`3o_g@0001d0;ooo`80oooo00X0okmd0018W03Oool0
oooo0;md0000M;l0oooo0?oog`2LB000M;oo1@3oool0203ookl0M0000000000007@0_ooo0=nLB000
04P0W=oo103oool0403o_g@0000007Boo`3oool0omnL04P0001dSg@0001d0;ooo`3oool0okmd0018
W03Oool0oooo0;md0000M;l20?ooo`070?oog`2LB000M;oo0?ooo`3ooml0W4P007Boo`0D0?ooo`<0
0000803oo`000`000000ool00?oo000O0?oo00D00000N@3oool003P0oooo00<0gia80000M02oool0
0P3oool02P3ookl0M00004RLg`3o_g@0001d0;ooo`3oool0_g@00000M02oool30?ooo`090=nLB000
07@0_ooo0?ooo`3ookl0M000001d_`3ooml0W4P00080000000H0M;oo0?ooo`3oool0okmd0000M02o
ool20?ooo`0:0?oOW01804P0W=oo0?oog`2LB000B9cO0?ooo`3ooml0W4P007Boo`<0oooo00D0oooO
09a800000000000007Boo`020?ooo`030=nLB0000000000000<000000140B9cO0?noM0000000M;oo
0?ooo`3ogi`0B00007B?M00007@0_ooo0?ooo`3ogi`0B01809cOo`3ooml0W4P004RLg`020?ooo`07
0?oog`2LB000M;oo0?ooo`3ooml0W4P007Boo`0G0?ooo`<000007@3oo`000`000000ool00?oo000K
0?oo00@00000OP3oool003P0oooo00<0gia80000M02oool00P3oool07P3ookl0M00004RLg`3ogi`0
B01d0;ooo`3oool0okmd0000B02Lgol0omnL04P00018W=l0omnL04P00018W=l0oooo0?noM0000000
M;oo0?oOW0180000B9cO0?ooo`2oM00004RL0=ooo`3ogi`0B01d0;ooo`80oooo00X0oooO09a8001d
W9`0B0000018W03Oool0oooo0?oo_`1d0000M;oo0`3oool07P3ogi`0B00004RLg`3oool0_g@00018
W03Oool0omnL04P0001d_ol0oooo0?oOW0180000M;oo0?noM000000007Bo0?ooo`3o_g@0000007BX
W01807@0_ooo0?ooo`3ooml0W4P007BLW018000004RL0=ooo`80oooo00L0oono07@0001d_ol0oooo
0?oo_`1d0000M;oo01X0oooo1000000I0?oo00030000003oo`00ool001L0ool0100000220?ooo`00
>03oool00`3o_g@0001809cOo`020?ooo`060?oOW0180000M;oo0?oog`2LB4P0W=oo0P3oool0102o
M000000000000000M;l20?ooo`050?noM000000000000000001d_ol00P3oool02@3OW4P000000000
00000000M;oo0?ooo`3ooml0W4Q809cOo`030?ooo`090=nLB000M;l0oooo0?noM000B9`0gooo0?oO
W018B9`0gooo00@0oooo00D0gia8000000000000000007Boo`020?ooo`090?noM000000000000000
0018W=l0oooo0?noM0000000M7Ad0080000000@004RL0=oog`2LB4P0W=oo0P3oool03P3OW4P007Bo
0?ooo`3o_g@004RL0=ooo`3oool0omnL04Q8W03Oool0oooo0?oOW018B9`0gooo7P3oool6000001<0
ool000<000000?oo003oo`004@3oo`06000008H0oooo000h0?ooo`0<0?oo_`1d000004RL0=ooo`3o
ool0_g@00018W03Oool0oooo0?oOW018B9`0gooo5@3oool00`3ogi`0B4RL0=ooo`020?ooo`080?oO
W01804P0W=oo0?oOW01807@0_ooo0;md001d_olI0?ooo`0=0?oOW018B9`0gooo0?ooo`3ogi`0B018
09cOo`3ogi`0B01d0;ooo`3oool0_g@007Boo`020?ooo`030;md001d_ol0oooo02@0oooo2000000;
0?oo00030000003oo`00ool000T0ool02000002<0?ooo`00>@3oool01P3ookl0M000000000000000
04RL0=ooo`<0oooo00<0omnL09boo`3oool05@3oool00`3ogi`0W;oo0?ooo`020?ooo`060?noM000
00000000001d_`3o_g@0M;oo6`3oool01@3ogi`0W;oo0?ooo`3oool0okmd0080000000@007Bo0?oo
o`3o_g@0M;oo0P3oool00`3o_g@0M;oo0?ooo`0]0?oooaL00000U03oool00;h0oooo00<0oooO09a8
M02oool01`3oool00`000000oooo0?ooo`2M0?ooo`00_03oool01@3ooml0W9bo0?oog`2LB7@0_ooo
00L0oooo00<000000?ooo`3oool0W@3oool00;d0oooo00@0okmd0000000007@0_ooo1`3oool00`00
0000oooo0?ooo`2M0?ooo`00_P3oool00`3ookl0M01d0;ooo`070?ooo`030000003oool0oooo09d0
oooo00380?ooo`030000003oool0oooo09d0oooo00380?ooo`030000003oool0oooo09d0oooo0038
0?ooo`030000003oool0oooo09d0oooo00380?ooo`030000003oool0oooo09d0oooo00380?ooo`03
0000003oool0oooo09d0oooo00380?ooo`030000003oool0oooo09d0oooo00380?ooo`030000003o
ool0oooo09d0oooo00380?ooo`030000003oool0oooo09d0oooo00380?ooo`800000WP3oool00<P0
oooo00<000000?ooo`3oool0W@3oool00<P0oooo00<000000?ooo`3oool0W@3oool00<P0oooo00<0
00000?ooo`3oool0W@3oool00<P0oooo00<000000?ooo`3oool0W@3oool00<P0oooo00<000000?oo
o`3oool0W@3oool00<P0oooo00<000000?ooo`3oool0W@3oool00<P0oooo00<000000?ooo`3oool0
W@3oool00<P0oooo00<000000?ooo`3oool0W@3oool00<P0oooo00<000000?ooo`3oool0W@3oool0
0<P0oooo00<000000?ooo`3oool0W@3oool00<P0oooo00<000000?ooo`3oool0W@3oool00<P0oooo
0P00002N0?ooo`00b03oool00`000000oooo0?ooo`2M0?ooo`00b03oool00`000000oooo0?ooo`2M
0?ooo`00b03oool00`000000oooo0?ooo`2M0?ooo`00b03oool00`000000oooo0?ooo`2M0?ooo`00
b03oool00`000000oooo0?ooo`2M0?ooo`00b03oool00`000000oooo0?ooo`2M0?ooo`00b03oool0
0`000000oooo0?ooo`2M0?ooo`00b03oool00`000000oooo0?ooo`2M0?ooo`00o`3ooomY0?ooo`00
\
\>"],
  ImageRangeCache->{{{112.438, 370.625}, {445.188, 215.813}} -> {-2.85337, \
1.12439, 0.0100069, 0.0100069}},
  CellTags->"figura7"],

Cell[TextData[{
  "Dal punto di vista geometrico, la differenza ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] - \[Beta]\)]],
  " appare come l'angolo evidenziato in color rosso. Poich\[EAcute] le \
convenzioni sugli angoli in goniometria impongono di trattare questi con un \
lato coincidente con il semiasse positivo delle ascisse, eseguiamo una \
rotazione attorno all'origine pari all'angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\)]],
  " in modo da riportare quest'angolo nell'ambito convenzionale corretto. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[{
    \(\(nPassi = 50;\)\), "\n", 
    \(\(suddivisioneAngolo = Range[0, \[Beta], \[Beta]/nPassi];\)\), "\n", 
    \(\(estremiAngoli = \({\[Beta] - #, \[Alpha] - #} &\) /@ 
          suddivisioneAngolo;\)\), "\n", 
    \(\(\(Show[Graphics[{colRosso, Disk[{0, 0},  .4, #]}], 
            Graphics[
              Line[{{0, 
                    0}, {Cos[#\[LeftDoubleBracket]1\[RightDoubleBracket]], 
                    Sin[#\[LeftDoubleBracket]1\[RightDoubleBracket]]}, {Cos[#\
\[LeftDoubleBracket]2\[RightDoubleBracket]], 
                    Sin[#\[LeftDoubleBracket]2\[RightDoubleBracket]]}, {0, 
                    0}}]], Graphics[{Circle[{0, 0}, 1], Line[{{0, 0}, pP}], 
                Line[{{0, 0}, pQ}], Line[{{\(-1.2\), 0}, {1.2, 0}}], 
                Line[{{0, \(-1.2\)}, {0, 1.2}}]}], 
            Graphics[{colRosso, AbsolutePointSize[4], 
                Point[{Cos[#\[LeftDoubleBracket]1\[RightDoubleBracket]], 
                    Sin[#\[LeftDoubleBracket]1\[RightDoubleBracket]]}], 
                Point[{Cos[#\[LeftDoubleBracket]2\[RightDoubleBracket]], 
                    Sin[#\[LeftDoubleBracket]2\[RightDoubleBracket]]}]}], \
\[IndentingNewLine]Graphics[{Text["\<Q\>", {Cos[#\[LeftDoubleBracket]1\
\[RightDoubleBracket]], 
                    Sin[#\[LeftDoubleBracket]1\[RightDoubleBracket]]}, {0, \
\(-1\)}, TextStyle \[Rule] stileTesto], 
                Text["\<P\>", \
{Cos[#\[LeftDoubleBracket]2\[RightDoubleBracket]], 
                    Sin[#\[LeftDoubleBracket]2\[RightDoubleBracket]]}, {0, \
\(-1\)}, TextStyle \[Rule] stileTesto]}], 
            Prolog -> {{colGiallo, 
                  Disk[{0, 0}, 1, {0, \[Alpha]}]}, {colVerde, 
                  Disk[{0, 0},  .3, {0, \[Beta]}]}}, 
            AspectRatio \[Rule] Automatic, Axes \[Rule] True] &\) /@ 
        estremiAngoli;\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Animazione", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.396825 0.5 0.396825 [
[.10317 .4875 -6.96875 -10.9375 ]
[.10317 .4875 6.96875 0 ]
[.30159 .4875 -10.3125 -10.9375 ]
[.30159 .4875 10.3125 0 ]
[.69841 .4875 -7.5625 -10.9375 ]
[.69841 .4875 7.5625 0 ]
[.89683 .4875 -4.21875 -10.9375 ]
[.89683 .4875 4.21875 0 ]
[.4875 .10317 -13.9375 -5.46875 ]
[.4875 .10317 0 5.46875 ]
[.4875 .30159 -20.625 -5.46875 ]
[.4875 .30159 0 5.46875 ]
[.4875 .69841 -15.125 -5.46875 ]
[.4875 .69841 0 5.46875 ]
[.4875 .89683 -8.4375 -5.46875 ]
[.4875 .89683 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .5 m
.10317 .50625 L
s
gsave
.10317 .4875 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.30159 .5 m
.30159 .50625 L
s
gsave
.30159 .4875 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.69841 .5 m
.69841 .50625 L
s
gsave
.69841 .4875 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.89683 .5 m
.89683 .50625 L
s
gsave
.89683 .4875 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.14286 .5 m
.14286 .50375 L
s
.18254 .5 m
.18254 .50375 L
s
.22222 .5 m
.22222 .50375 L
s
.2619 .5 m
.2619 .50375 L
s
.34127 .5 m
.34127 .50375 L
s
.38095 .5 m
.38095 .50375 L
s
.42063 .5 m
.42063 .50375 L
s
.46032 .5 m
.46032 .50375 L
s
.53968 .5 m
.53968 .50375 L
s
.57937 .5 m
.57937 .50375 L
s
.61905 .5 m
.61905 .50375 L
s
.65873 .5 m
.65873 .50375 L
s
.7381 .5 m
.7381 .50375 L
s
.77778 .5 m
.77778 .50375 L
s
.81746 .5 m
.81746 .50375 L
s
.85714 .5 m
.85714 .50375 L
s
.06349 .5 m
.06349 .50375 L
s
.02381 .5 m
.02381 .50375 L
s
.93651 .5 m
.93651 .50375 L
s
.97619 .5 m
.97619 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .10317 m
.50625 .10317 L
s
gsave
.4875 .10317 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .30159 m
.50625 .30159 L
s
gsave
.4875 .30159 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .69841 m
.50625 .69841 L
s
gsave
.4875 .69841 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .89683 m
.50625 .89683 L
s
gsave
.4875 .89683 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .14286 m
.50375 .14286 L
s
.5 .18254 m
.50375 .18254 L
s
.5 .22222 m
.50375 .22222 L
s
.5 .2619 m
.50375 .2619 L
s
.5 .34127 m
.50375 .34127 L
s
.5 .38095 m
.50375 .38095 L
s
.5 .42063 m
.50375 .42063 L
s
.5 .46032 m
.50375 .46032 L
s
.5 .53968 m
.50375 .53968 L
s
.5 .57937 m
.50375 .57937 L
s
.5 .61905 m
.50375 .61905 L
s
.5 .65873 m
.50375 .65873 L
s
.5 .7381 m
.50375 .7381 L
s
.5 .77778 m
.50375 .77778 L
s
.5 .81746 m
.50375 .81746 L
s
.5 .85714 m
.50375 .85714 L
s
.5 .06349 m
.50375 .06349 L
s
.5 .02381 m
.50375 .02381 L
s
.5 .93651 m
.50375 .93651 L
s
.5 .97619 m
.50375 .97619 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 1 0 r
.5 .5 m
.5 .5 .39683 0 170 arc
F
0 1 0 r
.5 .5 m
.5 .5 .11905 0 115 arc
F
1 0 0 r
.5 .5 m
.5 .5 .15873 23 78 arc
F
0 g
.5 Mabswid
.5 .5 m
.86528 .65505 L
.5825 .88815 L
.5 .5 L
s
newpath
.5 .5 .39683 0 365.73 arc
s
.5 .5 m
.1092 .56891 L
s
.5 .5 m
.33229 .85965 L
s
.02381 .5 m
.97619 .5 L
s
.5 .02381 m
.5 .97619 L
s
1 0 0 r
4 Mabswid
.86528 .65505 Mdot
.5825 .88815 Mdot
0 g
gsave
.86528 .65505 -66.4688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Q) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5825 .88815 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
69.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  Magnification->0.9,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?oo
o`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?oo
o`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3o
ool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo
0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?oo
o`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000
003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0
oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80
oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<00000
0?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3o
ool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0
oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<0
00000?ooo`3oool0/P3oool00:P0oooo00<0oooO09a8M02oool0203oool00`000000oooo0?ooo`2b
0?ooo`00Z03oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo0;80oooo002P0?ooo`03
0?noM000000000000080000000H004RL0=ooo`3oool0oooO09a8M02oool80?ooo`030000003oool0
oooo0;80oooo002S0?ooob400000Y03oool009`0oooo1`0000030?ooo`050?oog`2LW;l0oooO09a8
M02oool0203oool00`000000oooo0?ooo`0>0?ooo`L00000W@3oool009L0oooo1@00000;0?ooo`04
0?noM0000000001d0;ooo`P0oooo00<000000?ooo`3oool05@3oool5000009P0oooo002C0?ooo`@0
00004@3oool00`3ookl0M01d0;ooo`080?ooo`030000003oool0oooo01X0oooo1000002D0?ooo`00
SP3oool500000200oooo00<000000?ooo`3oool07P3oool5000008l0oooo002;0?ooo`<000009@3o
ool00`000000oooo0?ooo`0S0?ooo`<00000S03oool008L0oooo1000000X0?ooo`030000003oool0
oooo02H0oooo100000280?ooo`00QP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0Q@3oool00880oooo1000000]0?ooo`030000003oool0oooo02/0
oooo100000230?ooo`00O`3oool300000340oooo00<000000?ooo`3oool0;`3oool300000800oooo
001m0?ooo`800000=03oool00`000000oooo0?ooo`0b0?ooo`800000OP3oool007X0oooo0`00000f
0?ooo`030000003oool0oooo03@0oooo0`00001k0?ooo`00N03oool2000003T0oooo00<000000?oo
o`3oool0=`3oool2000007T0oooo001g0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`1f0?ooo`00M03oool3000003`0oooo0P00000k0?ooo`<00000
M@3oool00780oooo0P00000o0?ooo`030000003oool0oooo03d0oooo0P00001c0?ooo`00L03oool2
00000440oooo00<000000?ooo`3oool0?`3oool200000740oooo001_0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1^0?ooo`00K@3oool2000004@0
oooo00<000000?ooo`3oool0@P3oool2000006h0oooo001/0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1[0?ooo`00J@3oool3000004L0oooo00<0
00000?ooo`3oool0A@3oool3000006X0oooo001W0?ooo`800000BP3oool00`000000oooo0?ooo`18
0?ooo`800000J03oool006H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo06D0oooo001T0?ooo`800000C@3oool00`000000oooo0?ooo`1;0?ooo`80
0000I@3oool006<0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo0680oooo001Q0?ooo`800000D03oool00`000000oooo0?ooo`1>0?ooo`800000HP3o
ool00600oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo05l0oooo001N0?ooo`800000D`3oool00`000000oooo0?ooo`1A0?ooo`800000G`3oool005d0
oooo00<000000?ooo`3oool0D`3oool2000005@0oooo00<000000?ooo`3oool0G03oool005`0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05/0oooo
001K0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`1J0?ooo`00FP3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool0F@3oool005P0oooo0P00001I0?ooo`030000003oool0oooo05L0oooo0P00001I0?oo
o`00E`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0EP3oool005H0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo05D0oooo001E0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`1D0?ooo`00E03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo05`0oooo00<000000?ooo`3oool0D`3oool005<0oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`1M0?ooo`030000003oool0oooo0580oooo001B0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1A0?ooo`00D@3oool00`000000oooo
0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0D03oool00500oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo04l0oooo001?
0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1>
0?ooo`00CP3oool00`000000oooo0?ooo`1R0?ooo`800000H`3oool00`000000oooo0?ooo`1=0?oo
o`00C@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool0C03oool004`0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1T0?ooo`030000
003oool0oooo04/0oooo001;0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`1:0?ooo`00BP3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0
oooo06H0oooo00<000000?ooo`3oool0B@3oool004T0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`1W0?ooo`030000003oool0oooo04P0oooo00180?ooo`030000003oool0oooo06P0
oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`170?ooo`00A`3oool00`000000oooo
0?ooo`1Y0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0AP3oool004H0oooo00<0
00000?ooo`3oool0JP3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo04D0oooo0015
0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`14
0?ooo`00A@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0A03oool004@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo04<0oooo00130?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0
K@3oool00`000000oooo0?ooo`120?ooo`00@P3oool00`000000oooo0?ooo`1^0?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool0@@3oool00440oooo00<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0400oooo00100?ooo`030000003oool0oooo
0700oooo0P00001a0?ooo`030000003oool0oooo03l0oooo00100?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0o0?ooo`00?`3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0?P3oool003h0oooo00<0
00000?ooo`3oool0LP3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo03d0oooo000n
0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0m
0?ooo`00?@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool0?03oool003`0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo03/0oooo000l0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`0k0?ooo`00>`3oool00`000000oooo0?ooo`1e0?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool0>P3oool003X0oooo00<000000?ooo`3oool0MP3oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo03T0oooo000j0?ooo`030000003oool0oooo
07H0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0i0?ooo`00>@3oool00`000000
oooo0?ooo`1S0?ooo`0:0;md00000000001809cOo`3oool0oono07A8W03Oool0oooo0;md00800000
00<0B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo03P0oooo
000i0?ooo`030000003oool0oooo0680oooo00H0okmd0018W03Oool0okmd0018W03Oool30?ooo`06
0?noM018W=l0oooo0?ooo`3OW4P0M;oo1P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0
oooo03P0oooo000h0?ooo`030000003oool0oooo05`0oooo00<0okmd0000000000000P0000002000
B9`0gooo0=nLB018W=l0oooo0?oo_`1d07@0_ooo1`3oool00`3o_g@0B9cO0?ooo`050?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool0>03oool003P0oooo00<000000?ooo`3oool0H`3o
ool01P3OW4P0M;oo0?ooo`3ooml0W4Qd0;ooo`<0oooo00H0okmd0000M02oool0oooo0=nLB01d_ol6
0?ooo`<00000N03oool00`000000oooo0?ooo`0g0?ooo`00=`3oool00`000000oooo0?ooo`1T0?oo
o`060=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q804P00000000007Bo00L0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0f0?ooo`00=P3oool00`000000oooo0?oo
o`1U0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool00`3ooml0W4Q809cOo`090?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0
IP3oool0102oM00000000000B02Lgol50?ooo`050;md0000000000000000B02Lgol01P3oool00`00
0000oooo0?ooo`1j0?ooo`030000003oool0oooo03D0oooo000e0?ooo`030000003oool0oooo07/0
oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0d0?ooo`00=03oool00`000000oooo
0?ooo`1l0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0=03oool003@0oooo00<0
00000?ooo`3oool0O03oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03<0oooo000c
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0c
0?ooo`00<`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo07d0oooo00<000000?oo
o`3oool0<P3oool003<0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`1m0?ooo`03
0000003oool0oooo0380oooo000b0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0b0?ooo`00<P3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo07h0oooo00<000000?ooo`3oool0<@3oool00340oooo00<000000?ooo`3oool0O`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0300oooo000`0?ooo`030000003oool0oooo
0800oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0`0?ooo`00<03oool00`000000
oooo0?ooo`200?ooo`800000P@3oool00`000000oooo0?ooo`0_0?ooo`00<03oool00`000000oooo
0?ooo`200?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0;`3oool00300oooo00<0
00000?ooo`3oool0P03oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo02l0oooo000_
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0^
0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0840oooo00<000000?oo
o`3oool0;P3oool002h0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`220?ooo`03
0000003oool0oooo02d0oooo000^0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0
PP3oool00`000000oooo0?ooo`0]0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000003o
ool0oooo0880oooo00<000000?ooo`3oool0;@3oool002d0oooo00<000000?ooo`3oool0P`3oool0
0`000000oooo0?ooo`230?ooo`030000003oool0oooo02`0oooo000]0?ooo`030000003oool0oooo
08<0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0/0?ooo`00;@3oool00`000000
oooo0?ooo`230?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0;03oool002`0oooo
00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo02`0oooo
000/0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?oo
o`0[0?ooo`00:`3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0Q@3oool2000008H0oooo00<000000?oo
o`3oool0:P3oool002/0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`250?ooo`03
0000003oool0oooo02X0oooo000Z0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
Q@3oool00`000000oooo0?ooo`0Z0?ooo`00:P3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0:@3oool002X0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo02T0oooo000Y0?ooo`030000003oool0oooo
08L0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0Y0?ooo`00:@3oool00`000000
oooo0?ooo`270?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0:03oool002T0oooo
00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo02P0oooo
000Y0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?oo
o`0X0?ooo`00:@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo08L0oooo00<00000
0?ooo`3oool0:03oool002T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`270?oo
o`030000003oool0oooo02P0oooo000X0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool0R03oool00`000000oooo0?ooo`0W0?ooo`00:03oool00`000000oooo0?ooo`280?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool09`3oool002P0oooo00<000000?ooo`3oool0R03o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo02L0oooo000W0?ooo`030000003oool0
oooo08T0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0W0?ooo`009`3oool00`00
0000oooo0?ooo`290?ooo`800000RP3oool00`000000oooo0?ooo`0V0?ooo`009`3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool09P3oool002L0oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo02H0oooo
000W0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?oo
o`0V0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo08T0oooo00<00000
0?ooo`3oool09P3oool002H0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`2:0?oo
o`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000
003oool0oooo08X0oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool0RP3o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0
oooo08X0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`00
0000oooo0?ooo`2:0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool09@3oool002D0
oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02D0
oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo08/0oooo00<0
00000?ooo`3oool0903oool002D0oooo00D000000?ooo`3ooml0W4Qd0;ooo`0o0?ooo`0:0;md0000
0000001809cOo`3oool0oono07A8W03Oool0oooo0;md0080000000<0B9cO0?ooo`3oool0>`3oool2
000003l0oooo00X0_g@00000000004P0W=oo0?ooo`3ookl0M4RL0=ooo`3oool0_g@00P0000000`18
W=l0oooo0?ooo`0n0?ooo`030000002LB7@0_ooo02@0oooo000U0?ooo`050000003oool0oooO09a8
M02oool0?P3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00H0okmd04RLg`3oool0oooo
0=nLB01d_oll0?ooo`030000003oool0oooo03d0oooo00H0okmd0018W03Oool0okmd0018W03Oool3
0?ooo`060?noM018W=l0oooo0?ooo`3OW4P0M;oo?`3oool00`000000W4Qd0;ooo`0T0?ooo`007P3o
ool00`3o_g@0000000000002000000070018W03Oool000000?ooo`3ooml0W4Qd0;ooo`0g0?ooo`03
0?noM000000000000080000000P004RL0=ooo`3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`L0oooo00<0
okmd04RLg`3oool0>`3oool00`000000oooo0?ooo`0m0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0
_ooo1`3oool00`3o_g@0B9cO0?ooo`0n0?ooo`030000002LB7@0_ooo02@0oooo000U0?ooo`050000
003oool0oooO09a8M02oool0?P3oool01P3OW4P0M;oo0?ooo`3ooml0W4Qd0;ooo`<0oooo00H0okmd
0000M02oool0oooo0=nLB01d_oll0?ooo`030000003oool0oooo03d0oooo00H0gia807Boo`3oool0
oooO09a8M02oool30?ooo`060?noM00007@0_ooo0?ooo`3OW4P0M;oo?`3oool00`000000W4Qd0;oo
o`0T0?ooo`009@3oool01@000000W9bo0?oog`2LB7@0_ooo03h0oooo00H0gia804RLg`3oool0oono
07@0M02oool30?ooo`050?oo_`1dB4P0B00000000000M;l0?@3oool00`000000oooo0?ooo`0m0?oo
o`060=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q804P00000000007Bo03h0oooo
00D0oooO09bL_`000000W4Qd0;ooo`0T0?ooo`009@3oool01@000000okmd0000000007@0_ooo03h0
oooo00H0okmd0018W03Oool0okmd0018W03Oool30?ooo`030?oog`2LB4P0W=oo03l0oooo00<00000
0?ooo`3oool0?@3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00<0oooO09a8B02Lgol0
@@3oool0103o_g@000000000M02ooolT0?ooo`009@3oool01@000000oooo0?oo_`1d07@0_ooo03l0
oooo00@0_g@00000000004P0W=oo1@3oool01@2oM00000000000000004P0W=oo03`0oooo00<00000
0?ooo`3oool0?P3oool0102oM00000000000B02Lgol50?ooo`050;md0000000000000000B02Lgol0
?`3oool00`000000M01d0;ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003o
ool0oooo08/0oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0R`3oool0
0`000000oooo0?ooo`2;0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo
08/0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000
oooo0?ooo`2;0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0903oool002D0oooo
00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo02@0oooo
000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?oo
o`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo08/0oooo00<00000
0?ooo`3oool0903oool00?l00000J@00000000P0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo1P0000020?oo00040000003o000000000000
02L00?l0H`3oo`000`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01`3oool002D0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0g0?ooo`D0
00001`3oo`02000000<0o`000P00000U003o06<0ool000<000000?ooo`3oool0903oool002D0oooo
00<000000?ooo`3oool0N03oool6000000`0ool00`0000040?l000<000008P00o`1S0?oo00030000
003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo0780oooo1P00000A0?oo000400000000
o`000000000000L0o`000P00000P003o06<0ool000<000000?ooo`3oool0903oool002D0oooo00<0
00000?ooo`3oool0K@3oool5000001L0ool000@00000003o0000000000002@3o0002000001d00?l0
I03oo`000`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`1W0?ooo`H000006`3o
o`000`0000000?l0003o0002000000/0o`000`00000J003o06@0ool000<000000?ooo`3oool0903o
ool002D0oooo00<000000?ooo`3oool0HP3oool500000240ool000H00000003o0000o`000000003o
0000000=0?l0008000006000o`1T0?oo00030000003oool0oooo02@0oooo000U0?ooo`030000003o
ool0oooo05`0oooo1P00000U0?oo000700000000o`000?l0003o000000000?l00000000?0?l00080
00005P00o`1T0?oo00030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo05H0oooo
1P00000[0?oo000700000000o`000?l0003o000000000?l00000000A0?l000<000004`00o`1T0?oo
00030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo0540oooo1@00000`0?oo0003
00000000o`000?l000800?l000<00000003o00000000503o0002000001400?l0I03oo`000`000000
oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`1;0?ooo`H00000=@3oo`000`0000000?l0
003o0002003o000300000000o`00000001H0o`000P00000>003o06D0ool000<000000?ooo`3oool0
903oool002D0oooo00<000000?ooo`3oool0AP3oool5000003X0ool000<00000003o0000o`000`00
o`00100000000?l0003o0000000G0?l000<000002`00o`1U0?oo00030000003oool0oooo02@0oooo
000U0?ooo`030000003oool0oooo0400oooo1P00000o0?oo000300000000o`000?l000<00?l000@0
0000003o0000o`0000006P3o0002000000T00?l0I@3oo`000`000000oooo0?ooo`0T0?ooo`009@3o
ool00`000000oooo0?ooo`0j0?ooo`H00000A03oo`000`0000000?l0003o0004003o000400000000
o`000?l0000001`0o`000P000007003o06D0ool000<000000?ooo`3oool0903oool002D0oooo00<0
00000?ooo`3oool0=@3oool5000004X0ool000<00000003o0000o`001000o`00100000000?l0003o
0000000N0?l000<000001000o`1U0?oo00030000003oool0oooo02@0oooo000U0?ooo`030000003o
ool0oooo02l0oooo1P00001?0?oo000300000000o`000?l000@00?l000@00000003o0000o`000000
8@3o000200000003003o003oo`00ool006@0ool000<000000?ooo`3oool0903oool002D0oooo00<0
00000?ooo`3oool0:P3oool5000005@0ool000<00000003o0000o`001@00o`001@0000000?l0003o
0000o`0000000280o`000P00001T0?oo00030000003oool0oooo02D0oooo000V0?ooo`030000003o
ool0oooo02<0oooo1P00001I0?oo000300000000o`000?l000D00?l000D00000003o0000o`000?l0
0000000T0?l000<00000H@3oo`000`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?oo
o`0M0?ooo`H00000GP3oo`000`0000000?l0003o0006003o000500000000o`000?l0003o00000000
9`3o0002000005l0ool000<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool0603o
ool5000006@0ool000<00000003o0000o`001P00o`001@0000000?l0003o0000o`00000002T0o`00
0P00001M0?oo00030000003oool0oooo02D0oooo000V0?ooo`030000003oool0oooo0180oooo1P00
001X0?oo000300000000o`000?l000L00?l000<00000003o0000o`000P00o`000`000000o`000?l0
000X0?l000<00000FP3oo`000`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`0=
0?ooo`D00000KP3oo`000`0000000?l0003o0007003o000300000000o`000?l000800?l000<00000
0?l0003o0000:`3o0002000005P0ool000<000000?ooo`3oool09@3oool002H0oooo00<000000?oo
o`3oool01`3oool600000780ool000<00000003o0000o`002000o`000`0000000?l0003o0002003o
00030000003o0000o`0002`0o`0000<0ool0000000000000EP3oo`000`000000oooo0?ooo`0U0?oo
o`009P3oool010000000oooo0?ooo`3oool6000007P0ool000<00000003o0000o`002000o`000`00
00000?l0003o0002003o00030000003o0000o`0002`0o`000`3oo`0300000580ool000<000000?oo
o`3oool09P3oool002L0oooo0`00001m0?oo000300000000o`000?l000T00?l000<00000003o0000
o`000P00o`000`000000o`000?l0000[0?l000L0ool00P00001@0?oo00030000003oool0oooo02H0
oooo000W0?ooo`030000003oo`00ool007d0ool000<00000003o0000o`002@00o`000`0000000?l0
003o0003003o00030000003o0000o`0002X0o`002@3oo`02000004h0ool000<000000?ooo`3oool0
9P3oool002L0oooo00<000000?oo003oo`00O03oo`000`0000000?l0003o000:003o000300000000
o`000?l000<00?l000<000000?l0003o0000:@3o000<0?oo00<00000B`3oo`000`000000oooo0?oo
o`0V0?ooo`009`3oool00`000000ool00?oo001l0?oo000300000000o`000?l000X00?l000<00000
003o0000o`000`00o`000`000000o`000?l0000X0?l00100ool00P0000190?oo00030000003oool0
oooo02H0oooo000W0?ooo`030000003oo`00ool007`0ool000<00000003o0000o`002P00o`000`00
00000?l0003o0003003o00030000003o0000o`0002P0o`004P3oo`03000004D0ool000<000000?oo
o`3oool09`3oool002P0oooo00<000000?oo003oo`00NP3oo`000`0000000?l0003o000;003o0003
00000000o`000?l000<00?l000<000000?l0003o0000:03o000E0?oo00800000@`3oo`000`000000
oooo0?ooo`0W0?ooo`00:03oool00`000000ool00?oo001j0?oo000300000000o`000?l000/00?l0
00<00000003o0000o`001000o`000`000000o`000?l0000V0?l001P0ool00P0000110?oo00030000
003oool0oooo02L0oooo000X0?ooo`030000003oo`00ool007T0ool000<00000003o0000o`003000
o`000`0000000?l0003o0004003o00030000003o0000o`0002H0o`006P3oo`03000003h0ool000<0
00000?ooo`3oool09`3oool002P0oooo00<0ool00000003oo`00N@3oo`000`0000000?l0003o000<
003o000300000000o`000?l000@00?l000<000000?l0003o00009@3o000N0?oo00800000>`3oo`00
0`000000oooo0?ooo`0X0?ooo`00:@3oool00`000000ool00?oo001g0?oo000300000000o`000?l0
00d00?l000<00000003o0000o`001000o`000`000000o`000?l0000T0?l00240ool00P00000i0?oo
00030000003oool0oooo02P0oooo000Y0?ooo`030000003oo`00ool007L0ool000<00000003o0000
o`003@00o`000`0000000?l0003o0005003o00030000003o0000o`0002<0o`008`3oo`03000003H0
ool000<000000?ooo`3oool0:03oool002T0oooo00<000000?oo003oo`00MP3oo`000`0000000?l0
003o000>003o000300000000o`000?l000D00?l000<000000?l0003o00008P3o000W0?oo00800000
=03oo`000`000000oooo0?ooo`0X0?ooo`00:@3oool00`000000ool00?oo001f0?oo000300000000
o`000?l000h00?l000<00000003o0000o`001@00o`000`000000o`000?l0000Q0?l002X0ool00P00
000b0?oo00030000003oool0oooo02P0oooo000Y0?ooo`030000003oo`00ool007D0ool000<00000
003o0000o`003`00o`000`0000000?l0003o0005003o00030000003o0000o`000200o`00;@3oo`03
000002h0ool000<000000?ooo`3oool0:@3oool002X0oooo00<000000?oo003oo`00M03oo`000`00
00000?l0003o000?003o000300000000o`000?l000D00?l000<000000?l0003o00007P3o000b0?oo
00800000;03oo`000`000000oooo0?ooo`0Y0?ooo`00:P3oool00`000000ool00?oo001c0?oo0003
0000003oo`00ool001000?l000<00000003o0000o`001P00o`000`000000o`000?l0000M0?l003@0
ool00P00000Z0?oo00030000003oool0oooo02T0oooo000Z0?ooo`030000003oo`00ool007<0ool0
00<000000?oo003oo`000`3oo`0=003o000300000000o`000?l000H00?l000<000000?l0003o0000
703o000g0?oo00<000009P3oo`000`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000ool00?oo
001a0?oo00030000003oo`00ool000T0ool02000o`000`0000000?l0003o0005003o00030?oo0000
0000o`0001`0o`00>`3oo`02000002@0ool000<000000?ooo`3oool0:P3oool002/0oooo00<00000
0?oo003oo`00L@3oo`000`000000ool00?oo000>0?oo00<00?l000<00000003o0000o`001P3oo`00
0`000000o`000?l0000J0?l003h0ool00P00000R0?oo00030000003oool0oooo02X0oooo000[0?oo
o`030000003oo`00ool00740ool000<000000?oo003oo`004@3oo`000`000000ool00?oo00060?oo
00030000003o0000o`0001P0o`00@P3oo`03000001l0ool000<000000?ooo`3oool0:P3oool002`0
oooo00<000000?oo003oo`00K`3oo`000`000000ool00?oo000B0?oo00030000003oo`00ool000L0
ool000<000000?l0003o00005P3o00160?oo00800000703oo`000`000000oooo0?ooo`0[0?ooo`00
;03oool00`000000ool00?oo001_0?oo00030000003oo`00ool00180ool000<000000?oo003oo`00
1`3oo`000`000000o`000?l0000E0?l004T0ool00P00000I0?oo00030000003oool0oooo02`0oooo
000]0?ooo`030000003oo`00ool006d0ool000<000000?oo003oo`004`3oo`000`000000ool00?oo
00070?oo00030000003o0000o`0001@0o`00C03oo`03000001H0ool000<000000?ooo`3oool0;03o
ool002d0oooo00<000000?oo003oo`00K@3oo`000`000000ool00?oo000C0?oo00030000003oo`00
ool000L0ool000<000000?l0003o00004P3o001A0?oo00800000503oo`000`000000oooo0?ooo`0/
0?ooo`00;@3oool00`000000ool00?oo001/0?oo00030000003oo`00ool001@0ool000<000000?oo
003oo`00203oo`000`000000o`000?l0000@0?l005@0ool00P00000B0?oo00030000003oool0oooo
02`0oooo000^0?ooo`030000003oo`00ool006/0ool000<000000?oo003oo`00503oo`000`000000
ool00?oo00080?oo00030000003o0000o`0000h0o`00F03oo`03000000h0ool000<000000?ooo`3o
ool0;@3oool002h0oooo00<000000?oo003oo`00JP3oo`000`000000ool00?oo000E0?oo00030000
003oo`00ool000P0ool000<000000?l0003o00002`3o001N0?oo00800000303oo`000`000000oooo
0?ooo`0]0?ooo`00;P3oool00`000000ool00?oo001Z0?oo00030000003oo`00ool001D0ool000<0
00000?oo003oo`00203oo`000`000000o`000?l000090?l00680ool00P00000:0?oo00030000003o
ool0oooo02d0oooo000^0?ooo`030000003oo`00ool006T0ool000<000000?oo003oo`005P3oo`00
0`000000ool00?oo00080?oo00030000003o0000o`0000P0o`00I@3oo`03000000H0ool000<00000
0?ooo`3oool0;P3oool002l0oooo00<000000?oo003oo`00J03oo`000`000000ool00?oo000F0?oo
00030000003oo`00ool000T0ool000<000000?l0003o00000`3o001/0?oo008000000P3oo`030?l0
0300oooo000`0?ooo`030000003oo`00ool006H0ool000<000000?oo003oo`005`3oo`000`000000
ool00?oo00090?oo00030000003o0000o`000740ool000<000000?l0003o00000`3o000_0?ooo`00
<03oool00`000000ool00?oo001V0?oo00030000003oo`00ool001L0ool000<000000?oo003oo`00
2@3oo`000`000000ool00?oo001b0?oo00D0o`00;`3oool00300oooo00<000000?oo003oo`00I@3o
o`000`000000ool00?oo000H0?oo00030000003oo`00ool000T0ool000<000000?oo003oo`00LP3o
o`050?l002l0oooo000`0?ooo`030000003oo`00ool006D0ool000<000000?oo003oo`00603oo`00
0`000000ool00?oo000:0?oo00030000003oo`00ool00700ool00P0000030?l00300oooo000a0?oo
o`030000003oo`00ool006@0ool000<000000?oo003oo`00603oo`000`000000ool00?oo000:0?oo
00030000003oo`00ool006l0ool000@000000?oo003oo`000000<P3oool00380oooo00<000000?oo
003oo`00HP3oo`000`000000ool00?oo000I0?oo00030000003oo`00ool000X0ool000<000000?oo
003oo`00KP3oo`0010000000ool00?oo000000030?ooo`030?noM000M;l0oooo02d0oooo000b0?oo
o`030000003oo`00ool00680ool000<000000?oo003oo`006@3oo`000`000000ool00?oo000:0?oo
00030000003oo`00ool006d0ool000D000000?oo003oo`00000007@00003000000030000M02oool0
oooo02d0oooo000c0?ooo`030000003oo`00ool00600ool000<000000?oo003oo`006P3oo`000`00
0000ool00?oo000:0?oo00030000003oo`00ool006`0ool000/000000?oo003oo`00ool000000000
B9`0gooo0;md00000000001809cOo`0^0?ooo`00<`3oool00`000000ool00?oo001P0?oo00030000
003oo`00ool001X0ool000<000000?oo003oo`002`3oo`000`000000ool00?oo001Y0?oo00800000
0`3oo`00203o_`00000009cOo`3ogi`0B4RL0=oOW0180000B9cO;P3oool003<0oooo00<000000?oo
003oo`00G`3oo`000`000000ool00?oo000K0?oo00030000003oo`00ool000/0ool000<000000?oo
003oo`00J03oo`000`000000ool00?oo00030?oo00030000000007@0_ooo0080oooo00<0oono07@0
0018W=l0;P3oool003@0oooo00<000000?oo003oo`00GP3oo`000`000000ool00?oo000K0?oo0003
0000003oo`00ool000/0ool000<000000?oo003oo`00I`3oo`000`000000ool00?oo00040?oo0003
0000000007@0_ooo0080oooo00<0oono07@00018W=l0;P3oool003@0oooo00<000000?oo003oo`00
G@3oo`000`000000ool00?oo000L0?oo00030000003oo`00ool000/0ool000<000000?oo003oo`00
IP3oo`000`000000ool00?oo00040?oo00040000003o_g@0001809cOo`80oooo00<0omnL04P0001d
_ol0;P3oool003D0oooo00<000000?oo003oo`00G03oo`000`000000ool00?oo000L0?oo00030000
003oo`00ool000/0ool000<000000?oo003oo`00I@3oo`000`000000ool00?oo00050?oo00090000
003ookl0M0000018W03Oool0oooo0;md0000B9`0gooo02h0oooo000f0?ooo`030000003oo`00ool0
05X0ool000<000000?oo003oo`007@3oo`000`000000ool00?oo000<0?oo00030000003oo`00ool0
0680ool00P0000070?oo00050000003oool0oooo0?oo_`1d00000P0000000`00B9`0gooo0?ooo`0^
0?ooo`00=P3oool00`000000ool00?oo001J0?oo00030000003oo`00ool001d0ool000<000000?oo
003oo`00303oo`000`000000ool00?oo001Q0?oo00030000003oo`00ool000H0ool000<000000?oo
o`3oool0=P3oool003L0oooo00<000000?oo003oo`00F03oo`000`000000ool00?oo000N0?oo0003
0000003oo`00ool000`0ool000<000000?oo003oo`00H03oo`000`000000ool00?oo00070?oo0003
0000003oool0oooo03H0oooo000h0?ooo`030000003oo`00ool005L0ool000<000000?oo003oo`00
7P3oo`000`000000ool00?oo000<0?oo00030000003oo`00ool005l0ool000<000000?oo003oo`00
1`3oo`000`000000oooo0?ooo`0g0?ooo`00>03oool00`000000ool00?oo001G0?oo00030000003o
o`00ool001h0ool000<000000?oo003oo`003@3oo`000`000000ool00?oo001L0?oo008000002@3o
o`000`000000oooo0?ooo`0h0?ooo`00>@3oool00`000000ool00?oo001E0?oo00030000003oo`00
ool001l0ool000<000000?oo003oo`003@3oo`000`000000ool00?oo001K0?oo00030000003oo`00
ool000T0ool000<000000?ooo`3oool0>03oool003T0oooo00<000000?oo003oo`00E@3oo`000`00
0000ool00?oo000O0?oo00030000003oo`00ool000d0ool000<000000?oo003oo`00FP3oo`000`00
0000ool00?oo000:0?oo00030000003oool0oooo03P0oooo000j0?ooo`030000003oo`00ool005<0
ool000<000000?oo003oo`00803oo`000`000000ool00?oo000=0?oo00030000003oo`00ool005T0
ool000<000000?oo003oo`002P3oo`000`000000oooo0?ooo`0i0?ooo`00>P3oool00`000000ool0
0?oo001C0?oo00030000003oo`00ool00200ool000<000000?oo003oo`003@3oo`000`000000ool0
0?oo001H0?oo00030000003oo`00ool000/0ool000<000000?ooo`3oool0>@3oool003/0oooo00<0
00000?oo003oo`00D@3oo`000`000000ool00?oo000Q0?oo00030000003oo`00ool000h0ool000<0
00000?oo003oo`00E@3oo`02000000d0ool000<000000?ooo`3oool0>P3oool003`0oooo00<00000
0?oo003oo`00D03oo`000`000000ool00?oo000Q0?oo00030000003oo`00ool000h0ool000<00000
0?oo003oo`00E03oo`000`000000ool00?oo000<0?oo00030000003oool0oooo03/0oooo000l0?oo
o`030000003oo`00ool004l0ool000<000000?oo003oo`008P3oo`000`000000ool00?oo000>0?oo
00030000003oo`00ool005<0ool000<000000?oo003oo`003@3oo`000`000000oooo0?ooo`0k0?oo
o`00?@3oool00`000000ool00?oo001>0?oo00030000003oo`00ool00280ool000<000000?oo003o
o`003P3oo`000`000000ool00?oo001B0?oo00030000003oo`00ool000d0ool000<000000?ooo`3o
ool0?03oool003h0oooo00<000000?oo003oo`00C03oo`000`000000ool00?oo000S0?oo00030000
003oo`00ool000h0ool000<000000?oo003oo`00D03oo`02000000l0ool000<000000?ooo`3oool0
?@3oool003h0oooo00<000000?oo003oo`00C03oo`000`000000ool00?oo000S0?oo00030000003o
o`00ool000l0ool000<000000?oo003oo`00CP3oo`000`000000ool00?oo000>0?oo00030?ooo`00
0000oooo03h0oooo000o0?ooo`030000003oo`00ool004X0ool000<000000?oo003oo`00903oo`00
0`000000ool00?oo000?0?oo00030000003oo`00ool004d0ool000<000000?oo003oo`003P3oo`00
0`3oool000000?ooo`0o0?ooo`00@03oool00`000000ool00?oo00190?oo00030000003oo`00ool0
02@0ool000<000000?oo003oo`003`3oo`000`000000ool00?oo001<0?oo00030000003oo`00ool0
00l0ool000<000000?ooo`3oool0?`3oool00400oooo00<000000?oo003oo`00B03oo`000`000000
ool00?oo000U0?oo00030000003oo`00ool000l0ool000<000000?oo003oo`00B`3oo`000`000000
ool00?oo000?0?oo00030?ooo`000000oooo0400oooo00110?ooo`030000003oo`00ool004L0ool0
00<000000?oo003oo`009@3oo`000`000000ool00?oo000@0?oo00030000003oo`00ool004P0ool0
0P00000A0?oo00030?ooo`000000oooo0440oooo00120?ooo`030000003oo`00ool004H0ool000<0
00000?oo003oo`009@3oo`000`000000ool00?oo000@0?oo00030000003oo`00ool004L0ool000<0
00000?oo003oo`004@3oo`000`000000oooo0?ooo`110?ooo`00@`3oool00`000000ool00?oo0014
0?oo00030000003oo`00ool002H0ool000<000000?oo003oo`00403oo`000`000000ool00?oo0016
0?oo00030000003oo`00ool00140ool000<000000?ooo`3oool0@P3oool004@0oooo00<000000?oo
003oo`00@`3oo`000`000000ool00?oo000V0?oo00030000003oo`00ool00100ool000<000000?oo
003oo`00A@3oo`000`000000ool00?oo000A0?oo00030000003oool0oooo04<0oooo00150?ooo`03
0000003oo`00ool00440ool000<000000?oo003oo`009`3oo`000`000000ool00?oo000@0?oo0003
0000003oo`00ool004@0ool000<000000?oo003oo`004@3oo`000`000000oooo0?ooo`140?ooo`00
A@3oool00`000000ool00?oo00110?oo00030000003oo`00ool002L0ool000<000000?oo003oo`00
4@3oo`000`000000ool00?oo00110?oo008000004`3oo`000`3oool000000?ooo`150?ooo`00AP3o
ool00`000000ool00?oo000o0?oo00030000003oo`00ool002P0ool000<000000?oo003oo`004@3o
o`000`000000ool00?oo00100?oo00030000003oo`00ool001<0ool000<000000?ooo`3oool0A@3o
ool004L0oooo00<000000?oo003oo`00?P3oo`000`000000ool00?oo000X0?oo00030000003oo`00
ool00140ool000<000000?oo003oo`00?`3oo`000`000000ool00?oo000C0?oo00030000003oool0
oooo04H0oooo00180?ooo`030000003oo`00ool003`0ool000<000000?oo003oo`00:@3oo`000`00
0000ool00?oo000A0?oo00030000003oo`00ool003h0ool000<000000?oo003oo`004`3oo`000`00
0000oooo0?ooo`170?ooo`00B@3oool00`000000ool00?oo000k0?oo00030000003oo`00ool002T0
ool000<000000?oo003oo`004P3oo`000`000000ool00?oo000k0?oo008000005@3oo`000`000000
oooo0?ooo`180?ooo`00BP3oool00`000000ool00?oo000i0?oo00030000003oo`00ool002X0ool0
00<000000?oo003oo`004P3oo`000`000000ool00?oo000j0?oo00030000003oo`00ool001@0ool0
00<000000?ooo`3oool0B@3oool004/0oooo00<000000?oo003oo`00>03oo`000`000000ool00?oo
000Z0?oo00030000003oo`00ool00180ool000<000000?oo003oo`00>@3oo`000`000000ool00?oo
000D0?oo00030000003oool0oooo04X0oooo001;0?ooo`030?oo00000000ool003L0ool000<00000
0?oo003oo`00:`3oo`000`000000ool00?oo000B0?oo00030000003oo`00ool003P0ool000<00000
0?oo003oo`00503oo`000`000000oooo0?ooo`1;0?ooo`00C03oool00`3oo`0000000?oo000f0?oo
00030000003oo`00ool002/0ool000<000000?oo003oo`004P3oo`000`000000ool00?oo000g0?oo
00030000003oo`00ool001@0ool000<000000?ooo`3oool0C03oool004d0oooo00<0ool00000003o
o`00=03oo`000`000000ool00?oo000/0?oo00030000003oo`00ool001<0ool000<000000?oo003o
o`00=03oo`02000001H0ool000<000000?ooo`3oool0C@3oool004l0oooo00<000000?oo003oo`00
<P3oo`000`000000ool00?oo000/0?oo00030000003oo`00ool001<0ool000<000000?oo003oo`00
<`3oo`000`000000ool00?oo000E0?oo00030000003oool0oooo04h0oooo001@0?ooo`030000003o
o`00ool00340ool000<000000?oo003oo`00;03oo`000`000000ool00?oo000C0?oo00030000003o
o`00ool00380ool000<000000?oo003oo`005@3oo`000`000000oooo0?ooo`1?0?ooo`00D@3oool0
0`000000ool00?oo000_0?oo00030000003oo`00ool002d0ool000<000000?oo003oo`004`3oo`00
0`000000ool00?oo000a0?oo00030000003oo`00ool001D0ool000<000000?ooo`3oool0D03oool0
0580oooo00<000000?oo003oo`00;P3oo`000`000000ool00?oo000]0?oo00030000003oo`00ool0
01<0ool000<000000?oo003oo`00;`3oo`02000001L0ool000<000000?ooo`3oool0D@3oool00580
oooo00<0ool00000003oo`00;@3oo`000`000000ool00?oo000^0?oo00030000003oo`00ool001@0
ool000<000000?oo003oo`00;@3oo`000`000000ool00?oo000F0?oo00030000003oool0oooo0580
oooo001D0?ooo`030000003oo`00ool002/0ool000<000000?oo003oo`00;P3oo`000`000000ool0
0?oo000D0?oo00030000003oo`00ool002`0ool000<000000?oo003oo`005P3oo`000`000000oooo
0?ooo`1C0?ooo`00E@3oool00`000000ool00?oo000Y0?oo00030000003oo`00ool002l0ool000<0
00000?oo003oo`00503oo`000`000000ool00?oo000[0?oo00030000003oo`00ool001H0ool000<0
00000?ooo`3oool0E03oool005H0oooo00<000000?oo003oo`00:03oo`000`000000ool00?oo000_
0?oo00030000003oo`00ool001@0ool000<000000?oo003oo`00:P3oo`000`000000ool00?oo000F
0?oo00030000003oool0oooo05D0oooo001G0?ooo`030000003oo`00ool002H0ool000<000000?oo
003oo`00<03oo`000`000000ool00?oo000E0?oo00030000003oo`00ool002L0ool00P00000H0?oo
00030000003oool0oooo05H0oooo001H0?ooo`8000009P3oo`000`000000ool00?oo000`0?oo0003
0000003oo`00ool001D0ool000<000000?oo003oo`009P3oo`000`000000ool00?oo000F0?oo0080
0000F@3oool005X0oooo00<000000?oo003oo`008P3oo`000`000000ool00?oo000a0?oo00030000
003oo`00ool001D0ool000<000000?oo003oo`009@3oo`000`000000ool00?oo000F0?oo00030000
003oool0oooo05T0oooo001K0?ooo`030000003oo`00ool00240ool000<000000?oo003oo`00<@3o
o`000`000000ool00?oo000E0?oo00030000003oo`00ool002@0ool000<000000?oo003oo`005P3o
o`000`000000oooo0?ooo`1J0?ooo`00G03oool00`000000ool00?oo000O0?oo00030000003oo`00
ool00380ool000<000000?oo003oo`005@3oo`000`000000ool00?oo000S0?oo00030000003oo`00
ool001H0ool000<000000?ooo`3oool0F`3oool005d0oooo00<000000?oo003oo`007P3oo`000`00
0000ool00?oo000b0?oo00030000003oo`00ool001H0ool000<000000?oo003oo`00803oo`020000
01L0ool000<0oooo0000003oool0G@3oool005h0oooo0P00000N0?oo00030000003oo`00ool00380
ool000<000000?oo003oo`005P3oo`000`000000ool00?oo000O0?oo00030000003oo`00ool001H0
ool00P00001O0?ooo`00H03oool00`000000ool00?oo000J0?oo00030000003oo`00ool003<0ool0
00<000000?oo003oo`005P3oo`000`000000ool00?oo000N0?oo00030000003oo`00ool001H0ool0
00<000000?ooo`3oool0G`3oool00640oooo0P00000J0?oo00030000003oo`00ool003<0ool000<0
00000?oo003oo`005P3oo`000`000000ool00?oo000M0?oo00030000003oo`00ool001D0ool00P00
001R0?ooo`00H`3oool00`000000ool00?oo000F0?oo00030000003oo`00ool003@0ool000<00000
0?oo003oo`005P3oo`000`000000ool00?oo000K0?oo008000005`3oo`000`000000oooo0?ooo`1R
0?ooo`00I03oool2000001H0ool000<000000?oo003oo`00=03oo`000`000000ool00?oo000G0?oo
00030000003oo`00ool001T0ool000<000000?oo003oo`005@3oo`02000006D0oooo001V0?ooo`03
0000003oo`00ool00180ool000<000000?oo003oo`00=@3oo`000`000000ool00?oo000G0?oo0003
0000003oo`00ool001P0ool000<000000?oo003oo`005@3oo`000`000000oooo0?ooo`1U0?ooo`00
I`3oool200000180ool000<000000?oo003oo`00=@3oo`000`000000ool00?oo000G0?oo00030000
003oo`00ool001L0ool000<000000?oo003oo`00503oo`02000006P0oooo001Y0?ooo`8000003`3o
o`000`000000ool00?oo000f0?oo00030000003oo`00ool001L0ool000<000000?oo003oo`005P3o
o`000`000000ool00?oo000C0?oo00800000JP3oool006/0oooo0P00000=0?oo00030000003oo`00
ool003H0ool000<000000?oo003oo`00603oo`000`000000ool00?oo000C0?oo00800000503oo`02
000006`0oooo001]0?ooo`030000003oo`00ool000T0ool000<000000?oo003oo`00=`3oo`000`00
0000ool00?oo000H0?oo00030000003oo`00ool00180ool000<000000?oo003oo`004`3oo`000`00
0000oooo0?ooo`1/0?ooo`00KP3oool2000000T0ool000<000000?oo003oo`00=`3oo`000`000000
ool00?oo000H0?oo00030000003oo`00ool00140ool000<000000?oo003oo`004P3oo`02000006l0
oooo001`0?ooo`030000003oo`00ool000D0ool000<000000?oo003oo`00>03oo`000`000000ool0
0?oo000H0?oo00030000003oo`00ool00100ool000<000000?oo003oo`004@3oo`000`3oool00000
0?ooo`1`0?ooo`00L@3oool2000000D0ool000<000000?oo003oo`00>03oo`000`000000ool00?oo
000H0?oo00030000003oo`00ool000h0ool00P00000C0?oo00800000LP3oool007<0oooo0`000000
0`3oo`0000000?oo000j0?oo00030000003oo`00ool001T0ool000<000000?oo003oo`00303oo`00
0`000000ool00?oo000@0?oo00<00000M03oool007H0oooo0P00000k0?oo00030000003oo`00ool0
01T0ool000<000000?oo003oo`002`3oo`000`000000ool00?oo000?0?oo00800000M`3oool007P0
oooo00<000000?oo003oo`00>03oo`000`000000ool00?oo000I0?oo00030000003oo`00ool000X0
ool000<000000?oo003oo`003`3oo`000`000000oooo0?ooo`1g0?ooo`00N@3oool4000003H0ool0
00<000000?oo003oo`006@3oo`000`000000ool00?oo00090?oo00030000003oo`00ool000`0ool0
1000001j0?ooo`00O@3oool00`000000ool00?oo000c0?oo00030000003oo`00ool001T0ool000<0
00000?oo003oo`001`3oo`02000000h0ool000<000000?ooo`3oool0O03oool007h0oooo1000000a
0?oo00030000003oo`00ool001X0ool000<000000?oo003oo`001@3oo`000`000000ool00?oo000:
0?oo00@00000O`3oool00880oooo0`00000^0?oo00030000003oo`00ool001X0ool000<000000?oo
003oo`00103oo`000`000000ool00?oo00080?oo00<00000P`3oool008D0oooo0P00000/0?oo0003
0000003oo`00ool001X0ool000<000000?oo003oo`000`3oo`000`000000ool00?oo00070?oo0080
0000QP3oool008L0oooo0`00000Y0?oo00030000003oo`00ool001X0ool000<000000?oo003oo`00
0P3oo`000`000000ool00?oo00050?oo00<00000R03oool008X0oooo0`00000V0?oo00030000003o
o`00ool001X0ool00`3o0002000000D0ool00`00002;0?ooo`00S@3oool600000200ool000<00000
0?oo003oo`006@3oo`050?l000H00000SP3oool009<0oooo0`00000M0?oo00030000003oo`00ool0
01T0ool01@3o002D0?ooo`00UP3oool5000001P0ool000<000000?oo003oo`005P3oo`03000000D0
o`00U03oool009/0oooo1`00000A0?oo00030000003oo`00ool000l0ool01`0000040?ooo`<0o`00
U@3oool00:80oooo8`00002S0?ooo`00Z03oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0
oooo0;80oooo002V0?ooo`050?oog`2LW;l0oooO09a8M02oool0203oool00`000000oooo0?ooo`0G
0?ooo`030?oo_`1d0000B9cO09P0oooo002W0?ooo`040?noM0000000001d0;ooo`P0oooo00<00000
0?ooo`3oool05`3oool00`3ookl0M00004RLg`2H0?ooo`00Z03oool00`3ookl0M01d0;ooo`080?oo
o`030000003oool0oooo01L0oooo00<0oono07@00018W=l0V03oool00;<0oooo00<000000?ooo`3o
ool05`3oool00`3ookl0M0000000000200000003001d_`3oool0oooo09<0oooo002c0?ooo`030000
003oool0oooo01L0oooo00L0oono07@00018W=l0oooo0?oOW0180000B9cO09@0oooo002c0?ooo`03
0000003oool0oooo01L0oooo00L0oono07@00018W=l0oooo0?oo_`1d000007Bo09@0oooo002c0?oo
o`030000003oool0oooo01L0oooo00L0oono07@00018W=l0oooo0?oOW0180000B9cO09@0oooo002c
0?ooo`030000003oool0oooo01L0oooo00<0oono07@0000000000P0000000`00B9`0gooo0?ooo`2C
0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00
/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool200000;<0oooo002c0?ooo`030000003oool0oooo0;80
oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c
0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`03
0000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003o
ool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo
0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?oo
o`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0
/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo
00<000000?ooo`3oool0/P3oool00001\
\>"],
  ImageRangeCache->{{{105.25, 363.438}, {345.813, 87.625}} -> {-2.2873, \
-0.404754, 0.00878441, 0.00878441}}],

Cell[TextData[{
  "Appare evidente come in tale rotazione il punto ",
  Cell[BoxData[
      \(TraditionalForm\`Q\)]],
  ", alla fine, vada a coincidere con il punto ",
  Cell[BoxData[
      \(TraditionalForm\`A(1, 0)\)]],
  " di ",
  ButtonBox["fig. 8",
    ButtonData:>"figura8",
    ButtonStyle->"Hyperlink"],
  " mentre il punto ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " a sua volta ha per immagine finale il punto ",
  Cell[BoxData[
      \(TraditionalForm\`D(cos(\[Alpha] - \[Beta]), 
        sen(\[Alpha] - \[Beta]))\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(pA = {1, 0};\)\), "\[IndentingNewLine]", 
    \(\(pD = {Cos[\[Alpha] - \[Beta]], 
          Sin[\[Alpha] - \[Beta]]};\)\)}], "Input"],

Cell[TextData[{
  "In particolare, essendo le rotazioni delle isometrie, la lunghezza della \
corda ",
  Cell[BoxData[
      FormBox[
        StyleBox["PQ",
          FontSlant->"Italic"], TraditionalForm]]],
  " rimane invariata cosicch\[EAcute] possiamo porre in relazione la \
lunghezza del segmento originario ",
  Cell[BoxData[
      FormBox[
        StyleBox["PQ",
          FontSlant->"Italic"], TraditionalForm]]],
  " con quella della sua immagine ",
  Cell[BoxData[
      FormBox[
        StyleBox["DA",
          FontSlant->"Italic"], TraditionalForm]]],
  ": queste lunghezze sono uguali per cui vale ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(PQ = DA\),
          FontSlant->"Italic"], TraditionalForm]]],
  " oppure, elevando al quadrato"
}], "Text"],

Cell[BoxData[
    \(PQ\^2 = \(\(DA\^2\)\(.\)\)\)], "DisplayFormula",
  CellTags->"relazione1"]
}, Closed]],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[
    \(Show[
      Graphics[{Circle[{0, 0}, 1], Line[{{\(-1.2\), 0}, {1.2, 0}}], 
          Line[{pP, {0, 0}, pQ, pP}], Line[{{0, 0}, pD}], 
          Line[{{0, \(-1.2\)}, {0, 1.2}}], Line[{pD, {1, 0}}], 
          Line[{{0, \(-1.2\)}, {0, 
                1.2}}]}], \[IndentingNewLine]Graphics[{Text["\<D\>", 
            pD, {0, \(-1\)}, TextStyle \[Rule] stileTesto], 
          Text["\<A\>", pA + {0, \(-0.04\)}, {\(-1\), 0}, 
            TextStyle \[Rule] stileTesto]}], 
      Graphics[{Text["\<P\>", pP, {1, 0}, TextStyle \[Rule] stileTesto], 
          Text["\<Q\>", pQ, {0, \(-1\)}, TextStyle \[Rule] stileTesto]}], 
      Graphics[{colBlu, Arrow[pP, pD, stileVet], Arrow[pQ, pA, stileVet]}], 
      Prolog -> {{RGBColor[1, \ 0.517647, \ 1], 
            Disk[{0, 0}, 1, {0, \[Alpha] - \[Beta]}]}}, 
      AspectRatio \[Rule] Automatic, Axes \[Rule] True]; 
    Clear[\[Alpha], \[Beta]];\)], "Input",
  CellTags->"figura2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Grafico", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.396825 0.5 0.396825 [
[.10317 .4875 -6.96875 -10.9375 ]
[.10317 .4875 6.96875 0 ]
[.30159 .4875 -10.3125 -10.9375 ]
[.30159 .4875 10.3125 0 ]
[.69841 .4875 -7.5625 -10.9375 ]
[.69841 .4875 7.5625 0 ]
[.89683 .4875 -4.21875 -10.9375 ]
[.89683 .4875 4.21875 0 ]
[.4875 .10317 -13.9375 -5.46875 ]
[.4875 .10317 0 5.46875 ]
[.4875 .30159 -20.625 -5.46875 ]
[.4875 .30159 0 5.46875 ]
[.4875 .69841 -15.125 -5.46875 ]
[.4875 .69841 0 5.46875 ]
[.4875 .89683 -8.4375 -5.46875 ]
[.4875 .89683 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .5 m
.10317 .50625 L
s
gsave
.10317 .4875 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.30159 .5 m
.30159 .50625 L
s
gsave
.30159 .4875 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.69841 .5 m
.69841 .50625 L
s
gsave
.69841 .4875 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.89683 .5 m
.89683 .50625 L
s
gsave
.89683 .4875 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.14286 .5 m
.14286 .50375 L
s
.18254 .5 m
.18254 .50375 L
s
.22222 .5 m
.22222 .50375 L
s
.2619 .5 m
.2619 .50375 L
s
.34127 .5 m
.34127 .50375 L
s
.38095 .5 m
.38095 .50375 L
s
.42063 .5 m
.42063 .50375 L
s
.46032 .5 m
.46032 .50375 L
s
.53968 .5 m
.53968 .50375 L
s
.57937 .5 m
.57937 .50375 L
s
.61905 .5 m
.61905 .50375 L
s
.65873 .5 m
.65873 .50375 L
s
.7381 .5 m
.7381 .50375 L
s
.77778 .5 m
.77778 .50375 L
s
.81746 .5 m
.81746 .50375 L
s
.85714 .5 m
.85714 .50375 L
s
.06349 .5 m
.06349 .50375 L
s
.02381 .5 m
.02381 .50375 L
s
.93651 .5 m
.93651 .50375 L
s
.97619 .5 m
.97619 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .10317 m
.50625 .10317 L
s
gsave
.4875 .10317 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .30159 m
.50625 .30159 L
s
gsave
.4875 .30159 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .69841 m
.50625 .69841 L
s
gsave
.4875 .69841 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .89683 m
.50625 .89683 L
s
gsave
.4875 .89683 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .14286 m
.50375 .14286 L
s
.5 .18254 m
.50375 .18254 L
s
.5 .22222 m
.50375 .22222 L
s
.5 .2619 m
.50375 .2619 L
s
.5 .34127 m
.50375 .34127 L
s
.5 .38095 m
.50375 .38095 L
s
.5 .42063 m
.50375 .42063 L
s
.5 .46032 m
.50375 .46032 L
s
.5 .53968 m
.50375 .53968 L
s
.5 .57937 m
.50375 .57937 L
s
.5 .61905 m
.50375 .61905 L
s
.5 .65873 m
.50375 .65873 L
s
.5 .7381 m
.50375 .7381 L
s
.5 .77778 m
.50375 .77778 L
s
.5 .81746 m
.50375 .81746 L
s
.5 .85714 m
.50375 .85714 L
s
.5 .06349 m
.50375 .06349 L
s
.5 .02381 m
.50375 .02381 L
s
.5 .93651 m
.50375 .93651 L
s
.5 .97619 m
.50375 .97619 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto fill
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto
-0.03 0.0075 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
1 .518 1 r
.5 .5 m
.5 .5 .39683 0 55 arc
F
0 g
.5 Mabswid
newpath
.5 .5 .39683 0 365.73 arc
s
.02381 .5 m
.97619 .5 L
s
.1092 .56891 m
.5 .5 L
.33229 .85965 L
.1092 .56891 L
s
.5 .5 m
.72761 .82506 L
s
.5 .02381 m
.5 .97619 L
s
.72761 .82506 m
.89683 .5 L
s
.5 .02381 m
.5 .97619 L
s
gsave
.72761 .82506 -66.2188 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
69.438 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.89683 .48413 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
69.375 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.1092 .56891 -71 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
69.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.33229 .85965 -66.4688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Q) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
.1092 .56891 m
.72761 .82506 L
s
% Start of user PostScript
-0.984808 0.173648 0.573576 0.819152 MAarrowhead1
% End of user PostScript
.33229 .85965 m
.89683 .5 L
s
% Start of user PostScript
-0.422618 0.906308 1. 0 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  Magnification->0.9,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?oo
o`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?oo
o`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3o
ool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo
0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?oo
o`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000
003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0
oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80
oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<00000
0?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3o
ool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0
oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<0
00000?ooo`3oool0/P3oool00:P0oooo00<0oooO09a8M02oool0203oool00`000000oooo0?ooo`2b
0?ooo`00Z03oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo0;80oooo002P0?ooo`03
0?noM000000000000080000000H004RL0=ooo`3oool0oooO09a8M02oool80?ooo`030000003oool0
oooo0;80oooo002S0?ooob400000Y03oool009`0oooo1`0000030?ooo`050?oog`2LW;l0oooO09a8
M02oool0203oool00`000000oooo0?ooo`0>0?ooo`L00000W@3oool009L0oooo1@00000;0?ooo`04
0?noM0000000001d0;ooo`P0oooo00<000000?ooo`3oool05@3oool5000009P0oooo002C0?ooo`@0
00004@3oool00`3ookl0M01d0;ooo`080?ooo`030000003oool0oooo01X0oooo1000002D0?ooo`00
SP3oool500000200oooo00<000000?ooo`3oool07P3oool5000008l0oooo002;0?ooo`<000009@3o
ool00`000000oooo0?ooo`0S0?ooo`<00000S03oool008L0oooo1000000X0?ooo`030000003oool0
oooo02H0oooo100000280?ooo`00QP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0Q@3oool00880oooo1000000]0?ooo`030000003oool0oooo02/0
oooo100000230?ooo`00O`3oool300000340oooo00<000000?ooo`3oool0;`3oool300000800oooo
001m0?ooo`800000=03oool00`000000oooo0?ooo`0b0?ooo`800000OP3oool007X0oooo0`00000f
0?ooo`030000003oool0oooo03@0oooo0`00001k0?ooo`00N03oool2000003T0oooo00<000000?oo
o`3oool0=`3oool2000007T0oooo001g0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`1f0?ooo`00M03oool3000003`0oooo0P00000k0?ooo`<00000
M@3oool00780oooo0P00000o0?ooo`030000003oool0oooo03d0oooo0P00001c0?ooo`00L03oool2
00000440oooo00<000000?ooo`3oool0?`3oool200000740oooo001_0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1^0?ooo`00K@3oool2000004@0
oooo00<000000?ooo`3oool0@P3oool2000006h0oooo001/0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1[0?ooo`00J@3oool3000004L0oooo00<0
00000?ooo`3oool0A@3oool3000006X0oooo001W0?ooo`800000BP3oool00`000000oooo0?ooo`18
0?ooo`800000J03oool006H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo06D0oooo001T0?ooo`800000C@3oool00`000000oooo0?ooo`1;0?ooo`80
0000I@3oool006<0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo0680oooo001Q0?ooo`800000D03oool00`000000oooo0?ooo`1>0?ooo`800000HP3o
ool00600oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo05l0oooo001N0?ooo`800000D`3oool00`000000oooo0?ooo`1A0?ooo`800000G`3oool005d0
oooo00<000000?ooo`3oool0D`3oool2000005@0oooo00<000000?ooo`3oool0G03oool005`0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05/0oooo
001K0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`1J0?ooo`00FP3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool0F@3oool005P0oooo0P00001I0?ooo`030000003oool0oooo05L0oooo0P00001I0?oo
o`00E`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0EP3oool005H0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo05D0oooo001E0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`1D0?ooo`00E03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo05`0oooo00<000000?ooo`3oool0D`3oool005<0oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`1M0?ooo`030000003oool0oooo0580oooo001B0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1A0?ooo`00D@3oool00`000000oooo
0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0D03oool00500oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo04l0oooo001?
0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1>
0?ooo`00CP3oool00`000000oooo0?ooo`1R0?ooo`800000H`3oool00`000000oooo0?ooo`1=0?oo
o`00C@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool0C03oool004`0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1T0?ooo`030000
003oool0oooo04/0oooo001;0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`1:0?ooo`00BP3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0
oooo06H0oooo00<000000?ooo`3oool0B@3oool004T0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`1W0?ooo`030000003oool0oooo04P0oooo00180?ooo`030000003oool0oooo06P0
oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`170?ooo`00A`3oool00`000000oooo
0?ooo`1Y0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0AP3oool004H0oooo00<0
00000?ooo`3oool0JP3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo04D0oooo0015
0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`14
0?ooo`00A@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0A03oool004@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo04<0oooo00130?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0
K@3oool00`000000oooo0?ooo`120?ooo`00@P3oool00`000000oooo0?ooo`1^0?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool0@@3oool00440oooo00<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0400oooo00100?ooo`030000003oool0oooo
0700oooo0P00001a0?ooo`030000003oool0oooo03l0oooo00100?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0o0?ooo`00?`3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0?P3oool003h0oooo00<0
00000?ooo`3oool0LP3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo03d0oooo000n
0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0m
0?ooo`00?@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool0?03oool003`0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo03/0oooo000l0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`0k0?ooo`00>`3oool00`000000oooo0?ooo`1e0?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool0>P3oool003X0oooo00<000000?ooo`3oool0MP3oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo03T0oooo000j0?ooo`030000003oool0oooo
07H0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0i0?ooo`00>@3oool00`000000
oooo0?ooo`1S0?ooo`0:0;md00000000001809cOo`3oool0oono07A8W03Oool0oooo0;md00800000
00<0B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo03P0oooo
000i0?ooo`030000003oool0oooo0680oooo00H0okmd0018W03Oool0okmd0018W03Oool30?ooo`06
0?noM018W=l0oooo0?ooo`3OW4P0M;oo1P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0
oooo03P0oooo000h0?ooo`030000003oool0oooo05`0oooo00<0okmd0000000000000P0000002000
B9`0gooo0=nLB018W=l0oooo0?oo_`1d07@0_ooo1`3oool00`3o_g@0B9cO0?ooo`050?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool0>03oool003P0oooo00<000000?ooo`3oool0H`3o
ool01P3OW4P0M;oo0?ooo`3ooml0W4Qd0;ooo`<0oooo00H0okmd0000M02oool0oooo0=nLB01d_ol6
0?ooo`<00000N03oool00`000000oooo0?ooo`0g0?ooo`00=`3oool00`000000oooo0?ooo`1T0?oo
o`060=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q804P00000000007Bo00L0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0f0?ooo`00=P3oool00`000000oooo0?oo
o`1U0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool00`3ooml0W4Q809cOo`090?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0
IP3oool0102oM00000000000B02Lgol50?ooo`050;md0000000000000000B02Lgol01P3oool00`00
0000oooo0?ooo`1j0?ooo`030000003oool0oooo03D0oooo000e0?ooo`030000003oool0oooo07/0
oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0d0?ooo`00=03oool00`000000oooo
0?ooo`1l0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0=03oool003@0oooo00<0
00000?ooo`3oool0O03oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03<0oooo000c
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0c
0?ooo`00<`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo07d0oooo00<000000?oo
o`3oool0<P3oool003<0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`1m0?ooo`03
0000003oool0oooo0380oooo000b0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0b0?ooo`00<P3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo07h0oooo00<000000?ooo`3oool0<@3oool00340oooo00<000000?ooo`3oool0O`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0300oooo000`0?ooo`030000003oool0oooo
0800oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0`0?ooo`00<03oool00`000000
oooo0?ooo`200?ooo`800000P@3oool00`000000oooo0?ooo`0_0?ooo`00<03oool00`000000oooo
0?ooo`200?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0;`3oool00300oooo00<0
00000?ooo`3oool0P03oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo02l0oooo000_
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0^
0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0840oooo00<000000?oo
o`3oool0;P3oool002h0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`220?ooo`03
0000003oool0oooo02d0oooo000^0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0
PP3oool00`000000oooo0?ooo`0]0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000003o
ool0oooo0880oooo00<000000?ooo`3oool0;@3oool002d0oooo00<000000?ooo`3oool0P`3oool0
0`000000oooo0?ooo`230?ooo`030000003oool0oooo02`0oooo000]0?ooo`030000003oool0oooo
08<0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0/0?ooo`00;@3oool00`000000
oooo0?ooo`230?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0;03oool002`0oooo
00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo02`0oooo
000/0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?oo
o`0[0?ooo`00:`3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0Q@3oool2000008H0oooo00<000000?oo
o`3oool0:P3oool002/0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`250?ooo`03
0000003oool0oooo02X0oooo000Z0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
Q@3oool00`000000oooo0?ooo`0Z0?ooo`00:P3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0:@3oool002X0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo02T0oooo000Y0?ooo`030000003oool0oooo
08L0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0Y0?ooo`00:@3oool00`000000
oooo0?ooo`270?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0:03oool002T0oooo
00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo02P0oooo
000Y0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?oo
o`0X0?ooo`00:@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo08L0oooo00<00000
0?ooo`3oool0:03oool002T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`270?oo
o`030000003oool0oooo02P0oooo000X0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool0R03oool00`000000oooo0?ooo`0W0?ooo`00:03oool00`000000oooo0?ooo`280?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool09`3oool002P0oooo00<000000?ooo`3oool0R03o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo02L0oooo000W0?ooo`030000003oool0
oooo08T0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0W0?ooo`009`3oool00`00
0000oooo0?ooo`290?ooo`800000RP3oool00`000000oooo0?ooo`0V0?ooo`009`3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool09P3oool002L0oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo02H0oooo
000W0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?oo
o`0V0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo08T0oooo00<00000
0?ooo`3oool09P3oool002H0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`2:0?oo
o`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000
003oool0oooo08X0oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool0RP3o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0
oooo08X0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`00
0000oooo0?ooo`2:0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool09@3oool002D0
oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02D0
oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo08/0oooo00<0
00000?ooo`3oool0903oool002D0oooo00D000000?ooo`3ooml0W4Qd0;ooo`0o0?ooo`0:0;md0000
0000001809cOo`3oool0oono07A8W03Oool0oooo0;md0080000000<0B9cO0?ooo`3oool0>`3oool2
000003l0oooo00X0_g@00000000004P0W=oo0?ooo`3ookl0M4RL0=ooo`3oool0_g@00P0000000`18
W=l0oooo0?ooo`0n0?ooo`030000002LB7@0_ooo02@0oooo000U0?ooo`050000003oool0oooO09a8
M02oool0?P3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00H0okmd04RLg`3oool0oooo
0=nLB01d_oll0?ooo`030000003oool0oooo03d0oooo00H0okmd0018W03Oool0okmd0018W03Oool3
0?ooo`060?noM018W=l0oooo0?ooo`3OW4P0M;oo?`3oool00`000000W4Qd0;ooo`0T0?ooo`007P3o
ool00`3o_g@0000000000002000000070018W03Oool000000?ooo`3ooml0W4Qd0;ooo`0g0?ooo`03
0?noM000000000000080000000P004RL0=ooo`3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`L0oooo00<0
okmd04RLg`3oool0>`3oool00`000000oooo0?ooo`0m0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0
_ooo1`3oool00`3o_g@0B9cO0?ooo`0n0?ooo`030000002LB7@0_ooo02@0oooo000U0?ooo`050000
003oool0oooO09a8M02oool0?P3oool01P3OW4P0M;oo0?ooo`3ooml0W4Qd0;ooo`<0oooo00H0okmd
0000M02oool0oooo0=nLB01d_oll0?ooo`030000003oool0oooo03d0oooo00H0gia807Boo`3oool0
oooO09a8M02oool30?ooo`060?noM00007@0_ooo0?ooo`3OW4P0M;oo?`3oool00`000000W4Qd0;oo
o`0T0?ooo`009@3oool01@000000W9bo0?oog`2LB7@0_ooo03h0oooo00H0gia804RLg`3oool0oono
07@0M02oool30?ooo`050?oo_`1dB4P0B00000000000M;l0?@3oool00`000000oooo0?ooo`0m0?oo
o`060=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q804P00000000007Bo03h0oooo
00D0oooO09bL_`000000W4Qd0;ooo`0T0?ooo`009@3oool01@000000okmd0000000007@0_ooo03h0
oooo00H0okmd0018W03Oool0okmd0018W03Oool30?ooo`030?oog`2LB4P0W=oo03l0oooo00<00000
0?ooo`3oool0?@3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00<0oooO09a8B02Lgol0
@@3oool01`3o_g@000000000M02ooml0W4P00018W03Oool00P3oool00`3o_g@0000004RLg`0L0?oo
o`009@3oool01@000000oooo0?oo_`1d07@0_ooo03l0oooo00@0_g@00000000004P0W=oo1@3oool0
1@2oM00000000000000004P0W=oo03`0oooo00<000000?ooo`3oool0?P3oool0102oM00000000000
B02Lgol50?ooo`050;md0000000000000000B02Lgol0?`3oool01P000000M01d0;ooo`3OW4P00018
09cOo`80oooo00<0_g@00000M02oool0703oool002D0oooo00<000000?ooo`3oool0R`3oool00`00
0000oooo0?ooo`2;0?ooo`050000003oool0oooo0?oo_`1d0000100000000`00M;l0oooo0?ooo`0K
0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo08/0oooo00X000000?oo
o`3oool0oooo0;md0000B9`0gooo0?oOW0180000M;oo7@3oool002D0oooo00<000000?ooo`3oool0
R`3oool00`000000oooo0?ooo`2;0?ooo`0:0000003oool0oooo0?ooo`3o_g@0001809cOo`3OW4P0
001d0;oooad0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0R`3oool0
2@000000oooo0?ooo`3oool0oono07@00018W;l0W4P004RLg`0N0?ooo`009@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool00P3oool0103OW4P004Q8
04P0B02LgolN0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo08/0oooo
00<000000?ooo`3oool00P3oool0103ogi`0B0000018W03OoolN0?ooo`009@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0903oool00?l00000@@00
00020000obH0000000080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`030?ooo`H000000P3oool2000008T0ohCo0`000?l00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool002D0oooo00<000000?oo
o`3oool0A03oool00`000000oooo0?ooo`0g0?ooo`D000001`3oool3000008H0ohCo1@000?l20000
02H0oooo000U0?ooo`030000003oool0oooo07P0oooo1P00000<0?ooo`80000000<0oooo0000003o
Q?l0PP3oQ?l60000o`030000003oQ?l0000002H0oooo000U0?ooo`030000003oool0oooo0780oooo
1P00000A0?ooo`030000003oool000000080oooo00<000000?n4o`3oQ?l0OP3oQ?l70000o`040?n4
o`000000ohCo000002H0oooo000U0?ooo`030000003oool0oooo06d0oooo1@00000G0?ooo`030000
003oool0000000<0oooo00<000000?n4o`3oQ?l0OP3oQ?l60000o`040000003oQ?l0ohCo000002H0
oooo000U0?ooo`030000003oool0oooo06L0oooo1P00000K0?ooo`040000003oool0oooo000000<0
oooo00<000000?n4o`3oQ?l0O@3oQ?l60000o`050?n4o`000000ohCo0?n4o`0000009P3oool002D0
oooo00<000000?ooo`3oool0HP3oool500000240oooo00@000000?ooo`3oool00000103oool00`00
0000ohCo0?n4o`1k0?n4o`040000o`3oQ?l0ohCo0?n4o`80003o00<0ohCo0000003oQ?l00P3oQ?l0
0`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`1L0?ooo`H000009@3oool01@00
0000oooo0?ooo`3oool0000000D0oooo00<000000?n4o`3oQ?l0N03oQ?l20000o`@0ohCo00@0003o
0?n4o`3oQ?l000000`3oQ?l00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`1F
0?ooo`H00000:`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?n4o`3oQ?l0M`3o
Q?l00`000?l0ohCo0?n4o`060?n4o`030000003oQ?l0ohCo0080ohCo00<000000?ooo`3oool0903o
ool002D0oooo00<000000?ooo`3oool0D@3oool500000300oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`030000003oQ?l0ohCo07@0ohCo0P000?l90?n4o`030000003oQ?l0
ohCo0080ohCo00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0B`3oool60000
03D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oQ?l0ohCo
0740ohCo0P000?l:0?n4o`030000003oQ?l0ohCo00<0ohCo00<000000?ooo`3oool0903oool002D0
oooo00<000000?ooo`3oool0AP3oool5000003X0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`050?ooo`030000003oQ?l0ohCo0700ohCo00<0003o0?n4o`3oQ?l02P3oQ?l00`000000
ohCo0?n4o`030?n4o`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo0400oooo
1P00000o0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000ohCo
0?n4o`1]0?n4o`80003o303oQ?l00`000000ohCo0?n4o`040?n4o`030000003oool0oooo02@0oooo
000U0?ooo`030000003oool0oooo03X0oooo1P0000140?ooo`030000003oool0oooo00@0oooo0P00
00080?ooo`030000003oQ?l0ohCo06/0ohCo00<0003o0?n4o`3oQ?l0303oQ?l00`000000ohCo0?n4
o`040?n4o`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo03D0oooo1@00001:
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000ohCo0?n4o`1X
0?n4o`80003o3P3oQ?l00`000000ohCo0?n4o`050?n4o`030000003oool0oooo02@0oooo000U0?oo
o`030000003oool0oooo02l0oooo1P00001?0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0203oool00`000000ohCo0?n4o`1W0?n4o`030000o`3oQ?l0ohCo00h0ohCo00<000000?n4
o`3oQ?l01@3oQ?l00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`0Z0?ooo`D0
0000E03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?n4o`3o
Q?l0I03oQ?l20000oa00ohCo00<000000?n4o`3oQ?l01@3oQ?l00`000000oooo0?ooo`0U0?ooo`00
9P3oool00`000000oooo0?ooo`0S0?ooo`H00000F@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00X0oooo00<000000?n4o`3oQ?l0HP3oQ?l00`000?l0ohCo0?n4o`0@0?n4o`030000
003oQ?l0ohCo00D0ohCo00<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool07@3o
ool6000005h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
Q?l0ohCo0600ohCo0P000?lB0?n4o`030000003oQ?l0ohCo00H0ohCo00<000000?ooo`3oool09@3o
ool002H0oooo00<000000?ooo`3oool0603oool5000006@0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oQ?l0ohCo05d0ohCo0P000?lD0?n4o`030000003oQ?l0
ohCo00H0ohCo00<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool04P3oool60000
06P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003oQ?l0ohCo
05/0ohCo00<0003o0?n4o`3oQ?l04`3oQ?l00`000000ohCo0?n4o`070?n4o`030000003oool0oooo
02D0oooo000M0?ooo`030?oo_`1d0000B9cO00H0oooo00<000000?ooo`3oool03@3oool5000006h0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003oQ?l0ohCo05T0
ohCo0P000?lF0?n4o`030000003oQ?l0ohCo00L0ohCo00<000000?ooo`3oool09@3oool001d0oooo
00<0oono07@00018W=l01P3oool00`000000oooo0?ooo`070?ooo`H00000LP3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?n4o`3oQ?l0E`3oQ?l00`000?l0ohCo
0?n4o`0E0?n4o`030000003oQ?l0ohCo00P0ohCo00<000000?ooo`3oool09@3oool001d0oooo00<0
oono07@00018W=l01P3oool010000000oooo0?ooo`3oool6000007P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0>0?ooo`030000003oQ?l0ohCo05@0ohCo0P000?lH0?n4o`030000
003oQ?l0ohCo00L0ohCo00<000000?ooo`3oool09P3oool001d0oooo00<0oono07@0000000000P00
00000`00M;l0oooo0?ooo`020?ooo`80003o00<000000?ooo`3oool0N`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00l0oooo00<000000?n4o`3oQ?l0DP3oQ?l00`000?l0ohCo0?n4
o`0G0?n4o`030000003oQ?l0ohCo00P0ohCo00<000000?ooo`3oool09P3oool001d0oooo00L0oono
07@00018W=l0oooo0?oOW0180000B9cO00<0oooo0P0000020000og`0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0?0?ooo`030000003oQ?l0ohCo0500ohCo0P000?lJ0?n4o`030000
003oQ?l0ohCo00P0ohCo00<000000?ooo`3oool09P3oool001d0oooo00L0oono07@00018W=l0oooo
0?oo_`1d000007Bo00<0oooo00@000000?ooo`000000oooo0`000?mh0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0403oool00`000000ohCo0?n4o`1=0?n4o`80003o6`3oQ?l00`00
0000ohCo0?n4o`090?n4o`030000003oool0oooo02H0oooo000M0?ooo`070?oo_`1d0000B9cO0?oo
o`3ogi`0B00004RLg`030?ooo`030000003oool0000000@0oooo0P000?mf0?ooo`030000003oool0
oooo00X0oooo0P00000B0?ooo`030000003oQ?l0ohCo04/0ohCo00<0003o0?n4o`3oQ?l06`3oQ?l0
0`000000ohCo0?n4o`090?n4o`030000003oool0oooo02H0oooo000M0?ooo`030?oo_`1d00000000
0080000000<004RL0=ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`80003oM03oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0140oooo00<000000?n4o`3oQ?l0B@3oQ?l2
0000oad0ohCo00<000000?n4o`3oQ?l02@3oQ?l00`000000oooo0?ooo`0W0?ooo`00:03oool01000
0000oooo0?ooo`0000060?ooo`<0003oL03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0180oooo00<000000?n4o`3oQ?l0A`3oQ?l00`000?l0ohCo0?n4o`0M0?n4o`030000003oQ?l0
ohCo00T0ohCo00<000000?ooo`3oool09`3oool002P0oooo00D000000?ooo`3oool0oooo00000008
0?ooo`80003oKP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01<0oooo00<00000
0?n4o`3oQ?l0A03oQ?l20000oal0ohCo00<000000?n4o`3oQ?l02P3oQ?l00`000000oooo0?ooo`0W
0?ooo`00:03oool01@000000oooo0?ooo`3oool0000000X0oooo0`000?mZ0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool04`3oool00`000000ohCo0?n4o`130?n4o`030000o`3oQ?l0
ohCo01l0ohCo00<000000?n4o`3oQ?l02P3oQ?l00`000000oooo0?ooo`0W0?ooo`00:@3oool01@00
0000oooo0?ooo`3oool0000000`0oooo0P000?mX0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0503oool00`000000ohCo0?n4o`100?n4o`80003o8@3oQ?l00`000000ohCo0?n4o`0:
0?n4o`030000003oool0oooo02P0oooo000Y0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02`3oool20000ofD0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oQ?l0ohCo03d0ohCo0P000?lS0?n4o`030000003oQ?l0ohCo00X0ohCo00<000000?oo
o`3oool0:03oool002T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`<0
003oHP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01H0oooo00<000000?n4o`3o
Q?l0>`3oQ?l00`000?l0ohCo0?n4o`0R0?n4o`030000003oQ?l0ohCo00/0ohCo00<000000?ooo`3o
ool0:03oool002T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`80003o
G`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01H0oooo00<000000?n4o`3oQ?l0
>@3oQ?l20000obD0ohCo00<000000?n4o`3oQ?l02`3oQ?l00`000000oooo0?ooo`0X0?ooo`00:@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0100oooo0`000?mL0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool05`3oool00`000000ohCo0?n4o`0g0?n4o`030000o`3o
Q?l0ohCo02@0ohCo00<000000?n4o`3oQ?l0303oQ?l00`000000oooo0?ooo`0X0?ooo`00:@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo0P000?mI0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0603oool00`000000ohCo0?n4o`0d0?n4o`80003o9`3oQ?l0
0`000000ohCo0?n4o`0;0?n4o`030000003oool0oooo02T0oooo000Z0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool04`3oool20000oeL0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oQ?l0ohCo03<0ohCo00<0003o0?n4o`3oQ?l09P3oQ?l00`00
0000ohCo0?n4o`0<0?n4o`030000003oool0oooo02T0oooo000Z0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0503oool30000oe<0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0I0?ooo`030000003oQ?l0ohCo0300ohCo0P000?lX0?n4o`030000003oQ?l0ohCo00d0
ohCo00<000000?ooo`3oool0:@3oool002X0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0G0?ooo`80003oD@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01X0oooo
00<000000?n4o`3oQ?l0;P3oQ?l00`000?l0ohCo0?n4o`0X0?n4o`030000003oQ?l0ohCo00`0ohCo
00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0H0?ooo`<0003oC@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01X0oooo00<0
00000?n4o`3oQ?l0;03oQ?l20000obX0ohCo00<000000?n4o`3oQ?l03@3oQ?l00`000000oooo0?oo
o`0Z0?ooo`00:`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo0P000?m;
0?ooo`030000003oool0oooo0140oooo0P00000L0?ooo`030000003oQ?l0ohCo02T0ohCo0P000?l/
0?n4o`030000003oQ?l0ohCo00d0ohCo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0K0?ooo`<0003oB03oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo01`0oooo00<000000?n4o`3oQ?l09`3oQ?l00`000?l0ohCo0?n4o`0[0?n4
o`030000003oQ?l0ohCo00d0ohCo00<0oooo0000003oool0:`3oool002`0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0N0?ooo`80003oA@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo01d0oooo00<000000?n4o`3oQ?l0903oQ?l20000obh0ohCo00<000000?n4o`3o
Q?l03@3oQ?l00`000000oooo0?ooo`0[0?ooo`00;03oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo01l0oooo0P000?m30?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
7@3oool00`000000ohCo0?n4o`0S0?n4o`030000o`3oQ?l0ohCo02d0ohCo00<000000?n4o`3oQ?l0
3@3oQ?l00`000000oooo0?ooo`0/0?ooo`00;@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0200oooo0`000?lo0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool07P3o
ool00`000000ohCo0?n4o`0P0?n4o`80003o<03oQ?l00`000000ohCo0?n4o`0=0?n4o`030000003o
ool0oooo02`0oooo000]0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool08P3oool2
0000ocd0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0O0?ooo`030000003oQ?l0
ohCo01h0ohCo00<0003o0?n4o`3oQ?l0;`3oQ?l00`000000ohCo0?n4o`0>0?n4o`030000003oool0
oooo02`0oooo000]0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0903oool30000
ocT0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0O0?ooo`030000003oQ?l0ohCo
01`0ohCo0P000?lb0?n4o`030000003oQ?l0ohCo00h0ohCo00<000000?ooo`3oool0;03oool002h0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0V0?ooo`80003o=`3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0200oooo00<000000?n4o`3oQ?l06@3oQ?l20000oc<0
ohCo00<000000?n4o`3oQ?l03P3oQ?l00`000000oooo0?ooo`0]0?ooo`00;P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo02L0oooo0P000?ld0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool08@3oool00`000000ohCo0?n4o`0G0?n4o`030000o`3oQ?l0ohCo03<0ohCo
00<000000?n4o`3oQ?l03P3oQ?l00`000000oooo0?ooo`0]0?ooo`00;P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo02P0oooo0`000?la0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool08@3oool00`000000ohCo0?n4o`0E0?n4o`80003o=@3oQ?l00`000000ohCo0?n4
o`0?0?n4o`030000003oool0oooo02d0oooo000^0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0:P3oool20000obh0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0R
0?ooo`030000003oQ?l0ohCo01<0ohCo00<0003o0?n4o`3oQ?l0=@3oQ?l00`000000ohCo0?n4o`0>
0?n4o`030000003oool0oooo02h0oooo000_0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0;03oool30000ob/0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0S0?oo
o`030000003oQ?l0ohCo0100ohCo0P000?lg0?n4o`030000003oQ?l0ohCo00l0ohCo00<000000?oo
o`3oool0;P3oool00300oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0^0?ooo`80
003o:03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02@0oooo00<000000?n4o`3o
Q?l03P3oQ?l00`000?l0ohCo0?n4o`0g0?n4o`030000003oQ?l0ohCo00h0ohCo00<000000?ooo`3o
ool0;`3oool00300oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0_0?ooo`<0003o
9@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02@0oooo00<000000?n4o`3oQ?l0
303oQ?l20000ocT0ohCo00<000000?n4o`3oQ?l03`3oQ?l00`000000oooo0?ooo`0_0?ooo`00<03o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0340oooo0P000?lR0?ooo`030000003o
ool0oooo01P0oooo0P00000V0?ooo`030000003oQ?l0ohCo00T0ohCo0P000?lk0?n4o`030000003o
Q?l0ohCo00l0ohCo00<000000?ooo`3oool0;`3oool00300oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0c0?ooo`80003o803oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo02H0oooo00<000000?n4o`3oQ?l01`3oQ?l00`000?l0ohCo0?n4o`0j0?n4o`030000003oQ?l0
ohCo00l0ohCo00<000000?ooo`3oool0<03oool00340oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0d0?ooo`<0003o7@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
02H0oooo00<000000?n4o`3oQ?l01@3oQ?l20000ocd0ohCo00<000000?n4o`3oQ?l03`3oQ?l00`00
0000oooo0?ooo`0`0?ooo`00<P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03H0
oooo0P000?lJ0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool09`3oool00`000000
ohCo0?n4o`030?n4o`030000o`3oQ?l0ohCo03`0ohCo00<000000?n4o`3oQ?l03`3oQ?l00`000000
oooo0?ooo`0a0?ooo`00<P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03L0oooo
0`000?lG0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0:03oool00`000000ohCo
0?n4o`020000ocl0ohCo00<000000?n4o`3oQ?l03P3oQ?l00`000000oooo0?ooo`0b0?ooo`00<`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03X0oooo0P000?lD0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0:03oool00`000000ohCo0000o`100?n4o`030000003o
Q?l0ohCo00l0ohCo00<000000?ooo`3oool0<P3oool003<0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0k0?ooo`80003o4P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo02P0oooo0P000?m10?n4o`030000003oQ?l0ohCo00l0ohCo00<000000?ooo`3oool0<P3oool0
03<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0l0?ooo`<0003o3P3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo02L0oooo00@0003o0?ooo`3oool00000?`3oQ?l0
0`000000ohCo0?n4o`0?0?n4o`030000003oool0oooo03<0oooo000d0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0?P3oool20000o``0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0U0?ooo`80003o103oool00`000000ohCo0?n4o`0l0?n4o`030000003oQ?l0ohCo
00l0ohCo00<000000?ooo`3oool0<`3oool003@0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0o0?ooo`<0003o203oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02<0
oooo0P000?l60?ooo`030000003oQ?l0ohCo03/0ohCo00<000000?n4o`3oQ?l03`3oQ?l00`000000
oooo0?ooo`0d0?ooo`00=@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0480oooo
0P000?l60?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool08P3oool00`000?l0oooo
0?ooo`070?ooo`030000003oQ?l0ohCo03X0ohCo00<000000?n4o`3oQ?l03`3oQ?l00`000000oooo
0?ooo`0d0?ooo`00=P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04<0oooo0P00
0?l30?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0803oool20000o`/0oooo00<0
00000?n4o`3oQ?l0>03oQ?l00`000000ohCo0?n4o`0?0?n4o`030000003oool0oooo03D0oooo000f
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0A03oool30000o`030000003oool0
oooo00T0oooo00X0_g@00000000004P0W=oo0?ooo`3ookl0M4RL0=ooo`3oool0_g@00P0000000`18
W=l0oooo0?ooo`050?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool02`3oool00`00
0000ohCo0?n4o`0h0?n4o`030000003oQ?l0ohCo00h0ohCo00<000000?ooo`3oool0=P3oool003L0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`150?ooo`03000000000?l0003o00T0
oooo00H0okmd0018W03Oool0okmd0018W03Oool30?ooo`060?noM018W=l0oooo0?ooo`3OW4P0M;oo
1P3oool00`000000oooo0?ooo`0M0?ooo`80003o3`3oool00`000000ohCo0?n4o`0f0?n4o`030000
003oQ?l0ohCo00l0ohCo00<000000?ooo`3oool0=P3oool003P0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00<0003o1P3oool01P3OW4P0B9cO0?oo
o`3ookl0M01d0;ooo`L0oooo00<0okmd04RLg`3oool01@3oool3000001`0oooo00<0003o0?ooo`3o
ool0403oool00`000000ohCo0?n4o`0e0?n4o`030000003oQ?l0ohCo00h0ohCo00<000000?ooo`3o
ool0=`3oool003P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo00<0oooo0P000?l40?ooo`060=nLB01d_ol0oooo0?oog`2LB7@0_ooo0`3oool01P3o
_g@0001d0;ooo`3oool0gia807Boo`H0oooo00<000000?ooo`3oool06P3oool20000oa<0oooo00<0
00000?n4o`3oQ?l0=03oQ?l00`000000ohCo0?n4o`0>0?n4o`030000003oool0oooo03P0oooo000i
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`06
0?ooo`<0003o00L0oooo0=nLB018W=l0oooo0?oo_`1d07@0_ooo00<0oooo00D0oono07A8B0180000
0000001d_`070?ooo`030000003oool0oooo01P0oooo0P000?lF0?ooo`030000003oQ?l0ohCo03<0
ohCo00<000000?n4o`3oQ?l03P3oQ?l00`000000oooo0?ooo`0h0?ooo`00>@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool02@3oool20000o`050018
W03Oool0okmd0018W03Oool00`3oool00`3ooml0W4Q809cOo`090?ooo`030000003oool0oooo01L0
oooo00<0003o0?ooo`3oool05`3oool00`000000ohCo0?n4o`0a0?n4o`030000003oQ?l0ohCo00l0
ohCo00<000000?ooo`3oool0>03oool003X0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo00`0oooo0P000?l00`0004P0W=oo0?ooo`040?ooo`050;md
0000000000000000B02Lgol01P3oool00`000000oooo0?ooo`0E0?ooo`80003o6`3oool00`000000
ohCo0?n4o`0`0?n4o`030000003oQ?l0ohCo00h0ohCo00<000000?ooo`3oool0>@3oool003X0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00h0oooo
0`000?l?0?ooo`030000003oool0oooo01@0oooo00<0003o0?ooo`3oool06`3oool00`000000ohCo
0?n4o`0_0?n4o`030000003oQ?l0ohCo00l0ohCo00<000000?ooo`3oool0>@3oool003/0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0180oooo0P00
0?l=0?ooo`030000003oool0oooo0180oooo0P000?lO0?ooo`030000003oQ?l0ohCo02h0ohCo00<0
00000?n4o`3oQ?l03P3oQ?l00`000000oooo0?ooo`0j0?ooo`00?03oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0503oool30000o`X0oooo00<00000
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0P0?ooo`030000003oQ?l0ohCo02`0ohCo00<00000
0?n4o`3oQ?l03P3oQ?l00`000000oooo0?ooo`0k0?ooo`00?03oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0603oool20000o`P0oooo00<000000?oo
o`3oool03`3oool20000ob<0oooo00<000000?n4o`3oQ?l0:`3oQ?l00`000000ohCo0?n4o`0?0?n4
o`030000003oool0oooo03/0oooo000m0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0J0?ooo`80003o1P3oool00`000000oooo0?ooo`0=0?ooo`80
003o9P3oool00`000000ohCo0?n4o`0Z0?n4o`030000003oQ?l0ohCo00h0ohCo00<000000?ooo`3o
ool0?03oool003h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo01d0oooo0`000?l30?ooo`030000003oool0oooo00`0oooo00<0003o0?ooo`3oool0
9`3oool00`000000ohCo0?n4o`0X0?n4o`030000003oQ?l0ohCo00h0ohCo00<000000?ooo`3oool0
?@3oool003h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo0200oooo0P000?l00`3oool000000?ooo`0;0?ooo`80003o:P3oool00`000000ohCo0?n4
o`0X0?n4o`030000003oQ?l0ohCo00d0ohCo00<0oooo0000003oool0?P3oool003l0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo02<0oooo0`000?l:
0?ooo`030000o`3oool0oooo02/0oooo00<000000?n4o`3oQ?l09P3oQ?l00`000000ohCo0?n4o`0>
0?n4o`030000003oool0oooo03h0oooo00100?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0T0?ooo`040000003oool0003o0000o`H0oooo0P000?l_
0?ooo`030000003oQ?l0ohCo02D0ohCo00<000000?n4o`3oQ?l03@3oQ?l00`000000oooo0?ooo`0o
0?ooo`00@03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool09@3oool200000080oooo0P000?l30?ooo`030000o`3oool0oooo0300oooo00<000000?n4
o`3oQ?l08`3oQ?l00`000000ohCo0?n4o`0>0?n4o`030000003oool0oooo03l0oooo00110?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo00<0oooo0`000?lc0?ooo`030000003oQ?l0ohCo02<0ohCo00<000000?n4o`3o
Q?l03@3oQ?l00`000000oooo0?ooo`100?ooo`00@P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`80003o
0P3oool20000oc80oooo00<000000?n4o`3oQ?l08@3oQ?l00`000000ohCo0?n4o`0=0?n4o`030000
003oool0oooo0440oooo00130?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`0V0?ooo`050000003oool0oooo0?ooo`000?l01P3oool30000oc00oooo
00<000000?n4o`3oQ?l0803oQ?l00`000000ohCo0?n4o`0<0?n4o`030000003oool0oooo0480oooo
00140?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0003o0000o`X0oooo0P000?l^0?ooo`030000003oQ?l0ohCo01l0ohCo
00<000000?n4o`3oQ?l0303oQ?l00`000000oooo0?ooo`130?ooo`00A@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool09`3oool00`000000003o0?oo
o`0=0?ooo`<0003o;03oool00`000000ohCo0?n4o`0N0?n4o`030000003oQ?l0ohCo00/0ohCo00<0
00000?ooo`3oool0A03oool004D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo02H0oooo0P000?lB0?ooo`80003o:`3oool00`000000ohCo0?n4o`0L
0?n4o`030000003oQ?l0ohCo00`0ohCo00<000000?ooo`3oool0A03oool004H0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02H0oooo00<0003o0?oo
o`000000503oool20000obT0oooo00<000000?n4o`3oQ?l0703oQ?l00`000000ohCo0?n4o`0;0?n4
o`030000003oool0oooo04D0oooo00170?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`0T0?ooo`80003o0P3oool00`000000oooo0?ooo`0D0?ooo`<0
003o9`3oool00`000000ohCo0?n4o`0J0?n4o`030000003oQ?l0ohCo00/0ohCo00<000000?ooo`3o
ool0AP3oool004P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo02@0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`80003o
9P3oool00`000000ohCo0?n4o`0I0?n4o`030000003oQ?l0ohCo00X0ohCo00<000000?ooo`3oool0
A`3oool004T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo0280oooo0P000?l50?ooo`030000003oool0oooo01T0oooo0`000?lT0?ooo`030000003o
Q?l0ohCo01L0ohCo00<000000?n4o`3oQ?l02P3oQ?l00`000000oooo0?ooo`180?ooo`00BP3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool08@3oool2
0000o`L0oooo00<000000?ooo`3oool0703oool20000ob80oooo00<000000?n4o`3oQ?l05`3oQ?l0
0`000000ohCo0?n4o`090?n4o`030000003oool0oooo04T0oooo001;0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo
00L0oooo00<000000?ooo`3oool07P3oool20000ob40oooo00<000000?n4o`3oQ?l05@3oQ?l00`00
0000ohCo0?n4o`090?n4o`030000003oool0oooo04X0oooo001<0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0O0?ooo`80003o2P3oool00`000000
oooo0?ooo`0P0?ooo`<0003o7`3oool00`000000ohCo0?n4o`0D0?n4o`030000003oQ?l0ohCo00P0
ohCo00<000000?ooo`3oool0B`3oool004d0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool02P3oool00`000000oooo
0?ooo`0S0?ooo`80003o7@3oool00`000000ohCo0?n4o`0C0?n4o`030000003oQ?l0ohCo00P0ohCo
00<000000?ooo`3oool0C03oool004h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo01d0oooo0P000?l=0?ooo`8000009P3oool30000oa/0oooo00<0
00000?n4o`3oQ?l04P3oQ?l00`000000ohCo0?n4o`070?n4o`030000003oool0oooo04d0oooo001?
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0L
0?ooo`030000o`3oool0oooo00d0oooo00<000000?ooo`3oool0:03oool20000oaX0oooo00<00000
0?n4o`3oQ?l0403oQ?l00`000000ohCo0?n4o`070?n4o`030000003oool0oooo04h0oooo001@0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0J0?oo
o`80003o403oool00`000000oooo0?ooo`0Z0?ooo`<0003o5`3oool00`000000ohCo0?n4o`0@0?n4
o`030000003oQ?l0ohCo00H0ohCo00<000000?ooo`3oool0C`3oool00540oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01T0oooo0P000?lB0?ooo`03
0000003oool0oooo02d0oooo0P000?lF0?ooo`030000003oQ?l0ohCo00h0ohCo00<000000?n4o`3o
Q?l01P3oQ?l00`000000oooo0?ooo`1@0?ooo`00DP3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0603oool00`000?l0oooo0?ooo`0B0?ooo`030000
003oool0oooo02l0oooo0P000?lE0?ooo`030000003oQ?l0ohCo00d0ohCo00<000000?n4o`3oQ?l0
1@3oQ?l00`000000oooo0?ooo`1A0?ooo`00D`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool05`3oool20000oaD0oooo00<000000?ooo`3oool0<@3o
ool30000oa<0oooo00<000000?n4o`3oQ?l02`3oQ?l00`000000ohCo0?n4o`050?n4o`030000003o
ool0oooo0580oooo001D0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0F0?ooo`030000o`3oool0oooo01D0oooo00<000000?ooo`3oool0=03oool2
0000oa40oooo00<000000?n4o`3oQ?l02`3oQ?l00`000000ohCo0?n4o`040?n4o`030000003oool0
oooo05<0oooo001E0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0E0?ooo`80003o603oool00`000000oooo0?ooo`0f0?ooo`<0003o3`3oool00`00
0000ohCo0?n4o`090?n4o`030000003oQ?l0ohCo00<0ohCo00<0oooo0000003oool0E@3oool005H0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01@0
oooo00<0003o0?ooo`3oool0603oool00`000000oooo0?ooo`0i0?ooo`80003o3P3oool00`000000
ohCo0?n4o`080?n4o`030000003oQ?l0ohCo00<0ohCo00<000000?ooo`3oool0E@3oool005L0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01<0oooo
0P000?lK0?ooo`030000003oool0oooo03/0oooo0P000?l<0?ooo`030000003oQ?l0ohCo00L0ohCo
00<000000?n4o`3oQ?l00`3oQ?l00`000000oooo0?ooo`1F0?ooo`00F03oool2000000h0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`80003o7@3oool00`000000oooo0?oo
o`0m0?ooo`<0003o1P3oool01@000?l0oooo0?ooo`3oool0000000P0ohCo00@000000?n4o`3oQ?l0
ohCo0P00001I0?ooo`00FP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0M0?ooo`030000003oool0oooo0400oooo
0P000?l40?ooo`80003o0`3oool00`000000ohCo0?n4o`040?n4o`050000003oQ?l0ohCo0?n4o`00
0000F`3oool005/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00l0oooo0P000?lP0?ooo`030000003oool0oooo0480oooo0`000?l00`3oool0003o
0000o`020000o`030?ooo`000000ohCo00D0ohCo00@000000?n4o`3oQ?l00000G03oool005`0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo
00<0003o0?ooo`3oool0803oool00`000000oooo0?ooo`150?ooo`H0003o00<0oooo0000003oQ?l0
0`3oQ?l010000000ohCo0?n4o`00001M0?ooo`00G@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool03@3oool20000ob<0oooo0P0000160?ooo`L0003o
00<0oooo0000003oQ?l00P3oQ?l00`000000oooo0000001N0?ooo`00GP3oool2000000`0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0<0?ooo`030000o`3oool0oooo02<0oooo00<0
00000?ooo`3oool0A03oool:0000o`030000003oQ?l0000000800000G`3oool00600oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo0P000?lV
0?ooo`030000003oool0oooo04L0oooo20000?l00`3oQ?l000000?ooo`1P0?ooo`00H@3oool20000
00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
02H0oooo00<000000?ooo`3oool0C@3oool30000of80oooo001S0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`80003o:@3oool00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo0680oooo001T0?ooo`8000002@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00L0oooo0P000?l[0?ooo`030000003oool0oooo04/0oooo
0P00001U0?ooo`00IP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0[0?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool0I@3oool006L0oooo0P0000080?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01@3oool20000obh0oooo00<000000?ooo`3oool0B03oool2000006P0oooo001Y0?oo
o`8000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0003o0?oo
o`3oool0;P3oool00`000000oooo0?ooo`160?ooo`8000000`3oool00`3ogi`0B000000000020000
000307Boo`3oool0oooo05l0oooo001[0?ooo`8000001@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00<0oooo0P000?la0?ooo`030000003oool0oooo04@0oooo0P0000050?ooo`07
0?oOW0180000M;oo0?ooo`3o_g@0001809cOo`1P0?ooo`00K@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0a0?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool01@3oool01`3ogi`0B00007Boo`3oool0
oono07@00018W=l0H03oool006h0oooo0P0000040?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool0oooo0P000?ld0?ooo`030000003oool0oooo0440oooo0P0000080?ooo`070?oOW018
0000M;oo0?ooo`3ooml0W4P0001d_`1P0?ooo`00L03oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000080oooo0P000?lf0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool0203oool01`3ogi`0B00007Boo`3oool0oooO09a80000M;l0H03oool00740oooo0P0000020?oo
o`060000003oool0oooo0000003oool0003o>03oool00`000000oooo0?ooo`0n0?ooo`8000002`3o
ool01`3ogi`0B00007Boo`3oool0oono07@00018W=l0H03oool007<0oooo1@0000020000ocT0oooo
0P00000l0?ooo`<000003@3oool01`3ogi`0B00007Boo`3oool0gia80000B02Lgol0H03oool007H0
oooo00<000000000o`3oool0>P3oool00`000000oooo0?ooo`0i0?ooo`800000403oool00`3ogi`0
B000000000020000000307Boo`3oool0oooo05l0oooo001h0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1g0?ooo`00N@3oool4000003H0oooo00<0
00000?ooo`3oool0=03oool4000007X0oooo001m0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`1l0?ooo`00N03oool00`3o_g@007Bo0?ooo`030?oo
o`@00000<@3oool00`000000oooo0?ooo`0_0?ooo`@00000O`3oool007<0oooo00<0oono07@00000
00000P0000000`0007@0_ooo0?ooo`070?ooo`<00000;P3oool00`000000oooo0?ooo`0/0?ooo`<0
0000P`3oool00780oooo00P0oono07@00000B9`0gooo0;md00000000001809cOo`/0oooo0P00000/
0?ooo`030000003oool0oooo02X0oooo0P0000260?ooo`00LP3oool0203o_g@0001809cOo`3ogi`0
B4RL0=oOW0180000B9cO3@3oool3000002T0oooo00<000000?ooo`3oool09`3oool3000008P0oooo
001b0?ooo`030=nLB00007@0_ooo0080oooo00<0oono07@00018W=l0403oool3000002H0oooo00<0
00000?ooo`3oool0903oool3000008/0oooo001b0?ooo`030=nLB00007@0_ooo0080oooo00<0oono
07@00018W=l04`3oool600000200oooo00<000000?ooo`3oool07P3oool6000008h0oooo001b0?oo
o`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol06@3oool3000001d0oooo00<000000?oo
o`3oool06`3oool3000009@0oooo001b0?ooo`080?oo_`1d000004RL0=ooo`3oool0_g@00018W03O
oolL0?ooo`D000003@3oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo01H0oooo1@00
002G0?ooo`00L`3oool01P3ookl0M00000000000000004RL0=ooob80oooo1`0000060?ooo`030?oo
g`2LB7@0_ooo00P0oooo00<000000?ooo`3oool03`3oool7000009`0oooo002R0?ooob<00000X`3o
ool00:P0oooo00<0oooO09a8M02oool0203oool00`000000oooo0?ooo`2b0?ooo`00YP3oool01@3o
oml0W9bo0?oog`2LB7@0_ooo00P0oooo00<000000?ooo`3oool0/P3oool00:L0oooo00@0okmd0000
000007@0_ooo203oool00`000000oooo0?ooo`2b0?ooo`00Z03oool00`3ookl0M01d0;ooo`080?oo
o`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000
003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0
oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80
oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c
0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`80
0000/`3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3o
ool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0
oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<0
00000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?oo
o`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0
/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0;<0oooo0P00002c0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo
0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b
0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00
/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00\
\>"],
  ImageRangeCache->{{{112.438, 370.625}, {345.813, 87.625}} -> {-2.35746, \
-0.404754, 0.00878441, 0.00878441}},
  CellTags->"figura8"]
}, Closed]],

Cell[CellGroupData[{

Cell["Formula di sottrazione per il coseno", "Subsection"],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[{
    \(\(Clear[\[Alpha], \[Beta], "\<p*\>"];\)\), "\[IndentingNewLine]", 
    \(\({idFondamentale, senCompl, cosCompl, tanCompl, senDiffPi2, 
          cosDiffPi2, tanDiffPi2, senSuppl, cosSuppl, tanSuppl, senExpl, 
          cosExpl, tanExpl, senOpp, cosOpp, 
          tanOpp} = {cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 1, 
          sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          tan[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cot[\[Alpha]], 
          sen[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          tan[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-\(cos[\[Alpha]]\/sen[\
\[Alpha]]\)\), sen[\[Pi] - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          cos[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          sen[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] + \[Alpha]_] \[RuleDelayed] tan[\[Alpha]], 
          sen[\(-\[Alpha]_\)] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\(-\[Alpha]_\)] \[RuleDelayed] cos[\[Alpha]], 
          tan[\(-\[Alpha]_\)] \[RuleDelayed] \(-tan[\[Alpha]]\)};\)\)}], \
"Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Dimostrazione", "Subsubsection"],

Cell[TextData[{
  "Poich\[EAcute] i punti ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`Q\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " e ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " sono descritti dalle coppie ordinate"
}], "Text"],

Cell[BoxData[{
    \(\(pP = {cos[\[Alpha]], sen[\[Alpha]]};\)\), "\[IndentingNewLine]", 
    \(\(pQ = {cos[\[Beta]], sen[\[Beta]]};\)\), "\[IndentingNewLine]", 
    \(\(pA = {1, 0};\)\), "\[IndentingNewLine]", 
    \(\(pD = {cos[\[Alpha] - \[Beta]], 
          sen[\[Alpha] - \[Beta]]};\)\)}], "Input"],

Cell[TextData[{
  "ne segue che i quadrati dei segmenti ",
  StyleBox["dPQquadro", "InlineInput"],
  " e ",
  StyleBox["dDAquadro ", "InlineInput"],
  "in termini degli angoli ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " e ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\)]],
  " risultano"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({{"\<PQquadrato =\>", 
          PQquadrato = Plus @@ \(\((pP - pQ)\)\^2\)}, {"\<DAquadrato =\>", 
          DAquadrato = Plus @@ \(\((pD - pA)\)\^2\)}} // TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"PQquadrato =\"\>", \(\((cos[\[Alpha]] - cos[\[Beta]])\)\^2 + \
\((sen[\[Alpha]] - sen[\[Beta]])\)\^2\)},
          {"\<\"DAquadrato =\"\>", \(\((\(-1\) + cos[\[Alpha] - \
\[Beta]])\)\^2 + sen[\[Alpha] - \[Beta]]\^2\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Closed]],

Cell[TextData[{
  "Posti, ",
  ButtonBox["per quanto visto",
    ButtonData:>"relazione1",
    ButtonStyle->"Hyperlink"],
  ", uguali ne discende l'equazione"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PQquadrato == DAquadrato\)], "Input"],

Cell[BoxData[
    \(\((cos[\[Alpha]] - cos[\[Beta]])\)\^2 + \((sen[\[Alpha]] - \
sen[\[Beta]])\)\^2 \[Equal] \((\(-1\) + cos[\[Alpha] - \[Beta]])\)\^2 + 
        sen[\[Alpha] - \[Beta]]\^2\)], "Output"]
}, Closed]],

Cell["Possiamo ora eseguire i quadrati coinvolti nei due membri", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Expand /@ %\)], "Input"],

Cell[BoxData[
    \(cos[\[Alpha]]\^2 - 2\ cos[\[Alpha]]\ cos[\[Beta]] + cos[\[Beta]]\^2 + 
        sen[\[Alpha]]\^2 - 2\ sen[\[Alpha]]\ sen[\[Beta]] + 
        sen[\[Beta]]\^2 \[Equal] 
      1 - 2\ cos[\[Alpha] - \[Beta]] + cos[\[Alpha] - \[Beta]]\^2 + 
        sen[\[Alpha] - \[Beta]]\^2\)], "Output"]
}, Closed]],

Cell[TextData[{
  "e quindi utilizzando l'identit\[AGrave] goniometrica fondamentale ",
  Cell[BoxData[
      \(TraditionalForm\`\(sen\^2\) \[Alpha] + \(cos\^2\) \[Alpha] = 1\)]],
  ", ",
  "ridurre l'equazione alla forma equivalente pi\[UGrave] semplice"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% //. idFondamentale\)], "Input"],

Cell[BoxData[
    \(2 - 2\ cos[\[Alpha]]\ cos[\[Beta]] - 
        2\ sen[\[Alpha]]\ sen[\[Beta]] \[Equal] 
      2 - 2\ cos[\[Alpha] - \[Beta]]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Sottraendo ",
  Cell[BoxData[
      \(TraditionalForm\`2\)]],
  " ad entrambi i membri"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% - 2\)], "Input"],

Cell[BoxData[
    \(\(-2\)\ cos[\[Alpha]]\ cos[\[Beta]] - 
        2\ sen[\[Alpha]]\ sen[\[Beta]] \[Equal] \(-2\)\ cos[\[Alpha] - \
\[Beta]]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "e, dopo aver diviso per ",
  Cell[BoxData[
      \(TraditionalForm\`\(-2\)\)]],
  ", scambiamo i due membri e semplifichiamo"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(scambia[%/\(-2\)] // Simplify\)], "Input"],

Cell[BoxData[
    \(cos[\[Alpha] - \[Beta]] \[Equal] 
      cos[\[Alpha]]\ cos[\[Beta]] + sen[\[Alpha]]\ sen[\[Beta]]\)], "Output"]
}, Closed]],

Cell["\<\
In definitiva siamo giunti a dimostrare la validit\[AGrave] \
dell'espressione\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`cos(\[Alpha] - \[Beta])\  = \ \(cos(\[Alpha])\) \(cos(\
\[Beta])\) + \(sen(\[Alpha])\) \(sen(\[Beta])\)\)]]], "Definition",
  FontFamily->"Courier"],

Cell["\<\
Il coseno di una differenza \[EGrave] pertanto, ben diverso dall'aspettativa \
ingenua che lo \"vorrebbe\" pari alla differenza dei coseni! In termini pi\
\[UGrave] formali questa identit\[AGrave] (e le analoghe seguenti) dimostrano \
che le funzioni goniometriche non sono delle funzioni lineari dei propri \
argomenti.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cosDiff = toRule[%]\)], "Input"],

Cell[BoxData[
    \(cos[\[Alpha] - \[Beta]] \[RuleDelayed] 
      cos[\[Alpha]]\ cos[\[Beta]] + sen[\[Alpha]]\ sen[\[Beta]]\)], "Output"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Formule di addizione e sottrazione", "Section"],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\({idFondamentale, senCompl, cosCompl, tanCompl, senDiffPi2, 
          cosDiffPi2, tanDiffPi2, senSuppl, cosSuppl, tanSuppl, senExpl, 
          cosExpl, tanExpl, senOpp, cosOpp, tanOpp, 
          cosDiff} = {cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 1, 
          sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          tan[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cot[\[Alpha]], 
          sen[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          tan[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-\(cos[\[Alpha]]\/sen[\
\[Alpha]]\)\), sen[\[Pi] - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          cos[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          sen[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] + \[Alpha]_] \[RuleDelayed] tan[\[Alpha]], 
          sen[\(-\[Alpha]_\)] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\(-\[Alpha]_\)] \[RuleDelayed] cos[\[Alpha]], 
          tan[\(-\[Alpha]_\)] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          cos[\[Alpha]_ - \[Beta]_] \[RuleDelayed] 
            cos[\[Alpha]]\ cos[\[Beta]] + 
              sen[\[Alpha]]\ sen[\[Beta]]};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Formula di addizione per il coseno", "Subsection"],

Cell[TextData[{
  "La precedente identit\[AGrave] collega il ",
  StyleBox["coseno della differenza di due angoli",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " e ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\)]],
  " con le funzioni goniometriche di questi e costituisce la ",
  StyleBox["formula di sottrazione per il coseno",
    FontSlant->"Italic"],
  ". Questo risultato si pu\[OGrave] facilmente estendere e in questa sezione \
otterremo, per prima, la corrispondente formula di addizione e \
successivamente le formule di addizione e sottrazione per seno e tangente. A \
tal fine sostituiamo nell'identit\[AGrave] appena dimostrata"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(toIdentita[cosDiff]\)], "Input"],

Cell[BoxData[
    \(cos[\[Alpha] - \[Beta]] \[Equal] 
      cos[\[Alpha]]\ cos[\[Beta]] + sen[\[Alpha]]\ sen[\[Beta]]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "all'angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\)]],
  " l'angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Beta]\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. \[Beta] \[Rule] \(-\[Beta]\)\)], "Input"],

Cell[BoxData[
    \(cos[\[Alpha] + \[Beta]] \[Equal] 
      cos[\[Alpha]]\ cos[\(-\[Beta]\)] + 
        sen[\[Alpha]]\ sen[\(-\[Beta]\)]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Tenendo presente quanto gi\[AGrave] dimostrato ossia che il seno \[EGrave] \
una funzione ",
  ButtonBox["dispari",
    ButtonData:>"senodispari",
    ButtonStyle->"Hyperlink"],
  " valendo ",
  Cell[BoxData[
      \(TraditionalForm\`sen(\(-\[Beta]\)) = \(-\(sen(\[Beta])\)\)\)]],
  " mentre il coseno \[EGrave] ",
  ButtonBox["pari",
    ButtonData:>"cosenopari",
    ButtonStyle->"Hyperlink"],
  " dato che ",
  Cell[BoxData[
      \(TraditionalForm\`cos(\(-\[Beta]\)) = 
        cos(\[Beta]), \ \[ForAll] \ \[Beta]\  \[Element] \ \
\[DoubleStruckCapitalR]\)]],
  ", l'espressione precedente diviene   "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(% /. senOpp\) /. cosOpp\)], "Input"],

Cell[BoxData[
    \(cos[\[Alpha] + \[Beta]] \[Equal] 
      cos[\[Alpha]]\ cos[\[Beta]] - sen[\[Alpha]]\ sen[\[Beta]]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Il coseno della somma in termini delle funzioni di ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " e ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\)]],
  " risulta quindi "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`cos(\[Alpha] + \[Beta])\  = \ \(cos(\[Alpha])\) \(cos(\
\[Beta])\) - \(sen(\[Alpha])\) \(sen(\[Beta])\)\)]]], "Definition",
  FontFamily->"Courier",
  CellTags->"cosSomma"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cosAdd = toRule[%]\)], "Input"],

Cell[BoxData[
    \(cos[\[Alpha] + \[Beta]] \[RuleDelayed] 
      cos[\[Alpha]]\ cos[\[Beta]] - sen[\[Alpha]]\ sen[\[Beta]]\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Formule di addizione e sottrazione per il seno", "Subsection"],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\({idFondamentale, senCompl, cosCompl, tanCompl, senDiffPi2, 
          cosDiffPi2, tanDiffPi2, senSuppl, cosSuppl, tanSuppl, senExpl, 
          cosExpl, tanExpl, senOpp, cosOpp, tanOpp, cosDiff, 
          cosAdd} = {cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 1, 
          sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          tan[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cot[\[Alpha]], 
          sen[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          tan[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-\(cos[\[Alpha]]\/sen[\
\[Alpha]]\)\), sen[\[Pi] - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          cos[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          sen[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] + \[Alpha]_] \[RuleDelayed] tan[\[Alpha]], 
          sen[\(-\[Alpha]_\)] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\(-\[Alpha]_\)] \[RuleDelayed] cos[\[Alpha]], 
          tan[\(-\[Alpha]_\)] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          cos[\[Alpha]_ - \[Beta]_] \[RuleDelayed] 
            cos[\[Alpha]]\ cos[\[Beta]] + sen[\[Alpha]]\ sen[\[Beta]], 
          cos[\[Alpha]_ + \[Beta]_] \[RuleDelayed] 
            cos[\[Alpha]]\ cos[\[Beta]] - 
              sen[\[Alpha]]\ sen[\[Beta]]};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Seno della differenza", "Subsubsection"],

Cell[TextData[{
  "Sfruttiamo l'identit\[AGrave] ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(sen(\[Alpha])\), "=", 
          RowBox[{\(cos(\[Pi]\/2 - \[Alpha])\), Cell[""]}]}], 
        TraditionalForm]]],
  "per dedurre la formula di sottrazione per la funzione seno."
}], "Text",
  CellTags->"id1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sen[\[Alpha] - \[Beta]] \[Equal] 
      cos[\[Pi]\/2 - \((\[Alpha] - \[Beta])\)]\)], "Input"],

Cell[BoxData[
    \(sen[\[Alpha] - \[Beta]] \[Equal] 
      cos[\[Pi]\/2 - \[Alpha] + \[Beta]]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "e, in base alla propriet\[AGrave] associativa, riscriviamo il secondo \
membro sostituendo a ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/2 - \[Alpha] = \[Gamma]\)]],
  " "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. \[Pi]\/2 - \[Alpha] \[Rule] \[Gamma]\)], "Input"],

Cell[BoxData[
    \(sen[\[Alpha] - \[Beta]] \[Equal] cos[\[Beta] + \[Gamma]]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Possiamo ora applicare la ",
  ButtonBox["formula di addizione per il coseno",
    ButtonData:>"cosSomma",
    ButtonStyle->"Hyperlink"],
  " appena ottenuta"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. cosAdd\)], "Input"],

Cell[BoxData[
    \(sen[\[Alpha] - \[Beta]] \[Equal] 
      cos[\[Beta]]\ cos[\[Gamma]] - sen[\[Beta]]\ sen[\[Gamma]]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "e ritornando ad esprimere ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " in termini di ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. \[Gamma] -> \[Pi]\/2 - \[Alpha]\)], "Input"],

Cell[BoxData[
    \(sen[\[Alpha] - \[Beta]] \[Equal] 
      cos[\[Pi]\/2 - \[Alpha]]\ cos[\[Beta]] - 
        sen[\[Pi]\/2 - \[Alpha]]\ sen[\[Beta]]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Per l'identit\[AGrave] gi\[AGrave] ",
  ButtonBox["ricordata",
    ButtonData:>"id1",
    ButtonStyle->"Hyperlink"],
  " e per quella analoga riguardante il seno di angoli complementari ",
  Cell[BoxData[
      \(TraditionalForm\`sen(\[Pi]\/2 - \[Alpha]) = cos(\[Alpha])\)]],
  ", la precedente fornisce "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(% /. senCompl\) /. cosCompl\)], "Input"],

Cell[BoxData[
    \(sen[\[Alpha] - \[Beta]] \[Equal] 
      cos[\[Beta]]\ sen[\[Alpha]] - cos[\[Alpha]]\ sen[\[Beta]]\)], "Output"]
}, Closed]],

Cell["che \[EGrave] quanto si voleva ottenere.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(senDiff = toRule[%]\)], "Input"],

Cell[BoxData[
    \(sen[\[Alpha] - \[Beta]] \[RuleDelayed] 
      cos[\[Beta]]\ sen[\[Alpha]] - cos[\[Alpha]]\ sen[\[Beta]]\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[{
    \(\(senDiffEq = 
        sen[\[Alpha] - \[Beta]] \[Equal] 
          cos[\[Beta]]\ sen[\[Alpha]] - 
            cos[\[Alpha]]\ sen[\[Beta]];\)\), "\[IndentingNewLine]", 
    \(\({idFondamentale, senCompl, cosCompl, tanCompl, senDiffPi2, 
          cosDiffPi2, tanDiffPi2, senSuppl, cosSuppl, tanSuppl, senExpl, 
          cosExpl, tanExpl, senOpp, cosOpp, tanOpp, cosDiff, cosAdd, 
          senDiff} = {cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 1, 
          sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          tan[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cot[\[Alpha]], 
          sen[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          tan[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-\(cos[\[Alpha]]\/sen[\
\[Alpha]]\)\), sen[\[Pi] - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          cos[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          sen[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] + \[Alpha]_] \[RuleDelayed] tan[\[Alpha]], 
          sen[\(-\[Alpha]_\)] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\(-\[Alpha]_\)] \[RuleDelayed] cos[\[Alpha]], 
          tan[\(-\[Alpha]_\)] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          cos[\[Alpha]_ - \[Beta]_] \[RuleDelayed] 
            cos[\[Alpha]]\ cos[\[Beta]] + sen[\[Alpha]]\ sen[\[Beta]], 
          cos[\[Alpha]_ + \[Beta]_] \[RuleDelayed] 
            cos[\[Alpha]]\ cos[\[Beta]] - sen[\[Alpha]]\ sen[\[Beta]], 
          sen[\[Alpha]_ - \[Beta]_] \[RuleDelayed] 
            cos[\[Beta]]\ sen[\[Alpha]] - 
              cos[\[Alpha]]\ sen[\[Beta]]};\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Seno della somma", "Subsubsection"],

Cell[TextData[{
  "Nello stesso modo seguito per il coseno, sostituiamo a ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\)]],
  " l'angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Beta]\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(toIdentita[senDiff] /. \[Beta] \[Rule] \(-\[Beta]\)\)], "Input"],

Cell[BoxData[
    \(sen[\[Alpha] + \[Beta]] \[Equal] 
      cos[\(-\[Beta]\)]\ sen[\[Alpha]] - 
        cos[\[Alpha]]\ sen[\(-\[Beta]\)]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Per le propriet\[AGrave] di simmetria del ",
  ButtonBox["seno",
    ButtonData:>"senodispari",
    ButtonStyle->"Hyperlink"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`sen(\(-\[Beta]\)) = \(-\(sen(\[Beta])\)\)\)]],
  " e del ",
  ButtonBox["coseno",
    ButtonData:>"cosenopari",
    ButtonStyle->"Hyperlink"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`cos(\(-\[Beta]\)) = cos(\[Beta])\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[ForAll] \[Beta]\  \[Element] \ \
\[DoubleStruckCapitalR]\)]],
  ", otteniamo"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(% /. senOpp\) /. cosOpp\)], "Input"],

Cell[BoxData[
    \(sen[\[Alpha] + \[Beta]] \[Equal] 
      cos[\[Beta]]\ sen[\[Alpha]] + cos[\[Alpha]]\ sen[\[Beta]]\)], "Output"]
}, Closed]],

Cell["\<\
Riassumiamo in un'unica espressione le due identit\[AGrave] dimostrate\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`sen(\[Alpha]\  \[PlusMinus] \ \[Beta])\  = \ \(sen(\
\[Alpha])\) \(cos(\[Beta])\) \[PlusMinus] \(cos(\[Alpha])\) \
\(sen(\[Beta])\)\)]]], "Definition",
  FontFamily->"Courier"],

Cell["\<\
intendendo che i segni vanno considerati nell'ordine indicato ossia il segno \
superiore a primo membro va associato al segno superiore a secondo e cos\
\[IGrave] per quello inferiore.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(senAdd = toRule[%]\)], "Input"],

Cell[BoxData[
    \(sen[\[Alpha] + \[Beta]] \[RuleDelayed] 
      cos[\[Beta]]\ sen[\[Alpha]] + cos[\[Alpha]]\ sen[\[Beta]]\)], "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Formule di addizione e sottrazione per la tangente", "Subsection"],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\({idFondamentale, senCompl, cosCompl, tanCompl, senDiffPi2, 
          cosDiffPi2, tanDiffPi2, senSuppl, cosSuppl, tanSuppl, senExpl, 
          cosExpl, tanExpl, senOpp, cosOpp, tanOpp, cosDiff, cosAdd, senDiff, 
          senAdd} = {cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 1, 
          sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          tan[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cot[\[Alpha]], 
          sen[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          tan[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-\(cos[\[Alpha]]\/sen[\
\[Alpha]]\)\), sen[\[Pi] - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          cos[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          sen[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] + \[Alpha]_] \[RuleDelayed] tan[\[Alpha]], 
          sen[\(-\[Alpha]_\)] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\(-\[Alpha]_\)] \[RuleDelayed] cos[\[Alpha]], 
          tan[\(-\[Alpha]_\)] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          cos[\[Alpha]_ - \[Beta]_] \[RuleDelayed] 
            cos[\[Alpha]]\ cos[\[Beta]] + sen[\[Alpha]]\ sen[\[Beta]], 
          cos[\[Alpha]_ + \[Beta]_] \[RuleDelayed] 
            cos[\[Alpha]]\ cos[\[Beta]] - sen[\[Alpha]]\ sen[\[Beta]], 
          sen[\[Alpha]_ - \[Beta]_] \[RuleDelayed] 
            cos[\[Beta]]\ sen[\[Alpha]] - cos[\[Alpha]]\ sen[\[Beta]], 
          sen[\[Alpha]_ + \[Beta]_] \[RuleDelayed] 
            cos[\[Beta]]\ sen[\[Alpha]] + 
              cos[\[Alpha]]\ sen[\[Beta]]};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Tangente della somma", "Subsubsection"],

Cell["\<\
Sfruttiamo le identit\[AGrave] appena trovate per dimostrare quelle \
coinvolgenti la tangente di una somma o di una differenza. Poich\[EAcute] la \
tangente di un angolo si pu\[OGrave] esprimere come il rapporto tra il seno e \
il coseno, abbiamo \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tan[\[Alpha] + \[Beta]] \[Equal] 
      sen[\[Alpha] + \[Beta]]\/cos[\[Alpha] + \[Beta]]\)], "Input"],

Cell[BoxData[
    \(tan[\[Alpha] + \[Beta]] \[Equal] 
      sen[\[Alpha] + \[Beta]]\/cos[\[Alpha] + \[Beta]]\)], "Output"]
}, Closed]],

Cell["\<\
Sviluppiamo il numeratore e denominatore della precedente utilizzando le \
formule di addizione per il seno e coseno\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(% /. senAdd\) /. cosAdd\)], "Input"],

Cell[BoxData[
    \(tan[\[Alpha] + \[Beta]] \[Equal] \(cos[\[Beta]]\ sen[\[Alpha]] + cos[\
\[Alpha]]\ sen[\[Beta]]\)\/\(cos[\[Alpha]]\ cos[\[Beta]] - sen[\[Alpha]]\ \
sen[\[Beta]]\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Supponendo ",
  Cell[BoxData[
      \(TraditionalForm\`\(cos(\[Alpha])\) \(cos(\[Beta])\) \[NotEqual] 
        0\)]],
  " cio\[EGrave] ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha], \[Beta] \[NotEqual] \[Pi]\/2 + k\[Pi]\)]],
  ", dividiamo numeratore e denominatore del secondo membro per tale termine"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(applicaND[%, HoldForm[#/\((cos[\[Alpha]] cos[\[Beta]])\)] &]\)], "Input"],

Cell[BoxData[
    RowBox[{\(tan[\[Alpha] + \[Beta]]\), "\[Equal]", 
      FractionBox[
        TagBox[\(\(cos[\[Beta]]\ sen[\[Alpha]] + 
                cos[\[Alpha]]\ sen[\[Beta]]\)\/\(cos[\[Alpha]]\ \
cos[\[Beta]]\)\),
          HoldForm], 
        TagBox[\(\(cos[\[Alpha]]\ cos[\[Beta]] - 
                sen[\[Alpha]]\ sen[\[Beta]]\)\/\(cos[\[Alpha]]\ \
cos[\[Beta]]\)\),
          HoldForm]]}]], "Output"]
}, Closed]],

Cell["\<\
e quindi semplificando e tenendo conto della definizione di tangente in \
termini del seno e coseno, gli elementi coinvolti a secondo membro divengono \
rispettivamente\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(applicaND[%, Apart[rilascia[#]] &]\)], "Input"],

Cell[BoxData[
    \(tan[\[Alpha] + \[Beta]] \[Equal] \(sen[\[Alpha]]\/cos[\[Alpha]] + sen[\
\[Beta]]\/cos[\[Beta]]\)\/\(1 - \(sen[\[Alpha]]\ sen[\[Beta]]\)\/\(cos[\
\[Alpha]]\ cos[\[Beta]]\)\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% //. id4\)], "Input"],

Cell[BoxData[
    \(tan[\[Alpha] + \[Beta]] \[Equal] \(tan[\[Alpha]] + tan[\[Beta]]\)\/\(1 \
- tan[\[Alpha]]\ tan[\[Beta]]\)\)], "Output"]
}, Closed]],

Cell["che \[EGrave] la formula cercata.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tanAdd = toRule[%]\)], "Input"],

Cell[BoxData[
    \(tan[\[Alpha] + \[Beta]] \[RuleDelayed] \(tan[\[Alpha]] + tan[\[Beta]]\)\
\/\(1 - tan[\[Alpha]]\ tan[\[Beta]]\)\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\({idFondamentale, senCompl, cosCompl, tanCompl, senDiffPi2, 
          cosDiffPi2, tanDiffPi2, senSuppl, cosSuppl, tanSuppl, senExpl, 
          cosExpl, tanExpl, senOpp, cosOpp, tanOpp, cosDiff, cosAdd, senDiff, 
          senAdd, tanAdd} = {cos[\[Alpha]_]\^2 + 
              sen[\[Alpha]_]\^2 \[RuleDelayed] 1, 
          sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          tan[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cot[\[Alpha]], 
          sen[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          tan[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-\(cos[\[Alpha]]\/sen[\
\[Alpha]]\)\), sen[\[Pi] - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          cos[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          sen[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] + \[Alpha]_] \[RuleDelayed] tan[\[Alpha]], 
          sen[\(-\[Alpha]_\)] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\(-\[Alpha]_\)] \[RuleDelayed] cos[\[Alpha]], 
          tan[\(-\[Alpha]_\)] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          cos[\[Alpha]_ - \[Beta]_] \[RuleDelayed] 
            cos[\[Alpha]]\ cos[\[Beta]] + sen[\[Alpha]]\ sen[\[Beta]], 
          cos[\[Alpha]_ + \[Beta]_] \[RuleDelayed] 
            cos[\[Alpha]]\ cos[\[Beta]] - sen[\[Alpha]]\ sen[\[Beta]], 
          sen[\[Alpha]_ - \[Beta]_] \[RuleDelayed] 
            cos[\[Beta]]\ sen[\[Alpha]] - cos[\[Alpha]]\ sen[\[Beta]], 
          sen[\[Alpha]_ + \[Beta]_] \[RuleDelayed] 
            cos[\[Beta]]\ sen[\[Alpha]] + cos[\[Alpha]]\ sen[\[Beta]], 
          tan[\[Alpha]_ + \[Beta]_] \[RuleDelayed] \(tan[\[Alpha]] + tan[\
\[Beta]]\)\/\(1 - tan[\[Alpha]]\ tan[\[Beta]]\)};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Tangente della differenza", "Subsubsection"],

Cell[TextData[{
  "Per ottenere la formula corrispondente e relativa alla differenza degli \
angoli, procediamo alla sostituzione ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] \[RightArrow] \(-\[Beta]\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(toIdentita[tanAdd] /. \[Beta] \[Rule] \(-\[Beta]\)\)], "Input"],

Cell[BoxData[
    \(tan[\[Alpha] - \[Beta]] \[Equal] \(tan[\[Alpha]] + \
tan[\(-\[Beta]\)]\)\/\(1 - tan[\[Alpha]]\ tan[\(-\[Beta]\)]\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Ricordando che la tangente \[EGrave] una funzione ",
  ButtonBox["dispari",
    ButtonData:>"tandispari",
    ButtonStyle->"Hyperlink"],
  " che soddisfa quindi alla identit\[AGrave] ",
  Cell[BoxData[
      \(TraditionalForm\`tan(\(-\[Beta]\)) = \(-\(tan(\[Beta])\)\)\)]],
  " giungiamo infine alla"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. tanOpp\)], "Input"],

Cell[BoxData[
    \(tan[\[Alpha] - \[Beta]] \[Equal] \(tan[\[Alpha]] - tan[\[Beta]]\)\/\(1 \
+ tan[\[Alpha]]\ tan[\[Beta]]\)\)], "Output"]
}, Closed]],

Cell["\<\
In definitiva le formule di addizione e sottrazione per la tangente sono\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[Cell[TextData[Cell[BoxData[
          FormBox[
            RowBox[{
              FormBox[
                FormBox[
                  StyleBox[
                    
                    FormBox[\(tan(\[Alpha] \[PlusMinus] \[Beta]) = \(tan(\
\[Alpha]) \[PlusMinus] tan(\[Beta])\)\/\(1 \[MinusPlus] \(tan(\[Alpha])\) \
\(tan(\[Beta])\)\)\),
                      "TraditionalForm"],
                    "DisplayFormula"],
                  "TraditionalForm"],
                "TraditionalForm"], "\t", "con", " \t", 
              FormBox[\(\[Alpha], \[Beta] \[NotEqual] \[Pi]\/2 + k\[Pi]\),
                "TraditionalForm"]}], TraditionalForm]]]]], 
      TraditionalForm]]]], "Definition",
  FontFamily->"Courier",
  FontSize->10],

Cell[CellGroupData[{

Cell[BoxData[
    \(tanDiff = toRule[%]\)], "Input"],

Cell[BoxData[
    \(tan[\[Alpha] - \[Beta]] \[RuleDelayed] \(tan[\[Alpha]] - tan[\[Beta]]\)\
\/\(1 + tan[\[Alpha]]\ tan[\[Beta]]\)\)], "Output"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Formule di duplicazione", "Section"],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\({idFondamentale, senCompl, cosCompl, tanCompl, senDiffPi2, 
          cosDiffPi2, tanDiffPi2, senSuppl, cosSuppl, tanSuppl, senExpl, 
          cosExpl, tanExpl, senOpp, cosOpp, tanOpp, cosDiff, cosAdd, senDiff, 
          senAdd, tanAdd, 
          tanDiff} = {cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 1, 
          sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          tan[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cot[\[Alpha]], 
          sen[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          tan[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-\(cos[\[Alpha]]\/sen[\
\[Alpha]]\)\), sen[\[Pi] - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          cos[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          sen[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] + \[Alpha]_] \[RuleDelayed] tan[\[Alpha]], 
          sen[\(-\[Alpha]_\)] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\(-\[Alpha]_\)] \[RuleDelayed] cos[\[Alpha]], 
          tan[\(-\[Alpha]_\)] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          cos[\[Alpha]_ - \[Beta]_] \[RuleDelayed] 
            cos[\[Alpha]]\ cos[\[Beta]] + sen[\[Alpha]]\ sen[\[Beta]], 
          cos[\[Alpha]_ + \[Beta]_] \[RuleDelayed] 
            cos[\[Alpha]]\ cos[\[Beta]] - sen[\[Alpha]]\ sen[\[Beta]], 
          sen[\[Alpha]_ - \[Beta]_] \[RuleDelayed] 
            cos[\[Beta]]\ sen[\[Alpha]] - cos[\[Alpha]]\ sen[\[Beta]], 
          sen[\[Alpha]_ + \[Beta]_] \[RuleDelayed] 
            cos[\[Beta]]\ sen[\[Alpha]] + cos[\[Alpha]]\ sen[\[Beta]], 
          tan[\[Alpha]_ + \[Beta]_] \[RuleDelayed] \(tan[\[Alpha]] + tan[\
\[Beta]]\)\/\(1 - tan[\[Alpha]]\ tan[\[Beta]]\), 
          tan[\[Alpha]_ - \[Beta]_] \[RuleDelayed] \(tan[\[Alpha]] - tan[\
\[Beta]]\)\/\(1 + tan[\[Alpha]]\ tan[\[Beta]]\)};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Formule di duplicazione per seno coseno e tangente", "Subsection"],

Cell[TextData[{
  "Dall'insieme delle formule discusse finora possiamo derivare facilmente un \
altro gruppo di importanti identit\[AGrave] goniometriche. Iniziamo da quelle \
di duplicazione, formule che collegano le funzioni goniometriche dell'angolo \
",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Alpha]\)]],
  " con quelle dell'angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ".\nPartendo dalla"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(toIdentita[senAdd]\)], "Input"],

Cell[BoxData[
    \(sen[\[Alpha] + \[Beta]] \[Equal] 
      cos[\[Beta]]\ sen[\[Alpha]] + cos[\[Alpha]]\ sen[\[Beta]]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "basta porre ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] = \[Alpha]\)]],
  " per ottenere quanto si voleva"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. \[Beta] \[Rule] \[Alpha]\)], "Input"],

Cell[BoxData[
    \(sen[2\ \[Alpha]] \[Equal] 2\ cos[\[Alpha]]\ sen[\[Alpha]]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(senDupl = toRule[%]\)], "Input"],

Cell[BoxData[
    \(sen[2\ \[Alpha]] \[RuleDelayed] 
      2\ cos[\[Alpha]]\ sen[\[Alpha]]\)], "Output"]
}, Closed]],

Cell["Analogamente per il coseno si ottiene immediatamente", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(toIdentita[cosAdd]\)], "Input"],

Cell[BoxData[
    \(cos[\[Alpha] + \[Beta]] \[Equal] 
      cos[\[Alpha]]\ cos[\[Beta]] - sen[\[Alpha]]\ sen[\[Beta]]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cosDuplEq = % /. \[Beta] \[Rule] \[Alpha]\)], "Input"],

Cell[BoxData[
    \(cos[2\ \[Alpha]] \[Equal] 
      cos[\[Alpha]]\^2 - sen[\[Alpha]]\^2\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cosDupl = toRule[%]\)], "Input"],

Cell[BoxData[
    \(cos[2\ \[Alpha]] \[RuleDelayed] 
      cos[\[Alpha]]\^2 - sen[\[Alpha]]\^2\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Tenendo conto dell'identit\[AGrave] goniometrica fondamentale quest'ultima \
si pu\[OGrave] riscrivere anche in termini alternativi appena si sostituisca \
",
  Cell[BoxData[
      \(TraditionalForm\`\(cos\^2\)(\[Alpha]) = 1 - \(sen\^2\)(\[Alpha])\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(toIdentita[cosDupl] /. cos[a_]^2 \[Rule] 1 - sen[a]^2\)], "Input"],

Cell[BoxData[
    \(cos[2\ \[Alpha]] \[Equal] 1 - 2\ sen[\[Alpha]]\^2\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cosDuplSen = toRule[%]\)], "Input"],

Cell[BoxData[
    \(cos[2\ \[Alpha]] \[RuleDelayed] 1 - 2\ sen[\[Alpha]]\^2\)], "Output"]
}, Closed]],

Cell[TextData[{
  "oppure ancora, in base alla ",
  Cell[BoxData[
      \(TraditionalForm\`\(sen\^2\)(\[Alpha]) = 1 - \(cos\^2\)(\[Alpha])\)]],
  ", si ottiene una terza forma"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(toIdentita[cosDupl] /. sen[a_]^2 \[Rule] 1 - cos[a]^2\)], "Input"],

Cell[BoxData[
    \(cos[2\ \[Alpha]] \[Equal] \(-1\) + 2\ cos[\[Alpha]]\^2\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cosDuplCos = toRule[%]\)], "Input"],

Cell[BoxData[
    \(cos[2\ \[Alpha]] \[RuleDelayed] \(-1\) + 
        2\ cos[\[Alpha]]\^2\)], "Output"]
}, Closed]],

Cell["Infine la formula di addizione per la tangente", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(toIdentita[tanAdd]\)], "Input"],

Cell[BoxData[
    \(tan[\[Alpha] + \[Beta]] \[Equal] \(tan[\[Alpha]] + tan[\[Beta]]\)\/\(1 \
- tan[\[Alpha]]\ tan[\[Beta]]\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "fornisce con la sostituzione ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] \[Rule] \[Alpha]\)]],
  " ",
  "l'espressione cercata"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. \[Beta] \[Rule] \[Alpha]\)], "Input"],

Cell[BoxData[
    \(tan[
        2\ \[Alpha]] \[Equal] \(2\ tan[\[Alpha]]\)\/\(1 - \
tan[\[Alpha]]\^2\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tanDupl = toRule[%]\)], "Input"],

Cell[BoxData[
    \(tan[
        2\ \[Alpha]] \[RuleDelayed] \(2\ tan[\[Alpha]]\)\/\(1 - tan[\[Alpha]]\
\^2\)\)], "Output"]
}, Closed]],

Cell["Le formule di duplicazione sono pertanto ", "Text"],

Cell[TextData[Cell[BoxData[{
    FormBox[
      StyleBox[\(sen(2  \[Alpha]) = 2 \( sen(\[Alpha])\) \(cos(\[Alpha])\)\),
        "DisplayFormula"], TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      StyleBox[\(cos(
            2  \[Alpha]) = \(\(cos\^2\)(\[Alpha]) - \(sen\^2\)(\[Alpha]) = \
\(1 - 2 \(\( sen\^2\)(\[Alpha])\) = 2 \(\( cos\^2\)(\[Alpha])\) - 1\)\)\),
        "DisplayFormula"], TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      StyleBox[\(tan(
            2  \[Alpha]) = \(2 \( tan(\[Alpha])\)\)\/\(1 - \
\(tan\^2\)(\[Alpha])\)\),
        "DisplayFormula"], TraditionalForm]}]]], "Definition",
  FontFamily->"Courier"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Formule di bisezione", "Section"],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\({idFondamentale, senCompl, cosCompl, tanCompl, senDiffPi2, 
          cosDiffPi2, tanDiffPi2, senSuppl, cosSuppl, tanSuppl, senExpl, 
          cosExpl, tanExpl, senOpp, cosOpp, tanOpp, cosDiff, cosAdd, senDiff, 
          senAdd, tanAdd, tanDiff, senDupl, cosDupl, cosDuplSen, cosDuplCos, 
          tanDupl} = {cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 1, 
          sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          tan[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cot[\[Alpha]], 
          sen[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          tan[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-\(cos[\[Alpha]]\/sen[\
\[Alpha]]\)\), sen[\[Pi] - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          cos[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          sen[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] + \[Alpha]_] \[RuleDelayed] tan[\[Alpha]], 
          sen[\(-\[Alpha]_\)] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\(-\[Alpha]_\)] \[RuleDelayed] cos[\[Alpha]], 
          tan[\(-\[Alpha]_\)] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          cos[\[Alpha]_ - \[Beta]_] \[RuleDelayed] 
            cos[\[Alpha]]\ cos[\[Beta]] + sen[\[Alpha]]\ sen[\[Beta]], 
          cos[\[Alpha]_ + \[Beta]_] \[RuleDelayed] 
            cos[\[Alpha]]\ cos[\[Beta]] - sen[\[Alpha]]\ sen[\[Beta]], 
          sen[\[Alpha]_ - \[Beta]_] \[RuleDelayed] 
            cos[\[Beta]]\ sen[\[Alpha]] - cos[\[Alpha]]\ sen[\[Beta]], 
          sen[\[Alpha]_ + \[Beta]_] \[RuleDelayed] 
            cos[\[Beta]]\ sen[\[Alpha]] + cos[\[Alpha]]\ sen[\[Beta]], 
          tan[\[Alpha]_ + \[Beta]_] \[RuleDelayed] \(tan[\[Alpha]] + tan[\
\[Beta]]\)\/\(1 - tan[\[Alpha]]\ tan[\[Beta]]\), 
          tan[\[Alpha]_ - \[Beta]_] \[RuleDelayed] \(tan[\[Alpha]] - tan[\
\[Beta]]\)\/\(1 + tan[\[Alpha]]\ tan[\[Beta]]\), 
          sen[2\ \[Alpha]_] \[RuleDelayed] 2\ cos[\[Alpha]]\ sen[\[Alpha]], 
          cos[2\ \[Alpha]_] \[RuleDelayed] 
            cos[\[Alpha]]\^2 - sen[\[Alpha]]\^2, 
          cos[2\ \[Alpha]_] \[RuleDelayed] 1 - 2\ sen[\[Alpha]]\^2, 
          cos[2\ \[Alpha]_] \[RuleDelayed] \(-1\) + 2\ cos[\[Alpha]]\^2, 
          tan[2\ \[Alpha]_] \[RuleDelayed] \(2\ tan[\[Alpha]]\)\/\(1 - tan[\
\[Alpha]]\^2\)};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Formule di bisezione per seno, coseno, tangente", "Subsection"],

Cell[TextData[{
  "In modo inverso rispetto alle formule di duplicazione, quelle di bisezione \
esprimono le funzioni goniometriche di un angolo in termini dell'angolo \
doppio. Iniziamo sfruttando una delle tre forme della formula di duplicazione \
per il ",
  Cell[BoxData[
      \(TraditionalForm\`cos(2  \[Alpha])\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(toIdentita[cosDuplSen]\)], "Input"],

Cell[BoxData[
    \(cos[2\ \[Alpha]] \[Equal] 1 - 2\ sen[\[Alpha]]\^2\)], "Output"]
}, Closed]],

Cell[TextData[{
  "ed esplicitiamo il ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(sen(\[Alpha])\), Cell[""]}], TraditionalForm]]],
  "in funzione del ",
  Cell[BoxData[
      \(TraditionalForm\`cos(2  \[Alpha])\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% - 1\)], "Input"],

Cell[BoxData[
    \(\(-1\) + cos[2\ \[Alpha]] \[Equal] \(-2\)\ sen[\[Alpha]]\^2\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(scambia[\(-%\)/2]\)], "Input"],

Cell[BoxData[
    \(sen[\[Alpha]]\^2 \[Equal] 1\/2\ \((1 - cos[2\ \[Alpha]])\)\)], "Output"]
}, Closed]],

Cell["L'estrazione della radice quadrata comporta", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sqrt /@ %\)], "Input"],

Cell[BoxData[
    \(\@sen[\[Alpha]]\^2 \[Equal] \@\(1 - cos[2\ \[Alpha]]\)\/\@2\)], "Output"]
}, Closed]],

Cell["\<\
e quindi ricordando che il primo membro rappresenta un valore assoluto, \
l'espressione diventa\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MapAt[Abs, %, 1]\)], "Input"],

Cell[BoxData[
    \(Abs[sen[\[Alpha]]] \[Equal] \@\(1 - cos[2\ \[Alpha]]\)\/\@2\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Sostituendo ad ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " l'angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\/2\)]],
  " otteniamo quanto richiesto"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. \[Alpha] \[Rule] \[Alpha]/2\)], "Input"],

Cell[BoxData[
    \(Abs[sen[\[Alpha]\/2]] \[Equal] \@\(1 - cos[\[Alpha]]\)\/\@2\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Si tenga presente che per utilizzare proficuamente formule di questo tipo, \
contenenti il valore assoluto di una funzione goniometrica, sar\[AGrave] \
necessario conoscere il quadrante dell'angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\/2\)]],
  " cos\[IGrave] da riconoscere il segno della funzione ad argomento e \
\"aprire\" il valore assoluto. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(senBis = toRule[%]\)], "Input"],

Cell[BoxData[
    \(Abs[
        sen[\[Alpha]\/2]] \[RuleDelayed] \@\(1 - cos[\[Alpha]]\)\/\@2\)], \
"Output"]
}, Closed]],

Cell["Abbiamo in sostanza dimostrato", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(|\)\(sen\ \[Alpha]\/2\)\(|\)\) = \@\(\(1 - cos(\
\[Alpha])\)\/2\)\)]]], "Definition",
  FontFamily->"Courier"],

Cell["Partendo invece dalla forma", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(toIdentita[cosDuplCos]\)], "Input"],

Cell[BoxData[
    \(cos[2\ \[Alpha]] \[Equal] \(-1\) + 2\ cos[\[Alpha]]\^2\)], "Output"]
}, Closed]],

Cell[TextData[{
  "esplicitiamo il ",
  Cell[BoxData[
      \(TraditionalForm\`cos(\[Alpha])\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(scambia[\((% + 1)\) 1/2]\)], "Input"],

Cell[BoxData[
    \(cos[\[Alpha]]\^2 \[Equal] 1\/2\ \((1 + cos[2\ \[Alpha]])\)\)], "Output"]
}, Closed]],

Cell["e quindi l'estrazione della radice quadrata conduce alla", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sqrt /@ %\)], "Input"],

Cell[BoxData[
    \(\@cos[\[Alpha]]\^2 \[Equal] \@\(1 + cos[2\ \[Alpha]]\)\/\@2\)], "Output"]
}, Closed]],

Cell["ossia", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MapAt[Abs, %, 1]\)], "Input"],

Cell[BoxData[
    \(Abs[cos[\[Alpha]]] \[Equal] \@\(1 + cos[2\ \[Alpha]]\)\/\@2\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Eseguiamo infine la sostituzione ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] \[Rule] \[Alpha]\/2\)]],
  "per ottenere la scrittura canonica per tale identit\[AGrave]"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. \[Alpha] \[Rule] \[Alpha]/2\)], "Input"],

Cell[BoxData[
    \(Abs[cos[\[Alpha]\/2]] \[Equal] \@\(1 + cos[\[Alpha]]\)\/\@2\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cosBis = toRule[%]\)], "Input"],

Cell[BoxData[
    \(Abs[
        cos[\[Alpha]\/2]] \[RuleDelayed] \@\(1 + cos[\[Alpha]]\)\/\@2\)], \
"Output"]
}, Closed]],

Cell[TextData[{
  "Volendo giungere anche alla formula di bisezione per la tangente \[EGrave] \
sufficiente eseguire il rapporto, membro a membro, delle due identit\[AGrave] \
appena trovate: ovviamente quanto si deduce vale nell'ipotesi che il \
denominatore sia diverso dallo zero (",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] \[NotEqual] \[Pi] + 2  k\ \[Pi]\)]],
  "). Difatti"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(toIdentita[senBis]/toIdentita[cosBis]\)], "Input"],

Cell[BoxData[
    \(Abs[sen[\[Alpha]\/2]]\/Abs[cos[\[Alpha]\/2]] \[Equal] \@\(1 - cos[\
\[Alpha]]\)\/\@\(1 + cos[\[Alpha]]\)\)], "Output"]
}, Closed]],

Cell["Possiamo quindi porre", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Abs[Tan[\[Alpha]/2]] \[Equal] %[\([2]\)]\)], "Input"],

Cell[BoxData[
    \(Abs[
        Tan[\[Alpha]\/2]] \[Equal] \@\(1 - cos[\[Alpha]]\)\/\@\(1 + cos[\
\[Alpha]]\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tanBis = toRule[%]\)], "Input"],

Cell[BoxData[
    \(Abs[
        Tan[\[Alpha]\/2]] \[RuleDelayed] \@\(1 - cos[\[Alpha]]\)\/\@\(1 + \
cos[\[Alpha]]\)\)], "Output"]
}, Closed]],

Cell["Le tre identit\[AGrave] ottenute sono in conclusione ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(sen\ \[Alpha]\/2\)\(|\)\) = \@\(\(1 - cos(\
\[Alpha])\)\/2\)\)]],
  "\n\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(cos\ \[Alpha]\/2\)\(|\)\) = \@\(\(1 + cos(\
\[Alpha])\)\/2\)\)]],
  "\n\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(tan\ \[Alpha]\/2\)\(|\)\) = \@\(\(1 - cos(\
\[Alpha])\)\/\(1 + cos(\[Alpha])\)\)\)]]
}], "Definition",
  FontFamily->"Courier"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Formule parametriche razionali", "Section"],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\({idFondamentale, senCompl, cosCompl, tanCompl, senDiffPi2, 
          cosDiffPi2, tanDiffPi2, senSuppl, cosSuppl, tanSuppl, senExpl, 
          cosExpl, tanExpl, senOpp, cosOpp, tanOpp, cosDiff, cosAdd, senDiff, 
          senAdd, tanAdd, tanDiff, senDupl, cosDupl, cosDuplSen, cosDuplCos, 
          tanDupl, senBis, cosBis, 
          tanBis} = {cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 1, 
          sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          tan[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cot[\[Alpha]], 
          sen[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          tan[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-\(cos[\[Alpha]]\/sen[\
\[Alpha]]\)\), sen[\[Pi] - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          cos[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          sen[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] + \[Alpha]_] \[RuleDelayed] tan[\[Alpha]], 
          sen[\(-\[Alpha]_\)] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\(-\[Alpha]_\)] \[RuleDelayed] cos[\[Alpha]], 
          tan[\(-\[Alpha]_\)] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          cos[\[Alpha]_ - \[Beta]_] \[RuleDelayed] 
            cos[\[Alpha]]\ cos[\[Beta]] + sen[\[Alpha]]\ sen[\[Beta]], 
          cos[\[Alpha]_ + \[Beta]_] \[RuleDelayed] 
            cos[\[Alpha]]\ cos[\[Beta]] - sen[\[Alpha]]\ sen[\[Beta]], 
          sen[\[Alpha]_ - \[Beta]_] \[RuleDelayed] 
            cos[\[Beta]]\ sen[\[Alpha]] - cos[\[Alpha]]\ sen[\[Beta]], 
          sen[\[Alpha]_ + \[Beta]_] \[RuleDelayed] 
            cos[\[Beta]]\ sen[\[Alpha]] + cos[\[Alpha]]\ sen[\[Beta]], 
          tan[\[Alpha]_ + \[Beta]_] \[RuleDelayed] \(tan[\[Alpha]] + tan[\
\[Beta]]\)\/\(1 - tan[\[Alpha]]\ tan[\[Beta]]\), 
          tan[\[Alpha]_ - \[Beta]_] \[RuleDelayed] \(tan[\[Alpha]] - tan[\
\[Beta]]\)\/\(1 + tan[\[Alpha]]\ tan[\[Beta]]\), 
          sen[2\ \[Alpha]_] \[RuleDelayed] 2\ cos[\[Alpha]]\ sen[\[Alpha]], 
          cos[2\ \[Alpha]_] \[RuleDelayed] 
            cos[\[Alpha]]\^2 - sen[\[Alpha]]\^2, 
          cos[2\ \[Alpha]_] \[RuleDelayed] 1 - 2\ sen[\[Alpha]]\^2, 
          cos[2\ \[Alpha]_] \[RuleDelayed] \(-1\) + 2\ cos[\[Alpha]]\^2, 
          tan[2\ \[Alpha]_] \[RuleDelayed] \(2\ tan[\[Alpha]]\)\/\(1 - tan[\
\[Alpha]]\^2\), 
          Abs[sen[\[Alpha]_\/2]] \[RuleDelayed] \@\(1 - cos[\[Alpha]]\)\/\@2, 
          Abs[cos[\[Alpha]_\/2]] \[RuleDelayed] \@\(1 + cos[\[Alpha]]\)\/\@2, 
          Abs[Tan[\[Alpha]_\/2]] \[RuleDelayed] \@\(1 - \
cos[\[Alpha]]\)\/\@\(1 + cos[\[Alpha]]\)};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Formule parametriche razionali di seno, coseno e tangente", "Subsection"],

Cell[TextData[{
  "Le formule che dimostreremo in questa sezione si mostrano utili in diverse \
occasioni, in particolare quando non si dispone di sufficienti informazioni \
sul quadrante di appartenenza dell'angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ". Difatti nelle seguenti relazioni non compaiono termini entro valori \
assoluti per i quali \[EGrave] necessario disporre di tale informazione.  \n\
Partiamo dalla formula di duplicazione del seno"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(toIdentita[senDupl]\)], "Input"],

Cell[BoxData[
    \(sen[2\ \[Alpha]] \[Equal] 2\ cos[\[Alpha]]\ sen[\[Alpha]]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "e scriviamo il denominatore del secondo membro (che vale evidentemente 1) \
come ",
  Cell[BoxData[
      \(TraditionalForm\`\(sen\^2\)(\[Alpha]) + \(cos\^2\)(\[Alpha]) = 1\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MapAt[#\ \ 1/\((sen[\[Alpha]]^2 + 
                cos[\[Alpha]]^2)\) &, %, {2}]\)], "Input"],

Cell[BoxData[
    \(sen[
        2\ \[Alpha]] \[Equal] \(2\ cos[\[Alpha]]\ sen[\[Alpha]]\)\/\(cos[\
\[Alpha]]\^2 + sen[\[Alpha]]\^2\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Dividiamo ora il numeratore e il denominatore per ",
  Cell[BoxData[
      \(TraditionalForm\`\(cos\^2\)(\[Alpha]) \[NotEqual] 0\)]],
  " supponendo quindi che ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] \[NotEqual] \[Pi]\/2 + k\ \[Pi]\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(applicaND[%, HoldForm[#/cos[\[Alpha]]^2] &]\)], "Input"],

Cell[BoxData[
    RowBox[{\(sen[2\ \[Alpha]]\), "\[Equal]", 
      FractionBox[
        TagBox[\(\(2\ cos[\[Alpha]]\ sen[\[Alpha]]\)\/cos[\[Alpha]]\^2\),
          HoldForm], 
        TagBox[\(\(cos[\[Alpha]]\^2 + sen[\[Alpha]]\^2\)\/cos[\[Alpha]]\^2\),
          HoldForm]]}]], "Output"]
}, Closed]],

Cell[TextData[{
  "Ricordando che ",
  Cell[BoxData[
      \(TraditionalForm\`tan(\[Alpha]) = \(sen(\[Alpha])\)\/\(cos(\[Alpha])\)\
\)]],
  " il secondo membro si riscrive"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(applicaND[%, Apart[rilascia[#]] &] //. id4\)], "Input"],

Cell[BoxData[
    \(sen[
        2\ \[Alpha]] \[Equal] \(2\ tan[\[Alpha]]\)\/\(1 + \
tan[\[Alpha]]\^2\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Infine per riportare l'identit\[AGrave] appena trovata alla forma canonica \
eseguiamo la sostituzione ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] \[Rule] \[Alpha]\/2\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. \[Alpha] \[Rule] \[Alpha]/2\)], "Input"],

Cell[BoxData[
    \(sen[\[Alpha]] \[Equal] \(2\ tan[\[Alpha]\/2]\)\/\(1 + \
tan[\[Alpha]\/2]\^2\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(senRaz = toRule[%]\)], "Input"],

Cell[BoxData[
    \(sen[\[Alpha]] \[RuleDelayed] \(2\ tan[\[Alpha]\/2]\)\/\(1 + \
tan[\[Alpha]\/2]\^2\)\)], "Output"]
}, Closed]],

Cell["\<\
Procedendo allo stesso modo possiamo giungere all'identit\[AGrave] collegata \
al coseno: difatti, riscritta\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(toIdentita[cosDupl]\)], "Input"],

Cell[BoxData[
    \(cos[2\ \[Alpha]] \[Equal] 
      cos[\[Alpha]]\^2 - sen[\[Alpha]]\^2\)], "Output"]
}, Closed]],

Cell["come", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MapAt[#\ \ 1/\((sen[\[Alpha]]^2 + 
                cos[\[Alpha]]^2)\) &, %, {2}]\)], "Input"],

Cell[BoxData[
    \(cos[
        2\ \[Alpha]] \[Equal] \(cos[\[Alpha]]\^2 - sen[\[Alpha]]\^2\)\/\(cos[\
\[Alpha]]\^2 + sen[\[Alpha]]\^2\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "dividiamo ancora il numeratore e il denominatore per ",
  Cell[BoxData[
      \(TraditionalForm\`\(cos\^2\)(\[Alpha]) \[NotEqual] 0\)]],
  " supponendo quindi che ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] \[NotEqual] \[Pi]\/2 + k\ \[Pi]\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(applicaND[%, HoldForm[\((#)\)\ \((1/cos[\[Alpha]]^2)\)] &]\)], "Input"],

Cell[BoxData[
    RowBox[{\(cos[2\ \[Alpha]]\), "\[Equal]", 
      FractionBox[
        TagBox[\(\(cos[\[Alpha]]\^2 - sen[\[Alpha]]\^2\)\/cos[\[Alpha]]\^2\),
          HoldForm], 
        TagBox[\(\(cos[\[Alpha]]\^2 + sen[\[Alpha]]\^2\)\/cos[\[Alpha]]\^2\),
          HoldForm]]}]], "Output"]
}, Closed]],

Cell["\<\
Per la propriet\[AGrave] distributiva e la definizione della tangente, questa \
diviene\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(applicaND[%, Apart[rilascia[#]] &] //. id4\)], "Input"],

Cell[BoxData[
    \(cos[
        2\ \[Alpha]] \[Equal] \(1 - tan[\[Alpha]]\^2\)\/\(1 + \
tan[\[Alpha]]\^2\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "L'applicazione della sostituzione ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] \[Rule] \[Alpha]\/2\)]],
  " implica"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. \[Alpha] \[Rule] \[Alpha]/2\)], "Input"],

Cell[BoxData[
    \(cos[\[Alpha]] \[Equal] \(1 - tan[\[Alpha]\/2]\^2\)\/\(1 + \
tan[\[Alpha]\/2]\^2\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cosRaz = toRule[%]\)], "Input"],

Cell[BoxData[
    \(cos[\[Alpha]] \[RuleDelayed] \(1 - tan[\[Alpha]\/2]\^2\)\/\(1 + tan[\
\[Alpha]\/2]\^2\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "La terza ed ultima formula di bisezione si ottiene immediatamente con la \
sostituzione ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] \[Rule] \[Alpha]\/2\)]],
  "a partire da quella di duplicazione per la tangente"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(toIdentita[tanDupl]\)], "Input"],

Cell[BoxData[
    \(tan[
        2\ \[Alpha]] \[Equal] \(2\ tan[\[Alpha]]\)\/\(1 - \
tan[\[Alpha]]\^2\)\)], "Output"]
}, Closed]],

Cell["Difatti si ha", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. \[Alpha] \[Rule] \[Alpha]/2\)], "Input"],

Cell[BoxData[
    \(tan[\[Alpha]] \[Equal] \(2\ tan[\[Alpha]\/2]\)\/\(1 - \
tan[\[Alpha]\/2]\^2\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tanRaz = toRule[%]\)], "Input"],

Cell[BoxData[
    \(tan[\[Alpha]] \[RuleDelayed] \(2\ tan[\[Alpha]\/2]\)\/\(1 - \
tan[\[Alpha]\/2]\^2\)\)], "Output"]
}, Closed]],

Cell["In conclusione, le formule di bisezione ottenute sono", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`sen(\[Alpha]) = \(2 \( tan(\[Alpha]\/2)\)\)\/\(1 + \
\(tan\^2\)(\[Alpha]\/2)\)\)]],
  "\tcon ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\/2 \[NotEqual] \[Pi]\/2 + k\[Pi]\)]],
  "\n\n",
  Cell[BoxData[
      \(TraditionalForm\`cos(\[Alpha]) = \(1 - \(tan\^2\)(\[Alpha]\/2)\)\/\(1 \
+ \(tan\^2\)(\[Alpha]\/2)\)\)]],
  "\tcon ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\/2 \[NotEqual] \[Pi]\/2 + k\[Pi]\)]],
  "\n\ntan(\[Alpha])=",
  Cell[BoxData[
      \(TraditionalForm\`\(2 \( tan(\[Alpha]\/2)\)\)\/\(1 - \(tan\^2\)(\
\[Alpha]\/2)\)\)]],
  "\tcon ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\/2 \[NotEqual] \[Pi]\/2 + k\[Pi]\)]]
}], "Definition",
  FontFamily->"Courier"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Formule di Werner e prostaferesi", "Section"],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[
    \(\({idFondamentale, senCompl, cosCompl, tanCompl, senDiffPi2, 
          cosDiffPi2, tanDiffPi2, senSuppl, cosSuppl, tanSuppl, senExpl, 
          cosExpl, tanExpl, senOpp, cosOpp, tanOpp, cosDiff, cosAdd, senDiff, 
          senAdd, tanAdd, tanDiff, senDupl, cosDupl, cosDuplSen, cosDuplCos, 
          tanDupl, senBis, cosBis, tanBis, senRaz, cosRaz, 
          tanRaz} = {cos[\[Alpha]_]\^2 + sen[\[Alpha]_]\^2 \[RuleDelayed] 1, 
          sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          tan[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cot[\[Alpha]], 
          sen[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          tan[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-\(cos[\[Alpha]]\/sen[\
\[Alpha]]\)\), sen[\[Pi] - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          cos[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          sen[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] + \[Alpha]_] \[RuleDelayed] tan[\[Alpha]], 
          sen[\(-\[Alpha]_\)] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\(-\[Alpha]_\)] \[RuleDelayed] cos[\[Alpha]], 
          tan[\(-\[Alpha]_\)] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          cos[\[Alpha]_ - \[Beta]_] \[RuleDelayed] 
            cos[\[Alpha]]\ cos[\[Beta]] + sen[\[Alpha]]\ sen[\[Beta]], 
          cos[\[Alpha]_ + \[Beta]_] \[RuleDelayed] 
            cos[\[Alpha]]\ cos[\[Beta]] - sen[\[Alpha]]\ sen[\[Beta]], 
          sen[\[Alpha]_ - \[Beta]_] \[RuleDelayed] 
            cos[\[Beta]]\ sen[\[Alpha]] - cos[\[Alpha]]\ sen[\[Beta]], 
          sen[\[Alpha]_ + \[Beta]_] \[RuleDelayed] 
            cos[\[Beta]]\ sen[\[Alpha]] + cos[\[Alpha]]\ sen[\[Beta]], 
          tan[\[Alpha]_ + \[Beta]_] \[RuleDelayed] \(tan[\[Alpha]] + tan[\
\[Beta]]\)\/\(1 - tan[\[Alpha]]\ tan[\[Beta]]\), 
          tan[\[Alpha]_ - \[Beta]_] \[RuleDelayed] \(tan[\[Alpha]] - tan[\
\[Beta]]\)\/\(1 + tan[\[Alpha]]\ tan[\[Beta]]\), 
          sen[2\ \[Alpha]_] \[RuleDelayed] 2\ cos[\[Alpha]]\ sen[\[Alpha]], 
          cos[2\ \[Alpha]_] \[RuleDelayed] 
            cos[\[Alpha]]\^2 - sen[\[Alpha]]\^2, 
          cos[2\ \[Alpha]_] \[RuleDelayed] 1 - 2\ sen[\[Alpha]]\^2, 
          cos[2\ \[Alpha]_] \[RuleDelayed] \(-1\) + 2\ cos[\[Alpha]]\^2, 
          tan[2\ \[Alpha]_] \[RuleDelayed] \(2\ tan[\[Alpha]]\)\/\(1 - tan[\
\[Alpha]]\^2\), 
          Abs[sen[\[Alpha]_\/2]] \[RuleDelayed] \@\(1 - cos[\[Alpha]]\)\/\@2, 
          Abs[cos[\[Alpha]_\/2]] \[RuleDelayed] \@\(1 + cos[\[Alpha]]\)\/\@2, 
          Abs[Tan[\[Alpha]_\/2]] \[RuleDelayed] \@\(1 - \
cos[\[Alpha]]\)\/\@\(1 + cos[\[Alpha]]\), 
          sen[\[Alpha]_] \[RuleDelayed] \(2\ tan[\[Alpha]\/2]\)\/\(1 + tan[\
\[Alpha]\/2]\^2\), 
          cos[\[Alpha]_] \[RuleDelayed] \(1 - tan[\[Alpha]\/2]\^2\)\/\(1 + \
tan[\[Alpha]\/2]\^2\), 
          tan[\[Alpha]_] \[RuleDelayed] \(2\ tan[\[Alpha]\/2]\)\/\(1 - tan[\
\[Alpha]\/2]\^2\)};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Formule di Werner", "Subsection"],

Cell["\<\
Riportate di seguito le formule di addizione e sottrazione per il seno e \
coseno, deduciamo da queste delle ulteriori identit\[AGrave] con le quali \
potremo collegare prodotti di funzioni goniometriche con somme.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[{{"\<(1) senAdd\>", "\<(2) senDiff\>", "\<(3) cosAdd\>", \
"\<(4) cosDiff\>"}, toIdentita /@ {senAdd, senDiff, cosAdd, cosDiff}}] // 
      TableForm\)], "Input",
  CellTags->"riassunto"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"(1) senAdd\"\>", \(sen[\[Alpha] + \[Beta]] \[Equal] 
              cos[\[Beta]]\ sen[\[Alpha]] + cos[\[Alpha]]\ sen[\[Beta]]\)},
          {"\<\"(2) senDiff\"\>", \(sen[\[Alpha] - \[Beta]] \[Equal] 
              cos[\[Beta]]\ sen[\[Alpha]] - cos[\[Alpha]]\ sen[\[Beta]]\)},
          {"\<\"(3) cosAdd\"\>", \(cos[\[Alpha] + \[Beta]] \[Equal] 
              cos[\[Alpha]]\ cos[\[Beta]] - sen[\[Alpha]]\ sen[\[Beta]]\)},
          {"\<\"(4) cosDiff\"\>", \(cos[\[Alpha] - \[Beta]] \[Equal] 
              cos[\[Alpha]]\ cos[\[Beta]] + sen[\[Alpha]]\ sen[\[Beta]]\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellTags->"riassunto"]
}, Closed]],

Cell[TextData[{
  "Sommando quindi in colonna le ",
  ButtonBox["prime due",
    ButtonData:>"riassunto",
    ButtonStyle->"Hyperlink"],
  ", otteniamo"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus @@ \(toIdentita /@ {senAdd, senDiff}\)\)], "Input"],

Cell[BoxData[
    \(sen[\[Alpha] - \[Beta]] + sen[\[Alpha] + \[Beta]] \[Equal] 
      2\ cos[\[Beta]]\ sen[\[Alpha]]\)], "Output"]
}, Closed]],

Cell["\<\
che evidentemente associa il prodotto del seno e coseno con una somma. \
Dividendo per 2 e scrivendo il secondo membro come primo abbiamo \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(%\ /2 // scambia\)], "Input"],

Cell[BoxData[
    \(cos[\[Beta]]\ sen[\[Alpha]] \[Equal] 
      1\/2\ \((sen[\[Alpha] - \[Beta]] + 
            sen[\[Alpha] + \[Beta]])\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wernerCosSen = toRule[%]\)], "Input"],

Cell[BoxData[
    \(cos[\[Beta]]\ sen[\[Alpha]] \[RuleDelayed] 
      1\/2\ \((sen[\[Alpha] - \[Beta]] + 
            sen[\[Alpha] + \[Beta]])\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "espressione che costituisce la prima formula di Werner. Se, al contrario, \
eseguiamo la differenza delle ",
  ButtonBox["prime due",
    ButtonData:>"riassunto",
    ButtonStyle->"Hyperlink"],
  " identit\[AGrave] e procediamo allo stesso modo otteniamo"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Subtract @@ \(toIdentita /@ {senAdd, senDiff}\) // scambia\)], "Input"],

Cell[BoxData[
    \(2\ cos[\[Alpha]]\ sen[\[Beta]] \[Equal] \(-sen[\[Alpha] - \[Beta]]\) + 
        sen[\[Alpha] + \[Beta]]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(%/2\)], "Input"],

Cell[BoxData[
    \(cos[\[Alpha]]\ sen[\[Beta]] \[Equal] 
      1\/2\ \((\(-sen[\[Alpha] - \[Beta]]\) + 
            sen[\[Alpha] + \[Beta]])\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "che sostanzialmente mostra il medesimo risultato a parte lo scambio \
dell'angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " con ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\)]],
  ". Eseguendo invece la somma della ",
  ButtonBox["terza e quarta",
    ButtonData:>"riassunto",
    ButtonStyle->"Hyperlink"],
  " identit\[AGrave]"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus @@ \(toIdentita /@ {cosAdd, cosDiff}\)\)], "Input"],

Cell[BoxData[
    \(cos[\[Alpha] - \[Beta]] + cos[\[Alpha] + \[Beta]] \[Equal] 
      2\ cos[\[Alpha]]\ cos[\[Beta]]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "giungiamo, dopo aver scambiato i membri e diviso per ",
  Cell[BoxData[
      \(TraditionalForm\`2\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(%/2 // scambia\)], "Input"],

Cell[BoxData[
    \(cos[\[Alpha]]\ cos[\[Beta]] \[Equal] 
      1\/2\ \((cos[\[Alpha] - \[Beta]] + 
            cos[\[Alpha] + \[Beta]])\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wernerCosCos = toRule[%]\)], "Input"],

Cell[BoxData[
    \(cos[\[Alpha]]\ cos[\[Beta]] \[RuleDelayed] 
      1\/2\ \((cos[\[Alpha] - \[Beta]] + 
            cos[\[Alpha] + \[Beta]])\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "alla seconda formula di Werner: questa collega il prodotto di due coseni \
con una somma. Infine sottraendo la ",
  ButtonBox["quarta dalla terza",
    ButtonData:>"riassunto",
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Subtract @@ \(toIdentita /@ {cosAdd, cosDiff}\)\)], "Input"],

Cell[BoxData[
    \(\(-cos[\[Alpha] - \[Beta]]\) + 
        cos[\[Alpha] + \[Beta]] \[Equal] \(-2\)\ sen[\[Alpha]]\ \
sen[\[Beta]]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "e semplificata dividendola per ",
  Cell[BoxData[
      \(TraditionalForm\`\(-2\)\)]],
  " e quindi scambiati i membri, ricaviamo la terza formula di Werner che \
riporta un prodotto di seni in una somma."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(%/\(-2\) // scambia\)], "Input"],

Cell[BoxData[
    \(sen[\[Alpha]]\ sen[\[Beta]] \[Equal] 
      1\/2\ \((cos[\[Alpha] - \[Beta]] - 
            cos[\[Alpha] + \[Beta]])\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wernerSenSen = toRule[%]\)], "Input"],

Cell[BoxData[
    \(sen[\[Alpha]]\ sen[\[Beta]] \[RuleDelayed] 
      1\/2\ \((cos[\[Alpha] - \[Beta]] - 
            cos[\[Alpha] + \[Beta]])\)\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Formule di prostaferesi", "Subsection"],

Cell[TextData[{
  "Infine, le quattro formule di prostaferesi si deducono dalle espressioni \
intermedie servite per giungere alle relazioni di Werner. A tal fine si \
sostituiscono, in luogo degli angoli ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " e ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\)]],
  ", le nuove variabili"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox["{",
          SpanMaxSize->Infinity,
          FontColor->GrayLevel[0]], GridBox[{
            {\(p = \[Alpha] + \[Beta]\)},
            {\(q = \[Alpha] - \[Beta]\)}
            }]}], TraditionalForm]], "DisplayFormula"],

Cell[TextData[{
  "Esplicitati ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " e ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\)]],
  " in termini di ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " e ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(sol = 
      Flatten[Solve[{\[Alpha] + \[Beta] \[Equal] 
                p, \[Alpha] - \[Beta] \[Equal] q}, {\[Alpha], \[Beta]}]] // 
        Simplify\)\)\)], "Input"],

Cell[BoxData[
    \({\[Alpha] \[Rule] \(p + q\)\/2, \[Beta] \[Rule] \(p - q\)\/2}\)], \
"Output"]
}, Closed]],

Cell["\<\
e, dopo aver sommato la formula di addizione per il seno con quella della \
sottrazione,\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus @@ \(toIdentita /@ {senAdd, senDiff}\)\)], "Input"],

Cell[BoxData[
    \(sen[\[Alpha] - \[Beta]] + sen[\[Alpha] + \[Beta]] \[Equal] 
      2\ cos[\[Beta]]\ sen[\[Alpha]]\)], "Output"]
}, Closed]],

Cell["\[EGrave] sufficiente sostituire le nuove variabili", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. sol\)], "Input"],

Cell[BoxData[
    \(sen[\(p - q\)\/2 + \(p + q\)\/2] + 
        sen[1\/2\ \((\(-p\) + q)\) + \(p + q\)\/2] \[Equal] 
      2\ cos[\(p - q\)\/2]\ sen[\(p + q\)\/2]\)], "Output"]
}, Closed]],

Cell["e semplificare", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% // Simplify\)], "Input"],

Cell[BoxData[
    \(sen[p] + sen[q] \[Equal] 
      2\ cos[\(p - q\)\/2]\ sen[\(p + q\)\/2]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(proSenAddSen = toRule[%, {p, q}]\)], "Input"],

Cell[BoxData[
    \(sen[p_] + sen[q_] \[RuleDelayed] 
      2\ cos[\(p - q\)\/2]\ sen[\(p + q\)\/2]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "\[CapitalEGrave] questa la prima formula di prostaferesi che, come appare \
evidente, riduce una somma di seni ad un prodotto. Le altre si ottengono in \
maniera analoga: per ottenere la seconda identit\[AGrave] di prostaferesi, \
riferendoci sempre alle identit\[AGrave] di inizio sezione va sottratta la ",
  ButtonBox["seconda dalla prima",
    ButtonData:>"riassunto",
    ButtonStyle->"Hyperlink"],
  " "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Subtract @@ \(toIdentita /@ {senAdd, senDiff}\)\)], "Input"],

Cell[BoxData[
    \(\(-sen[\[Alpha] - \[Beta]]\) + sen[\[Alpha] + \[Beta]] \[Equal] 
      2\ cos[\[Alpha]]\ sen[\[Beta]]\)], "Output"]
}, Closed]],

Cell["per cui, scambiati i membri", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% // scambia\)], "Input"],

Cell[BoxData[
    \(2\ cos[\[Alpha]]\ sen[\[Beta]] \[Equal] \(-sen[\[Alpha] - \[Beta]]\) + 
        sen[\[Alpha] + \[Beta]]\)], "Output"]
}, Closed]],

Cell["e sostituite le nuove variabili angolari si ottiene", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. sol // Simplify\)], "Input"],

Cell[BoxData[
    \(sen[p] \[Equal] 
      2\ cos[\(p + q\)\/2]\ sen[\(p - q\)\/2] + sen[q]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% - sen[q]\)], "Input"],

Cell[BoxData[
    \(sen[p] - sen[q] \[Equal] 
      2\ cos[\(p + q\)\/2]\ sen[\(p - q\)\/2]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(proSenDiffSen = toRule[%, {p, q}]\)], "Input"],

Cell[BoxData[
    \(sen[p_] - sen[q_] \[RuleDelayed] 
      2\ cos[\(p + q\)\/2]\ sen[\(p - q\)\/2]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Per la terza di prostaferesi, si parte invece dalla somma della ",
  ButtonBox["terza identit\[AGrave]",
    ButtonData:>"riassunto",
    ButtonStyle->"Hyperlink"],
  " iniziale con la ",
  ButtonBox["quarta",
    ButtonData:>"riassunto",
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus @@ \(toIdentita /@ {cosAdd, cosDiff}\)\)], "Input"],

Cell[BoxData[
    \(cos[\[Alpha] - \[Beta]] + cos[\[Alpha] + \[Beta]] \[Equal] 
      2\ cos[\[Alpha]]\ cos[\[Beta]]\)], "Output"]
}, Closed]],

Cell["e con il medesimo processo si trova", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. sol // Simplify\)], "Input"],

Cell[BoxData[
    \(cos[p] + cos[q] \[Equal] 
      2\ cos[\(p - q\)\/2]\ cos[\(p + q\)\/2]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(proCosAddCos = toRule[%, {p, q}]\)], "Input"],

Cell[BoxData[
    \(cos[p_] + cos[q_] \[RuleDelayed] 
      2\ cos[\(p - q\)\/2]\ cos[\(p + q\)\/2]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Per ultimo, sottraendo la ",
  ButtonBox["quarta dalla terza",
    ButtonData:>"riassunto",
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Subtract @@ \(toIdentita /@ {cosAdd, cosDiff}\)\)], "Input"],

Cell[BoxData[
    \(\(-cos[\[Alpha] - \[Beta]]\) + 
        cos[\[Alpha] + \[Beta]] \[Equal] \(-2\)\ sen[\[Alpha]]\ \
sen[\[Beta]]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "e, inserite le varibili ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " e ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. sol // Simplify\)], "Input"],

Cell[BoxData[
    \(cos[p] + 2\ sen[\(p - q\)\/2]\ sen[\(p + q\)\/2] \[Equal] 
      cos[q]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% - cos[p] // scambia\)], "Input"],

Cell[BoxData[
    \(\(-cos[p]\) + cos[q] \[Equal] 
      2\ sen[\(p - q\)\/2]\ sen[\(p + q\)\/2]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "la moltiplicazione per ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  " conduce al risultato cercato"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(%\ \((\(-1\))\)\)], "Input"],

Cell[BoxData[
    \(cos[p] - 
        cos[q] \[Equal] \(-2\)\ sen[\(p - q\)\/2]\ sen[\(p + q\)\/2]\)], \
"Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(proCosDiffCos = toRule[%, {p, q}]\)], "Input"],

Cell[BoxData[
    \(cos[p_] - 
        cos[q_] \[RuleDelayed] \(-2\)\ sen[\(p - q\)\/2]\ sen[\(p + \
q\)\/2]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "In conclusione le",
  StyleBox[" 3 f",
    FontWeight->"Bold"],
  StyleBox["ormule distinte di Werner",
    FontWeight->"Bold"],
  " sono"
}], "Text"],

Cell[BoxData[{
    \(cos \((\[Alpha])\)\ sen \((\[Beta])\) \[Equal] \(1\/2\)\ [
        sen \((\[Alpha] + \[Beta])\) - 
          sen \((\[Alpha] - \[Beta])\)]\), "\[IndentingNewLine]", 
    \(cos \((\[Alpha])\)\ cos \((\[Beta])\) \[Equal] \(1\/2\)\ [
        cos \((\[Alpha] + \[Beta])\) + 
          cos \((\[Alpha] - \[Beta])\)]\), "\[IndentingNewLine]", 
    \(sen \((\[Alpha])\)\ sen \((\[Beta])\) \[Equal] \(1\/2\)\ [
        cos \((\[Alpha] - \[Beta])\) - 
          cos \((\[Alpha] + \[Beta])\)]\)}], "Definition"],

Cell[TextData[{
  "e collegano dei prodotti di funzioni con delle somme, mentre le quattro di \
",
  StyleBox["prostaferesi",
    FontWeight->"Bold"]
}], "Text"],

Cell[BoxData[{
    \(sen \((p)\) + sen \((q)\) \[Equal] 
      2\ cos \((\(p - q\)\/2)\)\ sen \((\(p + q\)\/2)\)\), "\
\[IndentingNewLine]", 
    \(sen \((p)\) - sen \((q)\) \[Equal] 
      2\ cos \((\(p + q\)\/2)\)\ sen \((\(p - q\)\/2)\)\), "\
\[IndentingNewLine]", 
    \(cos \((p)\) + cos \((q)\) \[Equal] 
      2\ cos \((\(p - q\)\/2)\)\ cos \((\(p + q\)\/2)\)\), "\
\[IndentingNewLine]", 
    \(cos \((p)\) - 
        cos \((q)\) \[Equal] \(-2\)\ sen \((\(p - q\)\/2)\)\ sen \((\(p + q\)\
\/2)\)\)}], "Definition"],

Cell["associano a somme delle medesime funzioni, dei prodotti.", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Riassunto di tutte le identit\[AGrave] dimostrate", "Section"],

Cell[CellGroupData[{

Cell["Identit\[AGrave] dimostrate", "Subsubsection"],

Cell[BoxData[{
    \(\({idFondamentale, cosNotosen, tanNotosen, senNotocos, tanNotocos, 
          senNototan, 
          cosNototan} = {cos[\[Alpha]]\^2 + sen[\[Alpha]]\^2 \[RuleDelayed] 
            1, Abs[cos[\[Alpha]]] \[RuleDelayed] \@\(1 - sen[\[Alpha]]\^2\), 
          Abs[tan[\[Alpha]]] \[RuleDelayed] 
            Abs[sen[\[Alpha]]]\/\@\(1 - sen[\[Alpha]]\^2\), 
          Abs[sen[\[Alpha]]] \[RuleDelayed] \@\(1 - cos[\[Alpha]]\^2\), 
          Abs[tan[\[Alpha]]] \[RuleDelayed] \@\(1 - \
cos[\[Alpha]]\^2\)\/Abs[cos[\[Alpha]]], 
          Abs[sen[\[Alpha]]] \[RuleDelayed] \@\(tan[\[Alpha]]\^2\/\(1 + tan[\
\[Alpha]]\^2\)\), 
          Abs[cos[\[Alpha]]] \[RuleDelayed] \@\(1\/\(1 + \
tan[\[Alpha]]\^2\)\)};\)\), "\n", 
    \(\(Transpose[{{"\<idFondamentale\>", "\<cosNotosen\>", "\<tanNotosen\>", \
"\<senNotocos\>", "\<tanNotocos\>", "\<senNototan\>", "\<cosNototan\>"}, 
            toIdentita /@ {idFondamentale, cosNotosen, tanNotosen, 
                senNotocos, tanNotocos, senNototan, cosNototan}}] // 
        TableForm\) // TraditionalForm\)}], "Input"],

Cell[BoxData[{
    \(\({idFondamentale, senCompl, cosCompl, tanCompl, senDiffPi2, 
          cosDiffPi2, tanDiffPi2, senSuppl, cosSuppl, tanSuppl, senExpl, 
          cosExpl, tanExpl, senOpp, cosOpp, tanOpp, cosDiff, cosAdd, senDiff, 
          senAdd, tanAdd, tanDiff, senDupl, cosDupl, cosDuplSen, cosDuplCos, 
          tanDupl, senBis, cosBis, tanBis, senRaz, cosRaz, tanRaz, 
          wernerCosSen, wernerCosCos, wernerSenSen, proSenAddSen, 
          proSenDiffSen, proCosAddCos, 
          proCosDiffCos} = {cos[\[Alpha]_]\^2 + 
              sen[\[Alpha]_]\^2 \[RuleDelayed] 1, 
          sen[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          tan[\[Pi]\/2 - \[Alpha]_] \[RuleDelayed] cot[\[Alpha]], 
          sen[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] cos[\[Alpha]], 
          cos[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          tan[\[Pi]\/2 + \[Alpha]_] \[RuleDelayed] \(-\(cos[\[Alpha]]\/sen[\
\[Alpha]]\)\), sen[\[Pi] - \[Alpha]_] \[RuleDelayed] sen[\[Alpha]], 
          cos[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] - \[Alpha]_] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          sen[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\[Pi] + \[Alpha]_] \[RuleDelayed] \(-cos[\[Alpha]]\), 
          tan[\[Pi] + \[Alpha]_] \[RuleDelayed] tan[\[Alpha]], 
          sen[\(-\[Alpha]_\)] \[RuleDelayed] \(-sen[\[Alpha]]\), 
          cos[\(-\[Alpha]_\)] \[RuleDelayed] cos[\[Alpha]], 
          tan[\(-\[Alpha]_\)] \[RuleDelayed] \(-tan[\[Alpha]]\), 
          cos[\[Alpha]_ - \[Beta]_] \[RuleDelayed] 
            cos[\[Alpha]]\ cos[\[Beta]] + sen[\[Alpha]]\ sen[\[Beta]], 
          cos[\[Alpha]_ + \[Beta]_] \[RuleDelayed] 
            cos[\[Alpha]]\ cos[\[Beta]] - sen[\[Alpha]]\ sen[\[Beta]], 
          sen[\[Alpha]_ - \[Beta]_] \[RuleDelayed] 
            cos[\[Beta]]\ sen[\[Alpha]] - cos[\[Alpha]]\ sen[\[Beta]], 
          sen[\[Alpha]_ + \[Beta]_] \[RuleDelayed] 
            cos[\[Beta]]\ sen[\[Alpha]] + cos[\[Alpha]]\ sen[\[Beta]], 
          tan[\[Alpha]_ + \[Beta]_] \[RuleDelayed] \(tan[\[Alpha]] + tan[\
\[Beta]]\)\/\(1 - tan[\[Alpha]]\ tan[\[Beta]]\), 
          
          tan[\[Alpha]_ - \[Beta]_] \[RuleDelayed] \(tan[\[Alpha]] - tan[\
\[Beta]]\)\/\(1 + tan[\[Alpha]]\ tan[\[Beta]]\), 
          sen[2\ \[Alpha]_] \[RuleDelayed] 2\ cos[\[Alpha]]\ sen[\[Alpha]], 
          cos[2\ \[Alpha]_] \[RuleDelayed] 
            cos[\[Alpha]]\^2 - sen[\[Alpha]]\^2, 
          cos[2\ \[Alpha]_] \[RuleDelayed] 1 - 2\ sen[\[Alpha]]\^2, 
          cos[2\ \[Alpha]_] \[RuleDelayed] \(-1\) + 2\ cos[\[Alpha]]\^2, 
          tan[2\ \[Alpha]_] \[RuleDelayed] \(2\ tan[\[Alpha]]\)\/\(1 - tan[\
\[Alpha]]\^2\), 
          Abs[sen[\[Alpha]_\/2]] \[RuleDelayed] \@\(1 - cos[\[Alpha]]\)\/\@2, 
          Abs[cos[\[Alpha]_\/2]] \[RuleDelayed] \@\(1 + cos[\[Alpha]]\)\/\@2, 
          Abs[Tan[\[Alpha]_\/2]] \[RuleDelayed] \@\(1 - \
cos[\[Alpha]]\)\/\@\(1 + cos[\[Alpha]]\), 
          sen[\[Alpha]_] \[RuleDelayed] \(2\ tan[\[Alpha]\/2]\)\/\(1 + tan[\
\[Alpha]\/2]\^2\), 
          cos[\[Alpha]_] \[RuleDelayed] \(1 - tan[\[Alpha]\/2]\^2\)\/\(1 + \
tan[\[Alpha]\/2]\^2\), 
          tan[\[Alpha]_] \[RuleDelayed] \(2\ tan[\[Alpha]\/2]\)\/\(1 - tan[\
\[Alpha]\/2]\^2\), 
          cos[\[Beta]_]\ sen[\[Alpha]_] \[RuleDelayed] 
            1\/2\ \((sen[\[Alpha] - \[Beta]] + sen[\[Alpha] + \[Beta]])\), 
          cos[\[Alpha]_]\ cos[\[Beta]_] \[RuleDelayed] 
            1\/2\ \((cos[\[Alpha] - \[Beta]] + cos[\[Alpha] + \[Beta]])\), 
          sen[\[Alpha]_]\ sen[\[Beta]_] \[RuleDelayed] 
            1\/2\ \((cos[\[Alpha] - \[Beta]] - cos[\[Alpha] + \[Beta]])\), 
          sen[p_] + sen[q_] \[RuleDelayed] 
            2\ cos[\(p - q\)\/2]\ sen[\(p + q\)\/2], 
          sen[p_] - sen[q_] \[RuleDelayed] 
            2\ cos[\(p + q\)\/2]\ sen[\(p - q\)\/2], 
          cos[p_] + cos[q_] \[RuleDelayed] 
            2\ cos[\(p - q\)\/2]\ cos[\(p + q\)\/2], 
          cos[p_] - 
              cos[q_] \[RuleDelayed] \(-2\)\ sen[\(p - q\)\/2]\ sen[\(p + q\)\
\/2]};\)\), "\n", 
    \(\(Transpose[{{"\<idFondamentale\>", "\<senCompl\>", "\<cosCompl\>", \
"\<tanCompl\>", "\<senDiffPi2\>", "\<cosDiffPi2\>", "\<tanDiffPi2\>", \
"\<senSuppl\>", "\<cosSuppl\>", "\<tanSuppl\>", "\<senExpl\>", "\<cosExpl\>", \
"\<tanExpl\>", "\<senOpp\>", "\<cosOpp\>", "\<tanOpp\>", "\<cosDiff\>", \
"\<cosAdd\>", "\<senDiff\>", "\<senAdd\>", "\<tanAdd\>", "\<tanDiff\>", \
"\<senDupl\>", "\<cosDupl\>", "\<cosDuplSen\>", "\<cosDuplCos\>", \
"\<tanDupl\>", "\<senBis\>", "\<cosBis\>", "\<tanBis\>", "\<senRaz\>", \
"\<cosRaz\>", "\<tanRaz\>", "\<wernerCosSen\>", "\<wernerCosCos\>", \
"\<wernerSenSen\>", "\<proSenAddSen\>", "\<proSenDiffSen\>", \
"\<proCosAddCos\>", "\<proCosDiffCos\>"}, 
            toIdentita /@ {idFondamentale, senCompl, cosCompl, tanCompl, 
                senDiffPi2, cosDiffPi2, tanDiffPi2, senSuppl, cosSuppl, 
                tanSuppl, senExpl, cosExpl, tanExpl, senOpp, cosOpp, tanOpp, 
                cosDiff, cosAdd, senDiff, senAdd, tanAdd, tanDiff, senDupl, 
                cosDupl, cosDuplSen, cosDuplCos, tanDupl, senBis, cosBis, 
                tanBis, senRaz, cosRaz, tanRaz, wernerCosSen, wernerCosCos, 
                wernerSenSen, proSenAddSen, proSenDiffSen, proCosAddCos, 
                proCosDiffCos}}] // TableForm\) // 
      TraditionalForm\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Tabelle", "Subsection"],

Cell["\<\
Presentiamo infine due tabelle riassuntive di tutte le identit\[AGrave] \
dimostrate in questo notebook con associati i rispettivi nomi simbolici \
usati.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Identit\[AGrave] goniometriche dello stesso angolo", "Subsubsection"],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {"\<\"idFondamentale\"\>", \(\(cos(\[Alpha])\)\^2 + \
\(sen(\[Alpha])\)\^2 \[Equal] 1\)},
            {"\<\"cosNotosen\"\>", \(\[LeftBracketingBar]cos(\[Alpha])\
\[RightBracketingBar] \[Equal] \@\(1 - \(sen(\[Alpha])\)\^2\)\)},
            {"\<\"tanNotosen\"\>", \(\[LeftBracketingBar]tan(\[Alpha])\
\[RightBracketingBar] \[Equal] \[LeftBracketingBar]sen(\[Alpha])\
\[RightBracketingBar]\/\@\(1 - \(sen(\[Alpha])\)\^2\)\)},
            {"\<\"senNotocos\"\>", \(\[LeftBracketingBar]sen(\[Alpha])\
\[RightBracketingBar] \[Equal] \@\(1 - \(cos(\[Alpha])\)\^2\)\)},
            {"\<\"tanNotocos\"\>", \(\[LeftBracketingBar]tan(\[Alpha])\
\[RightBracketingBar] \[Equal] \@\(1 - \(cos(\[Alpha])\)\^2\)\/\
\[LeftBracketingBar]cos(\[Alpha])\[RightBracketingBar]\)},
            {"\<\"senNototan\"\>", \(\[LeftBracketingBar]sen(\[Alpha])\
\[RightBracketingBar] \[Equal] \
\@\(\(tan(\[Alpha])\)\^2\/\(\(tan(\[Alpha])\)\^2 + 1\)\)\)},
            {"\<\"cosNototan\"\>", \(\[LeftBracketingBar]cos(\[Alpha])\
\[RightBracketingBar] \[Equal] \@\(1\/\(\(tan(\[Alpha])\)\^2 + 1\)\)\)}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ BoxForm`e$]]], TraditionalForm]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell["Identit\[AGrave] goniometriche di angoli diversi", "Subsubsection"],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {"\<\"senCompl\"\>", \(sen(\[Pi]\/2 - \[Alpha]) \[Equal] 
                cos(\[Alpha])\)},
            {"\<\"cosCompl\"\>", \(cos(\[Pi]\/2 - \[Alpha]) \[Equal] 
                sen(\[Alpha])\)},
            {"\<\"tanCompl\"\>", \(tan(\[Pi]\/2 - \[Alpha]) \[Equal] 
                cot(\[Alpha])\)},
            {"\<\"senDiffPi2\"\>", \(sen(\[Alpha] + \[Pi]\/2) \[Equal] 
                cos(\[Alpha])\)},
            {"\<\"cosDiffPi2\"\>", \(cos(\[Alpha] + \[Pi]\/2) \[Equal] \
\(-\(sen(\[Alpha])\)\)\)},
            {"\<\"tanDiffPi2\"\>", \(tan(\[Alpha] + \[Pi]\/2) \[Equal] \
\(-\(\(cos(\[Alpha])\)\/\(sen(\[Alpha])\)\)\)\)},
            {"\<\"senSuppl\"\>", \(sen(\[Pi] - \[Alpha]) \[Equal] 
                sen(\[Alpha])\)},
            {"\<\"cosSuppl\"\>", \(cos(\[Pi] - \[Alpha]) \[Equal] \(-\(cos(\
\[Alpha])\)\)\)},
            {"\<\"tanSuppl\"\>", \(tan(\[Pi] - \[Alpha]) \[Equal] \(-\(tan(\
\[Alpha])\)\)\)},
            {"\<\"senExpl\"\>", \(sen(\[Alpha] + \[Pi]) \[Equal] \(-\(sen(\
\[Alpha])\)\)\)},
            {"\<\"cosExpl\"\>", \(cos(\[Alpha] + \[Pi]) \[Equal] \(-\(cos(\
\[Alpha])\)\)\)},
            {"\<\"tanExpl\"\>", \(tan(\[Alpha] + \[Pi]) \[Equal] 
                tan(\[Alpha])\)},
            {"\<\"senOpp\"\>", \(sen(\(-\[Alpha]\)) \[Equal] \
\(-\(sen(\[Alpha])\)\)\)},
            {"\<\"cosOpp\"\>", \(cos(\(-\[Alpha]\)) \[Equal] 
                cos(\[Alpha])\)},
            {"\<\"tanOpp\"\>", \(tan(\(-\[Alpha]\)) \[Equal] \
\(-\(tan(\[Alpha])\)\)\)},
            {"\<\"cosDiff\"\>", \(cos(\[Alpha] - \[Beta]) \[Equal] \(cos(\
\[Alpha])\)\ \(cos(\[Beta])\) + \(sen(\[Alpha])\)\ \(sen(\[Beta])\)\)},
            {"\<\"cosAdd\"\>", \(cos(\[Alpha] + \[Beta]) \[Equal] \(cos(\
\[Alpha])\)\ \(cos(\[Beta])\) - \(sen(\[Alpha])\)\ \(sen(\[Beta])\)\)},
            {"\<\"senDiff\"\>", \(sen(\[Alpha] - \[Beta]) \[Equal] \(cos(\
\[Beta])\)\ \(sen(\[Alpha])\) - \(cos(\[Alpha])\)\ \(sen(\[Beta])\)\)},
            {"\<\"senAdd\"\>", \(sen(\[Alpha] + \[Beta]) \[Equal] \(cos(\
\[Beta])\)\ \(sen(\[Alpha])\) + \(cos(\[Alpha])\)\ \(sen(\[Beta])\)\)},
            {"\<\"tanAdd\"\>", \(tan(\[Alpha] + \[Beta]) \[Equal] \(tan(\
\[Alpha]) + tan(\[Beta])\)\/\(1 - \(tan(\[Alpha])\)\ \(tan(\[Beta])\)\)\)},
            {"\<\"tanDiff\"\>", \(tan(\[Alpha] - \[Beta]) \[Equal] \(tan(\
\[Alpha]) - tan(\[Beta])\)\/\(\(tan(\[Alpha])\)\ \(tan(\[Beta])\) + 1\)\)},
            {"\<\"senDupl\"\>", \(sen(2\ \[Alpha]) \[Equal] 
                2\ \(cos(\[Alpha])\)\ \(sen(\[Alpha])\)\)},
            {"\<\"cosDupl\"\>", \(cos(
                  2\ \[Alpha]) \[Equal] \(cos(\[Alpha])\)\^2 - \
\(sen(\[Alpha])\)\^2\)},
            {"\<\"cosDuplSen\"\>", \(cos(2\ \[Alpha]) \[Equal] 
                1 - 2\ \(sen(\[Alpha])\)\^2\)},
            {"\<\"cosDuplCos\"\>", \(cos(2\ \[Alpha]) \[Equal] 
                2\ \(cos(\[Alpha])\)\^2 - 1\)},
            {"\<\"tanDupl\"\>", \(tan(
                  2\ \[Alpha]) \[Equal] \(2\ \(tan(\[Alpha])\)\)\/\(1 - \
\(tan(\[Alpha])\)\^2\)\)},
            {"\<\"senBis\"\>", \(\[LeftBracketingBar]sen(\[Alpha]\/2)\
\[RightBracketingBar] \[Equal] \@\(1 - cos(\[Alpha])\)\/\@2\)},
            {"\<\"cosBis\"\>", \(\[LeftBracketingBar]cos(\[Alpha]\/2)\
\[RightBracketingBar] \[Equal] \@\(cos(\[Alpha]) + 1\)\/\@2\)},
            {"\<\"tanBis\"\>", \(\[LeftBracketingBar]tan(\[Alpha]\/2)\
\[RightBracketingBar] \[Equal] \@\(1 - cos(\[Alpha])\)\/\@\(cos(\[Alpha]) + 1\
\)\)},
            {"\<\"senRaz\"\>", \(sen(\[Alpha]) \[Equal] \(2\ \
\(tan(\[Alpha]\/2)\)\)\/\(\(tan(\[Alpha]\/2)\)\^2 + 1\)\)},
            {"\<\"cosRaz\"\>", \(cos(\[Alpha]) \[Equal] \(1 - \
\(tan(\[Alpha]\/2)\)\^2\)\/\(\(tan(\[Alpha]\/2)\)\^2 + 1\)\)},
            {"\<\"tanRaz\"\>", \(tan(\[Alpha]) \[Equal] \(2\ \
\(tan(\[Alpha]\/2)\)\)\/\(1 - \(tan(\[Alpha]\/2)\)\^2\)\)},
            {"\<\"wernerCosSen\"\>", \(\(cos(\[Beta])\)\ \(sen(\[Alpha])\) \
\[Equal] 1\/2\ \((sen(\[Alpha] - \[Beta]) + sen(\[Alpha] + \[Beta]))\)\)},
            {"\<\"wernerCosCos\"\>", \(\(cos(\[Alpha])\)\ \(cos(\[Beta])\) \
\[Equal] 1\/2\ \((cos(\[Alpha] - \[Beta]) + cos(\[Alpha] + \[Beta]))\)\)},
            {"\<\"wernerSenSen\"\>", \(\(sen(\[Alpha])\)\ \(sen(\[Beta])\) \
\[Equal] 1\/2\ \((cos(\[Alpha] - \[Beta]) - cos(\[Alpha] + \[Beta]))\)\)},
            {"\<\"proSenAddSen\"\>", \(sen(p) + sen(q) \[Equal] 
                2\ \(cos(\(p - q\)\/2)\)\ \(sen(\(p + q\)\/2)\)\)},
            {"\<\"proSenDiffSen\"\>", \(sen(p) - sen(q) \[Equal] 
                2\ \(cos(\(p + q\)\/2)\)\ \(sen(\(p - q\)\/2)\)\)},
            {"\<\"proCosAddCos\"\>", \(cos(p) + cos(q) \[Equal] 
                2\ \(cos(\(p - q\)\/2)\)\ \(cos(\(p + q\)\/2)\)\)},
            {"\<\"proCosDiffCos\"\>", \(cos(p) - 
                  cos(q) \[Equal] \(-2\)\ \(sen(\(p - q\)\/2)\)\ \(sen(\(p + \
q\)\/2)\)\)}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ BoxForm`e$]]], TraditionalForm]], "Output"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
ScreenStyleEnvironment->"Working",
PrintingStyleEnvironment->"OutputPDF",
WindowToolbars->{},
WindowSize->{908, 680},
WindowMargins->{{16, Automatic}, {Automatic, -1}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PrintingMargins"->{{56.6875, 56.6875}, {56.6875, \
56.6875}}},
ShowSelection->True,
Magnification->1.25,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->PaperWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}],
  
  Cell[StyleData[All, "OutputPDF"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ ""]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ ""]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"Formule goniometriche"}], "Footer"], None, Cell[ 
            TextData[ {"Lorenzo Roi 2006"}], "Footer"]}, {Cell[ 
            TextData[ {"Formule goniometriche"}], "Footer"], None, Cell[ 
            TextData[ {"Lorenzo Roi 2006"}], "Footer"]}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None,
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {0, 0}},
    CellGroupingRules->"TitleGrouping",
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    CellFrame->False,
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 0.8, 0.4]],
  
  Cell[StyleData["Title", "OutputPDF"],
    CellFrame->False,
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 0.8, 0.4]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 10}},
    ParagraphIndent->-85,
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Subtitle", "OutputPDF"],
    CellMargins->{{0, 0}, {0, 10}},
    ParagraphIndent->-85,
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    ShowCellBracket->True,
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14],
  
  Cell[StyleData["Subsubtitle", "OutputPDF"],
    ShowCellBracket->True,
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 25}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Section", "OutputPDF"],
    CellMargins->{{9, 0}, {2, 25}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 20}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "OutputPDF"],
    CellMargins->{{9, 0}, {4, 20}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{21, 0}, {4, 10}},
    FontSize->14],
  
  Cell[StyleData["Subsubsection", "OutputPDF"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{21, 0}, {4, 10}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{9, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6},
    FontSize->14],
  
  Cell[StyleData["Text", "OutputPDF"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}}],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->0.5,
    CellMargins->{{25, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.360784, 0.678431, 0.870588],
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[0.705882, 0.85098, 0.937255]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{25, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{25, 0}, {6, 6}}],
  
  Cell[StyleData["Input", "Printout"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{25, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Courier",
    FontSize->9,
    Background->None],
  
  Cell[StyleData["Input", "OutputPDF"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{25, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Courier",
    FontSize->8,
    Background->None]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->True,
    CellMargins->{{25, 10}, {8, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[1, 0.623529, 0.623529],
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontSize->12,
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{25, Inherited}, {12, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellFrameColor->GrayLevel[0],
    FontSize->12,
    Background->None],
  
  Cell[StyleData["Output", "OutputPDF"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellFrameColor->GrayLevel[0],
    FontSize->8,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "OutputPDF"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "OutputPDF"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}],
  
  Cell[StyleData["Graphics", "OutputPDF"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "OutputPDF"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{0, 4}, {2, 10}},
    TextAlignment->Left,
    FontFamily->"Helvetica",
    FontSize->12,
    FontSlant->"Italic",
    Background->RGBColor[1, 0.8, 0.4]],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{0, 10}, {2, 12}},
    TextAlignment->Left,
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{0, 10}, {1, 4}},
    TextAlignment->Left,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4},
    FontSize->9],
  
  Cell[StyleData["Author", "Printout"],
    CellFrame->False,
    CellMargins->{{0, 0}, {4, 12}},
    TextAlignment->Left,
    ParagraphSpacing->{0, 6},
    FontFamily->"Helvetica",
    Background->GrayLevel[1]],
  
  Cell[StyleData["Author", "OutputPDF"],
    CellFrame->False,
    CellMargins->{{0, 0}, {4, 12}},
    TextAlignment->Left,
    ParagraphSpacing->{0, 6},
    FontFamily->"Helvetica",
    FontSize->11,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    CellMargins->{{10, 10}, {40, 2}},
    TextAlignment->Right,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Copyright", "Presentation"],
    CellMargins->{{12, 10}, {50, 2}},
    TextAlignment->Right,
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["Copyright", "Condensed"],
    CellMargins->{{8, 10}, {12, 1}},
    TextAlignment->Right,
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{9, 0}, {72, 4}},
    TextAlignment->Right,
    FontSize->7],
  
  Cell[StyleData["Copyright", "OutputPDF"],
    CellMargins->{{9, 0}, {72, 4}},
    TextAlignment->Right,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10],
  
  Cell[StyleData["Abstract", "OutputPDF"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Example"],
    CellMargins->{{12, 10}, {5, 12}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Example",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Example", "Presentation"],
    CellMargins->{{18, 10}, {8, 20}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Example", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Example", "Printout"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["Example", "OutputPDF"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellFrame->True,
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.34902, 0.807843, 0.807843],
    ShowStringCharacters->True,
    CounterIncrements->"Definition",
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Normal",
    FontColor->GrayLevel[0],
    Background->RGBColor[0.639216, 0.894118, 0.894118]],
  
  Cell[StyleData["Definition", "Presentation"],
    CellFrame->True,
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Definition", "Condensed"],
    CellFrame->True,
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Definition", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    CellFrameColor->GrayLevel[0],
    FontSize->14,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Definition", "OutputPDF"],
    CellMargins->{{44, 44}, {2, 6}},
    CellFrameColor->GrayLevel[0],
    FontSize->8,
    FontWeight->"Normal",
    Background->RGBColor[0.823529, 0.94902, 0.94902]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->True,
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.647059, 0.219608, 0.647059],
    ShowStringCharacters->True,
    CounterIncrements->"Theorem",
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Normal",
    FontColor->RGBColor[0.25098, 0, 0.25098],
    Background->RGBColor[0.858824, 0.584314, 0.858824]],
  
  Cell[StyleData["Theorem", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Theorem", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    CellFrameColor->GrayLevel[0],
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Theorem", "OutputPDF"],
    CellMargins->{{44, 44}, {2, 6}},
    CellFrameColor->GrayLevel[0],
    FontSize->9,
    FontWeight->"Normal",
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caution"],
    CellFrame->True,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Caution",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 0.443137, 0.443137],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Caution", "Presentation"],
    CellFrame->True,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Caution", "Condensed"],
    CellFrame->True,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Caution", "Printout"],
    CellFrame->True,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Caution", "OutputPDF"],
    CellFrame->True,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Advice"],
    CellFrame->True,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Advice",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0.682353, 1, 0.682353],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Advice", "Presentation"],
    CellFrame->True,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Advice", "Condensed"],
    CellFrame->True,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Advice", "Printout"],
    CellFrame->True,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Advice", "OutputPDF"],
    CellFrame->True,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Exercise"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->"NormalGrouping",
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Exercise", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Exercise", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Exercise", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Exercise", "OutputPDF"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseMain"],
    CellFrame->{{6, 0}, {0, 1}},
    CellMargins->{{12, Inherited}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.571389, 0.19675, 0.570504],
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseMain", "Presentation"],
    CellMargins->{{18, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["ExerciseMain", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["ExerciseMain", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameColor->GrayLevel[0.500008],
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["ExerciseMain", "OutputPDF"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameColor->GrayLevel[0.500008],
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseTitle"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseTitle", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["ExerciseTitle", "Condensed"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["ExerciseTitle", "Printout"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["ExerciseTitle", "OutputPDF"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseText"],
    CellMargins->{{32, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ExcersiceText",
    FontFamily->"Times"],
  
  Cell[StyleData["ExerciseText", "Presentation"],
    CellMargins->{{32, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["ExerciseText", "Condensed"],
    CellMargins->{{32, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["ExerciseText", "Printout"],
    CellMargins->{{32, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["ExerciseText", "OutputPDF"],
    CellMargins->{{32, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Problem"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Problem", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Problem", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Problem", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Problem", "OutputPDF"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BulletedList"],
    CellDingbat->"\[FilledSmallCircle]",
    CellMargins->{{50, 10}, {Inherited, Inherited}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BulletedList", "Presentation"],
    CellMargins->{{50, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["BulletedList", "Printout"],
    CellMargins->{{50, 10}, {2, Inherited}},
    LineSpacing->{0, 12},
    FontSize->10],
  
  Cell[StyleData["BulletedList", "OutputPDF"],
    CellMargins->{{50, 10}, {2, Inherited}},
    LineSpacing->{0, 12},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "OutputPDF"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "OutputPDF"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{12, 10}, {Inherited, 6}},
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{13, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{9, 0}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "OutputPDF"],
    CellMargins->{{9, 0}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{62, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{74, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    CellMargins->{{52, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "OutputPDF"],
    CellMargins->{{54, 0}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figura ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"]],
  
  Cell[StyleData["NumberedFigure", "Condensed"]],
  
  Cell[StyleData["NumberedFigure", "Printout"]],
  
  Cell[StyleData["NumberedFigure", "OutputPDF"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"]],
  
  Cell[StyleData["NumberedTable", "Condensed"]],
  
  Cell[StyleData["NumberedTable", "Printout"]],
  
  Cell[StyleData["NumberedTable", "OutputPDF"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->11,
    FontWeight->"Normal",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->14,
    FontWeight->"Normal",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}],
  
  Cell[StyleData["Hyperlink", "OutputPDF"],
    FontSize->10,
    FontWeight->"Normal",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}],
  
  Cell[StyleData["MainBookLink", "OutputPDF"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}],
  
  Cell[StyleData["AddOnLink", "OutputPDF"],
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}],
  
  Cell[StyleData["RefGuideLink", "OutputPDF"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}],
  
  Cell[StyleData["GettingStartedLink", "OutputPDF"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}],
  
  Cell[StyleData["OtherInformationLink", "OutputPDF"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "figura1"->{
    Cell[13585, 340, 53267, 1202, 286, 15935, 735, "GraphicsData", 
    "PostScript", "NumberedFigure",
      CellTags->"figura1"],
    Cell[425912, 10754, 878, 15, 200, "Input",
      CellTags->"figura1"]},
  "cosNotosen"->{
    Cell[73214, 1787, 77, 2, 60, "Input",
      CellTags->"cosNotosen"],
    Cell[73294, 1791, 114, 2, 53, "Output",
      CellTags->"cosNotosen"]},
  "figura2"->{
    Cell[86370, 2282, 59471, 1358, 286, 18963, 852, "GraphicsData", 
    "PostScript", "NumberedFigure",
      CellTags->"figura2"],
    Cell[543531, 13394, 945, 17, 200, "Input",
      CellTags->"figura2"]},
  "figura3"->{
    Cell[157680, 4097, 59539, 1359, 286, 18967, 852, "GraphicsData", 
    "PostScript", "NumberedFigure",
      CellTags->"figura3"]},
  "osservazione1"->{
    Cell[217391, 5467, 1223, 39, 52, "Text",
      CellTags->"osservazione1"]},
  "figura4"->{
    Cell[225818, 5778, 57123, 1329, 286, 18961, 852, "GraphicsData", 
    "PostScript", "NumberedFigure",
      CellTags->"figura4"]},
  "osservazione2"->{
    Cell[283765, 7131, 1502, 50, 72, "Text",
      CellTags->"osservazione2"]},
  "figura5"->{
    Cell[291661, 7405, 56793, 1325, 286, 18962, 852, "GraphicsData", 
    "PostScript", "NumberedFigure",
      CellTags->"figura5"]},
  "osservazione3"->{
    Cell[349541, 8759, 770, 27, 32, "Text",
      CellTags->"osservazione3"]},
  "figura6"->{
    Cell[358133, 9061, 55924, 1307, 286, 18588, 840, "GraphicsData", 
    "PostScript", "NumberedFigure",
      CellTags->"figura6"]},
  "osservazione4"->{
    Cell[415334, 10398, 1183, 42, 32, "Text",
      CellTags->"osservazione4"]},
  "senodispari"->{
    Cell[416906, 10462, 69, 2, 60, "Input",
      CellTags->"senodispari"],
    Cell[416978, 10466, 107, 2, 50, "Output",
      CellTags->"senodispari"]},
  "cosenopari"->{
    Cell[419759, 10555, 68, 2, 60, "Input",
      CellTags->"cosenopari"],
    Cell[419830, 10559, 101, 2, 50, "Output",
      CellTags->"cosenopari"]},
  "tandispari"->{
    Cell[422630, 10646, 68, 2, 60, "Input",
      CellTags->"tandispari"],
    Cell[422701, 10650, 106, 2, 50, "Output",
      CellTags->"tandispari"]},
  "figura7"->{
    Cell[426862, 10776, 58412, 1351, 257, 20936, 882, "GraphicsData", 
    "PostScript", "NumberedFigure",
      CellTags->"figura7"]},
  "relazione1"->{
    Cell[543353, 13385, 94, 2, 35, "DisplayFormula",
      CellTags->"relazione1"]},
  "figura8"->{
    Cell[544548, 13418, 64504, 1375, 286, 17395, 788, "GraphicsData", 
    "PostScript", "NumberedFigure",
      CellTags->"figura8"]},
  "cosSomma"->{
    Cell[619641, 15137, 223, 4, 56, "Definition",
      CellTags->"cosSomma"]},
  "id1"->{
    Cell[621955, 15193, 309, 9, 36, "Text",
      CellTags->"id1"]},
  "riassunto"->{
    Cell[668228, 16645, 217, 4, 80, "Input",
      CellTags->"riassunto"],
    Cell[668448, 16651, 846, 17, 102, "Output",
      CellTags->"riassunto"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"figura1", 737251, 18936},
  {"cosNotosen", 737477, 18942},
  {"figura2", 737641, 18947},
  {"figura3", 737865, 18953},
  {"osservazione1", 738021, 18957},
  {"figura4", 738116, 18960},
  {"osservazione2", 738272, 18964},
  {"figura5", 738367, 18967},
  {"osservazione3", 738523, 18971},
  {"figura6", 738617, 18974},
  {"osservazione4", 738773, 18978},
  {"senodispari", 738873, 18981},
  {"cosenopari", 739046, 18986},
  {"tandispari", 739217, 18991},
  {"figura7", 739385, 18996},
  {"relazione1", 739539, 19000},
  {"figura8", 739639, 19003},
  {"cosSomma", 739791, 19007},
  {"id1", 739882, 19010},
  {"riassunto", 739968, 19013}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 65, 1, 69, "Title"],
Cell[1844, 56, 77, 0, 50, "Subtitle"],
Cell[1924, 58, 29, 0, 54, "Author"],
Cell[1956, 60, 265, 8, 33, "Copyright"],

Cell[CellGroupData[{
Cell[2246, 72, 30, 0, 56, "Subsection"],
Cell[2279, 74, 826, 18, 93, "Text"],

Cell[CellGroupData[{
Cell[3130, 96, 39, 0, 46, "Subsubsection"],
Cell[3172, 98, 642, 12, 92, "Text"],

Cell[CellGroupData[{
Cell[3839, 114, 82, 1, 72, "Input"],
Cell[3924, 117, 38, 1, 50, "Output"]
}, Closed]],
Cell[3977, 121, 739, 16, 93, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4753, 142, 37, 0, 46, "Subsubsection"],
Cell[4793, 144, 1952, 44, 248, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[6794, 194, 38, 0, 35, "Subsection"],
Cell[6835, 196, 108, 3, 32, "Text"],
Cell[6946, 201, 5452, 102, 1220, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[12435, 308, 48, 0, 43, "Section"],

Cell[CellGroupData[{
Cell[12508, 312, 44, 0, 46, "Subsubsection"],
Cell[12555, 314, 907, 17, 220, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[13499, 336, 83, 2, 46, "Subsubsection"],
Cell[13585, 340, 53267, 1202, 286, 15935, 735, "GraphicsData", "PostScript", \
"NumberedFigure",
  CellTags->"figura1"]
}, Closed]],

Cell[CellGroupData[{
Cell[66889, 1547, 73, 0, 46, "Subsubsection"],
Cell[66965, 1549, 1231, 37, 92, "Text"],

Cell[CellGroupData[{
Cell[68221, 1590, 173, 3, 60, "Input"],
Cell[68397, 1595, 1224, 41, 204, "Output"]
}, Closed]],
Cell[69636, 1639, 250, 8, 32, "Text"],

Cell[CellGroupData[{
Cell[69911, 1651, 61, 1, 61, "Input"],
Cell[69975, 1654, 62, 1, 50, "Output"]
}, Closed]],
Cell[70052, 1658, 346, 12, 32, "Text"],

Cell[CellGroupData[{
Cell[70423, 1674, 107, 2, 60, "Input"],
Cell[70533, 1678, 105, 2, 50, "Output"]
}, Closed]],
Cell[70653, 1683, 235, 8, 32, "Text"],

Cell[CellGroupData[{
Cell[70913, 1695, 52, 1, 61, "Input"],
Cell[70968, 1698, 80, 1, 50, "Output"]
}, Closed]],
Cell[71063, 1702, 155, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[71243, 1711, 485, 8, 140, "Input"],
Cell[71731, 1721, 86, 1, 50, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[71878, 1729, 67, 0, 43, "Section"],

Cell[CellGroupData[{
Cell[71970, 1733, 44, 0, 46, "Subsubsection"],
Cell[72017, 1735, 118, 2, 61, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[72172, 1742, 115, 4, 35, "Subsection"],
Cell[72290, 1748, 308, 7, 52, "Text"],

Cell[CellGroupData[{
Cell[72623, 1759, 77, 1, 60, "Input"],
Cell[72703, 1762, 80, 1, 50, "Output"]
}, Closed]],
Cell[72798, 1766, 59, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[72882, 1770, 42, 1, 60, "Input"],
Cell[72927, 1773, 88, 1, 53, "Output"]
}, Closed]],
Cell[73030, 1777, 159, 6, 37, "Text"],

Cell[CellGroupData[{
Cell[73214, 1787, 77, 2, 60, "Input",
  CellTags->"cosNotosen"],
Cell[73294, 1791, 114, 2, 53, "Output",
  CellTags->"cosNotosen"]
}, Closed]],

Cell[CellGroupData[{
Cell[73445, 1798, 55, 1, 60, "Input"],
Cell[73503, 1801, 103, 2, 53, "Output"]
}, Closed]],
Cell[73621, 1806, 69, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[73715, 1810, 48, 1, 60, "Input"],
Cell[73766, 1813, 85, 1, 67, "Output"]
}, Closed]],
Cell[73866, 1817, 51, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[73942, 1821, 106, 2, 78, "Input"],
Cell[74051, 1825, 107, 2, 67, "Output"]
}, Closed]],
Cell[74173, 1830, 183, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[74381, 1840, 48, 1, 60, "Input"],
Cell[74432, 1843, 115, 2, 72, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[74584, 1850, 55, 1, 60, "Input"],
Cell[74642, 1853, 121, 2, 72, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[74812, 1861, 115, 4, 56, "Subsection"],
Cell[74930, 1867, 168, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[75123, 1874, 77, 1, 60, "Input"],
Cell[75203, 1877, 80, 1, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[75320, 1883, 42, 1, 60, "Input"],
Cell[75365, 1886, 88, 1, 53, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[75490, 1892, 51, 1, 60, "Input"],
Cell[75544, 1895, 88, 1, 53, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[75669, 1901, 55, 1, 60, "Input"],
Cell[75727, 1904, 103, 2, 53, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[75867, 1911, 48, 1, 60, "Input"],
Cell[75918, 1914, 85, 1, 67, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[76040, 1920, 106, 2, 78, "Input"],
Cell[76149, 1924, 107, 2, 67, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[76293, 1931, 48, 1, 60, "Input"],
Cell[76344, 1934, 119, 3, 74, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[76500, 1942, 55, 1, 60, "Input"],
Cell[76558, 1945, 125, 3, 74, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[76732, 1954, 115, 4, 56, "Subsection"],
Cell[76850, 1960, 173, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[77048, 1969, 85, 1, 61, "Input"],
Cell[77136, 1972, 127, 3, 50, "Output"]
}, Closed]],
Cell[77278, 1978, 193, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[77496, 1987, 89, 1, 60, "Input"],
Cell[77588, 1990, 188, 5, 70, "Output"]
}, Closed]],
Cell[77791, 1998, 298, 8, 36, "Text"],

Cell[CellGroupData[{
Cell[78114, 2010, 76, 1, 60, "Input"],
Cell[78193, 2013, 302, 8, 95, "Output"]
}, Closed]],
Cell[78510, 2024, 197, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[78732, 2033, 75, 1, 60, "Input"],
Cell[78810, 2036, 160, 4, 70, "Output"]
}, Closed]],
Cell[78985, 2043, 95, 2, 32, "Text"],

Cell[CellGroupData[{
Cell[79105, 2049, 52, 1, 60, "Input"],
Cell[79160, 2052, 112, 2, 77, "Output"]
}, Closed]],
Cell[79287, 2057, 31, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[79343, 2061, 49, 1, 60, "Input"],
Cell[79395, 2064, 121, 3, 77, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[79553, 2072, 55, 1, 60, "Input"],
Cell[79611, 2075, 127, 3, 77, "Output"]
}, Closed]],
Cell[79753, 2081, 146, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[79924, 2088, 85, 1, 61, "Input"],
Cell[80012, 2091, 127, 3, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[80176, 2099, 89, 1, 60, "Input"],
Cell[80268, 2102, 188, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[80493, 2112, 76, 1, 60, "Input"],
Cell[80572, 2115, 302, 8, 95, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[80911, 2128, 75, 1, 60, "Input"],
Cell[80989, 2131, 138, 3, 67, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[81164, 2139, 52, 1, 60, "Input"],
Cell[81219, 2142, 97, 2, 78, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[81353, 2149, 49, 1, 60, "Input"],
Cell[81405, 2152, 104, 2, 78, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[81546, 2159, 55, 1, 60, "Input"],
Cell[81604, 2162, 112, 3, 78, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[81753, 2170, 52, 0, 46, "Subsubsection"],
Cell[81808, 2172, 179, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[82012, 2182, 1093, 18, 270, "Input"],
Cell[83108, 2202, 1367, 26, 286, "Output"]
}, Closed]],
Cell[84490, 2231, 155, 3, 32, "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[84706, 2241, 63, 0, 43, "Section"],

Cell[CellGroupData[{
Cell[84794, 2245, 42, 0, 56, "Subsection"],

Cell[CellGroupData[{
Cell[84861, 2249, 44, 0, 46, "Subsubsection"],
Cell[84908, 2251, 1390, 24, 280, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[86335, 2280, 32, 0, 46, "Subsubsection"],
Cell[86370, 2282, 59471, 1358, 286, 18963, 852, "GraphicsData", "PostScript", \
"NumberedFigure",
  CellTags->"figura2"]
}, Closed]],

Cell[CellGroupData[{
Cell[145878, 3645, 52, 0, 46, "Subsubsection"],
Cell[145933, 3647, 128, 2, 61, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[146098, 3654, 56, 0, 35, "Subsubsection"],
Cell[146157, 3656, 1325, 41, 96, "Text"],

Cell[CellGroupData[{
Cell[147507, 3701, 71, 1, 60, "Input"],
Cell[147581, 3704, 74, 1, 63, "Output"]
}, Closed]],
Cell[147670, 3708, 1128, 37, 52, "Text"],

Cell[CellGroupData[{
Cell[148823, 3749, 68, 1, 60, "Input"],
Cell[148894, 3752, 74, 1, 63, "Output"]
}, Closed]],
Cell[148983, 3756, 211, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[149219, 3765, 42, 1, 60, "Input"],
Cell[149264, 3768, 81, 1, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[149382, 3774, 53, 1, 60, "Input"],
Cell[149438, 3777, 87, 1, 61, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[149574, 3784, 52, 0, 46, "Subsubsection"],
Cell[149629, 3786, 216, 4, 72, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[149882, 3795, 58, 0, 35, "Subsubsection"],
Cell[149943, 3797, 252, 8, 36, "Text"],

Cell[CellGroupData[{
Cell[150220, 3809, 71, 1, 60, "Input"],
Cell[150294, 3812, 74, 1, 63, "Output"]
}, Closed]],
Cell[150383, 3816, 415, 16, 32, "Text"],

Cell[CellGroupData[{
Cell[150823, 3836, 68, 1, 60, "Input"],
Cell[150894, 3839, 74, 1, 63, "Output"]
}, Closed]],
Cell[150983, 3843, 123, 4, 32, "Text"],

Cell[CellGroupData[{
Cell[151131, 3851, 42, 1, 60, "Input"],
Cell[151176, 3854, 81, 1, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[151294, 3860, 53, 1, 60, "Input"],
Cell[151350, 3863, 87, 1, 61, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[151486, 3870, 52, 0, 46, "Subsubsection"],
Cell[151541, 3872, 293, 5, 93, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[151871, 3882, 60, 0, 35, "Subsubsection"],
Cell[151934, 3884, 110, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[152069, 3891, 65, 1, 60, "Input"],
Cell[152137, 3894, 74, 1, 63, "Output"]
}, Closed]],
Cell[152226, 3898, 702, 26, 32, "Text"],

Cell[CellGroupData[{
Cell[152953, 3928, 68, 1, 60, "Input"],
Cell[153024, 3931, 74, 1, 65, "Output"]
}, Closed]],
Cell[153113, 3935, 46, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[153184, 3939, 41, 1, 60, "Input"],
Cell[153228, 3942, 81, 1, 74, "Output"]
}, Closed]],
Cell[153324, 3946, 60, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[153409, 3950, 42, 1, 60, "Input"],
Cell[153454, 3953, 84, 1, 61, "Output"]
}, Closed]],
Cell[153553, 3957, 114, 4, 32, "Text"],

Cell[CellGroupData[{
Cell[153692, 3965, 48, 1, 60, "Input"],
Cell[153743, 3968, 84, 1, 67, "Output"]
}, Closed]],
Cell[153842, 3972, 67, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[153934, 3976, 41, 1, 60, "Input"],
Cell[153978, 3979, 81, 1, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[154096, 3985, 41, 1, 60, "Input"],
Cell[154140, 3988, 103, 2, 67, "Output"]
}, Closed]],
Cell[154258, 3993, 30, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[154313, 3997, 120, 2, 60, "Input"],
Cell[154436, 4001, 125, 2, 82, "Output"]
}, Closed]],
Cell[154576, 4006, 113, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[154714, 4013, 62, 1, 60, "Input"],
Cell[154779, 4016, 103, 2, 67, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[154919, 4023, 53, 1, 60, "Input"],
Cell[154975, 4026, 109, 2, 67, "Output"]
}, Closed]],
Cell[155099, 4031, 64, 0, 32, "Text"],
Cell[155166, 4033, 426, 8, 162, "Definition"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[155641, 4047, 65, 0, 56, "Subsection"],

Cell[CellGroupData[{
Cell[155731, 4051, 52, 0, 46, "Subsubsection"],
Cell[155786, 4053, 370, 6, 93, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[156193, 4064, 44, 0, 35, "Subsubsection"],
Cell[156240, 4066, 1368, 24, 280, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[157645, 4095, 32, 0, 46, "Subsubsection"],
Cell[157680, 4097, 59539, 1359, 286, 18967, 852, "GraphicsData", \
"PostScript", "NumberedFigure",
  CellTags->"figura3"]
}, Closed]],

Cell[CellGroupData[{
Cell[217256, 5461, 132, 4, 52, "Subsubsection"],
Cell[217391, 5467, 1223, 39, 52, "Text",
  CellTags->"osservazione1"],

Cell[CellGroupData[{
Cell[218639, 5510, 71, 1, 60, "Input"],
Cell[218713, 5513, 74, 1, 63, "Output"]
}, Closed]],
Cell[218802, 5517, 31, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[218858, 5521, 68, 1, 60, "Input"],
Cell[218929, 5524, 74, 1, 63, "Output"]
}, Closed]],
Cell[219018, 5528, 52, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[219095, 5532, 42, 1, 60, "Input"],
Cell[219140, 5535, 81, 1, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[219258, 5541, 55, 1, 60, "Input"],
Cell[219316, 5544, 87, 1, 61, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[219452, 5551, 52, 0, 46, "Subsubsection"],
Cell[219507, 5553, 449, 7, 102, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[219993, 5565, 134, 4, 41, "Subsubsection"],
Cell[220130, 5571, 33, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[220188, 5575, 71, 1, 60, "Input"],
Cell[220262, 5578, 74, 1, 63, "Output"]
}, Closed]],
Cell[220351, 5582, 173, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[220549, 5592, 73, 1, 60, "Input"],
Cell[220625, 5595, 83, 1, 63, "Output"]
}, Closed]],
Cell[220723, 5599, 23, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[220771, 5603, 42, 1, 60, "Input"],
Cell[220816, 5606, 86, 1, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[220939, 5612, 55, 1, 60, "Input"],
Cell[220997, 5615, 92, 1, 61, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[221138, 5622, 52, 0, 46, "Subsubsection"],
Cell[221193, 5624, 522, 8, 127, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[221752, 5637, 136, 4, 41, "Subsubsection"],
Cell[221891, 5643, 75, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[221991, 5647, 71, 1, 60, "Input"],
Cell[222065, 5650, 74, 1, 63, "Output"]
}, Closed]],
Cell[222154, 5654, 67, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[222246, 5658, 73, 1, 60, "Input"],
Cell[222322, 5661, 83, 1, 65, "Output"]
}, Closed]],
Cell[222420, 5665, 73, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[222518, 5669, 47, 1, 60, "Input"],
Cell[222568, 5672, 86, 1, 74, "Output"]
}, Closed]],
Cell[222669, 5676, 148, 4, 32, "Text"],

Cell[CellGroupData[{
Cell[222842, 5684, 42, 1, 60, "Input"],
Cell[222887, 5687, 89, 1, 61, "Output"]
}, Closed]],
Cell[222991, 5691, 49, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[223065, 5695, 48, 1, 60, "Input"],
Cell[223116, 5698, 93, 1, 67, "Output"]
}, Closed]],
Cell[223224, 5702, 56, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[223305, 5706, 52, 1, 60, "Input"],
Cell[223360, 5709, 107, 2, 67, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[223504, 5716, 55, 1, 60, "Input"],
Cell[223562, 5719, 113, 2, 67, "Output"]
}, Closed]],
Cell[223690, 5724, 55, 0, 32, "Text"],
Cell[223748, 5726, 471, 9, 162, "Definition"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[224268, 5741, 42, 0, 56, "Subsection"],

Cell[CellGroupData[{
Cell[224335, 5745, 44, 0, 46, "Subsubsection"],
Cell[224382, 5747, 1364, 24, 280, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[225783, 5776, 32, 0, 46, "Subsubsection"],
Cell[225818, 5778, 57123, 1329, 286, 18961, 852, "GraphicsData", \
"PostScript", "NumberedFigure",
  CellTags->"figura4"]
}, Closed]],

Cell[CellGroupData[{
Cell[282978, 7112, 52, 0, 46, "Subsubsection"],
Cell[283033, 7114, 636, 10, 134, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[283706, 7129, 56, 0, 35, "Subsubsection"],
Cell[283765, 7131, 1502, 50, 72, "Text",
  CellTags->"osservazione2"],

Cell[CellGroupData[{
Cell[285292, 7185, 69, 1, 60, "Input"],
Cell[285364, 7188, 71, 1, 63, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[285472, 7194, 68, 1, 60, "Input"],
Cell[285543, 7197, 71, 1, 63, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[285651, 7203, 42, 1, 60, "Input"],
Cell[285696, 7206, 78, 1, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[285811, 7212, 53, 1, 60, "Input"],
Cell[285867, 7215, 84, 1, 50, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[286000, 7222, 52, 0, 46, "Subsubsection"],
Cell[286055, 7224, 710, 11, 134, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[286802, 7240, 58, 0, 35, "Subsubsection"],
Cell[286863, 7242, 33, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[286921, 7246, 69, 1, 60, "Input"],
Cell[286993, 7249, 71, 1, 63, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[287101, 7255, 73, 1, 60, "Input"],
Cell[287177, 7258, 80, 1, 63, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[287294, 7264, 42, 1, 60, "Input"],
Cell[287339, 7267, 83, 1, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[287459, 7273, 53, 1, 60, "Input"],
Cell[287515, 7276, 89, 1, 50, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[287653, 7283, 52, 0, 46, "Subsubsection"],
Cell[287708, 7285, 780, 12, 164, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[288525, 7302, 60, 0, 35, "Subsubsection"],
Cell[288588, 7304, 58, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[288671, 7308, 69, 1, 60, "Input"],
Cell[288743, 7311, 71, 1, 63, "Output"]
}, Closed]],
Cell[288829, 7315, 185, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[289039, 7325, 73, 1, 60, "Input"],
Cell[289115, 7328, 80, 1, 65, "Output"]
}, Closed]],
Cell[289210, 7332, 22, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[289257, 7336, 42, 1, 60, "Input"],
Cell[289302, 7339, 83, 1, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[289422, 7345, 53, 1, 60, "Input"],
Cell[289478, 7348, 89, 1, 50, "Output"]
}, Closed]],
Cell[289582, 7352, 68, 0, 32, "Text"],
Cell[289653, 7354, 396, 8, 119, "Definition"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[290098, 7368, 54, 0, 56, "Subsection"],

Cell[CellGroupData[{
Cell[290177, 7372, 44, 0, 46, "Subsubsection"],
Cell[290224, 7374, 1365, 24, 280, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[291626, 7403, 32, 0, 46, "Subsubsection"],
Cell[291661, 7405, 56793, 1325, 286, 18962, 852, "GraphicsData", \
"PostScript", "NumberedFigure",
  CellTags->"figura5"]
}, Closed]],

Cell[CellGroupData[{
Cell[348491, 8735, 52, 0, 46, "Subsubsection"],
Cell[348546, 8737, 859, 13, 168, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[349442, 8755, 96, 2, 35, "Subsubsection"],
Cell[349541, 8759, 770, 27, 32, "Text",
  CellTags->"osservazione3"],

Cell[CellGroupData[{
Cell[350336, 8790, 69, 1, 60, "Input"],
Cell[350408, 8793, 71, 1, 63, "Output"]
}, Closed]],
Cell[350494, 8797, 46, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[350565, 8801, 73, 1, 60, "Input"],
Cell[350641, 8804, 80, 1, 63, "Output"]
}, Closed]],
Cell[350736, 8808, 146, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[350907, 8817, 42, 1, 60, "Input"],
Cell[350952, 8820, 83, 1, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[351072, 8826, 52, 1, 60, "Input"],
Cell[351127, 8829, 89, 1, 50, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[351265, 8836, 52, 0, 46, "Subsubsection"],
Cell[351320, 8838, 935, 14, 185, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[352292, 8857, 98, 2, 35, "Subsubsection"],
Cell[352393, 8861, 249, 9, 32, "Text"],

Cell[CellGroupData[{
Cell[352667, 8874, 69, 1, 60, "Input"],
Cell[352739, 8877, 71, 1, 63, "Output"]
}, Closed]],
Cell[352825, 8881, 192, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[353042, 8891, 73, 1, 60, "Input"],
Cell[353118, 8894, 80, 1, 63, "Output"]
}, Closed]],
Cell[353213, 8898, 22, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[353260, 8902, 42, 1, 60, "Input"],
Cell[353305, 8905, 83, 1, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[353425, 8911, 52, 1, 60, "Input"],
Cell[353480, 8914, 89, 1, 50, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[353618, 8921, 52, 0, 46, "Subsubsection"],
Cell[353673, 8923, 1013, 15, 185, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[354723, 8943, 100, 2, 35, "Subsubsection"],
Cell[354826, 8947, 67, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[354918, 8951, 69, 1, 60, "Input"],
Cell[354990, 8954, 71, 1, 63, "Output"]
}, Closed]],
Cell[355076, 8958, 147, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[355248, 8968, 78, 1, 60, "Input"],
Cell[355329, 8971, 71, 1, 65, "Output"]
}, Closed]],
Cell[355415, 8975, 23, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[355463, 8979, 42, 1, 60, "Input"],
Cell[355508, 8982, 78, 1, 50, "Output"]
}, Closed]],
Cell[355601, 8986, 217, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[355843, 8996, 52, 1, 60, "Input"],
Cell[355898, 8999, 84, 1, 50, "Output"]
}, Closed]],
Cell[355997, 9003, 181, 4, 32, "Text"],
Cell[356181, 9009, 408, 9, 119, "Definition"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[356638, 9024, 36, 0, 56, "Subsection"],

Cell[CellGroupData[{
Cell[356699, 9028, 32, 0, 46, "Subsubsection"],
Cell[356734, 9030, 1327, 24, 280, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[358098, 9059, 32, 0, 46, "Subsubsection"],
Cell[358133, 9061, 55924, 1307, 286, 18588, 840, "GraphicsData", \
"PostScript", "NumberedFigure",
  CellTags->"figura6"]
}, Closed]],

Cell[CellGroupData[{
Cell[414094, 10373, 52, 0, 46, "Subsubsection"],
Cell[414149, 10375, 1095, 16, 195, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[415281, 10396, 50, 0, 35, "Subsubsection"],
Cell[415334, 10398, 1183, 42, 32, "Text",
  CellTags->"osservazione4"],

Cell[CellGroupData[{
Cell[416542, 10444, 66, 1, 60, "Input"],
Cell[416611, 10447, 68, 1, 63, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[416716, 10453, 73, 1, 60, "Input"],
Cell[416792, 10456, 77, 1, 63, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[416906, 10462, 69, 2, 60, "Input",
  CellTags->"senodispari"],
Cell[416978, 10466, 107, 2, 50, "Output",
  CellTags->"senodispari"]
}, Closed]],
Cell[417100, 10471, 572, 16, 52, "Text"],

Cell[CellGroupData[{
Cell[417697, 10491, 51, 1, 60, "Input"],
Cell[417751, 10494, 86, 1, 50, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[417886, 10501, 52, 0, 46, "Subsubsection"],
Cell[417941, 10503, 1171, 18, 205, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[419149, 10526, 52, 0, 35, "Subsubsection"],
Cell[419204, 10528, 180, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[419409, 10537, 66, 1, 60, "Input"],
Cell[419478, 10540, 68, 1, 63, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[419583, 10546, 68, 1, 60, "Input"],
Cell[419654, 10549, 68, 1, 63, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[419759, 10555, 68, 2, 60, "Input",
  CellTags->"cosenopari"],
Cell[419830, 10559, 101, 2, 50, "Output",
  CellTags->"cosenopari"]
}, Closed]],
Cell[419946, 10564, 512, 14, 52, "Text"],

Cell[CellGroupData[{
Cell[420483, 10582, 51, 1, 60, "Input"],
Cell[420537, 10585, 81, 1, 50, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[420667, 10592, 52, 0, 46, "Subsubsection"],
Cell[420722, 10594, 1238, 18, 205, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[421997, 10617, 54, 0, 35, "Subsubsection"],
Cell[422054, 10619, 187, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[422266, 10628, 66, 1, 60, "Input"],
Cell[422335, 10631, 68, 1, 63, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[422440, 10637, 73, 1, 60, "Input"],
Cell[422516, 10640, 77, 1, 65, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[422630, 10646, 68, 2, 60, "Input",
  CellTags->"tandispari"],
Cell[422701, 10650, 106, 2, 50, "Output",
  CellTags->"tandispari"]
}, Closed]],
Cell[422822, 10655, 623, 14, 76, "Text"],

Cell[CellGroupData[{
Cell[423470, 10673, 51, 1, 60, "Input"],
Cell[423524, 10676, 86, 1, 50, "Output"]
}, Closed]],
Cell[423625, 10680, 39, 0, 32, "Text"],
Cell[423667, 10682, 381, 8, 119, "Definition"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[424109, 10697, 64, 0, 43, "Section"],

Cell[CellGroupData[{
Cell[424198, 10701, 40, 0, 46, "Subsubsection"],
Cell[424241, 10703, 937, 23, 124, "Text"],
Cell[425181, 10728, 122, 2, 80, "Input"],
Cell[425306, 10732, 372, 11, 52, "Text"],
Cell[425681, 10745, 147, 2, 80, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[425865, 10752, 44, 0, 46, "Subsubsection"],
Cell[425912, 10754, 878, 15, 200, "Input",
  CellTags->"figura1"]
}, Closed]],

Cell[CellGroupData[{
Cell[426827, 10774, 32, 0, 46, "Subsubsection"],
Cell[426862, 10776, 58412, 1351, 257, 20936, 882, "GraphicsData", \
"PostScript", "NumberedFigure",
  CellTags->"figura7"],
Cell[485277, 12129, 546, 11, 72, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[485860, 12145, 44, 0, 46, "Subsubsection"],
Cell[485907, 12147, 1843, 32, 280, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[487787, 12184, 35, 0, 46, "Subsubsection"],
Cell[487825, 12186, 54027, 1145, 267, 13868, 644, "GraphicsData", \
"PostScript", "Graphics"],
Cell[541855, 13333, 559, 19, 52, "Text"],
Cell[542417, 13354, 156, 3, 80, "Input"],
Cell[542576, 13359, 774, 24, 52, "Text"],
Cell[543353, 13385, 94, 2, 35, "DisplayFormula",
  CellTags->"relazione1"]
}, Closed]],

Cell[CellGroupData[{
Cell[543484, 13392, 44, 0, 46, "Subsubsection"],
Cell[543531, 13394, 945, 17, 200, "Input",
  CellTags->"figura2"]
}, Closed]],

Cell[CellGroupData[{
Cell[544513, 13416, 32, 0, 46, "Subsubsection"],
Cell[544548, 13418, 64504, 1375, 286, 17395, 788, "GraphicsData", \
"PostScript", "NumberedFigure",
  CellTags->"figura8"]
}, Closed]],

Cell[CellGroupData[{
Cell[609089, 14798, 58, 0, 56, "Subsection"],

Cell[CellGroupData[{
Cell[609172, 14802, 52, 0, 46, "Subsubsection"],
Cell[609227, 14804, 1389, 21, 225, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[610653, 14830, 38, 0, 35, "Subsubsection"],
Cell[610694, 14832, 315, 14, 32, "Text"],
Cell[611012, 14848, 302, 5, 120, "Input"],
Cell[611317, 14855, 323, 12, 33, "Text"],

Cell[CellGroupData[{
Cell[611665, 14871, 198, 3, 81, "Input"],
Cell[611866, 14876, 474, 12, 70, "Output"]
}, Closed]],
Cell[612355, 14891, 170, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[612550, 14901, 57, 1, 60, "Input"],
Cell[612610, 14904, 202, 3, 50, "Output"]
}, Closed]],
Cell[612827, 14910, 73, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[612925, 14914, 44, 1, 60, "Input"],
Cell[612972, 14917, 303, 5, 71, "Output"]
}, Closed]],
Cell[613290, 14925, 267, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[613582, 14935, 53, 1, 60, "Input"],
Cell[613638, 14938, 157, 3, 50, "Output"]
}, Closed]],
Cell[613810, 14944, 118, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[613953, 14953, 38, 1, 60, "Input"],
Cell[613994, 14956, 154, 3, 50, "Output"]
}, Closed]],
Cell[614163, 14962, 156, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[614344, 14971, 62, 1, 60, "Input"],
Cell[614409, 14974, 131, 2, 50, "Output"]
}, Closed]],
Cell[614555, 14979, 102, 3, 32, "Text"],
Cell[614660, 14984, 199, 3, 56, "Definition"],
Cell[614862, 14989, 344, 6, 52, "Text"],

Cell[CellGroupData[{
Cell[615231, 14999, 52, 1, 60, "Input"],
Cell[615286, 15002, 137, 2, 50, "Output"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[615496, 15012, 53, 0, 43, "Section"],

Cell[CellGroupData[{
Cell[615574, 15016, 52, 0, 46, "Subsubsection"],
Cell[615629, 15018, 1460, 22, 225, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[617126, 15045, 56, 0, 35, "Subsection"],
Cell[617185, 15047, 705, 17, 72, "Text"],

Cell[CellGroupData[{
Cell[617915, 15068, 52, 1, 60, "Input"],
Cell[617970, 15071, 131, 2, 50, "Output"]
}, Closed]],
Cell[618116, 15076, 172, 7, 32, "Text"],

Cell[CellGroupData[{
Cell[618313, 15087, 66, 1, 60, "Input"],
Cell[618382, 15090, 150, 3, 50, "Output"]
}, Closed]],
Cell[618547, 15096, 636, 19, 52, "Text"],

Cell[CellGroupData[{
Cell[619208, 15119, 58, 1, 60, "Input"],
Cell[619269, 15122, 131, 2, 50, "Output"]
}, Closed]],
Cell[619415, 15127, 223, 8, 32, "Text"],
Cell[619641, 15137, 223, 4, 56, "Definition",
  CellTags->"cosSomma"],

Cell[CellGroupData[{
Cell[619889, 15145, 51, 1, 60, "Input"],
Cell[619943, 15148, 137, 2, 50, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[620129, 15156, 68, 0, 56, "Subsection"],

Cell[CellGroupData[{
Cell[620222, 15160, 52, 0, 46, "Subsubsection"],
Cell[620277, 15162, 1592, 24, 225, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[621906, 15191, 46, 0, 35, "Subsubsection"],
Cell[621955, 15193, 309, 9, 36, "Text",
  CellTags->"id1"],

Cell[CellGroupData[{
Cell[622289, 15206, 113, 2, 72, "Input"],
Cell[622405, 15210, 108, 2, 61, "Output"]
}, Closed]],
Cell[622528, 15215, 209, 6, 36, "Text"],

Cell[CellGroupData[{
Cell[622762, 15225, 74, 1, 72, "Input"],
Cell[622839, 15228, 90, 1, 50, "Output"]
}, Closed]],
Cell[622944, 15232, 189, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[623158, 15242, 44, 1, 60, "Input"],
Cell[623205, 15245, 131, 2, 50, "Output"]
}, Closed]],
Cell[623351, 15250, 189, 7, 32, "Text"],

Cell[CellGroupData[{
Cell[623565, 15261, 69, 1, 72, "Input"],
Cell[623637, 15264, 162, 3, 61, "Output"]
}, Closed]],
Cell[623814, 15270, 336, 9, 36, "Text"],

Cell[CellGroupData[{
Cell[624175, 15283, 62, 1, 60, "Input"],
Cell[624240, 15286, 131, 2, 50, "Output"]
}, Closed]],
Cell[624386, 15291, 56, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[624467, 15295, 52, 1, 60, "Input"],
Cell[624522, 15298, 137, 2, 50, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[624708, 15306, 52, 0, 46, "Subsubsection"],
Cell[624763, 15308, 1901, 30, 265, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[626701, 15343, 41, 0, 35, "Subsubsection"],
Cell[626745, 15345, 216, 7, 32, "Text"],

Cell[CellGroupData[{
Cell[626986, 15356, 84, 1, 60, "Input"],
Cell[627073, 15359, 150, 3, 50, "Output"]
}, Closed]],
Cell[627238, 15365, 563, 20, 32, "Text"],

Cell[CellGroupData[{
Cell[627826, 15389, 58, 1, 60, "Input"],
Cell[627887, 15392, 131, 2, 50, "Output"]
}, Closed]],
Cell[628033, 15397, 94, 2, 32, "Text"],
Cell[628130, 15401, 227, 4, 56, "Definition"],
Cell[628360, 15407, 208, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[628593, 15415, 51, 1, 60, "Input"],
Cell[628647, 15418, 137, 2, 50, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[628845, 15427, 72, 0, 56, "Subsection"],

Cell[CellGroupData[{
Cell[628942, 15431, 52, 0, 46, "Subsubsection"],
Cell[628997, 15433, 1857, 28, 265, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[630891, 15466, 45, 0, 35, "Subsubsection"],
Cell[630939, 15468, 272, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[631236, 15477, 121, 2, 78, "Input"],
Cell[631360, 15481, 122, 2, 67, "Output"]
}, Closed]],
Cell[631497, 15486, 140, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[631662, 15493, 58, 1, 60, "Input"],
Cell[631723, 15496, 195, 3, 67, "Output"]
}, Closed]],
Cell[631933, 15502, 340, 9, 36, "Text"],

Cell[CellGroupData[{
Cell[632298, 15515, 93, 1, 60, "Input"],
Cell[632394, 15518, 411, 10, 88, "Output"]
}, Closed]],
Cell[632820, 15531, 192, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[633037, 15539, 67, 1, 60, "Input"],
Cell[633107, 15542, 206, 3, 88, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[633350, 15550, 42, 1, 60, "Input"],
Cell[633395, 15553, 138, 2, 67, "Output"]
}, Closed]],
Cell[633548, 15558, 49, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[633622, 15562, 51, 1, 60, "Input"],
Cell[633676, 15565, 144, 2, 67, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[633869, 15573, 52, 0, 46, "Subsubsection"],
Cell[633924, 15575, 1990, 30, 296, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[635951, 15610, 50, 0, 35, "Subsubsection"],
Cell[636004, 15612, 224, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[636253, 15621, 83, 1, 60, "Input"],
Cell[636339, 15624, 148, 2, 67, "Output"]
}, Closed]],
Cell[636502, 15629, 331, 9, 32, "Text"],

Cell[CellGroupData[{
Cell[636858, 15642, 44, 1, 60, "Input"],
Cell[636905, 15645, 138, 2, 67, "Output"]
}, Closed]],
Cell[637058, 15650, 96, 2, 32, "Text"],
Cell[637157, 15654, 771, 19, 72, "Definition"],

Cell[CellGroupData[{
Cell[637953, 15677, 52, 1, 60, "Input"],
Cell[638008, 15680, 144, 2, 67, "Output"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[638225, 15690, 42, 0, 43, "Section"],

Cell[CellGroupData[{
Cell[638292, 15694, 52, 0, 46, "Subsubsection"],
Cell[638347, 15696, 2120, 32, 296, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[640504, 15733, 72, 0, 35, "Subsection"],
Cell[640579, 15735, 434, 11, 84, "Text"],

Cell[CellGroupData[{
Cell[641038, 15750, 51, 1, 60, "Input"],
Cell[641092, 15753, 131, 2, 50, "Output"]
}, Closed]],
Cell[641238, 15758, 145, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[641408, 15767, 62, 1, 60, "Input"],
Cell[641473, 15770, 91, 1, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[641601, 15776, 52, 1, 60, "Input"],
Cell[641656, 15779, 104, 2, 50, "Output"]
}, Closed]],
Cell[641775, 15784, 68, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[641868, 15788, 51, 1, 60, "Input"],
Cell[641922, 15791, 131, 2, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[642090, 15798, 74, 1, 60, "Input"],
Cell[642167, 15801, 102, 2, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[642306, 15808, 52, 1, 60, "Input"],
Cell[642361, 15811, 108, 2, 50, "Output"]
}, Closed]],
Cell[642484, 15816, 282, 6, 49, "Text"],

Cell[CellGroupData[{
Cell[642791, 15826, 86, 1, 60, "Input"],
Cell[642880, 15829, 83, 1, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[643000, 15835, 55, 1, 60, "Input"],
Cell[643058, 15838, 89, 1, 50, "Output"]
}, Closed]],
Cell[643162, 15842, 188, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[643375, 15851, 86, 1, 60, "Input"],
Cell[643464, 15854, 88, 1, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[643589, 15860, 55, 1, 60, "Input"],
Cell[643647, 15863, 103, 2, 50, "Output"]
}, Closed]],
Cell[643765, 15868, 62, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[643852, 15872, 51, 1, 60, "Input"],
Cell[643906, 15875, 138, 2, 67, "Output"]
}, Closed]],
Cell[644059, 15880, 166, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[644250, 15890, 62, 1, 60, "Input"],
Cell[644315, 15893, 117, 3, 67, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[644469, 15901, 52, 1, 60, "Input"],
Cell[644524, 15904, 123, 3, 67, "Output"]
}, Closed]],
Cell[644662, 15910, 57, 0, 32, "Text"],
Cell[644722, 15912, 654, 14, 113, "Definition"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[645425, 15932, 39, 0, 43, "Section"],

Cell[CellGroupData[{
Cell[645489, 15936, 52, 0, 46, "Subsubsection"],
Cell[645544, 15938, 2579, 39, 380, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[648160, 15982, 69, 0, 35, "Subsection"],
Cell[648232, 15984, 333, 7, 52, "Text"],

Cell[CellGroupData[{
Cell[648590, 15995, 55, 1, 60, "Input"],
Cell[648648, 15998, 83, 1, 50, "Output"]
}, Closed]],
Cell[648746, 16002, 234, 8, 32, "Text"],

Cell[CellGroupData[{
Cell[649005, 16014, 38, 1, 60, "Input"],
Cell[649046, 16017, 93, 1, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[649176, 16023, 50, 1, 60, "Input"],
Cell[649229, 16026, 92, 1, 64, "Output"]
}, Closed]],
Cell[649336, 16030, 59, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[649420, 16034, 42, 1, 60, "Input"],
Cell[649465, 16037, 93, 1, 77, "Output"]
}, Closed]],
Cell[649573, 16041, 119, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[649717, 16048, 49, 1, 60, "Input"],
Cell[649769, 16051, 93, 1, 77, "Output"]
}, Closed]],
Cell[649877, 16055, 209, 8, 36, "Text"],

Cell[CellGroupData[{
Cell[650111, 16067, 65, 1, 60, "Input"],
Cell[650179, 16070, 93, 1, 77, "Output"]
}, Closed]],
Cell[650287, 16074, 395, 8, 56, "Text"],

Cell[CellGroupData[{
Cell[650707, 16086, 51, 1, 60, "Input"],
Cell[650761, 16089, 110, 3, 77, "Output"]
}, Closed]],
Cell[650886, 16095, 46, 0, 32, "Text"],
Cell[650935, 16097, 165, 3, 80, "Definition"],
Cell[651103, 16102, 43, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[651171, 16106, 55, 1, 60, "Input"],
Cell[651229, 16109, 88, 1, 50, "Output"]
}, Closed]],
Cell[651332, 16113, 108, 4, 32, "Text"],

Cell[CellGroupData[{
Cell[651465, 16121, 57, 1, 60, "Input"],
Cell[651525, 16124, 92, 1, 64, "Output"]
}, Closed]],
Cell[651632, 16128, 72, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[651729, 16132, 42, 1, 60, "Input"],
Cell[651774, 16135, 93, 1, 77, "Output"]
}, Closed]],
Cell[651882, 16139, 21, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[651928, 16143, 49, 1, 60, "Input"],
Cell[651980, 16146, 93, 1, 77, "Output"]
}, Closed]],
Cell[652088, 16150, 206, 5, 36, "Text"],

Cell[CellGroupData[{
Cell[652319, 16159, 65, 1, 60, "Input"],
Cell[652387, 16162, 93, 1, 77, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[652517, 16168, 51, 1, 60, "Input"],
Cell[652571, 16171, 110, 3, 77, "Output"]
}, Closed]],
Cell[652696, 16177, 400, 8, 52, "Text"],

Cell[CellGroupData[{
Cell[653121, 16189, 70, 1, 60, "Input"],
Cell[653194, 16192, 138, 2, 82, "Output"]
}, Closed]],
Cell[653347, 16197, 37, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[653409, 16201, 73, 1, 60, "Input"],
Cell[653485, 16204, 124, 3, 77, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[653646, 16212, 51, 1, 60, "Input"],
Cell[653700, 16215, 130, 3, 77, "Output"]
}, Closed]],
Cell[653845, 16221, 69, 0, 32, "Text"],
Cell[653917, 16223, 445, 13, 196, "Definition"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[654411, 16242, 49, 0, 43, "Section"],

Cell[CellGroupData[{
Cell[654485, 16246, 52, 0, 46, "Subsubsection"],
Cell[654540, 16248, 2873, 44, 422, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[657450, 16297, 79, 0, 35, "Subsection"],
Cell[657532, 16299, 487, 9, 104, "Text"],

Cell[CellGroupData[{
Cell[658044, 16312, 52, 1, 60, "Input"],
Cell[658099, 16315, 91, 1, 50, "Output"]
}, Closed]],
Cell[658205, 16319, 214, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[658444, 16329, 113, 2, 60, "Input"],
Cell[658560, 16333, 147, 3, 67, "Output"]
}, Closed]],
Cell[658722, 16339, 279, 7, 36, "Text"],

Cell[CellGroupData[{
Cell[659026, 16350, 76, 1, 60, "Input"],
Cell[659105, 16353, 288, 6, 91, "Output"]
}, Closed]],
Cell[659408, 16362, 184, 6, 38, "Text"],

Cell[CellGroupData[{
Cell[659617, 16372, 75, 1, 60, "Input"],
Cell[659695, 16375, 117, 3, 67, "Output"]
}, Closed]],
Cell[659827, 16381, 210, 5, 36, "Text"],

Cell[CellGroupData[{
Cell[660062, 16390, 65, 1, 60, "Input"],
Cell[660130, 16393, 111, 2, 84, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[660278, 16400, 51, 1, 60, "Input"],
Cell[660332, 16403, 117, 2, 84, "Output"]
}, Closed]],
Cell[660464, 16408, 132, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[660621, 16415, 52, 1, 60, "Input"],
Cell[660676, 16418, 102, 2, 50, "Output"]
}, Closed]],
Cell[660793, 16423, 20, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[660838, 16427, 113, 2, 60, "Input"],
Cell[660954, 16431, 151, 3, 70, "Output"]
}, Closed]],
Cell[661120, 16437, 282, 7, 36, "Text"],

Cell[CellGroupData[{
Cell[661427, 16448, 91, 1, 60, "Input"],
Cell[661521, 16451, 292, 6, 95, "Output"]
}, Closed]],
Cell[661828, 16460, 111, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[661964, 16467, 75, 1, 60, "Input"],
Cell[662042, 16470, 121, 3, 70, "Output"]
}, Closed]],
Cell[662178, 16476, 155, 5, 36, "Text"],

Cell[CellGroupData[{
Cell[662358, 16485, 65, 1, 60, "Input"],
Cell[662426, 16488, 115, 2, 86, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[662578, 16495, 51, 1, 60, "Input"],
Cell[662632, 16498, 121, 2, 86, "Output"]
}, Closed]],
Cell[662768, 16503, 252, 6, 36, "Text"],

Cell[CellGroupData[{
Cell[663045, 16513, 52, 1, 60, "Input"],
Cell[663100, 16516, 117, 3, 67, "Output"]
}, Closed]],
Cell[663232, 16522, 29, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[663286, 16526, 65, 1, 60, "Input"],
Cell[663354, 16529, 111, 2, 84, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[663502, 16536, 51, 1, 60, "Input"],
Cell[663556, 16539, 117, 2, 84, "Output"]
}, Closed]],
Cell[663688, 16544, 69, 0, 32, "Text"],
Cell[663760, 16546, 754, 22, 187, "Definition"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[664563, 16574, 51, 0, 43, "Section"],

Cell[CellGroupData[{
Cell[664639, 16578, 52, 0, 46, "Subsubsection"],
Cell[664694, 16580, 3192, 50, 450, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[667923, 16635, 39, 0, 35, "Subsection"],
Cell[667965, 16637, 238, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[668228, 16645, 217, 4, 80, "Input",
  CellTags->"riassunto"],
Cell[668448, 16651, 846, 17, 102, "Output",
  CellTags->"riassunto"]
}, Closed]],
Cell[669309, 16671, 164, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[669498, 16681, 76, 1, 60, "Input"],
Cell[669577, 16684, 130, 2, 50, "Output"]
}, Closed]],
Cell[669722, 16689, 162, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[669909, 16696, 49, 1, 60, "Input"],
Cell[669961, 16699, 152, 3, 64, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[670150, 16707, 57, 1, 60, "Input"],
Cell[670210, 16710, 158, 3, 64, "Output"]
}, Closed]],
Cell[670383, 16716, 286, 7, 52, "Text"],

Cell[CellGroupData[{
Cell[670694, 16727, 91, 1, 60, "Input"],
Cell[670788, 16730, 137, 2, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[670962, 16737, 36, 1, 60, "Input"],
Cell[671001, 16740, 157, 3, 64, "Output"]
}, Closed]],
Cell[671173, 16746, 387, 13, 32, "Text"],

Cell[CellGroupData[{
Cell[671585, 16763, 76, 1, 60, "Input"],
Cell[671664, 16766, 130, 2, 50, "Output"]
}, Closed]],
Cell[671809, 16771, 133, 4, 32, "Text"],

Cell[CellGroupData[{
Cell[671967, 16779, 47, 1, 60, "Input"],
Cell[672017, 16782, 152, 3, 64, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[672206, 16790, 57, 1, 60, "Input"],
Cell[672266, 16793, 158, 3, 64, "Output"]
}, Closed]],
Cell[672439, 16799, 237, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[672701, 16809, 80, 1, 60, "Input"],
Cell[672784, 16812, 144, 3, 50, "Output"]
}, Closed]],
Cell[672943, 16818, 236, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[673204, 16828, 52, 1, 60, "Input"],
Cell[673259, 16831, 152, 3, 64, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[673448, 16839, 57, 1, 60, "Input"],
Cell[673508, 16842, 158, 3, 64, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[673715, 16851, 45, 0, 56, "Subsection"],
Cell[673763, 16853, 362, 10, 52, "Text"],
Cell[674128, 16865, 280, 8, 51, "DisplayFormula"],
Cell[674411, 16875, 288, 13, 32, "Text"],

Cell[CellGroupData[{
Cell[674724, 16892, 197, 4, 60, "Input"],
Cell[674924, 16898, 97, 2, 62, "Output"]
}, Closed]],
Cell[675036, 16903, 112, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[675173, 16910, 76, 1, 60, "Input"],
Cell[675252, 16913, 130, 2, 50, "Output"]
}, Closed]],
Cell[675397, 16918, 67, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[675489, 16922, 41, 1, 60, "Input"],
Cell[675533, 16925, 176, 3, 64, "Output"]
}, Closed]],
Cell[675724, 16931, 30, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[675779, 16935, 46, 1, 60, "Input"],
Cell[675828, 16938, 105, 2, 62, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[675970, 16945, 65, 1, 60, "Input"],
Cell[676038, 16948, 113, 2, 62, "Output"]
}, Closed]],
Cell[676166, 16953, 440, 9, 52, "Text"],

Cell[CellGroupData[{
Cell[676631, 16966, 80, 1, 60, "Input"],
Cell[676714, 16969, 135, 2, 50, "Output"]
}, Closed]],
Cell[676864, 16974, 43, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[676932, 16978, 45, 1, 60, "Input"],
Cell[676980, 16981, 137, 2, 50, "Output"]
}, Closed]],
Cell[677132, 16986, 67, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[677224, 16990, 53, 1, 60, "Input"],
Cell[677280, 16993, 105, 2, 62, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[677422, 17000, 43, 1, 60, "Input"],
Cell[677468, 17003, 105, 2, 62, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[677610, 17010, 66, 1, 60, "Input"],
Cell[677679, 17013, 113, 2, 62, "Output"]
}, Closed]],
Cell[677807, 17018, 299, 9, 32, "Text"],

Cell[CellGroupData[{
Cell[678131, 17031, 76, 1, 60, "Input"],
Cell[678210, 17034, 130, 2, 50, "Output"]
}, Closed]],
Cell[678355, 17039, 51, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[678431, 17043, 53, 1, 60, "Input"],
Cell[678487, 17046, 105, 2, 62, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[678629, 17053, 65, 1, 60, "Input"],
Cell[678697, 17056, 113, 2, 62, "Output"]
}, Closed]],
Cell[678825, 17061, 152, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[679002, 17070, 80, 1, 60, "Input"],
Cell[679085, 17073, 144, 3, 50, "Output"]
}, Closed]],
Cell[679244, 17079, 161, 7, 32, "Text"],

Cell[CellGroupData[{
Cell[679430, 17090, 53, 1, 60, "Input"],
Cell[679486, 17093, 105, 2, 62, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[679628, 17100, 54, 1, 60, "Input"],
Cell[679685, 17103, 110, 2, 62, "Output"]
}, Closed]],
Cell[679810, 17108, 143, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[679978, 17117, 48, 1, 60, "Input"],
Cell[680029, 17120, 114, 3, 62, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[680180, 17128, 66, 1, 60, "Input"],
Cell[680249, 17131, 122, 3, 62, "Output"]
}, Closed]],
Cell[680386, 17137, 169, 7, 33, "Text"],
Cell[680558, 17146, 522, 9, 145, "Definition"],
Cell[681083, 17157, 161, 5, 33, "Text"],
Cell[681247, 17164, 521, 12, 170, "Definition"],
Cell[681771, 17178, 72, 0, 32, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[681892, 17184, 68, 0, 43, "Section"],

Cell[CellGroupData[{
Cell[681985, 17188, 52, 0, 46, "Subsubsection"],
Cell[682040, 17190, 1076, 18, 270, "Input"],
Cell[683119, 17210, 5444, 88, 859, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[688600, 17303, 29, 0, 35, "Subsection"],
Cell[688632, 17305, 178, 4, 32, "Text"],

Cell[CellGroupData[{
Cell[688835, 17313, 75, 0, 46, "Subsubsection"],
Cell[688913, 17315, 1367, 26, 286, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[690317, 17346, 73, 0, 46, "Subsubsection"],
Cell[690393, 17348, 5082, 91, 1136, "Output"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

